/**************************************************************************//**
 * @file
 * @brief EFR32FG25 RAC register and bit field definitions
 ******************************************************************************
 * # License
 * <b>Copyright 2022 Silicon Laboratories, Inc. www.silabs.com</b>
 ******************************************************************************
 *
 * SPDX-License-Identifier: Zlib
 *
 * The licensor of this software is Silicon Laboratories Inc.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 *
 *****************************************************************************/
#ifndef EFR32FG25_RAC_H
#define EFR32FG25_RAC_H
#define RAC_HAS_SET_CLEAR

/**************************************************************************//**
* @addtogroup Parts
* @{
******************************************************************************/
/**************************************************************************//**
 * @defgroup EFR32FG25_RAC RAC
 * @{
 * @brief EFR32FG25 RAC Register Declaration.
 *****************************************************************************/

/** RAC Register Declaration. */
typedef struct {
  __IM uint32_t  IPVERSION;                     /**< IP Version                                         */
  __IOM uint32_t EN;                            /**< Enable peripheral clock to this module             */
  __IOM uint32_t RXENSRCEN;                     /**< RXEN Source Enable                                 */
  __IM uint32_t  STATUS;                        /**< Radio State Machine Status                         */
  __IOM uint32_t CMD;                           /**< Radio Commands                                     */
  __IOM uint32_t CTRL;                          /**< Radio Control Register                             */
  __IOM uint32_t FORCESTATE;                    /**< Force state transition                             */
  __IOM uint32_t IF;                            /**< Radio Controller Interrupt Flags                   */
  __IOM uint32_t IEN;                           /**< Interrupt Enable Register                          */
  __IOM uint32_t TESTCTRL;                      /**< Test Control Register                              */
  __IOM uint32_t SEQIF;                         /**< SEQ Interrupt Flags                                */
  __IOM uint32_t SEQIEN;                        /**< SEQ Interrupt Enable Register                      */
  __IM uint32_t  STATUS1;                       /**< Radio State Machine Status                         */
  __IOM uint32_t FEMCTRL;                       /**< FEM Control                                        */
  __IOM uint32_t FEMDATA;                       /**< FEM Data                                           */
  uint32_t       RESERVED0[5U];                 /**< Reserved for future use                            */
  __IM uint32_t  STIMER;                        /**< Sequencer Timer Value                              */
  __IOM uint32_t STIMERCOMP;                    /**< Sequencer Timer Compare Value                      */
  __IOM uint32_t SEQCTRL;                       /**< Sequencer Control Register                         */
  __IOM uint32_t PRESC;                         /**< Sequencer prescaler Register                       */
  __IOM uint32_t SR0;                           /**< Storage Register 0                                 */
  __IOM uint32_t SR1;                           /**< Storage Register 1                                 */
  __IOM uint32_t SR2;                           /**< Storage Register 2                                 */
  __IOM uint32_t SR3;                           /**< Storage Register 3                                 */
  __IOM uint32_t STCTRL;                        /**< Sys tick timer Control Register                    */
  __IOM uint32_t FRCTXWORD;                     /**< FRC wordbuffer write                               */
  __IM uint32_t  FRCRXWORD;                     /**< FRC wordbuffer read                                */
  __IOM uint32_t EM1PCSR;                       /**< Radio EM1P Control and Status Register             */
  uint32_t       RESERVED1[6U];                 /**< Reserved for future use                            */
  __IOM uint32_t SYNTHENCTRL;                   /**< Synthesizer Enable Control Register                */
  __IOM uint32_t SYNTHREGCTRL;                  /**< Synthesizer Regulator Enable Control               */
  __IOM uint32_t VCOCTRL;                       /**< VCO Control Register                               */
  uint32_t       RESERVED2[2U];                 /**< Reserved for future use                            */
  uint32_t       RESERVED3[1U];                 /**< Reserved for future use                            */
  __IM uint32_t  STATUS2;                       /**< Radio State Machine Status 2                       */
  __IOM uint32_t IFPGACTRL;                     /**< IF PGA Control Register                            */
  __IOM uint32_t PAENCTRL;                      /**< PA Enable Control Register                         */
  __IOM uint32_t APC;                           /**< Automatic Power Control Register                   */
  __IOM uint32_t ANTDIV;                        /**< ANTDIV                                             */
  __IOM uint32_t AUXADCTRIM;                    /**< AUXADCTRIM                                         */
  __IOM uint32_t AUXADCEN;                      /**< AUXADCEN                                           */
  __IOM uint32_t AUXADCCTRL0;                   /**< Auxiliary ADC register control                     */
  __IOM uint32_t AUXADCCTRL1;                   /**< AUXADCCTRL1                                        */
  __IM uint32_t  AUXADCOUT;                     /**< Auxiliary ADC digital output                       */
  __IOM uint32_t CLKMULTEN0;                    /**< CLKMULTEN0                                         */
  __IOM uint32_t CLKMULTEN1;                    /**< CLKMULTEN1                                         */
  __IOM uint32_t CLKMULTCTRL;                   /**< CLKMULTCTRL                                        */
  __IM uint32_t  CLKMULTSTATUS;                 /**< CLKMULTSTATUS                                      */
  uint32_t       RESERVED4[1U];                 /**< Reserved for future use                            */
  __IOM uint32_t IFADCTRIM0;                    /**< IFADCTRIM0                                         */
  __IOM uint32_t IFADCTRIM1;                    /**< IFADCTRIM1                                         */
  __IOM uint32_t IFADCCAL;                      /**< IFADCCAL                                           */
  __IM uint32_t  IFADCSTATUS;                   /**< IFADCSTATUS                                        */
  uint32_t       RESERVED5[1U];                 /**< Reserved for future use                            */
  __IOM uint32_t LNAMIXTRIM0;                   /**< LNAMIXTRIM0                                        */
  __IOM uint32_t LNAMIXTRIM1;                   /**< LNAMIXTRIM1                                        */
  __IOM uint32_t LNAMIXTRIM2;                   /**< LNAMIXTRIM2                                        */
  __IOM uint32_t LNAMIXTRIM3;                   /**< LNAMIXTRIM3                                        */
  __IOM uint32_t LNAMIXTRIM4;                   /**< LNAMIXTRIM4                                        */
  __IOM uint32_t LNAMIXCAL;                     /**< LNAMIXCAL                                          */
  __IOM uint32_t LNAMIXEN;                      /**< LNAMIXEN                                           */
  __IOM uint32_t PRECTRL;                       /**< PRECTRL                                            */
  uint32_t       RESERVED6[1U];                 /**< Reserved for future use                            */
  __IOM uint32_t PATRIM1;                       /**< PATRIM1                                            */
  __IOM uint32_t PATRIM2;                       /**< PATRIM2                                            */
  __IOM uint32_t PATRIM3;                       /**< PATRIM3                                            */
  __IOM uint32_t PATRIM4;                       /**< PATRIM4                                            */
  __IOM uint32_t PATRIM5;                       /**< PATRIM5                                            */
  __IOM uint32_t PADEBUG0;                      /**< PADEBUG0                                           */
  __IOM uint32_t TXPOWER;                       /**< TXPOWER                                            */
  __IOM uint32_t TXRAMP;                        /**< TXRAMP                                             */
  uint32_t       RESERVED7[1U];                 /**< Reserved for future use                            */
  __IOM uint32_t PGATRIM;                       /**< PGATRIM                                            */
  __IOM uint32_t PGACAL;                        /**< PGACAL                                             */
  __IOM uint32_t PGACTRL;                       /**< PGACTRL                                            */
  __IOM uint32_t RFBIASCAL;                     /**< RFBIASCAL                                          */
  __IOM uint32_t RFBIASCTRL;                    /**< RFBIASCTRL                                         */
  __IOM uint32_t RADIOEN;                       /**< RADIOEN                                            */
  __IOM uint32_t RFPATHEN0;                     /**< RFPATHEN0                                          */
  __IOM uint32_t RFPATHEN1;                     /**< RFPATHEN1                                          */
  __IOM uint32_t RX;                            /**< RX                                                 */
  __IOM uint32_t TX;                            /**< TX                                                 */
  uint32_t       RESERVED8[1U];                 /**< Reserved for future use                            */
  __IOM uint32_t SYTRIM0;                       /**< SYTRIM0                                            */
  __IOM uint32_t SYTRIM1;                       /**< SYTRIM1                                            */
  __IOM uint32_t SYCAL;                         /**< SYCAL                                              */
  __IOM uint32_t SYEN;                          /**< SYEN                                               */
  __IOM uint32_t SYLOEN;                        /**< SYLOEN                                             */
  __IOM uint32_t SYMMDCTRL;                     /**< SYMMDCTRL                                          */
  __IOM uint32_t SYDIVCTRL;                     /**< SYDIVCTRL                                          */
  __IOM uint32_t DIGCLKRETIMECTRL;              /**< DIGCLKRETIMECTRL                                   */
  __IM uint32_t  DIGCLKRETIMESTATUS;            /**< DIGCLKRETIMESTATUS                                 */
  __IOM uint32_t XORETIMECTRL;                  /**< XORETIMECTRL                                       */
  __IM uint32_t  XORETIMESTATUS;                /**< XORETIMESTATUS                                     */
  __IOM uint32_t AGCOVERWRITE0;                 /**< OVERWRITE AGC                                      */
  __IOM uint32_t AGCOVERWRITE1;                 /**< OVERWRITE AGC                                      */
  uint32_t       RESERVED9[5U];                 /**< Reserved for future use                            */
  __IOM uint32_t TXOGNDPKD;                     /**< TXOGNDPKD                                          */
  __IM uint32_t  TXOGNDPKDSTATUS;               /**< TXOGNDPKDSTATUS                                    */
  uint32_t       RESERVED10[4U];                /**< Reserved for future use                            */
  __IOM uint32_t GPPLLCLKRETIMECTRL;            /**< GPPLLCLKRETIMECTRL                                 */
  __IM uint32_t  GPPLLCLKRETIMESTATUS;          /**< GPPLLCLKRETIMESTATUS                               */
  uint32_t       RESERVED11[2U];                /**< Reserved for future use                            */
  __IOM uint32_t PATRIM6;                       /**< PATRIM6                                            */
  __IOM uint32_t PATRIM7;                       /**< PATRIM7                                            */
  __IOM uint32_t PATRIM8;                       /**< PATRIM8                                            */
  __IOM uint32_t PATRIM9;                       /**< PATRIM9                                            */
  __IOM uint32_t PATRIM10;                      /**< PATRIM10                                           */
  uint32_t       RESERVED12[1U];                /**< Reserved for future use                            */
  __IOM uint32_t TXRFPKD;                       /**< TXRFPKD                                            */
  uint32_t       RESERVED13[1U];                /**< Reserved for future use                            */
  __IM uint32_t  TXSTATUS;                      /**< TXSTATUS                                           */
  __IOM uint32_t TXOFDM;                        /**< TXOFDM                                             */
  uint32_t       RESERVED14[1U];                /**< Reserved for future use                            */
  __IOM uint32_t TXMIX;                         /**< TXMIX                                              */
  __IOM uint32_t TXITC;                         /**< TXITC                                              */
  __IOM uint32_t TXCALITC;                      /**< TXCALITC                                           */
  uint32_t       RESERVED15[57U];               /**< Reserved for future use                            */
  __IOM uint32_t TXPKDCTRL;                     /**< Control Register                                   */
  __IOM uint32_t TXPKDCMD;                      /**< CMD Register                                       */
  __IM uint32_t  TXPKDSTATUS;                   /**< Status Register                                    */
  uint32_t       RESERVED16[49U];               /**< Reserved for future use                            */
  __IOM uint32_t RADIOCLKCTRL;                  /**< New Register                                       */
  uint32_t       RESERVED17[3U];                /**< Reserved for future use                            */
  __IOM uint32_t SCRATCH0;                      /**< SCRATCH0                                           */
  __IOM uint32_t SCRATCH1;                      /**< SCRATCH1                                           */
  __IOM uint32_t SCRATCH2;                      /**< SCRATCH2                                           */
  __IOM uint32_t SCRATCH3;                      /**< SCRATCH3                                           */
  __IOM uint32_t SCRATCH4;                      /**< SCRATCH4                                           */
  __IOM uint32_t SCRATCH5;                      /**< SCRATCH5                                           */
  __IOM uint32_t SCRATCH6;                      /**< SCRATCH6                                           */
  __IOM uint32_t SCRATCH7;                      /**< SCRATCH7                                           */
  __IOM uint32_t SOFTMCTRL;                     /**< Soft Modem Control                                 */
  __IOM uint32_t SFMIF;                         /**< Soft Modem Interrupt Flags                         */
  __IOM uint32_t SFMIEN;                        /**< Soft Modem Interrupt Enables                       */
  uint32_t       RESERVED18[247U];              /**< Reserved for future use                            */
  __IOM uint32_t THMSW;                         /**< Thermister control                                 */
  uint32_t       RESERVED19[1U];                /**< Reserved for future use                            */
  uint32_t       RESERVED20[2U];                /**< Reserved for future use                            */
  uint32_t       RESERVED21[1U];                /**< Reserved for future use                            */
  uint32_t       RESERVED22[513U];              /**< Reserved for future use                            */
  __IM uint32_t  IPVERSION_SET;                 /**< IP Version                                         */
  __IOM uint32_t EN_SET;                        /**< Enable peripheral clock to this module             */
  __IOM uint32_t RXENSRCEN_SET;                 /**< RXEN Source Enable                                 */
  __IM uint32_t  STATUS_SET;                    /**< Radio State Machine Status                         */
  __IOM uint32_t CMD_SET;                       /**< Radio Commands                                     */
  __IOM uint32_t CTRL_SET;                      /**< Radio Control Register                             */
  __IOM uint32_t FORCESTATE_SET;                /**< Force state transition                             */
  __IOM uint32_t IF_SET;                        /**< Radio Controller Interrupt Flags                   */
  __IOM uint32_t IEN_SET;                       /**< Interrupt Enable Register                          */
  __IOM uint32_t TESTCTRL_SET;                  /**< Test Control Register                              */
  __IOM uint32_t SEQIF_SET;                     /**< SEQ Interrupt Flags                                */
  __IOM uint32_t SEQIEN_SET;                    /**< SEQ Interrupt Enable Register                      */
  __IM uint32_t  STATUS1_SET;                   /**< Radio State Machine Status                         */
  __IOM uint32_t FEMCTRL_SET;                   /**< FEM Control                                        */
  __IOM uint32_t FEMDATA_SET;                   /**< FEM Data                                           */
  uint32_t       RESERVED23[5U];                /**< Reserved for future use                            */
  __IM uint32_t  STIMER_SET;                    /**< Sequencer Timer Value                              */
  __IOM uint32_t STIMERCOMP_SET;                /**< Sequencer Timer Compare Value                      */
  __IOM uint32_t SEQCTRL_SET;                   /**< Sequencer Control Register                         */
  __IOM uint32_t PRESC_SET;                     /**< Sequencer prescaler Register                       */
  __IOM uint32_t SR0_SET;                       /**< Storage Register 0                                 */
  __IOM uint32_t SR1_SET;                       /**< Storage Register 1                                 */
  __IOM uint32_t SR2_SET;                       /**< Storage Register 2                                 */
  __IOM uint32_t SR3_SET;                       /**< Storage Register 3                                 */
  __IOM uint32_t STCTRL_SET;                    /**< Sys tick timer Control Register                    */
  __IOM uint32_t FRCTXWORD_SET;                 /**< FRC wordbuffer write                               */
  __IM uint32_t  FRCRXWORD_SET;                 /**< FRC wordbuffer read                                */
  __IOM uint32_t EM1PCSR_SET;                   /**< Radio EM1P Control and Status Register             */
  uint32_t       RESERVED24[6U];                /**< Reserved for future use                            */
  __IOM uint32_t SYNTHENCTRL_SET;               /**< Synthesizer Enable Control Register                */
  __IOM uint32_t SYNTHREGCTRL_SET;              /**< Synthesizer Regulator Enable Control               */
  __IOM uint32_t VCOCTRL_SET;                   /**< VCO Control Register                               */
  uint32_t       RESERVED25[2U];                /**< Reserved for future use                            */
  uint32_t       RESERVED26[1U];                /**< Reserved for future use                            */
  __IM uint32_t  STATUS2_SET;                   /**< Radio State Machine Status 2                       */
  __IOM uint32_t IFPGACTRL_SET;                 /**< IF PGA Control Register                            */
  __IOM uint32_t PAENCTRL_SET;                  /**< PA Enable Control Register                         */
  __IOM uint32_t APC_SET;                       /**< Automatic Power Control Register                   */
  __IOM uint32_t ANTDIV_SET;                    /**< ANTDIV                                             */
  __IOM uint32_t AUXADCTRIM_SET;                /**< AUXADCTRIM                                         */
  __IOM uint32_t AUXADCEN_SET;                  /**< AUXADCEN                                           */
  __IOM uint32_t AUXADCCTRL0_SET;               /**< Auxiliary ADC register control                     */
  __IOM uint32_t AUXADCCTRL1_SET;               /**< AUXADCCTRL1                                        */
  __IM uint32_t  AUXADCOUT_SET;                 /**< Auxiliary ADC digital output                       */
  __IOM uint32_t CLKMULTEN0_SET;                /**< CLKMULTEN0                                         */
  __IOM uint32_t CLKMULTEN1_SET;                /**< CLKMULTEN1                                         */
  __IOM uint32_t CLKMULTCTRL_SET;               /**< CLKMULTCTRL                                        */
  __IM uint32_t  CLKMULTSTATUS_SET;             /**< CLKMULTSTATUS                                      */
  uint32_t       RESERVED27[1U];                /**< Reserved for future use                            */
  __IOM uint32_t IFADCTRIM0_SET;                /**< IFADCTRIM0                                         */
  __IOM uint32_t IFADCTRIM1_SET;                /**< IFADCTRIM1                                         */
  __IOM uint32_t IFADCCAL_SET;                  /**< IFADCCAL                                           */
  __IM uint32_t  IFADCSTATUS_SET;               /**< IFADCSTATUS                                        */
  uint32_t       RESERVED28[1U];                /**< Reserved for future use                            */
  __IOM uint32_t LNAMIXTRIM0_SET;               /**< LNAMIXTRIM0                                        */
  __IOM uint32_t LNAMIXTRIM1_SET;               /**< LNAMIXTRIM1                                        */
  __IOM uint32_t LNAMIXTRIM2_SET;               /**< LNAMIXTRIM2                                        */
  __IOM uint32_t LNAMIXTRIM3_SET;               /**< LNAMIXTRIM3                                        */
  __IOM uint32_t LNAMIXTRIM4_SET;               /**< LNAMIXTRIM4                                        */
  __IOM uint32_t LNAMIXCAL_SET;                 /**< LNAMIXCAL                                          */
  __IOM uint32_t LNAMIXEN_SET;                  /**< LNAMIXEN                                           */
  __IOM uint32_t PRECTRL_SET;                   /**< PRECTRL                                            */
  uint32_t       RESERVED29[1U];                /**< Reserved for future use                            */
  __IOM uint32_t PATRIM1_SET;                   /**< PATRIM1                                            */
  __IOM uint32_t PATRIM2_SET;                   /**< PATRIM2                                            */
  __IOM uint32_t PATRIM3_SET;                   /**< PATRIM3                                            */
  __IOM uint32_t PATRIM4_SET;                   /**< PATRIM4                                            */
  __IOM uint32_t PATRIM5_SET;                   /**< PATRIM5                                            */
  __IOM uint32_t PADEBUG0_SET;                  /**< PADEBUG0                                           */
  __IOM uint32_t TXPOWER_SET;                   /**< TXPOWER                                            */
  __IOM uint32_t TXRAMP_SET;                    /**< TXRAMP                                             */
  uint32_t       RESERVED30[1U];                /**< Reserved for future use                            */
  __IOM uint32_t PGATRIM_SET;                   /**< PGATRIM                                            */
  __IOM uint32_t PGACAL_SET;                    /**< PGACAL                                             */
  __IOM uint32_t PGACTRL_SET;                   /**< PGACTRL                                            */
  __IOM uint32_t RFBIASCAL_SET;                 /**< RFBIASCAL                                          */
  __IOM uint32_t RFBIASCTRL_SET;                /**< RFBIASCTRL                                         */
  __IOM uint32_t RADIOEN_SET;                   /**< RADIOEN                                            */
  __IOM uint32_t RFPATHEN0_SET;                 /**< RFPATHEN0                                          */
  __IOM uint32_t RFPATHEN1_SET;                 /**< RFPATHEN1                                          */
  __IOM uint32_t RX_SET;                        /**< RX                                                 */
  __IOM uint32_t TX_SET;                        /**< TX                                                 */
  uint32_t       RESERVED31[1U];                /**< Reserved for future use                            */
  __IOM uint32_t SYTRIM0_SET;                   /**< SYTRIM0                                            */
  __IOM uint32_t SYTRIM1_SET;                   /**< SYTRIM1                                            */
  __IOM uint32_t SYCAL_SET;                     /**< SYCAL                                              */
  __IOM uint32_t SYEN_SET;                      /**< SYEN                                               */
  __IOM uint32_t SYLOEN_SET;                    /**< SYLOEN                                             */
  __IOM uint32_t SYMMDCTRL_SET;                 /**< SYMMDCTRL                                          */
  __IOM uint32_t SYDIVCTRL_SET;                 /**< SYDIVCTRL                                          */
  __IOM uint32_t DIGCLKRETIMECTRL_SET;          /**< DIGCLKRETIMECTRL                                   */
  __IM uint32_t  DIGCLKRETIMESTATUS_SET;        /**< DIGCLKRETIMESTATUS                                 */
  __IOM uint32_t XORETIMECTRL_SET;              /**< XORETIMECTRL                                       */
  __IM uint32_t  XORETIMESTATUS_SET;            /**< XORETIMESTATUS                                     */
  __IOM uint32_t AGCOVERWRITE0_SET;             /**< OVERWRITE AGC                                      */
  __IOM uint32_t AGCOVERWRITE1_SET;             /**< OVERWRITE AGC                                      */
  uint32_t       RESERVED32[5U];                /**< Reserved for future use                            */
  __IOM uint32_t TXOGNDPKD_SET;                 /**< TXOGNDPKD                                          */
  __IM uint32_t  TXOGNDPKDSTATUS_SET;           /**< TXOGNDPKDSTATUS                                    */
  uint32_t       RESERVED33[4U];                /**< Reserved for future use                            */
  __IOM uint32_t GPPLLCLKRETIMECTRL_SET;        /**< GPPLLCLKRETIMECTRL                                 */
  __IM uint32_t  GPPLLCLKRETIMESTATUS_SET;      /**< GPPLLCLKRETIMESTATUS                               */
  uint32_t       RESERVED34[2U];                /**< Reserved for future use                            */
  __IOM uint32_t PATRIM6_SET;                   /**< PATRIM6                                            */
  __IOM uint32_t PATRIM7_SET;                   /**< PATRIM7                                            */
  __IOM uint32_t PATRIM8_SET;                   /**< PATRIM8                                            */
  __IOM uint32_t PATRIM9_SET;                   /**< PATRIM9                                            */
  __IOM uint32_t PATRIM10_SET;                  /**< PATRIM10                                           */
  uint32_t       RESERVED35[1U];                /**< Reserved for future use                            */
  __IOM uint32_t TXRFPKD_SET;                   /**< TXRFPKD                                            */
  uint32_t       RESERVED36[1U];                /**< Reserved for future use                            */
  __IM uint32_t  TXSTATUS_SET;                  /**< TXSTATUS                                           */
  __IOM uint32_t TXOFDM_SET;                    /**< TXOFDM                                             */
  uint32_t       RESERVED37[1U];                /**< Reserved for future use                            */
  __IOM uint32_t TXMIX_SET;                     /**< TXMIX                                              */
  __IOM uint32_t TXITC_SET;                     /**< TXITC                                              */
  __IOM uint32_t TXCALITC_SET;                  /**< TXCALITC                                           */
  uint32_t       RESERVED38[57U];               /**< Reserved for future use                            */
  __IOM uint32_t TXPKDCTRL_SET;                 /**< Control Register                                   */
  __IOM uint32_t TXPKDCMD_SET;                  /**< CMD Register                                       */
  __IM uint32_t  TXPKDSTATUS_SET;               /**< Status Register                                    */
  uint32_t       RESERVED39[49U];               /**< Reserved for future use                            */
  __IOM uint32_t RADIOCLKCTRL_SET;              /**< New Register                                       */
  uint32_t       RESERVED40[3U];                /**< Reserved for future use                            */
  __IOM uint32_t SCRATCH0_SET;                  /**< SCRATCH0                                           */
  __IOM uint32_t SCRATCH1_SET;                  /**< SCRATCH1                                           */
  __IOM uint32_t SCRATCH2_SET;                  /**< SCRATCH2                                           */
  __IOM uint32_t SCRATCH3_SET;                  /**< SCRATCH3                                           */
  __IOM uint32_t SCRATCH4_SET;                  /**< SCRATCH4                                           */
  __IOM uint32_t SCRATCH5_SET;                  /**< SCRATCH5                                           */
  __IOM uint32_t SCRATCH6_SET;                  /**< SCRATCH6                                           */
  __IOM uint32_t SCRATCH7_SET;                  /**< SCRATCH7                                           */
  __IOM uint32_t SOFTMCTRL_SET;                 /**< Soft Modem Control                                 */
  __IOM uint32_t SFMIF_SET;                     /**< Soft Modem Interrupt Flags                         */
  __IOM uint32_t SFMIEN_SET;                    /**< Soft Modem Interrupt Enables                       */
  uint32_t       RESERVED41[247U];              /**< Reserved for future use                            */
  __IOM uint32_t THMSW_SET;                     /**< Thermister control                                 */
  uint32_t       RESERVED42[1U];                /**< Reserved for future use                            */
  uint32_t       RESERVED43[2U];                /**< Reserved for future use                            */
  uint32_t       RESERVED44[1U];                /**< Reserved for future use                            */
  uint32_t       RESERVED45[513U];              /**< Reserved for future use                            */
  __IM uint32_t  IPVERSION_CLR;                 /**< IP Version                                         */
  __IOM uint32_t EN_CLR;                        /**< Enable peripheral clock to this module             */
  __IOM uint32_t RXENSRCEN_CLR;                 /**< RXEN Source Enable                                 */
  __IM uint32_t  STATUS_CLR;                    /**< Radio State Machine Status                         */
  __IOM uint32_t CMD_CLR;                       /**< Radio Commands                                     */
  __IOM uint32_t CTRL_CLR;                      /**< Radio Control Register                             */
  __IOM uint32_t FORCESTATE_CLR;                /**< Force state transition                             */
  __IOM uint32_t IF_CLR;                        /**< Radio Controller Interrupt Flags                   */
  __IOM uint32_t IEN_CLR;                       /**< Interrupt Enable Register                          */
  __IOM uint32_t TESTCTRL_CLR;                  /**< Test Control Register                              */
  __IOM uint32_t SEQIF_CLR;                     /**< SEQ Interrupt Flags                                */
  __IOM uint32_t SEQIEN_CLR;                    /**< SEQ Interrupt Enable Register                      */
  __IM uint32_t  STATUS1_CLR;                   /**< Radio State Machine Status                         */
  __IOM uint32_t FEMCTRL_CLR;                   /**< FEM Control                                        */
  __IOM uint32_t FEMDATA_CLR;                   /**< FEM Data                                           */
  uint32_t       RESERVED46[5U];                /**< Reserved for future use                            */
  __IM uint32_t  STIMER_CLR;                    /**< Sequencer Timer Value                              */
  __IOM uint32_t STIMERCOMP_CLR;                /**< Sequencer Timer Compare Value                      */
  __IOM uint32_t SEQCTRL_CLR;                   /**< Sequencer Control Register                         */
  __IOM uint32_t PRESC_CLR;                     /**< Sequencer prescaler Register                       */
  __IOM uint32_t SR0_CLR;                       /**< Storage Register 0                                 */
  __IOM uint32_t SR1_CLR;                       /**< Storage Register 1                                 */
  __IOM uint32_t SR2_CLR;                       /**< Storage Register 2                                 */
  __IOM uint32_t SR3_CLR;                       /**< Storage Register 3                                 */
  __IOM uint32_t STCTRL_CLR;                    /**< Sys tick timer Control Register                    */
  __IOM uint32_t FRCTXWORD_CLR;                 /**< FRC wordbuffer write                               */
  __IM uint32_t  FRCRXWORD_CLR;                 /**< FRC wordbuffer read                                */
  __IOM uint32_t EM1PCSR_CLR;                   /**< Radio EM1P Control and Status Register             */
  uint32_t       RESERVED47[6U];                /**< Reserved for future use                            */
  __IOM uint32_t SYNTHENCTRL_CLR;               /**< Synthesizer Enable Control Register                */
  __IOM uint32_t SYNTHREGCTRL_CLR;              /**< Synthesizer Regulator Enable Control               */
  __IOM uint32_t VCOCTRL_CLR;                   /**< VCO Control Register                               */
  uint32_t       RESERVED48[2U];                /**< Reserved for future use                            */
  uint32_t       RESERVED49[1U];                /**< Reserved for future use                            */
  __IM uint32_t  STATUS2_CLR;                   /**< Radio State Machine Status 2                       */
  __IOM uint32_t IFPGACTRL_CLR;                 /**< IF PGA Control Register                            */
  __IOM uint32_t PAENCTRL_CLR;                  /**< PA Enable Control Register                         */
  __IOM uint32_t APC_CLR;                       /**< Automatic Power Control Register                   */
  __IOM uint32_t ANTDIV_CLR;                    /**< ANTDIV                                             */
  __IOM uint32_t AUXADCTRIM_CLR;                /**< AUXADCTRIM                                         */
  __IOM uint32_t AUXADCEN_CLR;                  /**< AUXADCEN                                           */
  __IOM uint32_t AUXADCCTRL0_CLR;               /**< Auxiliary ADC register control                     */
  __IOM uint32_t AUXADCCTRL1_CLR;               /**< AUXADCCTRL1                                        */
  __IM uint32_t  AUXADCOUT_CLR;                 /**< Auxiliary ADC digital output                       */
  __IOM uint32_t CLKMULTEN0_CLR;                /**< CLKMULTEN0                                         */
  __IOM uint32_t CLKMULTEN1_CLR;                /**< CLKMULTEN1                                         */
  __IOM uint32_t CLKMULTCTRL_CLR;               /**< CLKMULTCTRL                                        */
  __IM uint32_t  CLKMULTSTATUS_CLR;             /**< CLKMULTSTATUS                                      */
  uint32_t       RESERVED50[1U];                /**< Reserved for future use                            */
  __IOM uint32_t IFADCTRIM0_CLR;                /**< IFADCTRIM0                                         */
  __IOM uint32_t IFADCTRIM1_CLR;                /**< IFADCTRIM1                                         */
  __IOM uint32_t IFADCCAL_CLR;                  /**< IFADCCAL                                           */
  __IM uint32_t  IFADCSTATUS_CLR;               /**< IFADCSTATUS                                        */
  uint32_t       RESERVED51[1U];                /**< Reserved for future use                            */
  __IOM uint32_t LNAMIXTRIM0_CLR;               /**< LNAMIXTRIM0                                        */
  __IOM uint32_t LNAMIXTRIM1_CLR;               /**< LNAMIXTRIM1                                        */
  __IOM uint32_t LNAMIXTRIM2_CLR;               /**< LNAMIXTRIM2                                        */
  __IOM uint32_t LNAMIXTRIM3_CLR;               /**< LNAMIXTRIM3                                        */
  __IOM uint32_t LNAMIXTRIM4_CLR;               /**< LNAMIXTRIM4                                        */
  __IOM uint32_t LNAMIXCAL_CLR;                 /**< LNAMIXCAL                                          */
  __IOM uint32_t LNAMIXEN_CLR;                  /**< LNAMIXEN                                           */
  __IOM uint32_t PRECTRL_CLR;                   /**< PRECTRL                                            */
  uint32_t       RESERVED52[1U];                /**< Reserved for future use                            */
  __IOM uint32_t PATRIM1_CLR;                   /**< PATRIM1                                            */
  __IOM uint32_t PATRIM2_CLR;                   /**< PATRIM2                                            */
  __IOM uint32_t PATRIM3_CLR;                   /**< PATRIM3                                            */
  __IOM uint32_t PATRIM4_CLR;                   /**< PATRIM4                                            */
  __IOM uint32_t PATRIM5_CLR;                   /**< PATRIM5                                            */
  __IOM uint32_t PADEBUG0_CLR;                  /**< PADEBUG0                                           */
  __IOM uint32_t TXPOWER_CLR;                   /**< TXPOWER                                            */
  __IOM uint32_t TXRAMP_CLR;                    /**< TXRAMP                                             */
  uint32_t       RESERVED53[1U];                /**< Reserved for future use                            */
  __IOM uint32_t PGATRIM_CLR;                   /**< PGATRIM                                            */
  __IOM uint32_t PGACAL_CLR;                    /**< PGACAL                                             */
  __IOM uint32_t PGACTRL_CLR;                   /**< PGACTRL                                            */
  __IOM uint32_t RFBIASCAL_CLR;                 /**< RFBIASCAL                                          */
  __IOM uint32_t RFBIASCTRL_CLR;                /**< RFBIASCTRL                                         */
  __IOM uint32_t RADIOEN_CLR;                   /**< RADIOEN                                            */
  __IOM uint32_t RFPATHEN0_CLR;                 /**< RFPATHEN0                                          */
  __IOM uint32_t RFPATHEN1_CLR;                 /**< RFPATHEN1                                          */
  __IOM uint32_t RX_CLR;                        /**< RX                                                 */
  __IOM uint32_t TX_CLR;                        /**< TX                                                 */
  uint32_t       RESERVED54[1U];                /**< Reserved for future use                            */
  __IOM uint32_t SYTRIM0_CLR;                   /**< SYTRIM0                                            */
  __IOM uint32_t SYTRIM1_CLR;                   /**< SYTRIM1                                            */
  __IOM uint32_t SYCAL_CLR;                     /**< SYCAL                                              */
  __IOM uint32_t SYEN_CLR;                      /**< SYEN                                               */
  __IOM uint32_t SYLOEN_CLR;                    /**< SYLOEN                                             */
  __IOM uint32_t SYMMDCTRL_CLR;                 /**< SYMMDCTRL                                          */
  __IOM uint32_t SYDIVCTRL_CLR;                 /**< SYDIVCTRL                                          */
  __IOM uint32_t DIGCLKRETIMECTRL_CLR;          /**< DIGCLKRETIMECTRL                                   */
  __IM uint32_t  DIGCLKRETIMESTATUS_CLR;        /**< DIGCLKRETIMESTATUS                                 */
  __IOM uint32_t XORETIMECTRL_CLR;              /**< XORETIMECTRL                                       */
  __IM uint32_t  XORETIMESTATUS_CLR;            /**< XORETIMESTATUS                                     */
  __IOM uint32_t AGCOVERWRITE0_CLR;             /**< OVERWRITE AGC                                      */
  __IOM uint32_t AGCOVERWRITE1_CLR;             /**< OVERWRITE AGC                                      */
  uint32_t       RESERVED55[5U];                /**< Reserved for future use                            */
  __IOM uint32_t TXOGNDPKD_CLR;                 /**< TXOGNDPKD                                          */
  __IM uint32_t  TXOGNDPKDSTATUS_CLR;           /**< TXOGNDPKDSTATUS                                    */
  uint32_t       RESERVED56[4U];                /**< Reserved for future use                            */
  __IOM uint32_t GPPLLCLKRETIMECTRL_CLR;        /**< GPPLLCLKRETIMECTRL                                 */
  __IM uint32_t  GPPLLCLKRETIMESTATUS_CLR;      /**< GPPLLCLKRETIMESTATUS                               */
  uint32_t       RESERVED57[2U];                /**< Reserved for future use                            */
  __IOM uint32_t PATRIM6_CLR;                   /**< PATRIM6                                            */
  __IOM uint32_t PATRIM7_CLR;                   /**< PATRIM7                                            */
  __IOM uint32_t PATRIM8_CLR;                   /**< PATRIM8                                            */
  __IOM uint32_t PATRIM9_CLR;                   /**< PATRIM9                                            */
  __IOM uint32_t PATRIM10_CLR;                  /**< PATRIM10                                           */
  uint32_t       RESERVED58[1U];                /**< Reserved for future use                            */
  __IOM uint32_t TXRFPKD_CLR;                   /**< TXRFPKD                                            */
  uint32_t       RESERVED59[1U];                /**< Reserved for future use                            */
  __IM uint32_t  TXSTATUS_CLR;                  /**< TXSTATUS                                           */
  __IOM uint32_t TXOFDM_CLR;                    /**< TXOFDM                                             */
  uint32_t       RESERVED60[1U];                /**< Reserved for future use                            */
  __IOM uint32_t TXMIX_CLR;                     /**< TXMIX                                              */
  __IOM uint32_t TXITC_CLR;                     /**< TXITC                                              */
  __IOM uint32_t TXCALITC_CLR;                  /**< TXCALITC                                           */
  uint32_t       RESERVED61[57U];               /**< Reserved for future use                            */
  __IOM uint32_t TXPKDCTRL_CLR;                 /**< Control Register                                   */
  __IOM uint32_t TXPKDCMD_CLR;                  /**< CMD Register                                       */
  __IM uint32_t  TXPKDSTATUS_CLR;               /**< Status Register                                    */
  uint32_t       RESERVED62[49U];               /**< Reserved for future use                            */
  __IOM uint32_t RADIOCLKCTRL_CLR;              /**< New Register                                       */
  uint32_t       RESERVED63[3U];                /**< Reserved for future use                            */
  __IOM uint32_t SCRATCH0_CLR;                  /**< SCRATCH0                                           */
  __IOM uint32_t SCRATCH1_CLR;                  /**< SCRATCH1                                           */
  __IOM uint32_t SCRATCH2_CLR;                  /**< SCRATCH2                                           */
  __IOM uint32_t SCRATCH3_CLR;                  /**< SCRATCH3                                           */
  __IOM uint32_t SCRATCH4_CLR;                  /**< SCRATCH4                                           */
  __IOM uint32_t SCRATCH5_CLR;                  /**< SCRATCH5                                           */
  __IOM uint32_t SCRATCH6_CLR;                  /**< SCRATCH6                                           */
  __IOM uint32_t SCRATCH7_CLR;                  /**< SCRATCH7                                           */
  __IOM uint32_t SOFTMCTRL_CLR;                 /**< Soft Modem Control                                 */
  __IOM uint32_t SFMIF_CLR;                     /**< Soft Modem Interrupt Flags                         */
  __IOM uint32_t SFMIEN_CLR;                    /**< Soft Modem Interrupt Enables                       */
  uint32_t       RESERVED64[247U];              /**< Reserved for future use                            */
  __IOM uint32_t THMSW_CLR;                     /**< Thermister control                                 */
  uint32_t       RESERVED65[1U];                /**< Reserved for future use                            */
  uint32_t       RESERVED66[2U];                /**< Reserved for future use                            */
  uint32_t       RESERVED67[1U];                /**< Reserved for future use                            */
  uint32_t       RESERVED68[513U];              /**< Reserved for future use                            */
  __IM uint32_t  IPVERSION_TGL;                 /**< IP Version                                         */
  __IOM uint32_t EN_TGL;                        /**< Enable peripheral clock to this module             */
  __IOM uint32_t RXENSRCEN_TGL;                 /**< RXEN Source Enable                                 */
  __IM uint32_t  STATUS_TGL;                    /**< Radio State Machine Status                         */
  __IOM uint32_t CMD_TGL;                       /**< Radio Commands                                     */
  __IOM uint32_t CTRL_TGL;                      /**< Radio Control Register                             */
  __IOM uint32_t FORCESTATE_TGL;                /**< Force state transition                             */
  __IOM uint32_t IF_TGL;                        /**< Radio Controller Interrupt Flags                   */
  __IOM uint32_t IEN_TGL;                       /**< Interrupt Enable Register                          */
  __IOM uint32_t TESTCTRL_TGL;                  /**< Test Control Register                              */
  __IOM uint32_t SEQIF_TGL;                     /**< SEQ Interrupt Flags                                */
  __IOM uint32_t SEQIEN_TGL;                    /**< SEQ Interrupt Enable Register                      */
  __IM uint32_t  STATUS1_TGL;                   /**< Radio State Machine Status                         */
  __IOM uint32_t FEMCTRL_TGL;                   /**< FEM Control                                        */
  __IOM uint32_t FEMDATA_TGL;                   /**< FEM Data                                           */
  uint32_t       RESERVED69[5U];                /**< Reserved for future use                            */
  __IM uint32_t  STIMER_TGL;                    /**< Sequencer Timer Value                              */
  __IOM uint32_t STIMERCOMP_TGL;                /**< Sequencer Timer Compare Value                      */
  __IOM uint32_t SEQCTRL_TGL;                   /**< Sequencer Control Register                         */
  __IOM uint32_t PRESC_TGL;                     /**< Sequencer prescaler Register                       */
  __IOM uint32_t SR0_TGL;                       /**< Storage Register 0                                 */
  __IOM uint32_t SR1_TGL;                       /**< Storage Register 1                                 */
  __IOM uint32_t SR2_TGL;                       /**< Storage Register 2                                 */
  __IOM uint32_t SR3_TGL;                       /**< Storage Register 3                                 */
  __IOM uint32_t STCTRL_TGL;                    /**< Sys tick timer Control Register                    */
  __IOM uint32_t FRCTXWORD_TGL;                 /**< FRC wordbuffer write                               */
  __IM uint32_t  FRCRXWORD_TGL;                 /**< FRC wordbuffer read                                */
  __IOM uint32_t EM1PCSR_TGL;                   /**< Radio EM1P Control and Status Register             */
  uint32_t       RESERVED70[6U];                /**< Reserved for future use                            */
  __IOM uint32_t SYNTHENCTRL_TGL;               /**< Synthesizer Enable Control Register                */
  __IOM uint32_t SYNTHREGCTRL_TGL;              /**< Synthesizer Regulator Enable Control               */
  __IOM uint32_t VCOCTRL_TGL;                   /**< VCO Control Register                               */
  uint32_t       RESERVED71[2U];                /**< Reserved for future use                            */
  uint32_t       RESERVED72[1U];                /**< Reserved for future use                            */
  __IM uint32_t  STATUS2_TGL;                   /**< Radio State Machine Status 2                       */
  __IOM uint32_t IFPGACTRL_TGL;                 /**< IF PGA Control Register                            */
  __IOM uint32_t PAENCTRL_TGL;                  /**< PA Enable Control Register                         */
  __IOM uint32_t APC_TGL;                       /**< Automatic Power Control Register                   */
  __IOM uint32_t ANTDIV_TGL;                    /**< ANTDIV                                             */
  __IOM uint32_t AUXADCTRIM_TGL;                /**< AUXADCTRIM                                         */
  __IOM uint32_t AUXADCEN_TGL;                  /**< AUXADCEN                                           */
  __IOM uint32_t AUXADCCTRL0_TGL;               /**< Auxiliary ADC register control                     */
  __IOM uint32_t AUXADCCTRL1_TGL;               /**< AUXADCCTRL1                                        */
  __IM uint32_t  AUXADCOUT_TGL;                 /**< Auxiliary ADC digital output                       */
  __IOM uint32_t CLKMULTEN0_TGL;                /**< CLKMULTEN0                                         */
  __IOM uint32_t CLKMULTEN1_TGL;                /**< CLKMULTEN1                                         */
  __IOM uint32_t CLKMULTCTRL_TGL;               /**< CLKMULTCTRL                                        */
  __IM uint32_t  CLKMULTSTATUS_TGL;             /**< CLKMULTSTATUS                                      */
  uint32_t       RESERVED73[1U];                /**< Reserved for future use                            */
  __IOM uint32_t IFADCTRIM0_TGL;                /**< IFADCTRIM0                                         */
  __IOM uint32_t IFADCTRIM1_TGL;                /**< IFADCTRIM1                                         */
  __IOM uint32_t IFADCCAL_TGL;                  /**< IFADCCAL                                           */
  __IM uint32_t  IFADCSTATUS_TGL;               /**< IFADCSTATUS                                        */
  uint32_t       RESERVED74[1U];                /**< Reserved for future use                            */
  __IOM uint32_t LNAMIXTRIM0_TGL;               /**< LNAMIXTRIM0                                        */
  __IOM uint32_t LNAMIXTRIM1_TGL;               /**< LNAMIXTRIM1                                        */
  __IOM uint32_t LNAMIXTRIM2_TGL;               /**< LNAMIXTRIM2                                        */
  __IOM uint32_t LNAMIXTRIM3_TGL;               /**< LNAMIXTRIM3                                        */
  __IOM uint32_t LNAMIXTRIM4_TGL;               /**< LNAMIXTRIM4                                        */
  __IOM uint32_t LNAMIXCAL_TGL;                 /**< LNAMIXCAL                                          */
  __IOM uint32_t LNAMIXEN_TGL;                  /**< LNAMIXEN                                           */
  __IOM uint32_t PRECTRL_TGL;                   /**< PRECTRL                                            */
  uint32_t       RESERVED75[1U];                /**< Reserved for future use                            */
  __IOM uint32_t PATRIM1_TGL;                   /**< PATRIM1                                            */
  __IOM uint32_t PATRIM2_TGL;                   /**< PATRIM2                                            */
  __IOM uint32_t PATRIM3_TGL;                   /**< PATRIM3                                            */
  __IOM uint32_t PATRIM4_TGL;                   /**< PATRIM4                                            */
  __IOM uint32_t PATRIM5_TGL;                   /**< PATRIM5                                            */
  __IOM uint32_t PADEBUG0_TGL;                  /**< PADEBUG0                                           */
  __IOM uint32_t TXPOWER_TGL;                   /**< TXPOWER                                            */
  __IOM uint32_t TXRAMP_TGL;                    /**< TXRAMP                                             */
  uint32_t       RESERVED76[1U];                /**< Reserved for future use                            */
  __IOM uint32_t PGATRIM_TGL;                   /**< PGATRIM                                            */
  __IOM uint32_t PGACAL_TGL;                    /**< PGACAL                                             */
  __IOM uint32_t PGACTRL_TGL;                   /**< PGACTRL                                            */
  __IOM uint32_t RFBIASCAL_TGL;                 /**< RFBIASCAL                                          */
  __IOM uint32_t RFBIASCTRL_TGL;                /**< RFBIASCTRL                                         */
  __IOM uint32_t RADIOEN_TGL;                   /**< RADIOEN                                            */
  __IOM uint32_t RFPATHEN0_TGL;                 /**< RFPATHEN0                                          */
  __IOM uint32_t RFPATHEN1_TGL;                 /**< RFPATHEN1                                          */
  __IOM uint32_t RX_TGL;                        /**< RX                                                 */
  __IOM uint32_t TX_TGL;                        /**< TX                                                 */
  uint32_t       RESERVED77[1U];                /**< Reserved for future use                            */
  __IOM uint32_t SYTRIM0_TGL;                   /**< SYTRIM0                                            */
  __IOM uint32_t SYTRIM1_TGL;                   /**< SYTRIM1                                            */
  __IOM uint32_t SYCAL_TGL;                     /**< SYCAL                                              */
  __IOM uint32_t SYEN_TGL;                      /**< SYEN                                               */
  __IOM uint32_t SYLOEN_TGL;                    /**< SYLOEN                                             */
  __IOM uint32_t SYMMDCTRL_TGL;                 /**< SYMMDCTRL                                          */
  __IOM uint32_t SYDIVCTRL_TGL;                 /**< SYDIVCTRL                                          */
  __IOM uint32_t DIGCLKRETIMECTRL_TGL;          /**< DIGCLKRETIMECTRL                                   */
  __IM uint32_t  DIGCLKRETIMESTATUS_TGL;        /**< DIGCLKRETIMESTATUS                                 */
  __IOM uint32_t XORETIMECTRL_TGL;              /**< XORETIMECTRL                                       */
  __IM uint32_t  XORETIMESTATUS_TGL;            /**< XORETIMESTATUS                                     */
  __IOM uint32_t AGCOVERWRITE0_TGL;             /**< OVERWRITE AGC                                      */
  __IOM uint32_t AGCOVERWRITE1_TGL;             /**< OVERWRITE AGC                                      */
  uint32_t       RESERVED78[5U];                /**< Reserved for future use                            */
  __IOM uint32_t TXOGNDPKD_TGL;                 /**< TXOGNDPKD                                          */
  __IM uint32_t  TXOGNDPKDSTATUS_TGL;           /**< TXOGNDPKDSTATUS                                    */
  uint32_t       RESERVED79[4U];                /**< Reserved for future use                            */
  __IOM uint32_t GPPLLCLKRETIMECTRL_TGL;        /**< GPPLLCLKRETIMECTRL                                 */
  __IM uint32_t  GPPLLCLKRETIMESTATUS_TGL;      /**< GPPLLCLKRETIMESTATUS                               */
  uint32_t       RESERVED80[2U];                /**< Reserved for future use                            */
  __IOM uint32_t PATRIM6_TGL;                   /**< PATRIM6                                            */
  __IOM uint32_t PATRIM7_TGL;                   /**< PATRIM7                                            */
  __IOM uint32_t PATRIM8_TGL;                   /**< PATRIM8                                            */
  __IOM uint32_t PATRIM9_TGL;                   /**< PATRIM9                                            */
  __IOM uint32_t PATRIM10_TGL;                  /**< PATRIM10                                           */
  uint32_t       RESERVED81[1U];                /**< Reserved for future use                            */
  __IOM uint32_t TXRFPKD_TGL;                   /**< TXRFPKD                                            */
  uint32_t       RESERVED82[1U];                /**< Reserved for future use                            */
  __IM uint32_t  TXSTATUS_TGL;                  /**< TXSTATUS                                           */
  __IOM uint32_t TXOFDM_TGL;                    /**< TXOFDM                                             */
  uint32_t       RESERVED83[1U];                /**< Reserved for future use                            */
  __IOM uint32_t TXMIX_TGL;                     /**< TXMIX                                              */
  __IOM uint32_t TXITC_TGL;                     /**< TXITC                                              */
  __IOM uint32_t TXCALITC_TGL;                  /**< TXCALITC                                           */
  uint32_t       RESERVED84[57U];               /**< Reserved for future use                            */
  __IOM uint32_t TXPKDCTRL_TGL;                 /**< Control Register                                   */
  __IOM uint32_t TXPKDCMD_TGL;                  /**< CMD Register                                       */
  __IM uint32_t  TXPKDSTATUS_TGL;               /**< Status Register                                    */
  uint32_t       RESERVED85[49U];               /**< Reserved for future use                            */
  __IOM uint32_t RADIOCLKCTRL_TGL;              /**< New Register                                       */
  uint32_t       RESERVED86[3U];                /**< Reserved for future use                            */
  __IOM uint32_t SCRATCH0_TGL;                  /**< SCRATCH0                                           */
  __IOM uint32_t SCRATCH1_TGL;                  /**< SCRATCH1                                           */
  __IOM uint32_t SCRATCH2_TGL;                  /**< SCRATCH2                                           */
  __IOM uint32_t SCRATCH3_TGL;                  /**< SCRATCH3                                           */
  __IOM uint32_t SCRATCH4_TGL;                  /**< SCRATCH4                                           */
  __IOM uint32_t SCRATCH5_TGL;                  /**< SCRATCH5                                           */
  __IOM uint32_t SCRATCH6_TGL;                  /**< SCRATCH6                                           */
  __IOM uint32_t SCRATCH7_TGL;                  /**< SCRATCH7                                           */
  __IOM uint32_t SOFTMCTRL_TGL;                 /**< Soft Modem Control                                 */
  __IOM uint32_t SFMIF_TGL;                     /**< Soft Modem Interrupt Flags                         */
  __IOM uint32_t SFMIEN_TGL;                    /**< Soft Modem Interrupt Enables                       */
  uint32_t       RESERVED87[247U];              /**< Reserved for future use                            */
  __IOM uint32_t THMSW_TGL;                     /**< Thermister control                                 */
  uint32_t       RESERVED88[1U];                /**< Reserved for future use                            */
  uint32_t       RESERVED89[2U];                /**< Reserved for future use                            */
  uint32_t       RESERVED90[1U];                /**< Reserved for future use                            */
} RAC_TypeDef;
/** @} End of group EFR32FG25_RAC */

/**************************************************************************//**
 * @addtogroup EFR32FG25_RAC
 * @{
 * @defgroup EFR32FG25_RAC_BitFields RAC Bit Fields
 * @{
 *****************************************************************************/

/* Bit fields for RAC IPVERSION */
#define _RAC_IPVERSION_RESETVALUE                                         0x00000004UL                            /**< Default value for RAC_IPVERSION             */
#define _RAC_IPVERSION_MASK                                               0xFFFFFFFFUL                            /**< Mask for RAC_IPVERSION                      */
#define _RAC_IPVERSION_IPVERSION_SHIFT                                    0                                       /**< Shift value for RAC_IPVERSION               */
#define _RAC_IPVERSION_IPVERSION_MASK                                     0xFFFFFFFFUL                            /**< Bit mask for RAC_IPVERSION                  */
#define _RAC_IPVERSION_IPVERSION_DEFAULT                                  0x00000004UL                            /**< Mode DEFAULT for RAC_IPVERSION              */
#define RAC_IPVERSION_IPVERSION_DEFAULT                                   (_RAC_IPVERSION_IPVERSION_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_IPVERSION      */

/* Bit fields for RAC EN */
#define _RAC_EN_RESETVALUE                                                0x00000000UL              /**< Default value for RAC_EN                    */
#define _RAC_EN_MASK                                                      0x00000001UL              /**< Mask for RAC_EN                             */
#define RAC_EN_EN                                                         (0x1UL << 0)              /**< Enable peripheral clock to this module      */
#define _RAC_EN_EN_SHIFT                                                  0                         /**< Shift value for RAC_EN                      */
#define _RAC_EN_EN_MASK                                                   0x1UL                     /**< Bit mask for RAC_EN                         */
#define _RAC_EN_EN_DEFAULT                                                0x00000000UL              /**< Mode DEFAULT for RAC_EN                     */
#define RAC_EN_EN_DEFAULT                                                 (_RAC_EN_EN_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_EN             */

/* Bit fields for RAC RXENSRCEN */
#define _RAC_RXENSRCEN_RESETVALUE                                         0x00000000UL                                /**< Default value for RAC_RXENSRCEN             */
#define _RAC_RXENSRCEN_MASK                                               0x00003FFFUL                                /**< Mask for RAC_RXENSRCEN                      */
#define _RAC_RXENSRCEN_SWRXEN_SHIFT                                       0                                           /**< Shift value for RAC_SWRXEN                  */
#define _RAC_RXENSRCEN_SWRXEN_MASK                                        0xFFUL                                      /**< Bit mask for RAC_SWRXEN                     */
#define _RAC_RXENSRCEN_SWRXEN_DEFAULT                                     0x00000000UL                                /**< Mode DEFAULT for RAC_RXENSRCEN              */
#define RAC_RXENSRCEN_SWRXEN_DEFAULT                                      (_RAC_RXENSRCEN_SWRXEN_DEFAULT << 0)        /**< Shifted mode DEFAULT for RAC_RXENSRCEN      */
#define RAC_RXENSRCEN_CHANNELBUSYEN                                       (0x1UL << 8)                                /**< Channel Busy Enable                         */
#define _RAC_RXENSRCEN_CHANNELBUSYEN_SHIFT                                8                                           /**< Shift value for RAC_CHANNELBUSYEN           */
#define _RAC_RXENSRCEN_CHANNELBUSYEN_MASK                                 0x100UL                                     /**< Bit mask for RAC_CHANNELBUSYEN              */
#define _RAC_RXENSRCEN_CHANNELBUSYEN_DEFAULT                              0x00000000UL                                /**< Mode DEFAULT for RAC_RXENSRCEN              */
#define RAC_RXENSRCEN_CHANNELBUSYEN_DEFAULT                               (_RAC_RXENSRCEN_CHANNELBUSYEN_DEFAULT << 8) /**< Shifted mode DEFAULT for RAC_RXENSRCEN      */
#define RAC_RXENSRCEN_TIMDETEN                                            (0x1UL << 9)                                /**< Timing Detected Enable                      */
#define _RAC_RXENSRCEN_TIMDETEN_SHIFT                                     9                                           /**< Shift value for RAC_TIMDETEN                */
#define _RAC_RXENSRCEN_TIMDETEN_MASK                                      0x200UL                                     /**< Bit mask for RAC_TIMDETEN                   */
#define _RAC_RXENSRCEN_TIMDETEN_DEFAULT                                   0x00000000UL                                /**< Mode DEFAULT for RAC_RXENSRCEN              */
#define RAC_RXENSRCEN_TIMDETEN_DEFAULT                                    (_RAC_RXENSRCEN_TIMDETEN_DEFAULT << 9)      /**< Shifted mode DEFAULT for RAC_RXENSRCEN      */
#define RAC_RXENSRCEN_PREDETEN                                            (0x1UL << 10)                               /**< Preamble Detected Enable                    */
#define _RAC_RXENSRCEN_PREDETEN_SHIFT                                     10                                          /**< Shift value for RAC_PREDETEN                */
#define _RAC_RXENSRCEN_PREDETEN_MASK                                      0x400UL                                     /**< Bit mask for RAC_PREDETEN                   */
#define _RAC_RXENSRCEN_PREDETEN_DEFAULT                                   0x00000000UL                                /**< Mode DEFAULT for RAC_RXENSRCEN              */
#define RAC_RXENSRCEN_PREDETEN_DEFAULT                                    (_RAC_RXENSRCEN_PREDETEN_DEFAULT << 10)     /**< Shifted mode DEFAULT for RAC_RXENSRCEN      */
#define RAC_RXENSRCEN_FRAMEDETEN                                          (0x1UL << 11)                               /**< Frame Detected Enable                       */
#define _RAC_RXENSRCEN_FRAMEDETEN_SHIFT                                   11                                          /**< Shift value for RAC_FRAMEDETEN              */
#define _RAC_RXENSRCEN_FRAMEDETEN_MASK                                    0x800UL                                     /**< Bit mask for RAC_FRAMEDETEN                 */
#define _RAC_RXENSRCEN_FRAMEDETEN_DEFAULT                                 0x00000000UL                                /**< Mode DEFAULT for RAC_RXENSRCEN              */
#define RAC_RXENSRCEN_FRAMEDETEN_DEFAULT                                  (_RAC_RXENSRCEN_FRAMEDETEN_DEFAULT << 11)   /**< Shifted mode DEFAULT for RAC_RXENSRCEN      */
#define RAC_RXENSRCEN_DEMODRXREQEN                                        (0x1UL << 12)                               /**< DEMOD RX Request Enable                     */
#define _RAC_RXENSRCEN_DEMODRXREQEN_SHIFT                                 12                                          /**< Shift value for RAC_DEMODRXREQEN            */
#define _RAC_RXENSRCEN_DEMODRXREQEN_MASK                                  0x1000UL                                    /**< Bit mask for RAC_DEMODRXREQEN               */
#define _RAC_RXENSRCEN_DEMODRXREQEN_DEFAULT                               0x00000000UL                                /**< Mode DEFAULT for RAC_RXENSRCEN              */
#define RAC_RXENSRCEN_DEMODRXREQEN_DEFAULT                                (_RAC_RXENSRCEN_DEMODRXREQEN_DEFAULT << 12) /**< Shifted mode DEFAULT for RAC_RXENSRCEN      */
#define RAC_RXENSRCEN_PRSRXEN                                             (0x1UL << 13)                               /**< PRS RX Enable                               */
#define _RAC_RXENSRCEN_PRSRXEN_SHIFT                                      13                                          /**< Shift value for RAC_PRSRXEN                 */
#define _RAC_RXENSRCEN_PRSRXEN_MASK                                       0x2000UL                                    /**< Bit mask for RAC_PRSRXEN                    */
#define _RAC_RXENSRCEN_PRSRXEN_DEFAULT                                    0x00000000UL                                /**< Mode DEFAULT for RAC_RXENSRCEN              */
#define RAC_RXENSRCEN_PRSRXEN_DEFAULT                                     (_RAC_RXENSRCEN_PRSRXEN_DEFAULT << 13)      /**< Shifted mode DEFAULT for RAC_RXENSRCEN      */

/* Bit fields for RAC STATUS */
#define _RAC_STATUS_RESETVALUE                                            0x00000000UL                                   /**< Default value for RAC_STATUS                */
#define _RAC_STATUS_MASK                                                  0xFFF8FFFFUL                                   /**< Mask for RAC_STATUS                         */
#define _RAC_STATUS_RXMASK_SHIFT                                          0                                              /**< Shift value for RAC_RXMASK                  */
#define _RAC_STATUS_RXMASK_MASK                                           0xFFFFUL                                       /**< Bit mask for RAC_RXMASK                     */
#define _RAC_STATUS_RXMASK_DEFAULT                                        0x00000000UL                                   /**< Mode DEFAULT for RAC_STATUS                 */
#define RAC_STATUS_RXMASK_DEFAULT                                         (_RAC_STATUS_RXMASK_DEFAULT << 0)              /**< Shifted mode DEFAULT for RAC_STATUS         */
#define RAC_STATUS_FORCESTATEACTIVE                                       (0x1UL << 19)                                  /**< FSM state force active                      */
#define _RAC_STATUS_FORCESTATEACTIVE_SHIFT                                19                                             /**< Shift value for RAC_FORCESTATEACTIVE        */
#define _RAC_STATUS_FORCESTATEACTIVE_MASK                                 0x80000UL                                      /**< Bit mask for RAC_FORCESTATEACTIVE           */
#define _RAC_STATUS_FORCESTATEACTIVE_DEFAULT                              0x00000000UL                                   /**< Mode DEFAULT for RAC_STATUS                 */
#define _RAC_STATUS_FORCESTATEACTIVE_X0                                   0x00000000UL                                   /**< Mode X0 for RAC_STATUS                      */
#define _RAC_STATUS_FORCESTATEACTIVE_X1                                   0x00000001UL                                   /**< Mode X1 for RAC_STATUS                      */
#define RAC_STATUS_FORCESTATEACTIVE_DEFAULT                               (_RAC_STATUS_FORCESTATEACTIVE_DEFAULT << 19)   /**< Shifted mode DEFAULT for RAC_STATUS         */
#define RAC_STATUS_FORCESTATEACTIVE_X0                                    (_RAC_STATUS_FORCESTATEACTIVE_X0 << 19)        /**< Shifted mode X0 for RAC_STATUS              */
#define RAC_STATUS_FORCESTATEACTIVE_X1                                    (_RAC_STATUS_FORCESTATEACTIVE_X1 << 19)        /**< Shifted mode X1 for RAC_STATUS              */
#define RAC_STATUS_TXAFTERFRAMEPEND                                       (0x1UL << 20)                                  /**< TX After Frame Pending                      */
#define _RAC_STATUS_TXAFTERFRAMEPEND_SHIFT                                20                                             /**< Shift value for RAC_TXAFTERFRAMEPEND        */
#define _RAC_STATUS_TXAFTERFRAMEPEND_MASK                                 0x100000UL                                     /**< Bit mask for RAC_TXAFTERFRAMEPEND           */
#define _RAC_STATUS_TXAFTERFRAMEPEND_DEFAULT                              0x00000000UL                                   /**< Mode DEFAULT for RAC_STATUS                 */
#define _RAC_STATUS_TXAFTERFRAMEPEND_X0                                   0x00000000UL                                   /**< Mode X0 for RAC_STATUS                      */
#define _RAC_STATUS_TXAFTERFRAMEPEND_X1                                   0x00000001UL                                   /**< Mode X1 for RAC_STATUS                      */
#define RAC_STATUS_TXAFTERFRAMEPEND_DEFAULT                               (_RAC_STATUS_TXAFTERFRAMEPEND_DEFAULT << 20)   /**< Shifted mode DEFAULT for RAC_STATUS         */
#define RAC_STATUS_TXAFTERFRAMEPEND_X0                                    (_RAC_STATUS_TXAFTERFRAMEPEND_X0 << 20)        /**< Shifted mode X0 for RAC_STATUS              */
#define RAC_STATUS_TXAFTERFRAMEPEND_X1                                    (_RAC_STATUS_TXAFTERFRAMEPEND_X1 << 20)        /**< Shifted mode X1 for RAC_STATUS              */
#define RAC_STATUS_TXAFTERFRAMEACTIVE                                     (0x1UL << 21)                                  /**< TX After Frame Active                       */
#define _RAC_STATUS_TXAFTERFRAMEACTIVE_SHIFT                              21                                             /**< Shift value for RAC_TXAFTERFRAMEACTIVE      */
#define _RAC_STATUS_TXAFTERFRAMEACTIVE_MASK                               0x200000UL                                     /**< Bit mask for RAC_TXAFTERFRAMEACTIVE         */
#define _RAC_STATUS_TXAFTERFRAMEACTIVE_DEFAULT                            0x00000000UL                                   /**< Mode DEFAULT for RAC_STATUS                 */
#define _RAC_STATUS_TXAFTERFRAMEACTIVE_X0                                 0x00000000UL                                   /**< Mode X0 for RAC_STATUS                      */
#define _RAC_STATUS_TXAFTERFRAMEACTIVE_X1                                 0x00000001UL                                   /**< Mode X1 for RAC_STATUS                      */
#define RAC_STATUS_TXAFTERFRAMEACTIVE_DEFAULT                             (_RAC_STATUS_TXAFTERFRAMEACTIVE_DEFAULT << 21) /**< Shifted mode DEFAULT for RAC_STATUS         */
#define RAC_STATUS_TXAFTERFRAMEACTIVE_X0                                  (_RAC_STATUS_TXAFTERFRAMEACTIVE_X0 << 21)      /**< Shifted mode X0 for RAC_STATUS              */
#define RAC_STATUS_TXAFTERFRAMEACTIVE_X1                                  (_RAC_STATUS_TXAFTERFRAMEACTIVE_X1 << 21)      /**< Shifted mode X1 for RAC_STATUS              */
#define RAC_STATUS_SEQSLEEPING                                            (0x1UL << 22)                                  /**< SEQ in sleeping                             */
#define _RAC_STATUS_SEQSLEEPING_SHIFT                                     22                                             /**< Shift value for RAC_SEQSLEEPING             */
#define _RAC_STATUS_SEQSLEEPING_MASK                                      0x400000UL                                     /**< Bit mask for RAC_SEQSLEEPING                */
#define _RAC_STATUS_SEQSLEEPING_DEFAULT                                   0x00000000UL                                   /**< Mode DEFAULT for RAC_STATUS                 */
#define RAC_STATUS_SEQSLEEPING_DEFAULT                                    (_RAC_STATUS_SEQSLEEPING_DEFAULT << 22)        /**< Shifted mode DEFAULT for RAC_STATUS         */
#define RAC_STATUS_SEQSLEEPDEEP                                           (0x1UL << 23)                                  /**< SEQ in deep sleep                           */
#define _RAC_STATUS_SEQSLEEPDEEP_SHIFT                                    23                                             /**< Shift value for RAC_SEQSLEEPDEEP            */
#define _RAC_STATUS_SEQSLEEPDEEP_MASK                                     0x800000UL                                     /**< Bit mask for RAC_SEQSLEEPDEEP               */
#define _RAC_STATUS_SEQSLEEPDEEP_DEFAULT                                  0x00000000UL                                   /**< Mode DEFAULT for RAC_STATUS                 */
#define RAC_STATUS_SEQSLEEPDEEP_DEFAULT                                   (_RAC_STATUS_SEQSLEEPDEEP_DEFAULT << 23)       /**< Shifted mode DEFAULT for RAC_STATUS         */
#define _RAC_STATUS_STATE_SHIFT                                           24                                             /**< Shift value for RAC_STATE                   */
#define _RAC_STATUS_STATE_MASK                                            0xF000000UL                                    /**< Bit mask for RAC_STATE                      */
#define _RAC_STATUS_STATE_DEFAULT                                         0x00000000UL                                   /**< Mode DEFAULT for RAC_STATUS                 */
#define _RAC_STATUS_STATE_OFF                                             0x00000000UL                                   /**< Mode OFF for RAC_STATUS                     */
#define _RAC_STATUS_STATE_RXWARM                                          0x00000001UL                                   /**< Mode RXWARM for RAC_STATUS                  */
#define _RAC_STATUS_STATE_RXSEARCH                                        0x00000002UL                                   /**< Mode RXSEARCH for RAC_STATUS                */
#define _RAC_STATUS_STATE_RXFRAME                                         0x00000003UL                                   /**< Mode RXFRAME for RAC_STATUS                 */
#define _RAC_STATUS_STATE_RXPD                                            0x00000004UL                                   /**< Mode RXPD for RAC_STATUS                    */
#define _RAC_STATUS_STATE_RX2RX                                           0x00000005UL                                   /**< Mode RX2RX for RAC_STATUS                   */
#define _RAC_STATUS_STATE_RXOVERFLOW                                      0x00000006UL                                   /**< Mode RXOVERFLOW for RAC_STATUS              */
#define _RAC_STATUS_STATE_RX2TX                                           0x00000007UL                                   /**< Mode RX2TX for RAC_STATUS                   */
#define _RAC_STATUS_STATE_TXWARM                                          0x00000008UL                                   /**< Mode TXWARM for RAC_STATUS                  */
#define _RAC_STATUS_STATE_TX                                              0x00000009UL                                   /**< Mode TX for RAC_STATUS                      */
#define _RAC_STATUS_STATE_TXPD                                            0x0000000AUL                                   /**< Mode TXPD for RAC_STATUS                    */
#define _RAC_STATUS_STATE_TX2RX                                           0x0000000BUL                                   /**< Mode TX2RX for RAC_STATUS                   */
#define _RAC_STATUS_STATE_TX2TX                                           0x0000000CUL                                   /**< Mode TX2TX for RAC_STATUS                   */
#define _RAC_STATUS_STATE_SHUTDOWN                                        0x0000000DUL                                   /**< Mode SHUTDOWN for RAC_STATUS                */
#define _RAC_STATUS_STATE_POR                                             0x0000000EUL                                   /**< Mode POR for RAC_STATUS                     */
#define RAC_STATUS_STATE_DEFAULT                                          (_RAC_STATUS_STATE_DEFAULT << 24)              /**< Shifted mode DEFAULT for RAC_STATUS         */
#define RAC_STATUS_STATE_OFF                                              (_RAC_STATUS_STATE_OFF << 24)                  /**< Shifted mode OFF for RAC_STATUS             */
#define RAC_STATUS_STATE_RXWARM                                           (_RAC_STATUS_STATE_RXWARM << 24)               /**< Shifted mode RXWARM for RAC_STATUS          */
#define RAC_STATUS_STATE_RXSEARCH                                         (_RAC_STATUS_STATE_RXSEARCH << 24)             /**< Shifted mode RXSEARCH for RAC_STATUS        */
#define RAC_STATUS_STATE_RXFRAME                                          (_RAC_STATUS_STATE_RXFRAME << 24)              /**< Shifted mode RXFRAME for RAC_STATUS         */
#define RAC_STATUS_STATE_RXPD                                             (_RAC_STATUS_STATE_RXPD << 24)                 /**< Shifted mode RXPD for RAC_STATUS            */
#define RAC_STATUS_STATE_RX2RX                                            (_RAC_STATUS_STATE_RX2RX << 24)                /**< Shifted mode RX2RX for RAC_STATUS           */
#define RAC_STATUS_STATE_RXOVERFLOW                                       (_RAC_STATUS_STATE_RXOVERFLOW << 24)           /**< Shifted mode RXOVERFLOW for RAC_STATUS      */
#define RAC_STATUS_STATE_RX2TX                                            (_RAC_STATUS_STATE_RX2TX << 24)                /**< Shifted mode RX2TX for RAC_STATUS           */
#define RAC_STATUS_STATE_TXWARM                                           (_RAC_STATUS_STATE_TXWARM << 24)               /**< Shifted mode TXWARM for RAC_STATUS          */
#define RAC_STATUS_STATE_TX                                               (_RAC_STATUS_STATE_TX << 24)                   /**< Shifted mode TX for RAC_STATUS              */
#define RAC_STATUS_STATE_TXPD                                             (_RAC_STATUS_STATE_TXPD << 24)                 /**< Shifted mode TXPD for RAC_STATUS            */
#define RAC_STATUS_STATE_TX2RX                                            (_RAC_STATUS_STATE_TX2RX << 24)                /**< Shifted mode TX2RX for RAC_STATUS           */
#define RAC_STATUS_STATE_TX2TX                                            (_RAC_STATUS_STATE_TX2TX << 24)                /**< Shifted mode TX2TX for RAC_STATUS           */
#define RAC_STATUS_STATE_SHUTDOWN                                         (_RAC_STATUS_STATE_SHUTDOWN << 24)             /**< Shifted mode SHUTDOWN for RAC_STATUS        */
#define RAC_STATUS_STATE_POR                                              (_RAC_STATUS_STATE_POR << 24)                  /**< Shifted mode POR for RAC_STATUS             */
#define RAC_STATUS_SEQACTIVE                                              (0x1UL << 28)                                  /**< SEQ active                                  */
#define _RAC_STATUS_SEQACTIVE_SHIFT                                       28                                             /**< Shift value for RAC_SEQACTIVE               */
#define _RAC_STATUS_SEQACTIVE_MASK                                        0x10000000UL                                   /**< Bit mask for RAC_SEQACTIVE                  */
#define _RAC_STATUS_SEQACTIVE_DEFAULT                                     0x00000000UL                                   /**< Mode DEFAULT for RAC_STATUS                 */
#define RAC_STATUS_SEQACTIVE_DEFAULT                                      (_RAC_STATUS_SEQACTIVE_DEFAULT << 28)          /**< Shifted mode DEFAULT for RAC_STATUS         */
#define RAC_STATUS_TXENS                                                  (0x1UL << 30)                                  /**< TXEN Status                                 */
#define _RAC_STATUS_TXENS_SHIFT                                           30                                             /**< Shift value for RAC_TXENS                   */
#define _RAC_STATUS_TXENS_MASK                                            0x40000000UL                                   /**< Bit mask for RAC_TXENS                      */
#define _RAC_STATUS_TXENS_DEFAULT                                         0x00000000UL                                   /**< Mode DEFAULT for RAC_STATUS                 */
#define _RAC_STATUS_TXENS_X0                                              0x00000000UL                                   /**< Mode X0 for RAC_STATUS                      */
#define _RAC_STATUS_TXENS_X1                                              0x00000001UL                                   /**< Mode X1 for RAC_STATUS                      */
#define RAC_STATUS_TXENS_DEFAULT                                          (_RAC_STATUS_TXENS_DEFAULT << 30)              /**< Shifted mode DEFAULT for RAC_STATUS         */
#define RAC_STATUS_TXENS_X0                                               (_RAC_STATUS_TXENS_X0 << 30)                   /**< Shifted mode X0 for RAC_STATUS              */
#define RAC_STATUS_TXENS_X1                                               (_RAC_STATUS_TXENS_X1 << 30)                   /**< Shifted mode X1 for RAC_STATUS              */
#define RAC_STATUS_RXENS                                                  (0x1UL << 31)                                  /**< RXEN Status                                 */
#define _RAC_STATUS_RXENS_SHIFT                                           31                                             /**< Shift value for RAC_RXENS                   */
#define _RAC_STATUS_RXENS_MASK                                            0x80000000UL                                   /**< Bit mask for RAC_RXENS                      */
#define _RAC_STATUS_RXENS_DEFAULT                                         0x00000000UL                                   /**< Mode DEFAULT for RAC_STATUS                 */
#define _RAC_STATUS_RXENS_X0                                              0x00000000UL                                   /**< Mode X0 for RAC_STATUS                      */
#define _RAC_STATUS_RXENS_X1                                              0x00000001UL                                   /**< Mode X1 for RAC_STATUS                      */
#define RAC_STATUS_RXENS_DEFAULT                                          (_RAC_STATUS_RXENS_DEFAULT << 31)              /**< Shifted mode DEFAULT for RAC_STATUS         */
#define RAC_STATUS_RXENS_X0                                               (_RAC_STATUS_RXENS_X0 << 31)                   /**< Shifted mode X0 for RAC_STATUS              */
#define RAC_STATUS_RXENS_X1                                               (_RAC_STATUS_RXENS_X1 << 31)                   /**< Shifted mode X1 for RAC_STATUS              */

/* Bit fields for RAC CMD */
#define _RAC_CMD_RESETVALUE                                               0x00000000UL                            /**< Default value for RAC_CMD                   */
#define _RAC_CMD_MASK                                                     0xC000FDFFUL                            /**< Mask for RAC_CMD                            */
#define RAC_CMD_TXEN                                                      (0x1UL << 0)                            /**< Transmitter Enable                          */
#define _RAC_CMD_TXEN_SHIFT                                               0                                       /**< Shift value for RAC_TXEN                    */
#define _RAC_CMD_TXEN_MASK                                                0x1UL                                   /**< Bit mask for RAC_TXEN                       */
#define _RAC_CMD_TXEN_DEFAULT                                             0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_TXEN_DEFAULT                                              (_RAC_CMD_TXEN_DEFAULT << 0)            /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_FORCETX                                                   (0x1UL << 1)                            /**< Force TX Command                            */
#define _RAC_CMD_FORCETX_SHIFT                                            1                                       /**< Shift value for RAC_FORCETX                 */
#define _RAC_CMD_FORCETX_MASK                                             0x2UL                                   /**< Bit mask for RAC_FORCETX                    */
#define _RAC_CMD_FORCETX_DEFAULT                                          0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_FORCETX_DEFAULT                                           (_RAC_CMD_FORCETX_DEFAULT << 1)         /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_TXONCCA                                                   (0x1UL << 2)                            /**< Transmit On CCA                             */
#define _RAC_CMD_TXONCCA_SHIFT                                            2                                       /**< Shift value for RAC_TXONCCA                 */
#define _RAC_CMD_TXONCCA_MASK                                             0x4UL                                   /**< Bit mask for RAC_TXONCCA                    */
#define _RAC_CMD_TXONCCA_DEFAULT                                          0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_TXONCCA_DEFAULT                                           (_RAC_CMD_TXONCCA_DEFAULT << 2)         /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_CLEARTXEN                                                 (0x1UL << 3)                            /**< Clear TX Enable                             */
#define _RAC_CMD_CLEARTXEN_SHIFT                                          3                                       /**< Shift value for RAC_CLEARTXEN               */
#define _RAC_CMD_CLEARTXEN_MASK                                           0x8UL                                   /**< Bit mask for RAC_CLEARTXEN                  */
#define _RAC_CMD_CLEARTXEN_DEFAULT                                        0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_CLEARTXEN_DEFAULT                                         (_RAC_CMD_CLEARTXEN_DEFAULT << 3)       /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_TXAFTERFRAME                                              (0x1UL << 4)                            /**< TX After Frame                              */
#define _RAC_CMD_TXAFTERFRAME_SHIFT                                       4                                       /**< Shift value for RAC_TXAFTERFRAME            */
#define _RAC_CMD_TXAFTERFRAME_MASK                                        0x10UL                                  /**< Bit mask for RAC_TXAFTERFRAME               */
#define _RAC_CMD_TXAFTERFRAME_DEFAULT                                     0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_TXAFTERFRAME_DEFAULT                                      (_RAC_CMD_TXAFTERFRAME_DEFAULT << 4)    /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_TXDIS                                                     (0x1UL << 5)                            /**< TX Disable                                  */
#define _RAC_CMD_TXDIS_SHIFT                                              5                                       /**< Shift value for RAC_TXDIS                   */
#define _RAC_CMD_TXDIS_MASK                                               0x20UL                                  /**< Bit mask for RAC_TXDIS                      */
#define _RAC_CMD_TXDIS_DEFAULT                                            0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_TXDIS_DEFAULT                                             (_RAC_CMD_TXDIS_DEFAULT << 5)           /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_CLEARRXOVERFLOW                                           (0x1UL << 6)                            /**< Clear RX Overflow                           */
#define _RAC_CMD_CLEARRXOVERFLOW_SHIFT                                    6                                       /**< Shift value for RAC_CLEARRXOVERFLOW         */
#define _RAC_CMD_CLEARRXOVERFLOW_MASK                                     0x40UL                                  /**< Bit mask for RAC_CLEARRXOVERFLOW            */
#define _RAC_CMD_CLEARRXOVERFLOW_DEFAULT                                  0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_CLEARRXOVERFLOW_DEFAULT                                   (_RAC_CMD_CLEARRXOVERFLOW_DEFAULT << 6) /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_RXCAL                                                     (0x1UL << 7)                            /**< Start an RX Calibration                     */
#define _RAC_CMD_RXCAL_SHIFT                                              7                                       /**< Shift value for RAC_RXCAL                   */
#define _RAC_CMD_RXCAL_MASK                                               0x80UL                                  /**< Bit mask for RAC_RXCAL                      */
#define _RAC_CMD_RXCAL_DEFAULT                                            0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_RXCAL_DEFAULT                                             (_RAC_CMD_RXCAL_DEFAULT << 7)           /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_RXDIS                                                     (0x1UL << 8)                            /**< RX Disable                                  */
#define _RAC_CMD_RXDIS_SHIFT                                              8                                       /**< Shift value for RAC_RXDIS                   */
#define _RAC_CMD_RXDIS_MASK                                               0x100UL                                 /**< Bit mask for RAC_RXDIS                      */
#define _RAC_CMD_RXDIS_DEFAULT                                            0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_RXDIS_DEFAULT                                             (_RAC_CMD_RXDIS_DEFAULT << 8)           /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_FRCWR                                                     (0x1UL << 10)                           /**< FRC write cmd                               */
#define _RAC_CMD_FRCWR_SHIFT                                              10                                      /**< Shift value for RAC_FRCWR                   */
#define _RAC_CMD_FRCWR_MASK                                               0x400UL                                 /**< Bit mask for RAC_FRCWR                      */
#define _RAC_CMD_FRCWR_DEFAULT                                            0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_FRCWR_DEFAULT                                             (_RAC_CMD_FRCWR_DEFAULT << 10)          /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_FRCRD                                                     (0x1UL << 11)                           /**< FRC read cmd                                */
#define _RAC_CMD_FRCRD_SHIFT                                              11                                      /**< Shift value for RAC_FRCRD                   */
#define _RAC_CMD_FRCRD_MASK                                               0x800UL                                 /**< Bit mask for RAC_FRCRD                      */
#define _RAC_CMD_FRCRD_DEFAULT                                            0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_FRCRD_DEFAULT                                             (_RAC_CMD_FRCRD_DEFAULT << 11)          /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_PAENSET                                                   (0x1UL << 12)                           /**< PAEN Set                                    */
#define _RAC_CMD_PAENSET_SHIFT                                            12                                      /**< Shift value for RAC_PAENSET                 */
#define _RAC_CMD_PAENSET_MASK                                             0x1000UL                                /**< Bit mask for RAC_PAENSET                    */
#define _RAC_CMD_PAENSET_DEFAULT                                          0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_PAENSET_DEFAULT                                           (_RAC_CMD_PAENSET_DEFAULT << 12)        /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_PAENCLEAR                                                 (0x1UL << 13)                           /**< PAEN Clear                                  */
#define _RAC_CMD_PAENCLEAR_SHIFT                                          13                                      /**< Shift value for RAC_PAENCLEAR               */
#define _RAC_CMD_PAENCLEAR_MASK                                           0x2000UL                                /**< Bit mask for RAC_PAENCLEAR                  */
#define _RAC_CMD_PAENCLEAR_DEFAULT                                        0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_PAENCLEAR_DEFAULT                                         (_RAC_CMD_PAENCLEAR_DEFAULT << 13)      /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_LNAENSET                                                  (0x1UL << 14)                           /**< LNAEN Set                                   */
#define _RAC_CMD_LNAENSET_SHIFT                                           14                                      /**< Shift value for RAC_LNAENSET                */
#define _RAC_CMD_LNAENSET_MASK                                            0x4000UL                                /**< Bit mask for RAC_LNAENSET                   */
#define _RAC_CMD_LNAENSET_DEFAULT                                         0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_LNAENSET_DEFAULT                                          (_RAC_CMD_LNAENSET_DEFAULT << 14)       /**< Shifted mode DEFAULT for RAC_CMD            */
#define RAC_CMD_LNAENCLEAR                                                (0x1UL << 15)                           /**< LNAEN Clear                                 */
#define _RAC_CMD_LNAENCLEAR_SHIFT                                         15                                      /**< Shift value for RAC_LNAENCLEAR              */
#define _RAC_CMD_LNAENCLEAR_MASK                                          0x8000UL                                /**< Bit mask for RAC_LNAENCLEAR                 */
#define _RAC_CMD_LNAENCLEAR_DEFAULT                                       0x00000000UL                            /**< Mode DEFAULT for RAC_CMD                    */
#define RAC_CMD_LNAENCLEAR_DEFAULT                                        (_RAC_CMD_LNAENCLEAR_DEFAULT << 15)     /**< Shifted mode DEFAULT for RAC_CMD            */

/* Bit fields for RAC CTRL */
#define _RAC_CTRL_RESETVALUE                                              0x00000000UL                              /**< Default value for RAC_CTRL                  */
#define _RAC_CTRL_MASK                                                    0x1F0107EFUL                              /**< Mask for RAC_CTRL                           */
#define RAC_CTRL_FORCEDISABLE                                             (0x1UL << 0)                              /**< Force Radio Disable                         */
#define _RAC_CTRL_FORCEDISABLE_SHIFT                                      0                                         /**< Shift value for RAC_FORCEDISABLE            */
#define _RAC_CTRL_FORCEDISABLE_MASK                                       0x1UL                                     /**< Bit mask for RAC_FORCEDISABLE               */
#define _RAC_CTRL_FORCEDISABLE_DEFAULT                                    0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define RAC_CTRL_FORCEDISABLE_DEFAULT                                     (_RAC_CTRL_FORCEDISABLE_DEFAULT << 0)     /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_PRSTXEN                                                  (0x1UL << 1)                              /**< PRS TX Enable                               */
#define _RAC_CTRL_PRSTXEN_SHIFT                                           1                                         /**< Shift value for RAC_PRSTXEN                 */
#define _RAC_CTRL_PRSTXEN_MASK                                            0x2UL                                     /**< Bit mask for RAC_PRSTXEN                    */
#define _RAC_CTRL_PRSTXEN_DEFAULT                                         0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define RAC_CTRL_PRSTXEN_DEFAULT                                          (_RAC_CTRL_PRSTXEN_DEFAULT << 1)          /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_TXAFTERRX                                                (0x1UL << 2)                              /**< TX After RX                                 */
#define _RAC_CTRL_TXAFTERRX_SHIFT                                         2                                         /**< Shift value for RAC_TXAFTERRX               */
#define _RAC_CTRL_TXAFTERRX_MASK                                          0x4UL                                     /**< Bit mask for RAC_TXAFTERRX                  */
#define _RAC_CTRL_TXAFTERRX_DEFAULT                                       0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define _RAC_CTRL_TXAFTERRX_X0                                            0x00000000UL                              /**< Mode X0 for RAC_CTRL                        */
#define _RAC_CTRL_TXAFTERRX_X1                                            0x00000001UL                              /**< Mode X1 for RAC_CTRL                        */
#define RAC_CTRL_TXAFTERRX_DEFAULT                                        (_RAC_CTRL_TXAFTERRX_DEFAULT << 2)        /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_TXAFTERRX_X0                                             (_RAC_CTRL_TXAFTERRX_X0 << 2)             /**< Shifted mode X0 for RAC_CTRL                */
#define RAC_CTRL_TXAFTERRX_X1                                             (_RAC_CTRL_TXAFTERRX_X1 << 2)             /**< Shifted mode X1 for RAC_CTRL                */
#define RAC_CTRL_PRSMODE                                                  (0x1UL << 3)                              /**< PRS RXEN Mode                               */
#define _RAC_CTRL_PRSMODE_SHIFT                                           3                                         /**< Shift value for RAC_PRSMODE                 */
#define _RAC_CTRL_PRSMODE_MASK                                            0x8UL                                     /**< Bit mask for RAC_PRSMODE                    */
#define _RAC_CTRL_PRSMODE_DEFAULT                                         0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define _RAC_CTRL_PRSMODE_DIRECT                                          0x00000000UL                              /**< Mode DIRECT for RAC_CTRL                    */
#define _RAC_CTRL_PRSMODE_PULSE                                           0x00000001UL                              /**< Mode PULSE for RAC_CTRL                     */
#define RAC_CTRL_PRSMODE_DEFAULT                                          (_RAC_CTRL_PRSMODE_DEFAULT << 3)          /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_PRSMODE_DIRECT                                           (_RAC_CTRL_PRSMODE_DIRECT << 3)           /**< Shifted mode DIRECT for RAC_CTRL            */
#define RAC_CTRL_PRSMODE_PULSE                                            (_RAC_CTRL_PRSMODE_PULSE << 3)            /**< Shifted mode PULSE for RAC_CTRL             */
#define RAC_CTRL_PRSCLR                                                   (0x1UL << 5)                              /**< PRS RXEN Clear                              */
#define _RAC_CTRL_PRSCLR_SHIFT                                            5                                         /**< Shift value for RAC_PRSCLR                  */
#define _RAC_CTRL_PRSCLR_MASK                                             0x20UL                                    /**< Bit mask for RAC_PRSCLR                     */
#define _RAC_CTRL_PRSCLR_DEFAULT                                          0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define _RAC_CTRL_PRSCLR_RXSEARCH                                         0x00000000UL                              /**< Mode RXSEARCH for RAC_CTRL                  */
#define _RAC_CTRL_PRSCLR_PRSCH                                            0x00000001UL                              /**< Mode PRSCH for RAC_CTRL                     */
#define RAC_CTRL_PRSCLR_DEFAULT                                           (_RAC_CTRL_PRSCLR_DEFAULT << 5)           /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_PRSCLR_RXSEARCH                                          (_RAC_CTRL_PRSCLR_RXSEARCH << 5)          /**< Shifted mode RXSEARCH for RAC_CTRL          */
#define RAC_CTRL_PRSCLR_PRSCH                                             (_RAC_CTRL_PRSCLR_PRSCH << 5)             /**< Shifted mode PRSCH for RAC_CTRL             */
#define RAC_CTRL_TXPOSTPONE                                               (0x1UL << 6)                              /**< TX Postpone                                 */
#define _RAC_CTRL_TXPOSTPONE_SHIFT                                        6                                         /**< Shift value for RAC_TXPOSTPONE              */
#define _RAC_CTRL_TXPOSTPONE_MASK                                         0x40UL                                    /**< Bit mask for RAC_TXPOSTPONE                 */
#define _RAC_CTRL_TXPOSTPONE_DEFAULT                                      0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define _RAC_CTRL_TXPOSTPONE_X0                                           0x00000000UL                              /**< Mode X0 for RAC_CTRL                        */
#define _RAC_CTRL_TXPOSTPONE_X1                                           0x00000001UL                              /**< Mode X1 for RAC_CTRL                        */
#define RAC_CTRL_TXPOSTPONE_DEFAULT                                       (_RAC_CTRL_TXPOSTPONE_DEFAULT << 6)       /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_TXPOSTPONE_X0                                            (_RAC_CTRL_TXPOSTPONE_X0 << 6)            /**< Shifted mode X0 for RAC_CTRL                */
#define RAC_CTRL_TXPOSTPONE_X1                                            (_RAC_CTRL_TXPOSTPONE_X1 << 6)            /**< Shifted mode X1 for RAC_CTRL                */
#define RAC_CTRL_ACTIVEPOL                                                (0x1UL << 7)                              /**< ACTIVE signal polarity                      */
#define _RAC_CTRL_ACTIVEPOL_SHIFT                                         7                                         /**< Shift value for RAC_ACTIVEPOL               */
#define _RAC_CTRL_ACTIVEPOL_MASK                                          0x80UL                                    /**< Bit mask for RAC_ACTIVEPOL                  */
#define _RAC_CTRL_ACTIVEPOL_DEFAULT                                       0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define _RAC_CTRL_ACTIVEPOL_X0                                            0x00000000UL                              /**< Mode X0 for RAC_CTRL                        */
#define _RAC_CTRL_ACTIVEPOL_X1                                            0x00000001UL                              /**< Mode X1 for RAC_CTRL                        */
#define RAC_CTRL_ACTIVEPOL_DEFAULT                                        (_RAC_CTRL_ACTIVEPOL_DEFAULT << 7)        /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_ACTIVEPOL_X0                                             (_RAC_CTRL_ACTIVEPOL_X0 << 7)             /**< Shifted mode X0 for RAC_CTRL                */
#define RAC_CTRL_ACTIVEPOL_X1                                             (_RAC_CTRL_ACTIVEPOL_X1 << 7)             /**< Shifted mode X1 for RAC_CTRL                */
#define RAC_CTRL_PAENPOL                                                  (0x1UL << 8)                              /**< PAEN signal polarity                        */
#define _RAC_CTRL_PAENPOL_SHIFT                                           8                                         /**< Shift value for RAC_PAENPOL                 */
#define _RAC_CTRL_PAENPOL_MASK                                            0x100UL                                   /**< Bit mask for RAC_PAENPOL                    */
#define _RAC_CTRL_PAENPOL_DEFAULT                                         0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define _RAC_CTRL_PAENPOL_X0                                              0x00000000UL                              /**< Mode X0 for RAC_CTRL                        */
#define _RAC_CTRL_PAENPOL_X1                                              0x00000001UL                              /**< Mode X1 for RAC_CTRL                        */
#define RAC_CTRL_PAENPOL_DEFAULT                                          (_RAC_CTRL_PAENPOL_DEFAULT << 8)          /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_PAENPOL_X0                                               (_RAC_CTRL_PAENPOL_X0 << 8)               /**< Shifted mode X0 for RAC_CTRL                */
#define RAC_CTRL_PAENPOL_X1                                               (_RAC_CTRL_PAENPOL_X1 << 8)               /**< Shifted mode X1 for RAC_CTRL                */
#define RAC_CTRL_LNAENPOL                                                 (0x1UL << 9)                              /**< LNAEN signal polarity                       */
#define _RAC_CTRL_LNAENPOL_SHIFT                                          9                                         /**< Shift value for RAC_LNAENPOL                */
#define _RAC_CTRL_LNAENPOL_MASK                                           0x200UL                                   /**< Bit mask for RAC_LNAENPOL                   */
#define _RAC_CTRL_LNAENPOL_DEFAULT                                        0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define _RAC_CTRL_LNAENPOL_X0                                             0x00000000UL                              /**< Mode X0 for RAC_CTRL                        */
#define _RAC_CTRL_LNAENPOL_X1                                             0x00000001UL                              /**< Mode X1 for RAC_CTRL                        */
#define RAC_CTRL_LNAENPOL_DEFAULT                                         (_RAC_CTRL_LNAENPOL_DEFAULT << 9)         /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_LNAENPOL_X0                                              (_RAC_CTRL_LNAENPOL_X0 << 9)              /**< Shifted mode X0 for RAC_CTRL                */
#define RAC_CTRL_LNAENPOL_X1                                              (_RAC_CTRL_LNAENPOL_X1 << 9)              /**< Shifted mode X1 for RAC_CTRL                */
#define RAC_CTRL_PRSRXDIS                                                 (0x1UL << 10)                             /**< PRS RX Disable                              */
#define _RAC_CTRL_PRSRXDIS_SHIFT                                          10                                        /**< Shift value for RAC_PRSRXDIS                */
#define _RAC_CTRL_PRSRXDIS_MASK                                           0x400UL                                   /**< Bit mask for RAC_PRSRXDIS                   */
#define _RAC_CTRL_PRSRXDIS_DEFAULT                                        0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define _RAC_CTRL_PRSRXDIS_X0                                             0x00000000UL                              /**< Mode X0 for RAC_CTRL                        */
#define _RAC_CTRL_PRSRXDIS_X1                                             0x00000001UL                              /**< Mode X1 for RAC_CTRL                        */
#define RAC_CTRL_PRSRXDIS_DEFAULT                                         (_RAC_CTRL_PRSRXDIS_DEFAULT << 10)        /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_PRSRXDIS_X0                                              (_RAC_CTRL_PRSRXDIS_X0 << 10)             /**< Shifted mode X0 for RAC_CTRL                */
#define RAC_CTRL_PRSRXDIS_X1                                              (_RAC_CTRL_PRSRXDIS_X1 << 10)             /**< Shifted mode X1 for RAC_CTRL                */
#define RAC_CTRL_PRSFORCETX                                               (0x1UL << 16)                             /**< PRS Force RX                                */
#define _RAC_CTRL_PRSFORCETX_SHIFT                                        16                                        /**< Shift value for RAC_PRSFORCETX              */
#define _RAC_CTRL_PRSFORCETX_MASK                                         0x10000UL                                 /**< Bit mask for RAC_PRSFORCETX                 */
#define _RAC_CTRL_PRSFORCETX_DEFAULT                                      0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define _RAC_CTRL_PRSFORCETX_X0                                           0x00000000UL                              /**< Mode X0 for RAC_CTRL                        */
#define _RAC_CTRL_PRSFORCETX_X1                                           0x00000001UL                              /**< Mode X1 for RAC_CTRL                        */
#define RAC_CTRL_PRSFORCETX_DEFAULT                                       (_RAC_CTRL_PRSFORCETX_DEFAULT << 16)      /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_PRSFORCETX_X0                                            (_RAC_CTRL_PRSFORCETX_X0 << 16)           /**< Shifted mode X0 for RAC_CTRL                */
#define RAC_CTRL_PRSFORCETX_X1                                            (_RAC_CTRL_PRSFORCETX_X1 << 16)           /**< Shifted mode X1 for RAC_CTRL                */
#define RAC_CTRL_SEQRESET                                                 (0x1UL << 24)                             /**< SEQ reset                                   */
#define _RAC_CTRL_SEQRESET_SHIFT                                          24                                        /**< Shift value for RAC_SEQRESET                */
#define _RAC_CTRL_SEQRESET_MASK                                           0x1000000UL                               /**< Bit mask for RAC_SEQRESET                   */
#define _RAC_CTRL_SEQRESET_DEFAULT                                        0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define RAC_CTRL_SEQRESET_DEFAULT                                         (_RAC_CTRL_SEQRESET_DEFAULT << 24)        /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_EXITSHUTDOWNDIS                                          (0x1UL << 25)                             /**< Exit SHUTDOWN state Disable                 */
#define _RAC_CTRL_EXITSHUTDOWNDIS_SHIFT                                   25                                        /**< Shift value for RAC_EXITSHUTDOWNDIS         */
#define _RAC_CTRL_EXITSHUTDOWNDIS_MASK                                    0x2000000UL                               /**< Bit mask for RAC_EXITSHUTDOWNDIS            */
#define _RAC_CTRL_EXITSHUTDOWNDIS_DEFAULT                                 0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define RAC_CTRL_EXITSHUTDOWNDIS_DEFAULT                                  (_RAC_CTRL_EXITSHUTDOWNDIS_DEFAULT << 25) /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_CPUWAITDIS                                               (0x1UL << 26)                             /**< SEQ CPU Wait Disable                        */
#define _RAC_CTRL_CPUWAITDIS_SHIFT                                        26                                        /**< Shift value for RAC_CPUWAITDIS              */
#define _RAC_CTRL_CPUWAITDIS_MASK                                         0x4000000UL                               /**< Bit mask for RAC_CPUWAITDIS                 */
#define _RAC_CTRL_CPUWAITDIS_DEFAULT                                      0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define RAC_CTRL_CPUWAITDIS_DEFAULT                                       (_RAC_CTRL_CPUWAITDIS_DEFAULT << 26)      /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_SEQCLKDIS                                                (0x1UL << 27)                             /**< SEQ Clk Disable                             */
#define _RAC_CTRL_SEQCLKDIS_SHIFT                                         27                                        /**< Shift value for RAC_SEQCLKDIS               */
#define _RAC_CTRL_SEQCLKDIS_MASK                                          0x8000000UL                               /**< Bit mask for RAC_SEQCLKDIS                  */
#define _RAC_CTRL_SEQCLKDIS_DEFAULT                                       0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define RAC_CTRL_SEQCLKDIS_DEFAULT                                        (_RAC_CTRL_SEQCLKDIS_DEFAULT << 27)       /**< Shifted mode DEFAULT for RAC_CTRL           */
#define RAC_CTRL_RXOFDIS                                                  (0x1UL << 28)                             /**< Switch to RXOVERFLOW Disable                */
#define _RAC_CTRL_RXOFDIS_SHIFT                                           28                                        /**< Shift value for RAC_RXOFDIS                 */
#define _RAC_CTRL_RXOFDIS_MASK                                            0x10000000UL                              /**< Bit mask for RAC_RXOFDIS                    */
#define _RAC_CTRL_RXOFDIS_DEFAULT                                         0x00000000UL                              /**< Mode DEFAULT for RAC_CTRL                   */
#define RAC_CTRL_RXOFDIS_DEFAULT                                          (_RAC_CTRL_RXOFDIS_DEFAULT << 28)         /**< Shifted mode DEFAULT for RAC_CTRL           */

/* Bit fields for RAC FORCESTATE */
#define _RAC_FORCESTATE_RESETVALUE                                        0x00000000UL                              /**< Default value for RAC_FORCESTATE            */
#define _RAC_FORCESTATE_MASK                                              0x0000000FUL                              /**< Mask for RAC_FORCESTATE                     */
#define _RAC_FORCESTATE_FORCESTATE_SHIFT                                  0                                         /**< Shift value for RAC_FORCESTATE              */
#define _RAC_FORCESTATE_FORCESTATE_MASK                                   0xFUL                                     /**< Bit mask for RAC_FORCESTATE                 */
#define _RAC_FORCESTATE_FORCESTATE_DEFAULT                                0x00000000UL                              /**< Mode DEFAULT for RAC_FORCESTATE             */
#define RAC_FORCESTATE_FORCESTATE_DEFAULT                                 (_RAC_FORCESTATE_FORCESTATE_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_FORCESTATE     */

/* Bit fields for RAC IF */
#define _RAC_IF_RESETVALUE                                                0x00000000UL                       /**< Default value for RAC_IF                    */
#define _RAC_IF_MASK                                                      0x00FF000FUL                       /**< Mask for RAC_IF                             */
#define RAC_IF_STATECHANGE                                                (0x1UL << 0)                       /**< Radio State Change                          */
#define _RAC_IF_STATECHANGE_SHIFT                                         0                                  /**< Shift value for RAC_STATECHANGE             */
#define _RAC_IF_STATECHANGE_MASK                                          0x1UL                              /**< Bit mask for RAC_STATECHANGE                */
#define _RAC_IF_STATECHANGE_DEFAULT                                       0x00000000UL                       /**< Mode DEFAULT for RAC_IF                     */
#define RAC_IF_STATECHANGE_DEFAULT                                        (_RAC_IF_STATECHANGE_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_IF             */
#define RAC_IF_STIMCMPEV                                                  (0x1UL << 1)                       /**< STIMER Compare Event                        */
#define _RAC_IF_STIMCMPEV_SHIFT                                           1                                  /**< Shift value for RAC_STIMCMPEV               */
#define _RAC_IF_STIMCMPEV_MASK                                            0x2UL                              /**< Bit mask for RAC_STIMCMPEV                  */
#define _RAC_IF_STIMCMPEV_DEFAULT                                         0x00000000UL                       /**< Mode DEFAULT for RAC_IF                     */
#define RAC_IF_STIMCMPEV_DEFAULT                                          (_RAC_IF_STIMCMPEV_DEFAULT << 1)   /**< Shifted mode DEFAULT for RAC_IF             */
#define RAC_IF_SEQLOCKUP                                                  (0x1UL << 2)                       /**< SEQ locked up                               */
#define _RAC_IF_SEQLOCKUP_SHIFT                                           2                                  /**< Shift value for RAC_SEQLOCKUP               */
#define _RAC_IF_SEQLOCKUP_MASK                                            0x4UL                              /**< Bit mask for RAC_SEQLOCKUP                  */
#define _RAC_IF_SEQLOCKUP_DEFAULT                                         0x00000000UL                       /**< Mode DEFAULT for RAC_IF                     */
#define RAC_IF_SEQLOCKUP_DEFAULT                                          (_RAC_IF_SEQLOCKUP_DEFAULT << 2)   /**< Shifted mode DEFAULT for RAC_IF             */
#define RAC_IF_SEQRESETREQ                                                (0x1UL << 3)                       /**< SEQ reset request                           */
#define _RAC_IF_SEQRESETREQ_SHIFT                                         3                                  /**< Shift value for RAC_SEQRESETREQ             */
#define _RAC_IF_SEQRESETREQ_MASK                                          0x8UL                              /**< Bit mask for RAC_SEQRESETREQ                */
#define _RAC_IF_SEQRESETREQ_DEFAULT                                       0x00000000UL                       /**< Mode DEFAULT for RAC_IF                     */
#define RAC_IF_SEQRESETREQ_DEFAULT                                        (_RAC_IF_SEQRESETREQ_DEFAULT << 3) /**< Shifted mode DEFAULT for RAC_IF             */
#define _RAC_IF_SEQ_SHIFT                                                 16                                 /**< Shift value for RAC_SEQ                     */
#define _RAC_IF_SEQ_MASK                                                  0xFF0000UL                         /**< Bit mask for RAC_SEQ                        */
#define _RAC_IF_SEQ_DEFAULT                                               0x00000000UL                       /**< Mode DEFAULT for RAC_IF                     */
#define RAC_IF_SEQ_DEFAULT                                                (_RAC_IF_SEQ_DEFAULT << 16)        /**< Shifted mode DEFAULT for RAC_IF             */

/* Bit fields for RAC IEN */
#define _RAC_IEN_RESETVALUE                                               0x00000000UL                        /**< Default value for RAC_IEN                   */
#define _RAC_IEN_MASK                                                     0x00FF000FUL                        /**< Mask for RAC_IEN                            */
#define RAC_IEN_STATECHANGE                                               (0x1UL << 0)                        /**< Radio State Change Interrupt Enable         */
#define _RAC_IEN_STATECHANGE_SHIFT                                        0                                   /**< Shift value for RAC_STATECHANGE             */
#define _RAC_IEN_STATECHANGE_MASK                                         0x1UL                               /**< Bit mask for RAC_STATECHANGE                */
#define _RAC_IEN_STATECHANGE_DEFAULT                                      0x00000000UL                        /**< Mode DEFAULT for RAC_IEN                    */
#define RAC_IEN_STATECHANGE_DEFAULT                                       (_RAC_IEN_STATECHANGE_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_IEN            */
#define RAC_IEN_STIMCMPEV                                                 (0x1UL << 1)                        /**< STIMER Compare Event Interrupt Enable       */
#define _RAC_IEN_STIMCMPEV_SHIFT                                          1                                   /**< Shift value for RAC_STIMCMPEV               */
#define _RAC_IEN_STIMCMPEV_MASK                                           0x2UL                               /**< Bit mask for RAC_STIMCMPEV                  */
#define _RAC_IEN_STIMCMPEV_DEFAULT                                        0x00000000UL                        /**< Mode DEFAULT for RAC_IEN                    */
#define RAC_IEN_STIMCMPEV_DEFAULT                                         (_RAC_IEN_STIMCMPEV_DEFAULT << 1)   /**< Shifted mode DEFAULT for RAC_IEN            */
#define RAC_IEN_SEQLOCKUP                                                 (0x1UL << 2)                        /**< SEQ locked up Interrupt Enable              */
#define _RAC_IEN_SEQLOCKUP_SHIFT                                          2                                   /**< Shift value for RAC_SEQLOCKUP               */
#define _RAC_IEN_SEQLOCKUP_MASK                                           0x4UL                               /**< Bit mask for RAC_SEQLOCKUP                  */
#define _RAC_IEN_SEQLOCKUP_DEFAULT                                        0x00000000UL                        /**< Mode DEFAULT for RAC_IEN                    */
#define RAC_IEN_SEQLOCKUP_DEFAULT                                         (_RAC_IEN_SEQLOCKUP_DEFAULT << 2)   /**< Shifted mode DEFAULT for RAC_IEN            */
#define RAC_IEN_SEQRESETREQ                                               (0x1UL << 3)                        /**< SEQ reset request Interrupt Enable          */
#define _RAC_IEN_SEQRESETREQ_SHIFT                                        3                                   /**< Shift value for RAC_SEQRESETREQ             */
#define _RAC_IEN_SEQRESETREQ_MASK                                         0x8UL                               /**< Bit mask for RAC_SEQRESETREQ                */
#define _RAC_IEN_SEQRESETREQ_DEFAULT                                      0x00000000UL                        /**< Mode DEFAULT for RAC_IEN                    */
#define RAC_IEN_SEQRESETREQ_DEFAULT                                       (_RAC_IEN_SEQRESETREQ_DEFAULT << 3) /**< Shifted mode DEFAULT for RAC_IEN            */
#define _RAC_IEN_SEQ_SHIFT                                                16                                  /**< Shift value for RAC_SEQ                     */
#define _RAC_IEN_SEQ_MASK                                                 0xFF0000UL                          /**< Bit mask for RAC_SEQ                        */
#define _RAC_IEN_SEQ_DEFAULT                                              0x00000000UL                        /**< Mode DEFAULT for RAC_IEN                    */
#define RAC_IEN_SEQ_DEFAULT                                               (_RAC_IEN_SEQ_DEFAULT << 16)        /**< Shifted mode DEFAULT for RAC_IEN            */

/* Bit fields for RAC TESTCTRL */
#define _RAC_TESTCTRL_RESETVALUE                                          0x00000000UL                         /**< Default value for RAC_TESTCTRL              */
#define _RAC_TESTCTRL_MASK                                                0x00000003UL                         /**< Mask for RAC_TESTCTRL                       */
#define RAC_TESTCTRL_MODEN                                                (0x1UL << 0)                         /**< Modulator enable                            */
#define _RAC_TESTCTRL_MODEN_SHIFT                                         0                                    /**< Shift value for RAC_MODEN                   */
#define _RAC_TESTCTRL_MODEN_MASK                                          0x1UL                                /**< Bit mask for RAC_MODEN                      */
#define _RAC_TESTCTRL_MODEN_DEFAULT                                       0x00000000UL                         /**< Mode DEFAULT for RAC_TESTCTRL               */
#define RAC_TESTCTRL_MODEN_DEFAULT                                        (_RAC_TESTCTRL_MODEN_DEFAULT << 0)   /**< Shifted mode DEFAULT for RAC_TESTCTRL       */
#define RAC_TESTCTRL_DEMODEN                                              (0x1UL << 1)                         /**< Demodulator enable                          */
#define _RAC_TESTCTRL_DEMODEN_SHIFT                                       1                                    /**< Shift value for RAC_DEMODEN                 */
#define _RAC_TESTCTRL_DEMODEN_MASK                                        0x2UL                                /**< Bit mask for RAC_DEMODEN                    */
#define _RAC_TESTCTRL_DEMODEN_DEFAULT                                     0x00000000UL                         /**< Mode DEFAULT for RAC_TESTCTRL               */
#define RAC_TESTCTRL_DEMODEN_DEFAULT                                      (_RAC_TESTCTRL_DEMODEN_DEFAULT << 1) /**< Shifted mode DEFAULT for RAC_TESTCTRL       */

/* Bit fields for RAC SEQIF */
#define _RAC_SEQIF_RESETVALUE                                             0x00000000UL                               /**< Default value for RAC_SEQIF                 */
#define _RAC_SEQIF_MASK                                                   0xBFFF000FUL                               /**< Mask for RAC_SEQIF                          */
#define RAC_SEQIF_STATECHANGESEQ                                          (0x1UL << 0)                               /**< Radio State Change                          */
#define _RAC_SEQIF_STATECHANGESEQ_SHIFT                                   0                                          /**< Shift value for RAC_STATECHANGESEQ          */
#define _RAC_SEQIF_STATECHANGESEQ_MASK                                    0x1UL                                      /**< Bit mask for RAC_STATECHANGESEQ             */
#define _RAC_SEQIF_STATECHANGESEQ_DEFAULT                                 0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATECHANGESEQ_DEFAULT                                  (_RAC_SEQIF_STATECHANGESEQ_DEFAULT << 0)   /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STIMCMPEVSEQ                                            (0x1UL << 1)                               /**< STIMER Compare Event                        */
#define _RAC_SEQIF_STIMCMPEVSEQ_SHIFT                                     1                                          /**< Shift value for RAC_STIMCMPEVSEQ            */
#define _RAC_SEQIF_STIMCMPEVSEQ_MASK                                      0x2UL                                      /**< Bit mask for RAC_STIMCMPEVSEQ               */
#define _RAC_SEQIF_STIMCMPEVSEQ_DEFAULT                                   0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STIMCMPEVSEQ_DEFAULT                                    (_RAC_SEQIF_STIMCMPEVSEQ_DEFAULT << 1)     /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_DEMODRXREQCLRSEQ                                        (0x1UL << 2)                               /**< Demod RX request clear                      */
#define _RAC_SEQIF_DEMODRXREQCLRSEQ_SHIFT                                 2                                          /**< Shift value for RAC_DEMODRXREQCLRSEQ        */
#define _RAC_SEQIF_DEMODRXREQCLRSEQ_MASK                                  0x4UL                                      /**< Bit mask for RAC_DEMODRXREQCLRSEQ           */
#define _RAC_SEQIF_DEMODRXREQCLRSEQ_DEFAULT                               0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_DEMODRXREQCLRSEQ_DEFAULT                                (_RAC_SEQIF_DEMODRXREQCLRSEQ_DEFAULT << 2) /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_PRSEVENTSEQ                                             (0x1UL << 3)                               /**< SEQ PRS Event                               */
#define _RAC_SEQIF_PRSEVENTSEQ_SHIFT                                      3                                          /**< Shift value for RAC_PRSEVENTSEQ             */
#define _RAC_SEQIF_PRSEVENTSEQ_MASK                                       0x8UL                                      /**< Bit mask for RAC_PRSEVENTSEQ                */
#define _RAC_SEQIF_PRSEVENTSEQ_DEFAULT                                    0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_PRSEVENTSEQ_DEFAULT                                     (_RAC_SEQIF_PRSEVENTSEQ_DEFAULT << 3)      /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATEOFF                                                (0x1UL << 16)                              /**< entering STATE_OFF                          */
#define _RAC_SEQIF_STATEOFF_SHIFT                                         16                                         /**< Shift value for RAC_STATEOFF                */
#define _RAC_SEQIF_STATEOFF_MASK                                          0x10000UL                                  /**< Bit mask for RAC_STATEOFF                   */
#define _RAC_SEQIF_STATEOFF_DEFAULT                                       0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATEOFF_DEFAULT                                        (_RAC_SEQIF_STATEOFF_DEFAULT << 16)        /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATERXWARM                                             (0x1UL << 17)                              /**< entering STATE_RXWARM                       */
#define _RAC_SEQIF_STATERXWARM_SHIFT                                      17                                         /**< Shift value for RAC_STATERXWARM             */
#define _RAC_SEQIF_STATERXWARM_MASK                                       0x20000UL                                  /**< Bit mask for RAC_STATERXWARM                */
#define _RAC_SEQIF_STATERXWARM_DEFAULT                                    0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATERXWARM_DEFAULT                                     (_RAC_SEQIF_STATERXWARM_DEFAULT << 17)     /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATERXSEARCH                                           (0x1UL << 18)                              /**< entering STATE_RXSEARCH                     */
#define _RAC_SEQIF_STATERXSEARCH_SHIFT                                    18                                         /**< Shift value for RAC_STATERXSEARCH           */
#define _RAC_SEQIF_STATERXSEARCH_MASK                                     0x40000UL                                  /**< Bit mask for RAC_STATERXSEARCH              */
#define _RAC_SEQIF_STATERXSEARCH_DEFAULT                                  0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATERXSEARCH_DEFAULT                                   (_RAC_SEQIF_STATERXSEARCH_DEFAULT << 18)   /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATERXFRAME                                            (0x1UL << 19)                              /**< entering STATE_RXFRAME                      */
#define _RAC_SEQIF_STATERXFRAME_SHIFT                                     19                                         /**< Shift value for RAC_STATERXFRAME            */
#define _RAC_SEQIF_STATERXFRAME_MASK                                      0x80000UL                                  /**< Bit mask for RAC_STATERXFRAME               */
#define _RAC_SEQIF_STATERXFRAME_DEFAULT                                   0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATERXFRAME_DEFAULT                                    (_RAC_SEQIF_STATERXFRAME_DEFAULT << 19)    /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATERXPD                                               (0x1UL << 20)                              /**< entering STATE_RXPD                         */
#define _RAC_SEQIF_STATERXPD_SHIFT                                        20                                         /**< Shift value for RAC_STATERXPD               */
#define _RAC_SEQIF_STATERXPD_MASK                                         0x100000UL                                 /**< Bit mask for RAC_STATERXPD                  */
#define _RAC_SEQIF_STATERXPD_DEFAULT                                      0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATERXPD_DEFAULT                                       (_RAC_SEQIF_STATERXPD_DEFAULT << 20)       /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATERX2RX                                              (0x1UL << 21)                              /**< entering STATE_RX2RX                        */
#define _RAC_SEQIF_STATERX2RX_SHIFT                                       21                                         /**< Shift value for RAC_STATERX2RX              */
#define _RAC_SEQIF_STATERX2RX_MASK                                        0x200000UL                                 /**< Bit mask for RAC_STATERX2RX                 */
#define _RAC_SEQIF_STATERX2RX_DEFAULT                                     0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATERX2RX_DEFAULT                                      (_RAC_SEQIF_STATERX2RX_DEFAULT << 21)      /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATERXOVERFLOW                                         (0x1UL << 22)                              /**< entering STATE_RXOVERFLOW                   */
#define _RAC_SEQIF_STATERXOVERFLOW_SHIFT                                  22                                         /**< Shift value for RAC_STATERXOVERFLOW         */
#define _RAC_SEQIF_STATERXOVERFLOW_MASK                                   0x400000UL                                 /**< Bit mask for RAC_STATERXOVERFLOW            */
#define _RAC_SEQIF_STATERXOVERFLOW_DEFAULT                                0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATERXOVERFLOW_DEFAULT                                 (_RAC_SEQIF_STATERXOVERFLOW_DEFAULT << 22) /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATERX2TX                                              (0x1UL << 23)                              /**< entering STATE_RX2TX                        */
#define _RAC_SEQIF_STATERX2TX_SHIFT                                       23                                         /**< Shift value for RAC_STATERX2TX              */
#define _RAC_SEQIF_STATERX2TX_MASK                                        0x800000UL                                 /**< Bit mask for RAC_STATERX2TX                 */
#define _RAC_SEQIF_STATERX2TX_DEFAULT                                     0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATERX2TX_DEFAULT                                      (_RAC_SEQIF_STATERX2TX_DEFAULT << 23)      /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATETXWARM                                             (0x1UL << 24)                              /**< entering STATE_TXWARM                       */
#define _RAC_SEQIF_STATETXWARM_SHIFT                                      24                                         /**< Shift value for RAC_STATETXWARM             */
#define _RAC_SEQIF_STATETXWARM_MASK                                       0x1000000UL                                /**< Bit mask for RAC_STATETXWARM                */
#define _RAC_SEQIF_STATETXWARM_DEFAULT                                    0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATETXWARM_DEFAULT                                     (_RAC_SEQIF_STATETXWARM_DEFAULT << 24)     /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATETX                                                 (0x1UL << 25)                              /**< entering STATE_TX                           */
#define _RAC_SEQIF_STATETX_SHIFT                                          25                                         /**< Shift value for RAC_STATETX                 */
#define _RAC_SEQIF_STATETX_MASK                                           0x2000000UL                                /**< Bit mask for RAC_STATETX                    */
#define _RAC_SEQIF_STATETX_DEFAULT                                        0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATETX_DEFAULT                                         (_RAC_SEQIF_STATETX_DEFAULT << 25)         /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATETXPD                                               (0x1UL << 26)                              /**< entering STATE_TXPD                         */
#define _RAC_SEQIF_STATETXPD_SHIFT                                        26                                         /**< Shift value for RAC_STATETXPD               */
#define _RAC_SEQIF_STATETXPD_MASK                                         0x4000000UL                                /**< Bit mask for RAC_STATETXPD                  */
#define _RAC_SEQIF_STATETXPD_DEFAULT                                      0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATETXPD_DEFAULT                                       (_RAC_SEQIF_STATETXPD_DEFAULT << 26)       /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATETX2RX                                              (0x1UL << 27)                              /**< entering STATE_TX2RX                        */
#define _RAC_SEQIF_STATETX2RX_SHIFT                                       27                                         /**< Shift value for RAC_STATETX2RX              */
#define _RAC_SEQIF_STATETX2RX_MASK                                        0x8000000UL                                /**< Bit mask for RAC_STATETX2RX                 */
#define _RAC_SEQIF_STATETX2RX_DEFAULT                                     0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATETX2RX_DEFAULT                                      (_RAC_SEQIF_STATETX2RX_DEFAULT << 27)      /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATETX2TX                                              (0x1UL << 28)                              /**< entering STATE_TX2TX                        */
#define _RAC_SEQIF_STATETX2TX_SHIFT                                       28                                         /**< Shift value for RAC_STATETX2TX              */
#define _RAC_SEQIF_STATETX2TX_MASK                                        0x10000000UL                               /**< Bit mask for RAC_STATETX2TX                 */
#define _RAC_SEQIF_STATETX2TX_DEFAULT                                     0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATETX2TX_DEFAULT                                      (_RAC_SEQIF_STATETX2TX_DEFAULT << 28)      /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_STATESHUTDOWN                                           (0x1UL << 29)                              /**< entering STATE_SHUTDOWN                     */
#define _RAC_SEQIF_STATESHUTDOWN_SHIFT                                    29                                         /**< Shift value for RAC_STATESHUTDOWN           */
#define _RAC_SEQIF_STATESHUTDOWN_MASK                                     0x20000000UL                               /**< Bit mask for RAC_STATESHUTDOWN              */
#define _RAC_SEQIF_STATESHUTDOWN_DEFAULT                                  0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_STATESHUTDOWN_DEFAULT                                   (_RAC_SEQIF_STATESHUTDOWN_DEFAULT << 29)   /**< Shifted mode DEFAULT for RAC_SEQIF          */
#define RAC_SEQIF_RFTXPKD                                                 (0x1UL << 31)                              /**< TX Peak Det Counter Interrupt Flag          */
#define _RAC_SEQIF_RFTXPKD_SHIFT                                          31                                         /**< Shift value for RAC_RFTXPKD                 */
#define _RAC_SEQIF_RFTXPKD_MASK                                           0x80000000UL                               /**< Bit mask for RAC_RFTXPKD                    */
#define _RAC_SEQIF_RFTXPKD_DEFAULT                                        0x00000000UL                               /**< Mode DEFAULT for RAC_SEQIF                  */
#define RAC_SEQIF_RFTXPKD_DEFAULT                                         (_RAC_SEQIF_RFTXPKD_DEFAULT << 31)         /**< Shifted mode DEFAULT for RAC_SEQIF          */

/* Bit fields for RAC SEQIEN */
#define _RAC_SEQIEN_RESETVALUE                                            0x00000000UL                                /**< Default value for RAC_SEQIEN                */
#define _RAC_SEQIEN_MASK                                                  0xBFFF000FUL                                /**< Mask for RAC_SEQIEN                         */
#define RAC_SEQIEN_STATECHANGESEQ                                         (0x1UL << 0)                                /**< Radio State Change Interrupt Enable         */
#define _RAC_SEQIEN_STATECHANGESEQ_SHIFT                                  0                                           /**< Shift value for RAC_STATECHANGESEQ          */
#define _RAC_SEQIEN_STATECHANGESEQ_MASK                                   0x1UL                                       /**< Bit mask for RAC_STATECHANGESEQ             */
#define _RAC_SEQIEN_STATECHANGESEQ_DEFAULT                                0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATECHANGESEQ_DEFAULT                                 (_RAC_SEQIEN_STATECHANGESEQ_DEFAULT << 0)   /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STIMCMPEVSEQ                                           (0x1UL << 1)                                /**< STIMER Compare Event Interrupt Enable       */
#define _RAC_SEQIEN_STIMCMPEVSEQ_SHIFT                                    1                                           /**< Shift value for RAC_STIMCMPEVSEQ            */
#define _RAC_SEQIEN_STIMCMPEVSEQ_MASK                                     0x2UL                                       /**< Bit mask for RAC_STIMCMPEVSEQ               */
#define _RAC_SEQIEN_STIMCMPEVSEQ_DEFAULT                                  0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STIMCMPEVSEQ_DEFAULT                                   (_RAC_SEQIEN_STIMCMPEVSEQ_DEFAULT << 1)     /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_DEMODRXREQCLRSEQ                                       (0x1UL << 2)                                /**< Demod RX req clr Interrupt Enable           */
#define _RAC_SEQIEN_DEMODRXREQCLRSEQ_SHIFT                                2                                           /**< Shift value for RAC_DEMODRXREQCLRSEQ        */
#define _RAC_SEQIEN_DEMODRXREQCLRSEQ_MASK                                 0x4UL                                       /**< Bit mask for RAC_DEMODRXREQCLRSEQ           */
#define _RAC_SEQIEN_DEMODRXREQCLRSEQ_DEFAULT                              0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_DEMODRXREQCLRSEQ_DEFAULT                               (_RAC_SEQIEN_DEMODRXREQCLRSEQ_DEFAULT << 2) /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_PRSEVENTSEQ                                            (0x1UL << 3)                                /**< PRS SEQ EVENT Interrupt Enable              */
#define _RAC_SEQIEN_PRSEVENTSEQ_SHIFT                                     3                                           /**< Shift value for RAC_PRSEVENTSEQ             */
#define _RAC_SEQIEN_PRSEVENTSEQ_MASK                                      0x8UL                                       /**< Bit mask for RAC_PRSEVENTSEQ                */
#define _RAC_SEQIEN_PRSEVENTSEQ_DEFAULT                                   0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_PRSEVENTSEQ_DEFAULT                                    (_RAC_SEQIEN_PRSEVENTSEQ_DEFAULT << 3)      /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATEOFF                                               (0x1UL << 16)                               /**< STATE_OFF Interrupt Enable                  */
#define _RAC_SEQIEN_STATEOFF_SHIFT                                        16                                          /**< Shift value for RAC_STATEOFF                */
#define _RAC_SEQIEN_STATEOFF_MASK                                         0x10000UL                                   /**< Bit mask for RAC_STATEOFF                   */
#define _RAC_SEQIEN_STATEOFF_DEFAULT                                      0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATEOFF_DEFAULT                                       (_RAC_SEQIEN_STATEOFF_DEFAULT << 16)        /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATERXWARM                                            (0x1UL << 17)                               /**< STATE_RXWARM Interrupt Enable               */
#define _RAC_SEQIEN_STATERXWARM_SHIFT                                     17                                          /**< Shift value for RAC_STATERXWARM             */
#define _RAC_SEQIEN_STATERXWARM_MASK                                      0x20000UL                                   /**< Bit mask for RAC_STATERXWARM                */
#define _RAC_SEQIEN_STATERXWARM_DEFAULT                                   0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATERXWARM_DEFAULT                                    (_RAC_SEQIEN_STATERXWARM_DEFAULT << 17)     /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATERXSEARCH                                          (0x1UL << 18)                               /**< STATE_RXSEARC Interrupt Enable              */
#define _RAC_SEQIEN_STATERXSEARCH_SHIFT                                   18                                          /**< Shift value for RAC_STATERXSEARCH           */
#define _RAC_SEQIEN_STATERXSEARCH_MASK                                    0x40000UL                                   /**< Bit mask for RAC_STATERXSEARCH              */
#define _RAC_SEQIEN_STATERXSEARCH_DEFAULT                                 0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATERXSEARCH_DEFAULT                                  (_RAC_SEQIEN_STATERXSEARCH_DEFAULT << 18)   /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATERXFRAME                                           (0x1UL << 19)                               /**< STATE_RXFRAME Interrupt Enable              */
#define _RAC_SEQIEN_STATERXFRAME_SHIFT                                    19                                          /**< Shift value for RAC_STATERXFRAME            */
#define _RAC_SEQIEN_STATERXFRAME_MASK                                     0x80000UL                                   /**< Bit mask for RAC_STATERXFRAME               */
#define _RAC_SEQIEN_STATERXFRAME_DEFAULT                                  0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATERXFRAME_DEFAULT                                   (_RAC_SEQIEN_STATERXFRAME_DEFAULT << 19)    /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATERXPD                                              (0x1UL << 20)                               /**< STATE_RXPD Interrupt Enable                 */
#define _RAC_SEQIEN_STATERXPD_SHIFT                                       20                                          /**< Shift value for RAC_STATERXPD               */
#define _RAC_SEQIEN_STATERXPD_MASK                                        0x100000UL                                  /**< Bit mask for RAC_STATERXPD                  */
#define _RAC_SEQIEN_STATERXPD_DEFAULT                                     0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATERXPD_DEFAULT                                      (_RAC_SEQIEN_STATERXPD_DEFAULT << 20)       /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATERX2RX                                             (0x1UL << 21)                               /**< STATE_RX2RX Interrupt Enable                */
#define _RAC_SEQIEN_STATERX2RX_SHIFT                                      21                                          /**< Shift value for RAC_STATERX2RX              */
#define _RAC_SEQIEN_STATERX2RX_MASK                                       0x200000UL                                  /**< Bit mask for RAC_STATERX2RX                 */
#define _RAC_SEQIEN_STATERX2RX_DEFAULT                                    0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATERX2RX_DEFAULT                                     (_RAC_SEQIEN_STATERX2RX_DEFAULT << 21)      /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATERXOVERFLOW                                        (0x1UL << 22)                               /**< STATE_RXOVERFLOW Interrupt Enable           */
#define _RAC_SEQIEN_STATERXOVERFLOW_SHIFT                                 22                                          /**< Shift value for RAC_STATERXOVERFLOW         */
#define _RAC_SEQIEN_STATERXOVERFLOW_MASK                                  0x400000UL                                  /**< Bit mask for RAC_STATERXOVERFLOW            */
#define _RAC_SEQIEN_STATERXOVERFLOW_DEFAULT                               0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATERXOVERFLOW_DEFAULT                                (_RAC_SEQIEN_STATERXOVERFLOW_DEFAULT << 22) /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATERX2TX                                             (0x1UL << 23)                               /**< STATE_RX2TX Interrupt Enable                */
#define _RAC_SEQIEN_STATERX2TX_SHIFT                                      23                                          /**< Shift value for RAC_STATERX2TX              */
#define _RAC_SEQIEN_STATERX2TX_MASK                                       0x800000UL                                  /**< Bit mask for RAC_STATERX2TX                 */
#define _RAC_SEQIEN_STATERX2TX_DEFAULT                                    0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATERX2TX_DEFAULT                                     (_RAC_SEQIEN_STATERX2TX_DEFAULT << 23)      /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATETXWARM                                            (0x1UL << 24)                               /**< STATE_TXWARM Interrupt Enable               */
#define _RAC_SEQIEN_STATETXWARM_SHIFT                                     24                                          /**< Shift value for RAC_STATETXWARM             */
#define _RAC_SEQIEN_STATETXWARM_MASK                                      0x1000000UL                                 /**< Bit mask for RAC_STATETXWARM                */
#define _RAC_SEQIEN_STATETXWARM_DEFAULT                                   0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATETXWARM_DEFAULT                                    (_RAC_SEQIEN_STATETXWARM_DEFAULT << 24)     /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATETX                                                (0x1UL << 25)                               /**< STATE_TX Interrupt Enable                   */
#define _RAC_SEQIEN_STATETX_SHIFT                                         25                                          /**< Shift value for RAC_STATETX                 */
#define _RAC_SEQIEN_STATETX_MASK                                          0x2000000UL                                 /**< Bit mask for RAC_STATETX                    */
#define _RAC_SEQIEN_STATETX_DEFAULT                                       0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATETX_DEFAULT                                        (_RAC_SEQIEN_STATETX_DEFAULT << 25)         /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATETXPD                                              (0x1UL << 26)                               /**< STATE_TXPD Interrupt Enable                 */
#define _RAC_SEQIEN_STATETXPD_SHIFT                                       26                                          /**< Shift value for RAC_STATETXPD               */
#define _RAC_SEQIEN_STATETXPD_MASK                                        0x4000000UL                                 /**< Bit mask for RAC_STATETXPD                  */
#define _RAC_SEQIEN_STATETXPD_DEFAULT                                     0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATETXPD_DEFAULT                                      (_RAC_SEQIEN_STATETXPD_DEFAULT << 26)       /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATETX2RX                                             (0x1UL << 27)                               /**< STATE_TX2RX Interrupt Enable                */
#define _RAC_SEQIEN_STATETX2RX_SHIFT                                      27                                          /**< Shift value for RAC_STATETX2RX              */
#define _RAC_SEQIEN_STATETX2RX_MASK                                       0x8000000UL                                 /**< Bit mask for RAC_STATETX2RX                 */
#define _RAC_SEQIEN_STATETX2RX_DEFAULT                                    0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATETX2RX_DEFAULT                                     (_RAC_SEQIEN_STATETX2RX_DEFAULT << 27)      /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATETX2TX                                             (0x1UL << 28)                               /**< STATE_TX2TX Interrupt Enable                */
#define _RAC_SEQIEN_STATETX2TX_SHIFT                                      28                                          /**< Shift value for RAC_STATETX2TX              */
#define _RAC_SEQIEN_STATETX2TX_MASK                                       0x10000000UL                                /**< Bit mask for RAC_STATETX2TX                 */
#define _RAC_SEQIEN_STATETX2TX_DEFAULT                                    0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATETX2TX_DEFAULT                                     (_RAC_SEQIEN_STATETX2TX_DEFAULT << 28)      /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_STATESHUTDOWN                                          (0x1UL << 29)                               /**< STATE_SHUTDOWN Interrupt Enable             */
#define _RAC_SEQIEN_STATESHUTDOWN_SHIFT                                   29                                          /**< Shift value for RAC_STATESHUTDOWN           */
#define _RAC_SEQIEN_STATESHUTDOWN_MASK                                    0x20000000UL                                /**< Bit mask for RAC_STATESHUTDOWN              */
#define _RAC_SEQIEN_STATESHUTDOWN_DEFAULT                                 0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_STATESHUTDOWN_DEFAULT                                  (_RAC_SEQIEN_STATESHUTDOWN_DEFAULT << 29)   /**< Shifted mode DEFAULT for RAC_SEQIEN         */
#define RAC_SEQIEN_RFTXPKD                                                (0x1UL << 31)                               /**< TX Peak Det Counter Interrupt Enable        */
#define _RAC_SEQIEN_RFTXPKD_SHIFT                                         31                                          /**< Shift value for RAC_RFTXPKD                 */
#define _RAC_SEQIEN_RFTXPKD_MASK                                          0x80000000UL                                /**< Bit mask for RAC_RFTXPKD                    */
#define _RAC_SEQIEN_RFTXPKD_DEFAULT                                       0x00000000UL                                /**< Mode DEFAULT for RAC_SEQIEN                 */
#define RAC_SEQIEN_RFTXPKD_DEFAULT                                        (_RAC_SEQIEN_RFTXPKD_DEFAULT << 31)         /**< Shifted mode DEFAULT for RAC_SEQIEN         */

/* Bit fields for RAC STATUS1 */
#define _RAC_STATUS1_RESETVALUE                                           0x00000000UL                       /**< Default value for RAC_STATUS1               */
#define _RAC_STATUS1_MASK                                                 0x000000FFUL                       /**< Mask for RAC_STATUS1                        */
#define _RAC_STATUS1_TXMASK_SHIFT                                         0                                  /**< Shift value for RAC_TXMASK                  */
#define _RAC_STATUS1_TXMASK_MASK                                          0xFFUL                             /**< Bit mask for RAC_TXMASK                     */
#define _RAC_STATUS1_TXMASK_DEFAULT                                       0x00000000UL                       /**< Mode DEFAULT for RAC_STATUS1                */
#define RAC_STATUS1_TXMASK_DEFAULT                                        (_RAC_STATUS1_TXMASK_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_STATUS1        */

/* Bit fields for RAC FEMCTRL */
#define _RAC_FEMCTRL_RESETVALUE                                           0x00000000UL                      /**< Default value for RAC_FEMCTRL               */
#define _RAC_FEMCTRL_MASK                                                 0x0000000FUL                      /**< Mask for RAC_FEMCTRL                        */
#define _RAC_FEMCTRL_FEMEN_SHIFT                                          0                                 /**< Shift value for RAC_FEMEN                   */
#define _RAC_FEMCTRL_FEMEN_MASK                                           0xFUL                             /**< Bit mask for RAC_FEMEN                      */
#define _RAC_FEMCTRL_FEMEN_DEFAULT                                        0x00000000UL                      /**< Mode DEFAULT for RAC_FEMCTRL                */
#define RAC_FEMCTRL_FEMEN_DEFAULT                                         (_RAC_FEMCTRL_FEMEN_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_FEMCTRL        */

/* Bit fields for RAC FEMDATA */
#define _RAC_FEMDATA_RESETVALUE                                           0x00000000UL                        /**< Default value for RAC_FEMDATA               */
#define _RAC_FEMDATA_MASK                                                 0x0000000FUL                        /**< Mask for RAC_FEMDATA                        */
#define _RAC_FEMDATA_FEMDATA_SHIFT                                        0                                   /**< Shift value for RAC_FEMDATA                 */
#define _RAC_FEMDATA_FEMDATA_MASK                                         0xFUL                               /**< Bit mask for RAC_FEMDATA                    */
#define _RAC_FEMDATA_FEMDATA_DEFAULT                                      0x00000000UL                        /**< Mode DEFAULT for RAC_FEMDATA                */
#define RAC_FEMDATA_FEMDATA_DEFAULT                                       (_RAC_FEMDATA_FEMDATA_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_FEMDATA        */

/* Bit fields for RAC STIMER */
#define _RAC_STIMER_RESETVALUE                                            0x00000000UL                      /**< Default value for RAC_STIMER                */
#define _RAC_STIMER_MASK                                                  0x0000FFFFUL                      /**< Mask for RAC_STIMER                         */
#define _RAC_STIMER_STIMER_SHIFT                                          0                                 /**< Shift value for RAC_STIMER                  */
#define _RAC_STIMER_STIMER_MASK                                           0xFFFFUL                          /**< Bit mask for RAC_STIMER                     */
#define _RAC_STIMER_STIMER_DEFAULT                                        0x00000000UL                      /**< Mode DEFAULT for RAC_STIMER                 */
#define RAC_STIMER_STIMER_DEFAULT                                         (_RAC_STIMER_STIMER_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_STIMER         */

/* Bit fields for RAC STIMERCOMP */
#define _RAC_STIMERCOMP_RESETVALUE                                        0x00000000UL                              /**< Default value for RAC_STIMERCOMP            */
#define _RAC_STIMERCOMP_MASK                                              0x0000FFFFUL                              /**< Mask for RAC_STIMERCOMP                     */
#define _RAC_STIMERCOMP_STIMERCOMP_SHIFT                                  0                                         /**< Shift value for RAC_STIMERCOMP              */
#define _RAC_STIMERCOMP_STIMERCOMP_MASK                                   0xFFFFUL                                  /**< Bit mask for RAC_STIMERCOMP                 */
#define _RAC_STIMERCOMP_STIMERCOMP_DEFAULT                                0x00000000UL                              /**< Mode DEFAULT for RAC_STIMERCOMP             */
#define RAC_STIMERCOMP_STIMERCOMP_DEFAULT                                 (_RAC_STIMERCOMP_STIMERCOMP_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_STIMERCOMP     */

/* Bit fields for RAC SEQCTRL */
#define _RAC_SEQCTRL_RESETVALUE                                           0x00000000UL                                  /**< Default value for RAC_SEQCTRL               */
#define _RAC_SEQCTRL_MASK                                                 0x0300007FUL                                  /**< Mask for RAC_SEQCTRL                        */
#define RAC_SEQCTRL_COMPACT                                               (0x1UL << 0)                                  /**< STIMER Compare Action                       */
#define _RAC_SEQCTRL_COMPACT_SHIFT                                        0                                             /**< Shift value for RAC_COMPACT                 */
#define _RAC_SEQCTRL_COMPACT_MASK                                         0x1UL                                         /**< Bit mask for RAC_COMPACT                    */
#define _RAC_SEQCTRL_COMPACT_DEFAULT                                      0x00000000UL                                  /**< Mode DEFAULT for RAC_SEQCTRL                */
#define _RAC_SEQCTRL_COMPACT_WRAP                                         0x00000000UL                                  /**< Mode WRAP for RAC_SEQCTRL                   */
#define _RAC_SEQCTRL_COMPACT_CONTINUE                                     0x00000001UL                                  /**< Mode CONTINUE for RAC_SEQCTRL               */
#define RAC_SEQCTRL_COMPACT_DEFAULT                                       (_RAC_SEQCTRL_COMPACT_DEFAULT << 0)           /**< Shifted mode DEFAULT for RAC_SEQCTRL        */
#define RAC_SEQCTRL_COMPACT_WRAP                                          (_RAC_SEQCTRL_COMPACT_WRAP << 0)              /**< Shifted mode WRAP for RAC_SEQCTRL           */
#define RAC_SEQCTRL_COMPACT_CONTINUE                                      (_RAC_SEQCTRL_COMPACT_CONTINUE << 0)          /**< Shifted mode CONTINUE for RAC_SEQCTRL       */
#define _RAC_SEQCTRL_COMPINVALMODE_SHIFT                                  1                                             /**< Shift value for RAC_COMPINVALMODE           */
#define _RAC_SEQCTRL_COMPINVALMODE_MASK                                   0x6UL                                         /**< Bit mask for RAC_COMPINVALMODE              */
#define _RAC_SEQCTRL_COMPINVALMODE_DEFAULT                                0x00000000UL                                  /**< Mode DEFAULT for RAC_SEQCTRL                */
#define _RAC_SEQCTRL_COMPINVALMODE_NEVER                                  0x00000000UL                                  /**< Mode NEVER for RAC_SEQCTRL                  */
#define _RAC_SEQCTRL_COMPINVALMODE_STATECHANGE                            0x00000001UL                                  /**< Mode STATECHANGE for RAC_SEQCTRL            */
#define _RAC_SEQCTRL_COMPINVALMODE_COMPEVENT                              0x00000002UL                                  /**< Mode COMPEVENT for RAC_SEQCTRL              */
#define _RAC_SEQCTRL_COMPINVALMODE_STATECOMP                              0x00000003UL                                  /**< Mode STATECOMP for RAC_SEQCTRL              */
#define RAC_SEQCTRL_COMPINVALMODE_DEFAULT                                 (_RAC_SEQCTRL_COMPINVALMODE_DEFAULT << 1)     /**< Shifted mode DEFAULT for RAC_SEQCTRL        */
#define RAC_SEQCTRL_COMPINVALMODE_NEVER                                   (_RAC_SEQCTRL_COMPINVALMODE_NEVER << 1)       /**< Shifted mode NEVER for RAC_SEQCTRL          */
#define RAC_SEQCTRL_COMPINVALMODE_STATECHANGE                             (_RAC_SEQCTRL_COMPINVALMODE_STATECHANGE << 1) /**< Shifted mode STATECHANGE for RAC_SEQCTRL    */
#define RAC_SEQCTRL_COMPINVALMODE_COMPEVENT                               (_RAC_SEQCTRL_COMPINVALMODE_COMPEVENT << 1)   /**< Shifted mode COMPEVENT for RAC_SEQCTRL      */
#define RAC_SEQCTRL_COMPINVALMODE_STATECOMP                               (_RAC_SEQCTRL_COMPINVALMODE_STATECOMP << 1)   /**< Shifted mode STATECOMP for RAC_SEQCTRL      */
#define RAC_SEQCTRL_RELATIVE                                              (0x1UL << 3)                                  /**< STIMER Compare value relative               */
#define _RAC_SEQCTRL_RELATIVE_SHIFT                                       3                                             /**< Shift value for RAC_RELATIVE                */
#define _RAC_SEQCTRL_RELATIVE_MASK                                        0x8UL                                         /**< Bit mask for RAC_RELATIVE                   */
#define _RAC_SEQCTRL_RELATIVE_DEFAULT                                     0x00000000UL                                  /**< Mode DEFAULT for RAC_SEQCTRL                */
#define _RAC_SEQCTRL_RELATIVE_Absolute                                    0x00000000UL                                  /**< Mode Absolute for RAC_SEQCTRL               */
#define _RAC_SEQCTRL_RELATIVE_Relative                                    0x00000001UL                                  /**< Mode Relative for RAC_SEQCTRL               */
#define RAC_SEQCTRL_RELATIVE_DEFAULT                                      (_RAC_SEQCTRL_RELATIVE_DEFAULT << 3)          /**< Shifted mode DEFAULT for RAC_SEQCTRL        */
#define RAC_SEQCTRL_RELATIVE_Absolute                                     (_RAC_SEQCTRL_RELATIVE_Absolute << 3)         /**< Shifted mode Absolute for RAC_SEQCTRL       */
#define RAC_SEQCTRL_RELATIVE_Relative                                     (_RAC_SEQCTRL_RELATIVE_Relative << 3)         /**< Shifted mode Relative for RAC_SEQCTRL       */
#define RAC_SEQCTRL_STIMERALWAYSRUN                                       (0x1UL << 4)                                  /**< STIMER always Run                           */
#define _RAC_SEQCTRL_STIMERALWAYSRUN_SHIFT                                4                                             /**< Shift value for RAC_STIMERALWAYSRUN         */
#define _RAC_SEQCTRL_STIMERALWAYSRUN_MASK                                 0x10UL                                        /**< Bit mask for RAC_STIMERALWAYSRUN            */
#define _RAC_SEQCTRL_STIMERALWAYSRUN_DEFAULT                              0x00000000UL                                  /**< Mode DEFAULT for RAC_SEQCTRL                */
#define RAC_SEQCTRL_STIMERALWAYSRUN_DEFAULT                               (_RAC_SEQCTRL_STIMERALWAYSRUN_DEFAULT << 4)   /**< Shifted mode DEFAULT for RAC_SEQCTRL        */
#define RAC_SEQCTRL_STIMERDEBUGRUN                                        (0x1UL << 5)                                  /**< STIMER Debug Run                            */
#define _RAC_SEQCTRL_STIMERDEBUGRUN_SHIFT                                 5                                             /**< Shift value for RAC_STIMERDEBUGRUN          */
#define _RAC_SEQCTRL_STIMERDEBUGRUN_MASK                                  0x20UL                                        /**< Bit mask for RAC_STIMERDEBUGRUN             */
#define _RAC_SEQCTRL_STIMERDEBUGRUN_DEFAULT                               0x00000000UL                                  /**< Mode DEFAULT for RAC_SEQCTRL                */
#define _RAC_SEQCTRL_STIMERDEBUGRUN_X0                                    0x00000000UL                                  /**< Mode X0 for RAC_SEQCTRL                     */
#define _RAC_SEQCTRL_STIMERDEBUGRUN_X1                                    0x00000001UL                                  /**< Mode X1 for RAC_SEQCTRL                     */
#define RAC_SEQCTRL_STIMERDEBUGRUN_DEFAULT                                (_RAC_SEQCTRL_STIMERDEBUGRUN_DEFAULT << 5)    /**< Shifted mode DEFAULT for RAC_SEQCTRL        */
#define RAC_SEQCTRL_STIMERDEBUGRUN_X0                                     (_RAC_SEQCTRL_STIMERDEBUGRUN_X0 << 5)         /**< Shifted mode X0 for RAC_SEQCTRL             */
#define RAC_SEQCTRL_STIMERDEBUGRUN_X1                                     (_RAC_SEQCTRL_STIMERDEBUGRUN_X1 << 5)         /**< Shifted mode X1 for RAC_SEQCTRL             */
#define RAC_SEQCTRL_STATEDEBUGRUN                                         (0x1UL << 6)                                  /**< FSM state Debug Run                         */
#define _RAC_SEQCTRL_STATEDEBUGRUN_SHIFT                                  6                                             /**< Shift value for RAC_STATEDEBUGRUN           */
#define _RAC_SEQCTRL_STATEDEBUGRUN_MASK                                   0x40UL                                        /**< Bit mask for RAC_STATEDEBUGRUN              */
#define _RAC_SEQCTRL_STATEDEBUGRUN_DEFAULT                                0x00000000UL                                  /**< Mode DEFAULT for RAC_SEQCTRL                */
#define _RAC_SEQCTRL_STATEDEBUGRUN_X0                                     0x00000000UL                                  /**< Mode X0 for RAC_SEQCTRL                     */
#define _RAC_SEQCTRL_STATEDEBUGRUN_X1                                     0x00000001UL                                  /**< Mode X1 for RAC_SEQCTRL                     */
#define RAC_SEQCTRL_STATEDEBUGRUN_DEFAULT                                 (_RAC_SEQCTRL_STATEDEBUGRUN_DEFAULT << 6)     /**< Shifted mode DEFAULT for RAC_SEQCTRL        */
#define RAC_SEQCTRL_STATEDEBUGRUN_X0                                      (_RAC_SEQCTRL_STATEDEBUGRUN_X0 << 6)          /**< Shifted mode X0 for RAC_SEQCTRL             */
#define RAC_SEQCTRL_STATEDEBUGRUN_X1                                      (_RAC_SEQCTRL_STATEDEBUGRUN_X1 << 6)          /**< Shifted mode X1 for RAC_SEQCTRL             */
#define _RAC_SEQCTRL_SWIRQ_SHIFT                                          24                                            /**< Shift value for RAC_SWIRQ                   */
#define _RAC_SEQCTRL_SWIRQ_MASK                                           0x3000000UL                                   /**< Bit mask for RAC_SWIRQ                      */
#define _RAC_SEQCTRL_SWIRQ_DEFAULT                                        0x00000000UL                                  /**< Mode DEFAULT for RAC_SEQCTRL                */
#define RAC_SEQCTRL_SWIRQ_DEFAULT                                         (_RAC_SEQCTRL_SWIRQ_DEFAULT << 24)            /**< Shifted mode DEFAULT for RAC_SEQCTRL        */

/* Bit fields for RAC PRESC */
#define _RAC_PRESC_RESETVALUE                                             0x00000007UL                     /**< Default value for RAC_PRESC                 */
#define _RAC_PRESC_MASK                                                   0x0000007FUL                     /**< Mask for RAC_PRESC                          */
#define _RAC_PRESC_STIMER_SHIFT                                           0                                /**< Shift value for RAC_STIMER                  */
#define _RAC_PRESC_STIMER_MASK                                            0x7FUL                           /**< Bit mask for RAC_STIMER                     */
#define _RAC_PRESC_STIMER_DEFAULT                                         0x00000007UL                     /**< Mode DEFAULT for RAC_PRESC                  */
#define RAC_PRESC_STIMER_DEFAULT                                          (_RAC_PRESC_STIMER_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_PRESC          */

/* Bit fields for RAC SR0 */
#define _RAC_SR0_RESETVALUE                                               0x00000000UL                /**< Default value for RAC_SR0                   */
#define _RAC_SR0_MASK                                                     0xFFFFFFFFUL                /**< Mask for RAC_SR0                            */
#define _RAC_SR0_SR0_SHIFT                                                0                           /**< Shift value for RAC_SR0                     */
#define _RAC_SR0_SR0_MASK                                                 0xFFFFFFFFUL                /**< Bit mask for RAC_SR0                        */
#define _RAC_SR0_SR0_DEFAULT                                              0x00000000UL                /**< Mode DEFAULT for RAC_SR0                    */
#define RAC_SR0_SR0_DEFAULT                                               (_RAC_SR0_SR0_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SR0            */

/* Bit fields for RAC SR1 */
#define _RAC_SR1_RESETVALUE                                               0x00000000UL                /**< Default value for RAC_SR1                   */
#define _RAC_SR1_MASK                                                     0xFFFFFFFFUL                /**< Mask for RAC_SR1                            */
#define _RAC_SR1_SR1_SHIFT                                                0                           /**< Shift value for RAC_SR1                     */
#define _RAC_SR1_SR1_MASK                                                 0xFFFFFFFFUL                /**< Bit mask for RAC_SR1                        */
#define _RAC_SR1_SR1_DEFAULT                                              0x00000000UL                /**< Mode DEFAULT for RAC_SR1                    */
#define RAC_SR1_SR1_DEFAULT                                               (_RAC_SR1_SR1_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SR1            */

/* Bit fields for RAC SR2 */
#define _RAC_SR2_RESETVALUE                                               0x00000000UL                /**< Default value for RAC_SR2                   */
#define _RAC_SR2_MASK                                                     0xFFFFFFFFUL                /**< Mask for RAC_SR2                            */
#define _RAC_SR2_SR2_SHIFT                                                0                           /**< Shift value for RAC_SR2                     */
#define _RAC_SR2_SR2_MASK                                                 0xFFFFFFFFUL                /**< Bit mask for RAC_SR2                        */
#define _RAC_SR2_SR2_DEFAULT                                              0x00000000UL                /**< Mode DEFAULT for RAC_SR2                    */
#define RAC_SR2_SR2_DEFAULT                                               (_RAC_SR2_SR2_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SR2            */

/* Bit fields for RAC SR3 */
#define _RAC_SR3_RESETVALUE                                               0x00000000UL                /**< Default value for RAC_SR3                   */
#define _RAC_SR3_MASK                                                     0xFFFFFFFFUL                /**< Mask for RAC_SR3                            */
#define _RAC_SR3_SR3_SHIFT                                                0                           /**< Shift value for RAC_SR3                     */
#define _RAC_SR3_SR3_MASK                                                 0xFFFFFFFFUL                /**< Bit mask for RAC_SR3                        */
#define _RAC_SR3_SR3_DEFAULT                                              0x00000000UL                /**< Mode DEFAULT for RAC_SR3                    */
#define RAC_SR3_SR3_DEFAULT                                               (_RAC_SR3_SR3_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SR3            */

/* Bit fields for RAC STCTRL */
#define _RAC_STCTRL_RESETVALUE                                            0x00000000UL                       /**< Default value for RAC_STCTRL                */
#define _RAC_STCTRL_MASK                                                  0x01FFFFFFUL                       /**< Mask for RAC_STCTRL                         */
#define _RAC_STCTRL_STCAL_SHIFT                                           0                                  /**< Shift value for RAC_STCAL                   */
#define _RAC_STCTRL_STCAL_MASK                                            0xFFFFFFUL                         /**< Bit mask for RAC_STCAL                      */
#define _RAC_STCTRL_STCAL_DEFAULT                                         0x00000000UL                       /**< Mode DEFAULT for RAC_STCTRL                 */
#define RAC_STCTRL_STCAL_DEFAULT                                          (_RAC_STCTRL_STCAL_DEFAULT << 0)   /**< Shifted mode DEFAULT for RAC_STCTRL         */
#define RAC_STCTRL_STSKEW                                                 (0x1UL << 24)                      /**< Systick timer skew                          */
#define _RAC_STCTRL_STSKEW_SHIFT                                          24                                 /**< Shift value for RAC_STSKEW                  */
#define _RAC_STCTRL_STSKEW_MASK                                           0x1000000UL                        /**< Bit mask for RAC_STSKEW                     */
#define _RAC_STCTRL_STSKEW_DEFAULT                                        0x00000000UL                       /**< Mode DEFAULT for RAC_STCTRL                 */
#define RAC_STCTRL_STSKEW_DEFAULT                                         (_RAC_STCTRL_STSKEW_DEFAULT << 24) /**< Shifted mode DEFAULT for RAC_STCTRL         */

/* Bit fields for RAC FRCTXWORD */
#define _RAC_FRCTXWORD_RESETVALUE                                         0x00000000UL                        /**< Default value for RAC_FRCTXWORD             */
#define _RAC_FRCTXWORD_MASK                                               0x000000FFUL                        /**< Mask for RAC_FRCTXWORD                      */
#define _RAC_FRCTXWORD_WDATA_SHIFT                                        0                                   /**< Shift value for RAC_WDATA                   */
#define _RAC_FRCTXWORD_WDATA_MASK                                         0xFFUL                              /**< Bit mask for RAC_WDATA                      */
#define _RAC_FRCTXWORD_WDATA_DEFAULT                                      0x00000000UL                        /**< Mode DEFAULT for RAC_FRCTXWORD              */
#define RAC_FRCTXWORD_WDATA_DEFAULT                                       (_RAC_FRCTXWORD_WDATA_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_FRCTXWORD      */

/* Bit fields for RAC FRCRXWORD */
#define _RAC_FRCRXWORD_RESETVALUE                                         0x00000000UL                        /**< Default value for RAC_FRCRXWORD             */
#define _RAC_FRCRXWORD_MASK                                               0x000000FFUL                        /**< Mask for RAC_FRCRXWORD                      */
#define _RAC_FRCRXWORD_RDATA_SHIFT                                        0                                   /**< Shift value for RAC_RDATA                   */
#define _RAC_FRCRXWORD_RDATA_MASK                                         0xFFUL                              /**< Bit mask for RAC_RDATA                      */
#define _RAC_FRCRXWORD_RDATA_DEFAULT                                      0x00000000UL                        /**< Mode DEFAULT for RAC_FRCRXWORD              */
#define RAC_FRCRXWORD_RDATA_DEFAULT                                       (_RAC_FRCRXWORD_RDATA_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_FRCRXWORD      */

/* Bit fields for RAC EM1PCSR */
#define _RAC_EM1PCSR_RESETVALUE                                           0x00000000UL                                  /**< Default value for RAC_EM1PCSR               */
#define _RAC_EM1PCSR_MASK                                                 0x000F0033UL                                  /**< Mask for RAC_EM1PCSR                        */
#define RAC_EM1PCSR_RADIOEM1PMODE                                         (0x1UL << 0)                                  /**<                                             */
#define _RAC_EM1PCSR_RADIOEM1PMODE_SHIFT                                  0                                             /**< Shift value for RAC_RADIOEM1PMODE           */
#define _RAC_EM1PCSR_RADIOEM1PMODE_MASK                                   0x1UL                                         /**< Bit mask for RAC_RADIOEM1PMODE              */
#define _RAC_EM1PCSR_RADIOEM1PMODE_DEFAULT                                0x00000000UL                                  /**< Mode DEFAULT for RAC_EM1PCSR                */
#define _RAC_EM1PCSR_RADIOEM1PMODE_HWCTRL                                 0x00000000UL                                  /**< Mode HWCTRL for RAC_EM1PCSR                 */
#define _RAC_EM1PCSR_RADIOEM1PMODE_SWCTRL                                 0x00000001UL                                  /**< Mode SWCTRL for RAC_EM1PCSR                 */
#define RAC_EM1PCSR_RADIOEM1PMODE_DEFAULT                                 (_RAC_EM1PCSR_RADIOEM1PMODE_DEFAULT << 0)     /**< Shifted mode DEFAULT for RAC_EM1PCSR        */
#define RAC_EM1PCSR_RADIOEM1PMODE_HWCTRL                                  (_RAC_EM1PCSR_RADIOEM1PMODE_HWCTRL << 0)      /**< Shifted mode HWCTRL for RAC_EM1PCSR         */
#define RAC_EM1PCSR_RADIOEM1PMODE_SWCTRL                                  (_RAC_EM1PCSR_RADIOEM1PMODE_SWCTRL << 0)      /**< Shifted mode SWCTRL for RAC_EM1PCSR         */
#define RAC_EM1PCSR_RADIOEM1PDISSWREQ                                     (0x1UL << 1)                                  /**<                                             */
#define _RAC_EM1PCSR_RADIOEM1PDISSWREQ_SHIFT                              1                                             /**< Shift value for RAC_RADIOEM1PDISSWREQ       */
#define _RAC_EM1PCSR_RADIOEM1PDISSWREQ_MASK                               0x2UL                                         /**< Bit mask for RAC_RADIOEM1PDISSWREQ          */
#define _RAC_EM1PCSR_RADIOEM1PDISSWREQ_DEFAULT                            0x00000000UL                                  /**< Mode DEFAULT for RAC_EM1PCSR                */
#define RAC_EM1PCSR_RADIOEM1PDISSWREQ_DEFAULT                             (_RAC_EM1PCSR_RADIOEM1PDISSWREQ_DEFAULT << 1) /**< Shifted mode DEFAULT for RAC_EM1PCSR        */
#define RAC_EM1PCSR_MCUEM1PMODE                                           (0x1UL << 4)                                  /**<                                             */
#define _RAC_EM1PCSR_MCUEM1PMODE_SHIFT                                    4                                             /**< Shift value for RAC_MCUEM1PMODE             */
#define _RAC_EM1PCSR_MCUEM1PMODE_MASK                                     0x10UL                                        /**< Bit mask for RAC_MCUEM1PMODE                */
#define _RAC_EM1PCSR_MCUEM1PMODE_DEFAULT                                  0x00000000UL                                  /**< Mode DEFAULT for RAC_EM1PCSR                */
#define _RAC_EM1PCSR_MCUEM1PMODE_HWCTRL                                   0x00000000UL                                  /**< Mode HWCTRL for RAC_EM1PCSR                 */
#define _RAC_EM1PCSR_MCUEM1PMODE_SWCTRL                                   0x00000001UL                                  /**< Mode SWCTRL for RAC_EM1PCSR                 */
#define RAC_EM1PCSR_MCUEM1PMODE_DEFAULT                                   (_RAC_EM1PCSR_MCUEM1PMODE_DEFAULT << 4)       /**< Shifted mode DEFAULT for RAC_EM1PCSR        */
#define RAC_EM1PCSR_MCUEM1PMODE_HWCTRL                                    (_RAC_EM1PCSR_MCUEM1PMODE_HWCTRL << 4)        /**< Shifted mode HWCTRL for RAC_EM1PCSR         */
#define RAC_EM1PCSR_MCUEM1PMODE_SWCTRL                                    (_RAC_EM1PCSR_MCUEM1PMODE_SWCTRL << 4)        /**< Shifted mode SWCTRL for RAC_EM1PCSR         */
#define RAC_EM1PCSR_MCUEM1PDISSWREQ                                       (0x1UL << 5)                                  /**<                                             */
#define _RAC_EM1PCSR_MCUEM1PDISSWREQ_SHIFT                                5                                             /**< Shift value for RAC_MCUEM1PDISSWREQ         */
#define _RAC_EM1PCSR_MCUEM1PDISSWREQ_MASK                                 0x20UL                                        /**< Bit mask for RAC_MCUEM1PDISSWREQ            */
#define _RAC_EM1PCSR_MCUEM1PDISSWREQ_DEFAULT                              0x00000000UL                                  /**< Mode DEFAULT for RAC_EM1PCSR                */
#define RAC_EM1PCSR_MCUEM1PDISSWREQ_DEFAULT                               (_RAC_EM1PCSR_MCUEM1PDISSWREQ_DEFAULT << 5)   /**< Shifted mode DEFAULT for RAC_EM1PCSR        */
#define RAC_EM1PCSR_RADIOEM1PREQ                                          (0x1UL << 16)                                 /**<                                             */
#define _RAC_EM1PCSR_RADIOEM1PREQ_SHIFT                                   16                                            /**< Shift value for RAC_RADIOEM1PREQ            */
#define _RAC_EM1PCSR_RADIOEM1PREQ_MASK                                    0x10000UL                                     /**< Bit mask for RAC_RADIOEM1PREQ               */
#define _RAC_EM1PCSR_RADIOEM1PREQ_DEFAULT                                 0x00000000UL                                  /**< Mode DEFAULT for RAC_EM1PCSR                */
#define RAC_EM1PCSR_RADIOEM1PREQ_DEFAULT                                  (_RAC_EM1PCSR_RADIOEM1PREQ_DEFAULT << 16)     /**< Shifted mode DEFAULT for RAC_EM1PCSR        */
#define RAC_EM1PCSR_RADIOEM1PACK                                          (0x1UL << 17)                                 /**<                                             */
#define _RAC_EM1PCSR_RADIOEM1PACK_SHIFT                                   17                                            /**< Shift value for RAC_RADIOEM1PACK            */
#define _RAC_EM1PCSR_RADIOEM1PACK_MASK                                    0x20000UL                                     /**< Bit mask for RAC_RADIOEM1PACK               */
#define _RAC_EM1PCSR_RADIOEM1PACK_DEFAULT                                 0x00000000UL                                  /**< Mode DEFAULT for RAC_EM1PCSR                */
#define RAC_EM1PCSR_RADIOEM1PACK_DEFAULT                                  (_RAC_EM1PCSR_RADIOEM1PACK_DEFAULT << 17)     /**< Shifted mode DEFAULT for RAC_EM1PCSR        */
#define RAC_EM1PCSR_RADIOEM1PHWREQ                                        (0x1UL << 18)                                 /**<                                             */
#define _RAC_EM1PCSR_RADIOEM1PHWREQ_SHIFT                                 18                                            /**< Shift value for RAC_RADIOEM1PHWREQ          */
#define _RAC_EM1PCSR_RADIOEM1PHWREQ_MASK                                  0x40000UL                                     /**< Bit mask for RAC_RADIOEM1PHWREQ             */
#define _RAC_EM1PCSR_RADIOEM1PHWREQ_DEFAULT                               0x00000000UL                                  /**< Mode DEFAULT for RAC_EM1PCSR                */
#define RAC_EM1PCSR_RADIOEM1PHWREQ_DEFAULT                                (_RAC_EM1PCSR_RADIOEM1PHWREQ_DEFAULT << 18)   /**< Shifted mode DEFAULT for RAC_EM1PCSR        */
#define RAC_EM1PCSR_MCUEM1PSWRUNNING                                      (0x1UL << 19)                                 /**<                                             */
#define _RAC_EM1PCSR_MCUEM1PSWRUNNING_SHIFT                               19                                            /**< Shift value for RAC_MCUEM1PSWRUNNING        */
#define _RAC_EM1PCSR_MCUEM1PSWRUNNING_MASK                                0x80000UL                                     /**< Bit mask for RAC_MCUEM1PSWRUNNING           */
#define _RAC_EM1PCSR_MCUEM1PSWRUNNING_DEFAULT                             0x00000000UL                                  /**< Mode DEFAULT for RAC_EM1PCSR                */
#define RAC_EM1PCSR_MCUEM1PSWRUNNING_DEFAULT                              (_RAC_EM1PCSR_MCUEM1PSWRUNNING_DEFAULT << 19) /**< Shifted mode DEFAULT for RAC_EM1PCSR        */

/* Bit fields for RAC SYNTHENCTRL */
#define _RAC_SYNTHENCTRL_RESETVALUE                                       0x00000000UL                                                      /**< Default value for RAC_SYNTHENCTRL           */
#define _RAC_SYNTHENCTRL_MASK                                             0x00100682UL                                                      /**< Mask for RAC_SYNTHENCTRL                    */
#define RAC_SYNTHENCTRL_VCOSTARTUP                                        (0x1UL << 1)                                                      /**< SYVCOFASTSTARTUP                            */
#define _RAC_SYNTHENCTRL_VCOSTARTUP_SHIFT                                 1                                                                 /**< Shift value for RAC_VCOSTARTUP              */
#define _RAC_SYNTHENCTRL_VCOSTARTUP_MASK                                  0x2UL                                                             /**< Bit mask for RAC_VCOSTARTUP                 */
#define _RAC_SYNTHENCTRL_VCOSTARTUP_DEFAULT                               0x00000000UL                                                      /**< Mode DEFAULT for RAC_SYNTHENCTRL            */
#define _RAC_SYNTHENCTRL_VCOSTARTUP_fast_start_up_0                       0x00000000UL                                                      /**< Mode fast_start_up_0 for RAC_SYNTHENCTRL    */
#define _RAC_SYNTHENCTRL_VCOSTARTUP_fast_start_up_1                       0x00000001UL                                                      /**< Mode fast_start_up_1 for RAC_SYNTHENCTRL    */
#define RAC_SYNTHENCTRL_VCOSTARTUP_DEFAULT                                (_RAC_SYNTHENCTRL_VCOSTARTUP_DEFAULT << 1)                        /**< Shifted mode DEFAULT for RAC_SYNTHENCTRL    */
#define RAC_SYNTHENCTRL_VCOSTARTUP_fast_start_up_0                        (_RAC_SYNTHENCTRL_VCOSTARTUP_fast_start_up_0 << 1)                /**< Shifted mode fast_start_up_0 for RAC_SYNTHENCTRL*/
#define RAC_SYNTHENCTRL_VCOSTARTUP_fast_start_up_1                        (_RAC_SYNTHENCTRL_VCOSTARTUP_fast_start_up_1 << 1)                /**< Shifted mode fast_start_up_1 for RAC_SYNTHENCTRL*/
#define RAC_SYNTHENCTRL_VCBUFEN                                           (0x1UL << 7)                                                      /**< SYLPFVCBUFEN                                */
#define _RAC_SYNTHENCTRL_VCBUFEN_SHIFT                                    7                                                                 /**< Shift value for RAC_VCBUFEN                 */
#define _RAC_SYNTHENCTRL_VCBUFEN_MASK                                     0x80UL                                                            /**< Bit mask for RAC_VCBUFEN                    */
#define _RAC_SYNTHENCTRL_VCBUFEN_DEFAULT                                  0x00000000UL                                                      /**< Mode DEFAULT for RAC_SYNTHENCTRL            */
#define _RAC_SYNTHENCTRL_VCBUFEN_Disabled                                 0x00000000UL                                                      /**< Mode Disabled for RAC_SYNTHENCTRL           */
#define _RAC_SYNTHENCTRL_VCBUFEN_Enabled                                  0x00000001UL                                                      /**< Mode Enabled for RAC_SYNTHENCTRL            */
#define RAC_SYNTHENCTRL_VCBUFEN_DEFAULT                                   (_RAC_SYNTHENCTRL_VCBUFEN_DEFAULT << 7)                           /**< Shifted mode DEFAULT for RAC_SYNTHENCTRL    */
#define RAC_SYNTHENCTRL_VCBUFEN_Disabled                                  (_RAC_SYNTHENCTRL_VCBUFEN_Disabled << 7)                          /**< Shifted mode Disabled for RAC_SYNTHENCTRL   */
#define RAC_SYNTHENCTRL_VCBUFEN_Enabled                                   (_RAC_SYNTHENCTRL_VCBUFEN_Enabled << 7)                           /**< Shifted mode Enabled for RAC_SYNTHENCTRL    */
#define RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE                            (0x1UL << 10)                                                     /**< SYMMDPOWERBALANCEENB                        */
#define _RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_SHIFT                     10                                                                /**< Shift value for RAC_MMDPOWERBALANCEDISABLE  */
#define _RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_MASK                      0x400UL                                                           /**< Bit mask for RAC_MMDPOWERBALANCEDISABLE     */
#define _RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_DEFAULT                   0x00000000UL                                                      /**< Mode DEFAULT for RAC_SYNTHENCTRL            */
#define _RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_EnablePowerbleed          0x00000000UL                                                      /**< Mode EnablePowerbleed for RAC_SYNTHENCTRL   */
#define _RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_DisablePowerBleed         0x00000001UL                                                      /**< Mode DisablePowerBleed for RAC_SYNTHENCTRL  */
#define RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_DEFAULT                    (_RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_DEFAULT << 10)           /**< Shifted mode DEFAULT for RAC_SYNTHENCTRL    */
#define RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_EnablePowerbleed           (_RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_EnablePowerbleed << 10)  /**< Shifted mode EnablePowerbleed for RAC_SYNTHENCTRL*/
#define RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_DisablePowerBleed          (_RAC_SYNTHENCTRL_MMDPOWERBALANCEDISABLE_DisablePowerBleed << 10) /**< Shifted mode DisablePowerBleed for RAC_SYNTHENCTRL*/
#define RAC_SYNTHENCTRL_LPFBWSEL                                          (0x1UL << 20)                                                     /**< LPF bandwidth register selection            */
#define _RAC_SYNTHENCTRL_LPFBWSEL_SHIFT                                   20                                                                /**< Shift value for RAC_LPFBWSEL                */
#define _RAC_SYNTHENCTRL_LPFBWSEL_MASK                                    0x100000UL                                                        /**< Bit mask for RAC_LPFBWSEL                   */
#define _RAC_SYNTHENCTRL_LPFBWSEL_DEFAULT                                 0x00000000UL                                                      /**< Mode DEFAULT for RAC_SYNTHENCTRL            */
#define _RAC_SYNTHENCTRL_LPFBWSEL_LPFBWRX                                 0x00000000UL                                                      /**< Mode LPFBWRX for RAC_SYNTHENCTRL            */
#define _RAC_SYNTHENCTRL_LPFBWSEL_LPFBWTX                                 0x00000001UL                                                      /**< Mode LPFBWTX for RAC_SYNTHENCTRL            */
#define RAC_SYNTHENCTRL_LPFBWSEL_DEFAULT                                  (_RAC_SYNTHENCTRL_LPFBWSEL_DEFAULT << 20)                         /**< Shifted mode DEFAULT for RAC_SYNTHENCTRL    */
#define RAC_SYNTHENCTRL_LPFBWSEL_LPFBWRX                                  (_RAC_SYNTHENCTRL_LPFBWSEL_LPFBWRX << 20)                         /**< Shifted mode LPFBWRX for RAC_SYNTHENCTRL    */
#define RAC_SYNTHENCTRL_LPFBWSEL_LPFBWTX                                  (_RAC_SYNTHENCTRL_LPFBWSEL_LPFBWTX << 20)                         /**< Shifted mode LPFBWTX for RAC_SYNTHENCTRL    */

/* Bit fields for RAC SYNTHREGCTRL */
#define _RAC_SYNTHREGCTRL_RESETVALUE                                      0x04000C00UL                                        /**< Default value for RAC_SYNTHREGCTRL          */
#define _RAC_SYNTHREGCTRL_MASK                                            0x07001C00UL                                        /**< Mask for RAC_SYNTHREGCTRL                   */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_SHIFT                            10                                                  /**< Shift value for RAC_MMDLDOVREFTRIM          */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_MASK                             0x1C00UL                                            /**< Bit mask for RAC_MMDLDOVREFTRIM             */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_DEFAULT                          0x00000003UL                                        /**< Mode DEFAULT for RAC_SYNTHREGCTRL           */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5125                       0x00000000UL                                        /**< Mode vref0p5125 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5250                       0x00000001UL                                        /**< Mode vref0p5250 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5375                       0x00000002UL                                        /**< Mode vref0p5375 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5500                       0x00000003UL                                        /**< Mode vref0p5500 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5625                       0x00000004UL                                        /**< Mode vref0p5625 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5750                       0x00000005UL                                        /**< Mode vref0p5750 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5875                       0x00000006UL                                        /**< Mode vref0p5875 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p6000                       0x00000007UL                                        /**< Mode vref0p6000 for RAC_SYNTHREGCTRL        */
#define RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_DEFAULT                           (_RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_DEFAULT << 10)    /**< Shifted mode DEFAULT for RAC_SYNTHREGCTRL   */
#define RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5125                        (_RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5125 << 10) /**< Shifted mode vref0p5125 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5250                        (_RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5250 << 10) /**< Shifted mode vref0p5250 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5375                        (_RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5375 << 10) /**< Shifted mode vref0p5375 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5500                        (_RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5500 << 10) /**< Shifted mode vref0p5500 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5625                        (_RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5625 << 10) /**< Shifted mode vref0p5625 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5750                        (_RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5750 << 10) /**< Shifted mode vref0p5750 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5875                        (_RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p5875 << 10) /**< Shifted mode vref0p5875 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p6000                        (_RAC_SYNTHREGCTRL_MMDLDOVREFTRIM_vref0p6000 << 10) /**< Shifted mode vref0p6000 for RAC_SYNTHREGCTRL*/
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_SHIFT                            24                                                  /**< Shift value for RAC_CHPLDOVREFTRIM          */
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_MASK                             0x7000000UL                                         /**< Bit mask for RAC_CHPLDOVREFTRIM             */
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_DEFAULT                          0x00000004UL                                        /**< Mode DEFAULT for RAC_SYNTHREGCTRL           */
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6000                       0x00000000UL                                        /**< Mode vref0p6000 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6125                       0x00000001UL                                        /**< Mode vref0p6125 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6250                       0x00000002UL                                        /**< Mode vref0p6250 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6375                       0x00000003UL                                        /**< Mode vref0p6375 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6500                       0x00000004UL                                        /**< Mode vref0p6500 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6625                       0x00000005UL                                        /**< Mode vref0p6625 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6750                       0x00000006UL                                        /**< Mode vref0p6750 for RAC_SYNTHREGCTRL        */
#define _RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6875                       0x00000007UL                                        /**< Mode vref0p6875 for RAC_SYNTHREGCTRL        */
#define RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_DEFAULT                           (_RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_DEFAULT << 24)    /**< Shifted mode DEFAULT for RAC_SYNTHREGCTRL   */
#define RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6000                        (_RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6000 << 24) /**< Shifted mode vref0p6000 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6125                        (_RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6125 << 24) /**< Shifted mode vref0p6125 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6250                        (_RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6250 << 24) /**< Shifted mode vref0p6250 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6375                        (_RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6375 << 24) /**< Shifted mode vref0p6375 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6500                        (_RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6500 << 24) /**< Shifted mode vref0p6500 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6625                        (_RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6625 << 24) /**< Shifted mode vref0p6625 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6750                        (_RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6750 << 24) /**< Shifted mode vref0p6750 for RAC_SYNTHREGCTRL*/
#define RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6875                        (_RAC_SYNTHREGCTRL_CHPLDOVREFTRIM_vref0p6875 << 24) /**< Shifted mode vref0p6875 for RAC_SYNTHREGCTRL*/

/* Bit fields for RAC VCOCTRL */
#define _RAC_VCOCTRL_RESETVALUE                                           0x0000044CUL                                  /**< Default value for RAC_VCOCTRL               */
#define _RAC_VCOCTRL_MASK                                                 0x00000FFFUL                                  /**< Mask for RAC_VCOCTRL                        */
#define _RAC_VCOCTRL_VCOAMPLITUDE_SHIFT                                   0                                             /**< Shift value for RAC_VCOAMPLITUDE            */
#define _RAC_VCOCTRL_VCOAMPLITUDE_MASK                                    0xFUL                                         /**< Bit mask for RAC_VCOAMPLITUDE               */
#define _RAC_VCOCTRL_VCOAMPLITUDE_DEFAULT                                 0x0000000CUL                                  /**< Mode DEFAULT for RAC_VCOCTRL                */
#define RAC_VCOCTRL_VCOAMPLITUDE_DEFAULT                                  (_RAC_VCOCTRL_VCOAMPLITUDE_DEFAULT << 0)      /**< Shifted mode DEFAULT for RAC_VCOCTRL        */
#define _RAC_VCOCTRL_VCODETAMPLITUDERX_SHIFT                              4                                             /**< Shift value for RAC_VCODETAMPLITUDERX       */
#define _RAC_VCOCTRL_VCODETAMPLITUDERX_MASK                               0xF0UL                                        /**< Bit mask for RAC_VCODETAMPLITUDERX          */
#define _RAC_VCOCTRL_VCODETAMPLITUDERX_DEFAULT                            0x00000004UL                                  /**< Mode DEFAULT for RAC_VCOCTRL                */
#define RAC_VCOCTRL_VCODETAMPLITUDERX_DEFAULT                             (_RAC_VCOCTRL_VCODETAMPLITUDERX_DEFAULT << 4) /**< Shifted mode DEFAULT for RAC_VCOCTRL        */
#define _RAC_VCOCTRL_VCODETAMPLITUDETX_SHIFT                              8                                             /**< Shift value for RAC_VCODETAMPLITUDETX       */
#define _RAC_VCOCTRL_VCODETAMPLITUDETX_MASK                               0xF00UL                                       /**< Bit mask for RAC_VCODETAMPLITUDETX          */
#define _RAC_VCOCTRL_VCODETAMPLITUDETX_DEFAULT                            0x00000004UL                                  /**< Mode DEFAULT for RAC_VCOCTRL                */
#define RAC_VCOCTRL_VCODETAMPLITUDETX_DEFAULT                             (_RAC_VCOCTRL_VCODETAMPLITUDETX_DEFAULT << 8) /**< Shifted mode DEFAULT for RAC_VCOCTRL        */

/* Bit fields for RAC STATUS2 */
#define _RAC_STATUS2_RESETVALUE                                           0x00000000UL                              /**< Default value for RAC_STATUS2               */
#define _RAC_STATUS2_MASK                                                 0x0000FFFFUL                              /**< Mask for RAC_STATUS2                        */
#define _RAC_STATUS2_PREVSTATE1_SHIFT                                     0                                         /**< Shift value for RAC_PREVSTATE1              */
#define _RAC_STATUS2_PREVSTATE1_MASK                                      0xFUL                                     /**< Bit mask for RAC_PREVSTATE1                 */
#define _RAC_STATUS2_PREVSTATE1_DEFAULT                                   0x00000000UL                              /**< Mode DEFAULT for RAC_STATUS2                */
#define _RAC_STATUS2_PREVSTATE1_OFF                                       0x00000000UL                              /**< Mode OFF for RAC_STATUS2                    */
#define _RAC_STATUS2_PREVSTATE1_RXWARM                                    0x00000001UL                              /**< Mode RXWARM for RAC_STATUS2                 */
#define _RAC_STATUS2_PREVSTATE1_RXSEARCH                                  0x00000002UL                              /**< Mode RXSEARCH for RAC_STATUS2               */
#define _RAC_STATUS2_PREVSTATE1_RXFRAME                                   0x00000003UL                              /**< Mode RXFRAME for RAC_STATUS2                */
#define _RAC_STATUS2_PREVSTATE1_RXPD                                      0x00000004UL                              /**< Mode RXPD for RAC_STATUS2                   */
#define _RAC_STATUS2_PREVSTATE1_RX2RX                                     0x00000005UL                              /**< Mode RX2RX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE1_RXOVERFLOW                                0x00000006UL                              /**< Mode RXOVERFLOW for RAC_STATUS2             */
#define _RAC_STATUS2_PREVSTATE1_RX2TX                                     0x00000007UL                              /**< Mode RX2TX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE1_TXWARM                                    0x00000008UL                              /**< Mode TXWARM for RAC_STATUS2                 */
#define _RAC_STATUS2_PREVSTATE1_TX                                        0x00000009UL                              /**< Mode TX for RAC_STATUS2                     */
#define _RAC_STATUS2_PREVSTATE1_TXPD                                      0x0000000AUL                              /**< Mode TXPD for RAC_STATUS2                   */
#define _RAC_STATUS2_PREVSTATE1_TX2RX                                     0x0000000BUL                              /**< Mode TX2RX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE1_TX2TX                                     0x0000000CUL                              /**< Mode TX2TX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE1_SHUTDOWN                                  0x0000000DUL                              /**< Mode SHUTDOWN for RAC_STATUS2               */
#define _RAC_STATUS2_PREVSTATE1_POR                                       0x0000000EUL                              /**< Mode POR for RAC_STATUS2                    */
#define RAC_STATUS2_PREVSTATE1_DEFAULT                                    (_RAC_STATUS2_PREVSTATE1_DEFAULT << 0)    /**< Shifted mode DEFAULT for RAC_STATUS2        */
#define RAC_STATUS2_PREVSTATE1_OFF                                        (_RAC_STATUS2_PREVSTATE1_OFF << 0)        /**< Shifted mode OFF for RAC_STATUS2            */
#define RAC_STATUS2_PREVSTATE1_RXWARM                                     (_RAC_STATUS2_PREVSTATE1_RXWARM << 0)     /**< Shifted mode RXWARM for RAC_STATUS2         */
#define RAC_STATUS2_PREVSTATE1_RXSEARCH                                   (_RAC_STATUS2_PREVSTATE1_RXSEARCH << 0)   /**< Shifted mode RXSEARCH for RAC_STATUS2       */
#define RAC_STATUS2_PREVSTATE1_RXFRAME                                    (_RAC_STATUS2_PREVSTATE1_RXFRAME << 0)    /**< Shifted mode RXFRAME for RAC_STATUS2        */
#define RAC_STATUS2_PREVSTATE1_RXPD                                       (_RAC_STATUS2_PREVSTATE1_RXPD << 0)       /**< Shifted mode RXPD for RAC_STATUS2           */
#define RAC_STATUS2_PREVSTATE1_RX2RX                                      (_RAC_STATUS2_PREVSTATE1_RX2RX << 0)      /**< Shifted mode RX2RX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE1_RXOVERFLOW                                 (_RAC_STATUS2_PREVSTATE1_RXOVERFLOW << 0) /**< Shifted mode RXOVERFLOW for RAC_STATUS2     */
#define RAC_STATUS2_PREVSTATE1_RX2TX                                      (_RAC_STATUS2_PREVSTATE1_RX2TX << 0)      /**< Shifted mode RX2TX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE1_TXWARM                                     (_RAC_STATUS2_PREVSTATE1_TXWARM << 0)     /**< Shifted mode TXWARM for RAC_STATUS2         */
#define RAC_STATUS2_PREVSTATE1_TX                                         (_RAC_STATUS2_PREVSTATE1_TX << 0)         /**< Shifted mode TX for RAC_STATUS2             */
#define RAC_STATUS2_PREVSTATE1_TXPD                                       (_RAC_STATUS2_PREVSTATE1_TXPD << 0)       /**< Shifted mode TXPD for RAC_STATUS2           */
#define RAC_STATUS2_PREVSTATE1_TX2RX                                      (_RAC_STATUS2_PREVSTATE1_TX2RX << 0)      /**< Shifted mode TX2RX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE1_TX2TX                                      (_RAC_STATUS2_PREVSTATE1_TX2TX << 0)      /**< Shifted mode TX2TX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE1_SHUTDOWN                                   (_RAC_STATUS2_PREVSTATE1_SHUTDOWN << 0)   /**< Shifted mode SHUTDOWN for RAC_STATUS2       */
#define RAC_STATUS2_PREVSTATE1_POR                                        (_RAC_STATUS2_PREVSTATE1_POR << 0)        /**< Shifted mode POR for RAC_STATUS2            */
#define _RAC_STATUS2_PREVSTATE2_SHIFT                                     4                                         /**< Shift value for RAC_PREVSTATE2              */
#define _RAC_STATUS2_PREVSTATE2_MASK                                      0xF0UL                                    /**< Bit mask for RAC_PREVSTATE2                 */
#define _RAC_STATUS2_PREVSTATE2_DEFAULT                                   0x00000000UL                              /**< Mode DEFAULT for RAC_STATUS2                */
#define _RAC_STATUS2_PREVSTATE2_OFF                                       0x00000000UL                              /**< Mode OFF for RAC_STATUS2                    */
#define _RAC_STATUS2_PREVSTATE2_RXWARM                                    0x00000001UL                              /**< Mode RXWARM for RAC_STATUS2                 */
#define _RAC_STATUS2_PREVSTATE2_RXSEARCH                                  0x00000002UL                              /**< Mode RXSEARCH for RAC_STATUS2               */
#define _RAC_STATUS2_PREVSTATE2_RXFRAME                                   0x00000003UL                              /**< Mode RXFRAME for RAC_STATUS2                */
#define _RAC_STATUS2_PREVSTATE2_RXPD                                      0x00000004UL                              /**< Mode RXPD for RAC_STATUS2                   */
#define _RAC_STATUS2_PREVSTATE2_RX2RX                                     0x00000005UL                              /**< Mode RX2RX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE2_RXOVERFLOW                                0x00000006UL                              /**< Mode RXOVERFLOW for RAC_STATUS2             */
#define _RAC_STATUS2_PREVSTATE2_RX2TX                                     0x00000007UL                              /**< Mode RX2TX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE2_TXWARM                                    0x00000008UL                              /**< Mode TXWARM for RAC_STATUS2                 */
#define _RAC_STATUS2_PREVSTATE2_TX                                        0x00000009UL                              /**< Mode TX for RAC_STATUS2                     */
#define _RAC_STATUS2_PREVSTATE2_TXPD                                      0x0000000AUL                              /**< Mode TXPD for RAC_STATUS2                   */
#define _RAC_STATUS2_PREVSTATE2_TX2RX                                     0x0000000BUL                              /**< Mode TX2RX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE2_TX2TX                                     0x0000000CUL                              /**< Mode TX2TX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE2_SHUTDOWN                                  0x0000000DUL                              /**< Mode SHUTDOWN for RAC_STATUS2               */
#define _RAC_STATUS2_PREVSTATE2_POR                                       0x0000000EUL                              /**< Mode POR for RAC_STATUS2                    */
#define RAC_STATUS2_PREVSTATE2_DEFAULT                                    (_RAC_STATUS2_PREVSTATE2_DEFAULT << 4)    /**< Shifted mode DEFAULT for RAC_STATUS2        */
#define RAC_STATUS2_PREVSTATE2_OFF                                        (_RAC_STATUS2_PREVSTATE2_OFF << 4)        /**< Shifted mode OFF for RAC_STATUS2            */
#define RAC_STATUS2_PREVSTATE2_RXWARM                                     (_RAC_STATUS2_PREVSTATE2_RXWARM << 4)     /**< Shifted mode RXWARM for RAC_STATUS2         */
#define RAC_STATUS2_PREVSTATE2_RXSEARCH                                   (_RAC_STATUS2_PREVSTATE2_RXSEARCH << 4)   /**< Shifted mode RXSEARCH for RAC_STATUS2       */
#define RAC_STATUS2_PREVSTATE2_RXFRAME                                    (_RAC_STATUS2_PREVSTATE2_RXFRAME << 4)    /**< Shifted mode RXFRAME for RAC_STATUS2        */
#define RAC_STATUS2_PREVSTATE2_RXPD                                       (_RAC_STATUS2_PREVSTATE2_RXPD << 4)       /**< Shifted mode RXPD for RAC_STATUS2           */
#define RAC_STATUS2_PREVSTATE2_RX2RX                                      (_RAC_STATUS2_PREVSTATE2_RX2RX << 4)      /**< Shifted mode RX2RX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE2_RXOVERFLOW                                 (_RAC_STATUS2_PREVSTATE2_RXOVERFLOW << 4) /**< Shifted mode RXOVERFLOW for RAC_STATUS2     */
#define RAC_STATUS2_PREVSTATE2_RX2TX                                      (_RAC_STATUS2_PREVSTATE2_RX2TX << 4)      /**< Shifted mode RX2TX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE2_TXWARM                                     (_RAC_STATUS2_PREVSTATE2_TXWARM << 4)     /**< Shifted mode TXWARM for RAC_STATUS2         */
#define RAC_STATUS2_PREVSTATE2_TX                                         (_RAC_STATUS2_PREVSTATE2_TX << 4)         /**< Shifted mode TX for RAC_STATUS2             */
#define RAC_STATUS2_PREVSTATE2_TXPD                                       (_RAC_STATUS2_PREVSTATE2_TXPD << 4)       /**< Shifted mode TXPD for RAC_STATUS2           */
#define RAC_STATUS2_PREVSTATE2_TX2RX                                      (_RAC_STATUS2_PREVSTATE2_TX2RX << 4)      /**< Shifted mode TX2RX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE2_TX2TX                                      (_RAC_STATUS2_PREVSTATE2_TX2TX << 4)      /**< Shifted mode TX2TX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE2_SHUTDOWN                                   (_RAC_STATUS2_PREVSTATE2_SHUTDOWN << 4)   /**< Shifted mode SHUTDOWN for RAC_STATUS2       */
#define RAC_STATUS2_PREVSTATE2_POR                                        (_RAC_STATUS2_PREVSTATE2_POR << 4)        /**< Shifted mode POR for RAC_STATUS2            */
#define _RAC_STATUS2_PREVSTATE3_SHIFT                                     8                                         /**< Shift value for RAC_PREVSTATE3              */
#define _RAC_STATUS2_PREVSTATE3_MASK                                      0xF00UL                                   /**< Bit mask for RAC_PREVSTATE3                 */
#define _RAC_STATUS2_PREVSTATE3_DEFAULT                                   0x00000000UL                              /**< Mode DEFAULT for RAC_STATUS2                */
#define _RAC_STATUS2_PREVSTATE3_OFF                                       0x00000000UL                              /**< Mode OFF for RAC_STATUS2                    */
#define _RAC_STATUS2_PREVSTATE3_RXWARM                                    0x00000001UL                              /**< Mode RXWARM for RAC_STATUS2                 */
#define _RAC_STATUS2_PREVSTATE3_RXSEARCH                                  0x00000002UL                              /**< Mode RXSEARCH for RAC_STATUS2               */
#define _RAC_STATUS2_PREVSTATE3_RXFRAME                                   0x00000003UL                              /**< Mode RXFRAME for RAC_STATUS2                */
#define _RAC_STATUS2_PREVSTATE3_RXPD                                      0x00000004UL                              /**< Mode RXPD for RAC_STATUS2                   */
#define _RAC_STATUS2_PREVSTATE3_RX2RX                                     0x00000005UL                              /**< Mode RX2RX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE3_RXOVERFLOW                                0x00000006UL                              /**< Mode RXOVERFLOW for RAC_STATUS2             */
#define _RAC_STATUS2_PREVSTATE3_RX2TX                                     0x00000007UL                              /**< Mode RX2TX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE3_TXWARM                                    0x00000008UL                              /**< Mode TXWARM for RAC_STATUS2                 */
#define _RAC_STATUS2_PREVSTATE3_TX                                        0x00000009UL                              /**< Mode TX for RAC_STATUS2                     */
#define _RAC_STATUS2_PREVSTATE3_TXPD                                      0x0000000AUL                              /**< Mode TXPD for RAC_STATUS2                   */
#define _RAC_STATUS2_PREVSTATE3_TX2RX                                     0x0000000BUL                              /**< Mode TX2RX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE3_TX2TX                                     0x0000000CUL                              /**< Mode TX2TX for RAC_STATUS2                  */
#define _RAC_STATUS2_PREVSTATE3_SHUTDOWN                                  0x0000000DUL                              /**< Mode SHUTDOWN for RAC_STATUS2               */
#define _RAC_STATUS2_PREVSTATE3_POR                                       0x0000000EUL                              /**< Mode POR for RAC_STATUS2                    */
#define RAC_STATUS2_PREVSTATE3_DEFAULT                                    (_RAC_STATUS2_PREVSTATE3_DEFAULT << 8)    /**< Shifted mode DEFAULT for RAC_STATUS2        */
#define RAC_STATUS2_PREVSTATE3_OFF                                        (_RAC_STATUS2_PREVSTATE3_OFF << 8)        /**< Shifted mode OFF for RAC_STATUS2            */
#define RAC_STATUS2_PREVSTATE3_RXWARM                                     (_RAC_STATUS2_PREVSTATE3_RXWARM << 8)     /**< Shifted mode RXWARM for RAC_STATUS2         */
#define RAC_STATUS2_PREVSTATE3_RXSEARCH                                   (_RAC_STATUS2_PREVSTATE3_RXSEARCH << 8)   /**< Shifted mode RXSEARCH for RAC_STATUS2       */
#define RAC_STATUS2_PREVSTATE3_RXFRAME                                    (_RAC_STATUS2_PREVSTATE3_RXFRAME << 8)    /**< Shifted mode RXFRAME for RAC_STATUS2        */
#define RAC_STATUS2_PREVSTATE3_RXPD                                       (_RAC_STATUS2_PREVSTATE3_RXPD << 8)       /**< Shifted mode RXPD for RAC_STATUS2           */
#define RAC_STATUS2_PREVSTATE3_RX2RX                                      (_RAC_STATUS2_PREVSTATE3_RX2RX << 8)      /**< Shifted mode RX2RX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE3_RXOVERFLOW                                 (_RAC_STATUS2_PREVSTATE3_RXOVERFLOW << 8) /**< Shifted mode RXOVERFLOW for RAC_STATUS2     */
#define RAC_STATUS2_PREVSTATE3_RX2TX                                      (_RAC_STATUS2_PREVSTATE3_RX2TX << 8)      /**< Shifted mode RX2TX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE3_TXWARM                                     (_RAC_STATUS2_PREVSTATE3_TXWARM << 8)     /**< Shifted mode TXWARM for RAC_STATUS2         */
#define RAC_STATUS2_PREVSTATE3_TX                                         (_RAC_STATUS2_PREVSTATE3_TX << 8)         /**< Shifted mode TX for RAC_STATUS2             */
#define RAC_STATUS2_PREVSTATE3_TXPD                                       (_RAC_STATUS2_PREVSTATE3_TXPD << 8)       /**< Shifted mode TXPD for RAC_STATUS2           */
#define RAC_STATUS2_PREVSTATE3_TX2RX                                      (_RAC_STATUS2_PREVSTATE3_TX2RX << 8)      /**< Shifted mode TX2RX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE3_TX2TX                                      (_RAC_STATUS2_PREVSTATE3_TX2TX << 8)      /**< Shifted mode TX2TX for RAC_STATUS2          */
#define RAC_STATUS2_PREVSTATE3_SHUTDOWN                                   (_RAC_STATUS2_PREVSTATE3_SHUTDOWN << 8)   /**< Shifted mode SHUTDOWN for RAC_STATUS2       */
#define RAC_STATUS2_PREVSTATE3_POR                                        (_RAC_STATUS2_PREVSTATE3_POR << 8)        /**< Shifted mode POR for RAC_STATUS2            */
#define _RAC_STATUS2_CURRSTATE_SHIFT                                      12                                        /**< Shift value for RAC_CURRSTATE               */
#define _RAC_STATUS2_CURRSTATE_MASK                                       0xF000UL                                  /**< Bit mask for RAC_CURRSTATE                  */
#define _RAC_STATUS2_CURRSTATE_DEFAULT                                    0x00000000UL                              /**< Mode DEFAULT for RAC_STATUS2                */
#define _RAC_STATUS2_CURRSTATE_OFF                                        0x00000000UL                              /**< Mode OFF for RAC_STATUS2                    */
#define _RAC_STATUS2_CURRSTATE_RXWARM                                     0x00000001UL                              /**< Mode RXWARM for RAC_STATUS2                 */
#define _RAC_STATUS2_CURRSTATE_RXSEARCH                                   0x00000002UL                              /**< Mode RXSEARCH for RAC_STATUS2               */
#define _RAC_STATUS2_CURRSTATE_RXFRAME                                    0x00000003UL                              /**< Mode RXFRAME for RAC_STATUS2                */
#define _RAC_STATUS2_CURRSTATE_RXPD                                       0x00000004UL                              /**< Mode RXPD for RAC_STATUS2                   */
#define _RAC_STATUS2_CURRSTATE_RX2RX                                      0x00000005UL                              /**< Mode RX2RX for RAC_STATUS2                  */
#define _RAC_STATUS2_CURRSTATE_RXOVERFLOW                                 0x00000006UL                              /**< Mode RXOVERFLOW for RAC_STATUS2             */
#define _RAC_STATUS2_CURRSTATE_RX2TX                                      0x00000007UL                              /**< Mode RX2TX for RAC_STATUS2                  */
#define _RAC_STATUS2_CURRSTATE_TXWARM                                     0x00000008UL                              /**< Mode TXWARM for RAC_STATUS2                 */
#define _RAC_STATUS2_CURRSTATE_TX                                         0x00000009UL                              /**< Mode TX for RAC_STATUS2                     */
#define _RAC_STATUS2_CURRSTATE_TXPD                                       0x0000000AUL                              /**< Mode TXPD for RAC_STATUS2                   */
#define _RAC_STATUS2_CURRSTATE_TX2RX                                      0x0000000BUL                              /**< Mode TX2RX for RAC_STATUS2                  */
#define _RAC_STATUS2_CURRSTATE_TX2TX                                      0x0000000CUL                              /**< Mode TX2TX for RAC_STATUS2                  */
#define _RAC_STATUS2_CURRSTATE_SHUTDOWN                                   0x0000000DUL                              /**< Mode SHUTDOWN for RAC_STATUS2               */
#define _RAC_STATUS2_CURRSTATE_POR                                        0x0000000EUL                              /**< Mode POR for RAC_STATUS2                    */
#define RAC_STATUS2_CURRSTATE_DEFAULT                                     (_RAC_STATUS2_CURRSTATE_DEFAULT << 12)    /**< Shifted mode DEFAULT for RAC_STATUS2        */
#define RAC_STATUS2_CURRSTATE_OFF                                         (_RAC_STATUS2_CURRSTATE_OFF << 12)        /**< Shifted mode OFF for RAC_STATUS2            */
#define RAC_STATUS2_CURRSTATE_RXWARM                                      (_RAC_STATUS2_CURRSTATE_RXWARM << 12)     /**< Shifted mode RXWARM for RAC_STATUS2         */
#define RAC_STATUS2_CURRSTATE_RXSEARCH                                    (_RAC_STATUS2_CURRSTATE_RXSEARCH << 12)   /**< Shifted mode RXSEARCH for RAC_STATUS2       */
#define RAC_STATUS2_CURRSTATE_RXFRAME                                     (_RAC_STATUS2_CURRSTATE_RXFRAME << 12)    /**< Shifted mode RXFRAME for RAC_STATUS2        */
#define RAC_STATUS2_CURRSTATE_RXPD                                        (_RAC_STATUS2_CURRSTATE_RXPD << 12)       /**< Shifted mode RXPD for RAC_STATUS2           */
#define RAC_STATUS2_CURRSTATE_RX2RX                                       (_RAC_STATUS2_CURRSTATE_RX2RX << 12)      /**< Shifted mode RX2RX for RAC_STATUS2          */
#define RAC_STATUS2_CURRSTATE_RXOVERFLOW                                  (_RAC_STATUS2_CURRSTATE_RXOVERFLOW << 12) /**< Shifted mode RXOVERFLOW for RAC_STATUS2     */
#define RAC_STATUS2_CURRSTATE_RX2TX                                       (_RAC_STATUS2_CURRSTATE_RX2TX << 12)      /**< Shifted mode RX2TX for RAC_STATUS2          */
#define RAC_STATUS2_CURRSTATE_TXWARM                                      (_RAC_STATUS2_CURRSTATE_TXWARM << 12)     /**< Shifted mode TXWARM for RAC_STATUS2         */
#define RAC_STATUS2_CURRSTATE_TX                                          (_RAC_STATUS2_CURRSTATE_TX << 12)         /**< Shifted mode TX for RAC_STATUS2             */
#define RAC_STATUS2_CURRSTATE_TXPD                                        (_RAC_STATUS2_CURRSTATE_TXPD << 12)       /**< Shifted mode TXPD for RAC_STATUS2           */
#define RAC_STATUS2_CURRSTATE_TX2RX                                       (_RAC_STATUS2_CURRSTATE_TX2RX << 12)      /**< Shifted mode TX2RX for RAC_STATUS2          */
#define RAC_STATUS2_CURRSTATE_TX2TX                                       (_RAC_STATUS2_CURRSTATE_TX2TX << 12)      /**< Shifted mode TX2TX for RAC_STATUS2          */
#define RAC_STATUS2_CURRSTATE_SHUTDOWN                                    (_RAC_STATUS2_CURRSTATE_SHUTDOWN << 12)   /**< Shifted mode SHUTDOWN for RAC_STATUS2       */
#define RAC_STATUS2_CURRSTATE_POR                                         (_RAC_STATUS2_CURRSTATE_POR << 12)        /**< Shifted mode POR for RAC_STATUS2            */

/* Bit fields for RAC IFPGACTRL */
#define _RAC_IFPGACTRL_RESETVALUE                                         0x00000000UL                               /**< Default value for RAC_IFPGACTRL             */
#define _RAC_IFPGACTRL_MASK                                               0x1FF80000UL                               /**< Mask for RAC_IFPGACTRL                      */
#define RAC_IFPGACTRL_DCCALON                                             (0x1UL << 19)                              /**< Enable/Disable DCCAL in DEMOD               */
#define _RAC_IFPGACTRL_DCCALON_SHIFT                                      19                                         /**< Shift value for RAC_DCCALON                 */
#define _RAC_IFPGACTRL_DCCALON_MASK                                       0x80000UL                                  /**< Bit mask for RAC_DCCALON                    */
#define _RAC_IFPGACTRL_DCCALON_DEFAULT                                    0x00000000UL                               /**< Mode DEFAULT for RAC_IFPGACTRL              */
#define _RAC_IFPGACTRL_DCCALON_DISABLE                                    0x00000000UL                               /**< Mode DISABLE for RAC_IFPGACTRL              */
#define _RAC_IFPGACTRL_DCCALON_ENABLE                                     0x00000001UL                               /**< Mode ENABLE for RAC_IFPGACTRL               */
#define RAC_IFPGACTRL_DCCALON_DEFAULT                                     (_RAC_IFPGACTRL_DCCALON_DEFAULT << 19)     /**< Shifted mode DEFAULT for RAC_IFPGACTRL      */
#define RAC_IFPGACTRL_DCCALON_DISABLE                                     (_RAC_IFPGACTRL_DCCALON_DISABLE << 19)     /**< Shifted mode DISABLE for RAC_IFPGACTRL      */
#define RAC_IFPGACTRL_DCCALON_ENABLE                                      (_RAC_IFPGACTRL_DCCALON_ENABLE << 19)      /**< Shifted mode ENABLE for RAC_IFPGACTRL       */
#define RAC_IFPGACTRL_DCRSTEN                                             (0x1UL << 20)                              /**< DC Compensation Filter Reset Enable         */
#define _RAC_IFPGACTRL_DCRSTEN_SHIFT                                      20                                         /**< Shift value for RAC_DCRSTEN                 */
#define _RAC_IFPGACTRL_DCRSTEN_MASK                                       0x100000UL                                 /**< Bit mask for RAC_DCRSTEN                    */
#define _RAC_IFPGACTRL_DCRSTEN_DEFAULT                                    0x00000000UL                               /**< Mode DEFAULT for RAC_IFPGACTRL              */
#define _RAC_IFPGACTRL_DCRSTEN_DISABLE                                    0x00000000UL                               /**< Mode DISABLE for RAC_IFPGACTRL              */
#define _RAC_IFPGACTRL_DCRSTEN_ENABLE                                     0x00000001UL                               /**< Mode ENABLE for RAC_IFPGACTRL               */
#define RAC_IFPGACTRL_DCRSTEN_DEFAULT                                     (_RAC_IFPGACTRL_DCRSTEN_DEFAULT << 20)     /**< Shifted mode DEFAULT for RAC_IFPGACTRL      */
#define RAC_IFPGACTRL_DCRSTEN_DISABLE                                     (_RAC_IFPGACTRL_DCRSTEN_DISABLE << 20)     /**< Shifted mode DISABLE for RAC_IFPGACTRL      */
#define RAC_IFPGACTRL_DCRSTEN_ENABLE                                      (_RAC_IFPGACTRL_DCRSTEN_ENABLE << 20)      /**< Shifted mode ENABLE for RAC_IFPGACTRL       */
#define RAC_IFPGACTRL_DCESTIEN                                            (0x1UL << 21)                              /**< DCESTIEN Override for RAC                   */
#define _RAC_IFPGACTRL_DCESTIEN_SHIFT                                     21                                         /**< Shift value for RAC_DCESTIEN                */
#define _RAC_IFPGACTRL_DCESTIEN_MASK                                      0x200000UL                                 /**< Bit mask for RAC_DCESTIEN                   */
#define _RAC_IFPGACTRL_DCESTIEN_DEFAULT                                   0x00000000UL                               /**< Mode DEFAULT for RAC_IFPGACTRL              */
#define _RAC_IFPGACTRL_DCESTIEN_DISABLE                                   0x00000000UL                               /**< Mode DISABLE for RAC_IFPGACTRL              */
#define _RAC_IFPGACTRL_DCESTIEN_ENABLE                                    0x00000001UL                               /**< Mode ENABLE for RAC_IFPGACTRL               */
#define RAC_IFPGACTRL_DCESTIEN_DEFAULT                                    (_RAC_IFPGACTRL_DCESTIEN_DEFAULT << 21)    /**< Shifted mode DEFAULT for RAC_IFPGACTRL      */
#define RAC_IFPGACTRL_DCESTIEN_DISABLE                                    (_RAC_IFPGACTRL_DCESTIEN_DISABLE << 21)    /**< Shifted mode DISABLE for RAC_IFPGACTRL      */
#define RAC_IFPGACTRL_DCESTIEN_ENABLE                                     (_RAC_IFPGACTRL_DCESTIEN_ENABLE << 21)     /**< Shifted mode ENABLE for RAC_IFPGACTRL       */
#define _RAC_IFPGACTRL_DCCALDEC0_SHIFT                                    22                                         /**< Shift value for RAC_DCCALDEC0               */
#define _RAC_IFPGACTRL_DCCALDEC0_MASK                                     0x1C00000UL                                /**< Bit mask for RAC_DCCALDEC0                  */
#define _RAC_IFPGACTRL_DCCALDEC0_DEFAULT                                  0x00000000UL                               /**< Mode DEFAULT for RAC_IFPGACTRL              */
#define _RAC_IFPGACTRL_DCCALDEC0_DF3                                      0x00000000UL                               /**< Mode DF3 for RAC_IFPGACTRL                  */
#define _RAC_IFPGACTRL_DCCALDEC0_DF4WIDE                                  0x00000001UL                               /**< Mode DF4WIDE for RAC_IFPGACTRL              */
#define _RAC_IFPGACTRL_DCCALDEC0_DF4NARROW                                0x00000002UL                               /**< Mode DF4NARROW for RAC_IFPGACTRL            */
#define _RAC_IFPGACTRL_DCCALDEC0_DF8WIDE                                  0x00000003UL                               /**< Mode DF8WIDE for RAC_IFPGACTRL              */
#define _RAC_IFPGACTRL_DCCALDEC0_DF8NARROW                                0x00000004UL                               /**< Mode DF8NARROW for RAC_IFPGACTRL            */
#define RAC_IFPGACTRL_DCCALDEC0_DEFAULT                                   (_RAC_IFPGACTRL_DCCALDEC0_DEFAULT << 22)   /**< Shifted mode DEFAULT for RAC_IFPGACTRL      */
#define RAC_IFPGACTRL_DCCALDEC0_DF3                                       (_RAC_IFPGACTRL_DCCALDEC0_DF3 << 22)       /**< Shifted mode DF3 for RAC_IFPGACTRL          */
#define RAC_IFPGACTRL_DCCALDEC0_DF4WIDE                                   (_RAC_IFPGACTRL_DCCALDEC0_DF4WIDE << 22)   /**< Shifted mode DF4WIDE for RAC_IFPGACTRL      */
#define RAC_IFPGACTRL_DCCALDEC0_DF4NARROW                                 (_RAC_IFPGACTRL_DCCALDEC0_DF4NARROW << 22) /**< Shifted mode DF4NARROW for RAC_IFPGACTRL    */
#define RAC_IFPGACTRL_DCCALDEC0_DF8WIDE                                   (_RAC_IFPGACTRL_DCCALDEC0_DF8WIDE << 22)   /**< Shifted mode DF8WIDE for RAC_IFPGACTRL      */
#define RAC_IFPGACTRL_DCCALDEC0_DF8NARROW                                 (_RAC_IFPGACTRL_DCCALDEC0_DF8NARROW << 22) /**< Shifted mode DF8NARROW for RAC_IFPGACTRL    */
#define _RAC_IFPGACTRL_DCCALDCGEAR_SHIFT                                  25                                         /**< Shift value for RAC_DCCALDCGEAR             */
#define _RAC_IFPGACTRL_DCCALDCGEAR_MASK                                   0x1E000000UL                               /**< Bit mask for RAC_DCCALDCGEAR                */
#define _RAC_IFPGACTRL_DCCALDCGEAR_DEFAULT                                0x00000000UL                               /**< Mode DEFAULT for RAC_IFPGACTRL              */
#define RAC_IFPGACTRL_DCCALDCGEAR_DEFAULT                                 (_RAC_IFPGACTRL_DCCALDCGEAR_DEFAULT << 25) /**< Shifted mode DEFAULT for RAC_IFPGACTRL      */

/* Bit fields for RAC PAENCTRL */
#define _RAC_PAENCTRL_RESETVALUE                                          0x00000000UL                                 /**< Default value for RAC_PAENCTRL              */
#define _RAC_PAENCTRL_MASK                                                0x00070100UL                                 /**< Mask for RAC_PAENCTRL                       */
#define RAC_PAENCTRL_PARAMP                                               (0x1UL << 8)                                 /**< PA output level ramping                     */
#define _RAC_PAENCTRL_PARAMP_SHIFT                                        8                                            /**< Shift value for RAC_PARAMP                  */
#define _RAC_PAENCTRL_PARAMP_MASK                                         0x100UL                                      /**< Bit mask for RAC_PARAMP                     */
#define _RAC_PAENCTRL_PARAMP_DEFAULT                                      0x00000000UL                                 /**< Mode DEFAULT for RAC_PAENCTRL               */
#define RAC_PAENCTRL_PARAMP_DEFAULT                                       (_RAC_PAENCTRL_PARAMP_DEFAULT << 8)          /**< Shifted mode DEFAULT for RAC_PAENCTRL       */
#define RAC_PAENCTRL_INVRAMPCLK                                           (0x1UL << 16)                                /**< Invert PA ramping clock                     */
#define _RAC_PAENCTRL_INVRAMPCLK_SHIFT                                    16                                           /**< Shift value for RAC_INVRAMPCLK              */
#define _RAC_PAENCTRL_INVRAMPCLK_MASK                                     0x10000UL                                    /**< Bit mask for RAC_INVRAMPCLK                 */
#define _RAC_PAENCTRL_INVRAMPCLK_DEFAULT                                  0x00000000UL                                 /**< Mode DEFAULT for RAC_PAENCTRL               */
#define RAC_PAENCTRL_INVRAMPCLK_DEFAULT                                   (_RAC_PAENCTRL_INVRAMPCLK_DEFAULT << 16)     /**< Shifted mode DEFAULT for RAC_PAENCTRL       */
#define RAC_PAENCTRL_DIV2RAMPCLK                                          (0x1UL << 17)                                /**< Div PA ramping clock by 2                   */
#define _RAC_PAENCTRL_DIV2RAMPCLK_SHIFT                                   17                                           /**< Shift value for RAC_DIV2RAMPCLK             */
#define _RAC_PAENCTRL_DIV2RAMPCLK_MASK                                    0x20000UL                                    /**< Bit mask for RAC_DIV2RAMPCLK                */
#define _RAC_PAENCTRL_DIV2RAMPCLK_DEFAULT                                 0x00000000UL                                 /**< Mode DEFAULT for RAC_PAENCTRL               */
#define RAC_PAENCTRL_DIV2RAMPCLK_DEFAULT                                  (_RAC_PAENCTRL_DIV2RAMPCLK_DEFAULT << 17)    /**< Shifted mode DEFAULT for RAC_PAENCTRL       */
#define RAC_PAENCTRL_RSTDIV2RAMPCLK                                       (0x1UL << 18)                                /**< Reset Div2 PA ramping clock                 */
#define _RAC_PAENCTRL_RSTDIV2RAMPCLK_SHIFT                                18                                           /**< Shift value for RAC_RSTDIV2RAMPCLK          */
#define _RAC_PAENCTRL_RSTDIV2RAMPCLK_MASK                                 0x40000UL                                    /**< Bit mask for RAC_RSTDIV2RAMPCLK             */
#define _RAC_PAENCTRL_RSTDIV2RAMPCLK_DEFAULT                              0x00000000UL                                 /**< Mode DEFAULT for RAC_PAENCTRL               */
#define RAC_PAENCTRL_RSTDIV2RAMPCLK_DEFAULT                               (_RAC_PAENCTRL_RSTDIV2RAMPCLK_DEFAULT << 18) /**< Shifted mode DEFAULT for RAC_PAENCTRL       */

/* Bit fields for RAC APC */
#define _RAC_APC_RESETVALUE                                               0xFF000000UL                               /**< Default value for RAC_APC                   */
#define _RAC_APC_MASK                                                     0xFF000004UL                               /**< Mask for RAC_APC                            */
#define RAC_APC_ENAPCSW                                                   (0x1UL << 2)                               /**< software control bit for apc                */
#define _RAC_APC_ENAPCSW_SHIFT                                            2                                          /**< Shift value for RAC_ENAPCSW                 */
#define _RAC_APC_ENAPCSW_MASK                                             0x4UL                                      /**< Bit mask for RAC_ENAPCSW                    */
#define _RAC_APC_ENAPCSW_DEFAULT                                          0x00000000UL                               /**< Mode DEFAULT for RAC_APC                    */
#define _RAC_APC_ENAPCSW_DISABLE                                          0x00000000UL                               /**< Mode DISABLE for RAC_APC                    */
#define _RAC_APC_ENAPCSW_ENABLE                                           0x00000001UL                               /**< Mode ENABLE for RAC_APC                     */
#define RAC_APC_ENAPCSW_DEFAULT                                           (_RAC_APC_ENAPCSW_DEFAULT << 2)            /**< Shifted mode DEFAULT for RAC_APC            */
#define RAC_APC_ENAPCSW_DISABLE                                           (_RAC_APC_ENAPCSW_DISABLE << 2)            /**< Shifted mode DISABLE for RAC_APC            */
#define RAC_APC_ENAPCSW_ENABLE                                            (_RAC_APC_ENAPCSW_ENABLE << 2)             /**< Shifted mode ENABLE for RAC_APC             */
#define _RAC_APC_AMPCONTROLLIMITSW_SHIFT                                  24                                         /**< Shift value for RAC_AMPCONTROLLIMITSW       */
#define _RAC_APC_AMPCONTROLLIMITSW_MASK                                   0xFF000000UL                               /**< Bit mask for RAC_AMPCONTROLLIMITSW          */
#define _RAC_APC_AMPCONTROLLIMITSW_DEFAULT                                0x000000FFUL                               /**< Mode DEFAULT for RAC_APC                    */
#define RAC_APC_AMPCONTROLLIMITSW_DEFAULT                                 (_RAC_APC_AMPCONTROLLIMITSW_DEFAULT << 24) /**< Shifted mode DEFAULT for RAC_APC            */

/* Bit fields for RAC ANTDIV */
#define _RAC_ANTDIV_RESETVALUE                                            0x00000000UL                                       /**< Default value for RAC_ANTDIV                */
#define _RAC_ANTDIV_MASK                                                  0x00000FFFUL                                       /**< Mask for RAC_ANTDIV                         */
#define RAC_ANTDIV_INTDIVLNAMIXEN0                                        (0x1UL << 0)                                       /**< INTDIVLNAMIXEN0                             */
#define _RAC_ANTDIV_INTDIVLNAMIXEN0_SHIFT                                 0                                                  /**< Shift value for RAC_INTDIVLNAMIXEN0         */
#define _RAC_ANTDIV_INTDIVLNAMIXEN0_MASK                                  0x1UL                                              /**< Bit mask for RAC_INTDIVLNAMIXEN0            */
#define _RAC_ANTDIV_INTDIVLNAMIXEN0_DEFAULT                               0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define RAC_ANTDIV_INTDIVLNAMIXEN0_DEFAULT                                (_RAC_ANTDIV_INTDIVLNAMIXEN0_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define RAC_ANTDIV_INTDIVLNAMIXENAMP0                                     (0x1UL << 1)                                       /**< INTDIVLNAMIXENAMP0                          */
#define _RAC_ANTDIV_INTDIVLNAMIXENAMP0_SHIFT                              1                                                  /**< Shift value for RAC_INTDIVLNAMIXENAMP0      */
#define _RAC_ANTDIV_INTDIVLNAMIXENAMP0_MASK                               0x2UL                                              /**< Bit mask for RAC_INTDIVLNAMIXENAMP0         */
#define _RAC_ANTDIV_INTDIVLNAMIXENAMP0_DEFAULT                            0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define RAC_ANTDIV_INTDIVLNAMIXENAMP0_DEFAULT                             (_RAC_ANTDIV_INTDIVLNAMIXENAMP0_DEFAULT << 1)      /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN0                                 (0x1UL << 2)                                       /**< INTDIVLNAMIXRFATTDCEN0                      */
#define _RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN0_SHIFT                          2                                                  /**< Shift value for RAC_INTDIVLNAMIXRFATTDCEN0  */
#define _RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN0_MASK                           0x4UL                                              /**< Bit mask for RAC_INTDIVLNAMIXRFATTDCEN0     */
#define _RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN0_DEFAULT                        0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN0_DEFAULT                         (_RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN0_DEFAULT << 2)  /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF0                                 (0x1UL << 3)                                       /**< INTDIVLNAMIXRFPKDENRF0                      */
#define _RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF0_SHIFT                          3                                                  /**< Shift value for RAC_INTDIVLNAMIXRFPKDENRF0  */
#define _RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF0_MASK                           0x8UL                                              /**< Bit mask for RAC_INTDIVLNAMIXRFPKDENRF0     */
#define _RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF0_DEFAULT                        0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF0_DEFAULT                         (_RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF0_DEFAULT << 3)  /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define RAC_ANTDIV_INTDIVSYLODIVRLO0SUBGEN                                (0x1UL << 4)                                       /**< INTDIVSYLODIVRLO0SUBGEN                     */
#define _RAC_ANTDIV_INTDIVSYLODIVRLO0SUBGEN_SHIFT                         4                                                  /**< Shift value for RAC_INTDIVSYLODIVRLO0SUBGEN */
#define _RAC_ANTDIV_INTDIVSYLODIVRLO0SUBGEN_MASK                          0x10UL                                             /**< Bit mask for RAC_INTDIVSYLODIVRLO0SUBGEN    */
#define _RAC_ANTDIV_INTDIVSYLODIVRLO0SUBGEN_DEFAULT                       0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define RAC_ANTDIV_INTDIVSYLODIVRLO0SUBGEN_DEFAULT                        (_RAC_ANTDIV_INTDIVSYLODIVRLO0SUBGEN_DEFAULT << 4) /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define RAC_ANTDIV_INTDIVLNAMIXEN1                                        (0x1UL << 5)                                       /**< INTDIVLNAMIXEN1                             */
#define _RAC_ANTDIV_INTDIVLNAMIXEN1_SHIFT                                 5                                                  /**< Shift value for RAC_INTDIVLNAMIXEN1         */
#define _RAC_ANTDIV_INTDIVLNAMIXEN1_MASK                                  0x20UL                                             /**< Bit mask for RAC_INTDIVLNAMIXEN1            */
#define _RAC_ANTDIV_INTDIVLNAMIXEN1_DEFAULT                               0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define RAC_ANTDIV_INTDIVLNAMIXEN1_DEFAULT                                (_RAC_ANTDIV_INTDIVLNAMIXEN1_DEFAULT << 5)         /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define RAC_ANTDIV_INTDIVLNAMIXENAMP1                                     (0x1UL << 6)                                       /**< INTDIVLNAMIXENAMP1                          */
#define _RAC_ANTDIV_INTDIVLNAMIXENAMP1_SHIFT                              6                                                  /**< Shift value for RAC_INTDIVLNAMIXENAMP1      */
#define _RAC_ANTDIV_INTDIVLNAMIXENAMP1_MASK                               0x40UL                                             /**< Bit mask for RAC_INTDIVLNAMIXENAMP1         */
#define _RAC_ANTDIV_INTDIVLNAMIXENAMP1_DEFAULT                            0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define RAC_ANTDIV_INTDIVLNAMIXENAMP1_DEFAULT                             (_RAC_ANTDIV_INTDIVLNAMIXENAMP1_DEFAULT << 6)      /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN1                                 (0x1UL << 7)                                       /**< INTDIVLNAMIXRFATTDCEN1                      */
#define _RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN1_SHIFT                          7                                                  /**< Shift value for RAC_INTDIVLNAMIXRFATTDCEN1  */
#define _RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN1_MASK                           0x80UL                                             /**< Bit mask for RAC_INTDIVLNAMIXRFATTDCEN1     */
#define _RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN1_DEFAULT                        0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN1_DEFAULT                         (_RAC_ANTDIV_INTDIVLNAMIXRFATTDCEN1_DEFAULT << 7)  /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF1                                 (0x1UL << 8)                                       /**< INTDIVLNAMIXRFPKDENRF1                      */
#define _RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF1_SHIFT                          8                                                  /**< Shift value for RAC_INTDIVLNAMIXRFPKDENRF1  */
#define _RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF1_MASK                           0x100UL                                            /**< Bit mask for RAC_INTDIVLNAMIXRFPKDENRF1     */
#define _RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF1_DEFAULT                        0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF1_DEFAULT                         (_RAC_ANTDIV_INTDIVLNAMIXRFPKDENRF1_DEFAULT << 8)  /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define RAC_ANTDIV_INTDIVSYLODIVRLO1SUBGEN                                (0x1UL << 9)                                       /**< INTDIVSYLODIVRLO1SUBGEN                     */
#define _RAC_ANTDIV_INTDIVSYLODIVRLO1SUBGEN_SHIFT                         9                                                  /**< Shift value for RAC_INTDIVSYLODIVRLO1SUBGEN */
#define _RAC_ANTDIV_INTDIVSYLODIVRLO1SUBGEN_MASK                          0x200UL                                            /**< Bit mask for RAC_INTDIVSYLODIVRLO1SUBGEN    */
#define _RAC_ANTDIV_INTDIVSYLODIVRLO1SUBGEN_DEFAULT                       0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define RAC_ANTDIV_INTDIVSYLODIVRLO1SUBGEN_DEFAULT                        (_RAC_ANTDIV_INTDIVSYLODIVRLO1SUBGEN_DEFAULT << 9) /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define _RAC_ANTDIV_ANTDIVSTATUS_SHIFT                                    10                                                 /**< Shift value for RAC_ANTDIVSTATUS            */
#define _RAC_ANTDIV_ANTDIVSTATUS_MASK                                     0xC00UL                                            /**< Bit mask for RAC_ANTDIVSTATUS               */
#define _RAC_ANTDIV_ANTDIVSTATUS_DEFAULT                                  0x00000000UL                                       /**< Mode DEFAULT for RAC_ANTDIV                 */
#define _RAC_ANTDIV_ANTDIVSTATUS_OFF                                      0x00000000UL                                       /**< Mode OFF for RAC_ANTDIV                     */
#define _RAC_ANTDIV_ANTDIVSTATUS_ANT1                                     0x00000001UL                                       /**< Mode ANT1 for RAC_ANTDIV                    */
#define _RAC_ANTDIV_ANTDIVSTATUS_ANT2                                     0x00000002UL                                       /**< Mode ANT2 for RAC_ANTDIV                    */
#define _RAC_ANTDIV_ANTDIVSTATUS_BOTH                                     0x00000003UL                                       /**< Mode BOTH for RAC_ANTDIV                    */
#define RAC_ANTDIV_ANTDIVSTATUS_DEFAULT                                   (_RAC_ANTDIV_ANTDIVSTATUS_DEFAULT << 10)           /**< Shifted mode DEFAULT for RAC_ANTDIV         */
#define RAC_ANTDIV_ANTDIVSTATUS_OFF                                       (_RAC_ANTDIV_ANTDIVSTATUS_OFF << 10)               /**< Shifted mode OFF for RAC_ANTDIV             */
#define RAC_ANTDIV_ANTDIVSTATUS_ANT1                                      (_RAC_ANTDIV_ANTDIVSTATUS_ANT1 << 10)              /**< Shifted mode ANT1 for RAC_ANTDIV            */
#define RAC_ANTDIV_ANTDIVSTATUS_ANT2                                      (_RAC_ANTDIV_ANTDIVSTATUS_ANT2 << 10)              /**< Shifted mode ANT2 for RAC_ANTDIV            */
#define RAC_ANTDIV_ANTDIVSTATUS_BOTH                                      (_RAC_ANTDIV_ANTDIVSTATUS_BOTH << 10)              /**< Shifted mode BOTH for RAC_ANTDIV            */

/* Bit fields for RAC AUXADCTRIM */
#define _RAC_AUXADCTRIM_RESETVALUE                                        0x06D55504UL                                                     /**< Default value for RAC_AUXADCTRIM            */
#define _RAC_AUXADCTRIM_MASK                                              0x1FFFFFFFUL                                                     /**< Mask for RAC_AUXADCTRIM                     */
#define RAC_AUXADCTRIM_AUXADCCLKINVERT                                    (0x1UL << 0)                                                     /**< AUXADCCLKINVERT                             */
#define _RAC_AUXADCTRIM_AUXADCCLKINVERT_SHIFT                             0                                                                /**< Shift value for RAC_AUXADCCLKINVERT         */
#define _RAC_AUXADCTRIM_AUXADCCLKINVERT_MASK                              0x1UL                                                            /**< Bit mask for RAC_AUXADCCLKINVERT            */
#define _RAC_AUXADCTRIM_AUXADCCLKINVERT_DEFAULT                           0x00000000UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCCLKINVERT_Disable_Invert                    0x00000000UL                                                     /**< Mode Disable_Invert for RAC_AUXADCTRIM      */
#define _RAC_AUXADCTRIM_AUXADCCLKINVERT_Enable_Invert                     0x00000001UL                                                     /**< Mode Enable_Invert for RAC_AUXADCTRIM       */
#define RAC_AUXADCTRIM_AUXADCCLKINVERT_DEFAULT                            (_RAC_AUXADCTRIM_AUXADCCLKINVERT_DEFAULT << 0)                   /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCCLKINVERT_Disable_Invert                     (_RAC_AUXADCTRIM_AUXADCCLKINVERT_Disable_Invert << 0)            /**< Shifted mode Disable_Invert for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCCLKINVERT_Enable_Invert                      (_RAC_AUXADCTRIM_AUXADCCLKINVERT_Enable_Invert << 0)             /**< Shifted mode Enable_Invert for RAC_AUXADCTRIM*/
#define _RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_SHIFT                           1                                                                /**< Shift value for RAC_AUXADCLDOVREFTRIM       */
#define _RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_MASK                            0x6UL                                                            /**< Bit mask for RAC_AUXADCLDOVREFTRIM          */
#define _RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_DEFAULT                         0x00000002UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p27                        0x00000000UL                                                     /**< Mode TRIM1p27 for RAC_AUXADCTRIM            */
#define _RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p3                         0x00000001UL                                                     /**< Mode TRIM1p3 for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p35                        0x00000002UL                                                     /**< Mode TRIM1p35 for RAC_AUXADCTRIM            */
#define _RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p4                         0x00000003UL                                                     /**< Mode TRIM1p4 for RAC_AUXADCTRIM             */
#define RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_DEFAULT                          (_RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_DEFAULT << 1)                 /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p27                         (_RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p27 << 1)                /**< Shifted mode TRIM1p27 for RAC_AUXADCTRIM    */
#define RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p3                          (_RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p3 << 1)                 /**< Shifted mode TRIM1p3 for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p35                         (_RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p35 << 1)                /**< Shifted mode TRIM1p35 for RAC_AUXADCTRIM    */
#define RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p4                          (_RAC_AUXADCTRIM_AUXADCLDOVREFTRIM_TRIM1p4 << 1)                 /**< Shifted mode TRIM1p4 for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCOUTPUTINVERT                                 (0x1UL << 3)                                                     /**< AUXADCOUTPUTINVERT                          */
#define _RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_SHIFT                          3                                                                /**< Shift value for RAC_AUXADCOUTPUTINVERT      */
#define _RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_MASK                           0x8UL                                                            /**< Bit mask for RAC_AUXADCOUTPUTINVERT         */
#define _RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_DEFAULT                        0x00000000UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_Disabled                       0x00000000UL                                                     /**< Mode Disabled for RAC_AUXADCTRIM            */
#define _RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_Enabled                        0x00000001UL                                                     /**< Mode Enabled for RAC_AUXADCTRIM             */
#define RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_DEFAULT                         (_RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_DEFAULT << 3)                /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_Disabled                        (_RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_Disabled << 3)               /**< Shifted mode Disabled for RAC_AUXADCTRIM    */
#define RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_Enabled                         (_RAC_AUXADCTRIM_AUXADCOUTPUTINVERT_Enabled << 3)                /**< Shifted mode Enabled for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCRCTUNE_SHIFT                                4                                                                /**< Shift value for RAC_AUXADCRCTUNE            */
#define _RAC_AUXADCTRIM_AUXADCRCTUNE_MASK                                 0x1F0UL                                                          /**< Bit mask for RAC_AUXADCRCTUNE               */
#define _RAC_AUXADCTRIM_AUXADCRCTUNE_DEFAULT                              0x00000010UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define RAC_AUXADCTRIM_AUXADCRCTUNE_DEFAULT                               (_RAC_AUXADCTRIM_AUXADCRCTUNE_DEFAULT << 4)                      /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_SHIFT                       9                                                                /**< Shift value for RAC_AUXADCTRIMADCINPUTRES   */
#define _RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_MASK                        0x600UL                                                          /**< Bit mask for RAC_AUXADCTRIMADCINPUTRES      */
#define _RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_DEFAULT                     0x00000002UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES200k                     0x00000000UL                                                     /**< Mode RES200k for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES250k                     0x00000001UL                                                     /**< Mode RES250k for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES300k                     0x00000002UL                                                     /**< Mode RES300k for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES350k                     0x00000003UL                                                     /**< Mode RES350k for RAC_AUXADCTRIM             */
#define RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_DEFAULT                      (_RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_DEFAULT << 9)             /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES200k                      (_RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES200k << 9)             /**< Shifted mode RES200k for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES250k                      (_RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES250k << 9)             /**< Shifted mode RES250k for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES300k                      (_RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES300k << 9)             /**< Shifted mode RES300k for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES350k                      (_RAC_AUXADCTRIM_AUXADCTRIMADCINPUTRES_RES350k << 9)             /**< Shifted mode RES350k for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_SHIFT                      11                                                               /**< Shift value for RAC_AUXADCTRIMCURRINPUTBUF  */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_MASK                       0x1800UL                                                         /**< Bit mask for RAC_AUXADCTRIMCURRINPUTBUF     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_DEFAULT                    0x00000002UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ_minus_40pct            0x00000000UL                                                     /**< Mode Typ_minus_40pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ_minus_20pct            0x00000001UL                                                     /**< Mode Typ_minus_20pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ                        0x00000002UL                                                     /**< Mode Typ for RAC_AUXADCTRIM                 */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ_plus_20pct             0x00000003UL                                                     /**< Mode Typ_plus_20pct for RAC_AUXADCTRIM      */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_DEFAULT                     (_RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_DEFAULT << 11)           /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ_minus_40pct             (_RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ_minus_40pct << 11)   /**< Shifted mode Typ_minus_40pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ_minus_20pct             (_RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ_minus_20pct << 11)   /**< Shifted mode Typ_minus_20pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ                         (_RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ << 11)               /**< Shifted mode Typ for RAC_AUXADCTRIM         */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ_plus_20pct              (_RAC_AUXADCTRIM_AUXADCTRIMCURRINPUTBUF_Typ_plus_20pct << 11)    /**< Shifted mode Typ_plus_20pct for RAC_AUXADCTRIM*/
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_SHIFT                          13                                                               /**< Shift value for RAC_AUXADCTRIMCURROPA1      */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_MASK                           0x6000UL                                                         /**< Bit mask for RAC_AUXADCTRIMCURROPA1         */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_DEFAULT                        0x00000002UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ_minus_40pct                0x00000000UL                                                     /**< Mode Typ_minus_40pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ_minus_20pct                0x00000001UL                                                     /**< Mode Typ_minus_20pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ                            0x00000002UL                                                     /**< Mode Typ for RAC_AUXADCTRIM                 */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ_plus_20pct                 0x00000003UL                                                     /**< Mode Typ_plus_20pct for RAC_AUXADCTRIM      */
#define RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_DEFAULT                         (_RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_DEFAULT << 13)               /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ_minus_40pct                 (_RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ_minus_40pct << 13)       /**< Shifted mode Typ_minus_40pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ_minus_20pct                 (_RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ_minus_20pct << 13)       /**< Shifted mode Typ_minus_20pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ                             (_RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ << 13)                   /**< Shifted mode Typ for RAC_AUXADCTRIM         */
#define RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ_plus_20pct                  (_RAC_AUXADCTRIM_AUXADCTRIMCURROPA1_Typ_plus_20pct << 13)        /**< Shifted mode Typ_plus_20pct for RAC_AUXADCTRIM*/
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_SHIFT                          15                                                               /**< Shift value for RAC_AUXADCTRIMCURROPA2      */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_MASK                           0x18000UL                                                        /**< Bit mask for RAC_AUXADCTRIMCURROPA2         */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_DEFAULT                        0x00000002UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ_minus_40pct                0x00000000UL                                                     /**< Mode Typ_minus_40pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ_minus_20pct                0x00000001UL                                                     /**< Mode Typ_minus_20pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ                            0x00000002UL                                                     /**< Mode Typ for RAC_AUXADCTRIM                 */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ_plus_20pct                 0x00000003UL                                                     /**< Mode Typ_plus_20pct for RAC_AUXADCTRIM      */
#define RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_DEFAULT                         (_RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_DEFAULT << 15)               /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ_minus_40pct                 (_RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ_minus_40pct << 15)       /**< Shifted mode Typ_minus_40pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ_minus_20pct                 (_RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ_minus_20pct << 15)       /**< Shifted mode Typ_minus_20pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ                             (_RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ << 15)                   /**< Shifted mode Typ for RAC_AUXADCTRIM         */
#define RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ_plus_20pct                  (_RAC_AUXADCTRIM_AUXADCTRIMCURROPA2_Typ_plus_20pct << 15)        /**< Shifted mode Typ_plus_20pct for RAC_AUXADCTRIM*/
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_SHIFT                        17                                                               /**< Shift value for RAC_AUXADCTRIMCURRREFBUF    */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_MASK                         0x60000UL                                                        /**< Bit mask for RAC_AUXADCTRIMCURRREFBUF       */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_DEFAULT                      0x00000002UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ_minus_40pct              0x00000000UL                                                     /**< Mode Typ_minus_40pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ_minus_20pct              0x00000001UL                                                     /**< Mode Typ_minus_20pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ                          0x00000002UL                                                     /**< Mode Typ for RAC_AUXADCTRIM                 */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ_plus_20pct               0x00000003UL                                                     /**< Mode Typ_plus_20pct for RAC_AUXADCTRIM      */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_DEFAULT                       (_RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_DEFAULT << 17)             /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ_minus_40pct               (_RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ_minus_40pct << 17)     /**< Shifted mode Typ_minus_40pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ_minus_20pct               (_RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ_minus_20pct << 17)     /**< Shifted mode Typ_minus_20pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ                           (_RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ << 17)                 /**< Shifted mode Typ for RAC_AUXADCTRIM         */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ_plus_20pct                (_RAC_AUXADCTRIM_AUXADCTRIMCURRREFBUF_Typ_plus_20pct << 17)      /**< Shifted mode Typ_plus_20pct for RAC_AUXADCTRIM*/
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_SHIFT                        19                                                               /**< Shift value for RAC_AUXADCTRIMCURRTSENSE    */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_MASK                         0x180000UL                                                       /**< Bit mask for RAC_AUXADCTRIMCURRTSENSE       */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_DEFAULT                      0x00000002UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ_minus_40pct              0x00000000UL                                                     /**< Mode Typ_minus_40pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ_minus_20pct              0x00000001UL                                                     /**< Mode Typ_minus_20pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ                          0x00000002UL                                                     /**< Mode Typ for RAC_AUXADCTRIM                 */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ_plus_20pct               0x00000003UL                                                     /**< Mode Typ_plus_20pct for RAC_AUXADCTRIM      */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_DEFAULT                       (_RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_DEFAULT << 19)             /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ_minus_40pct               (_RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ_minus_40pct << 19)     /**< Shifted mode Typ_minus_40pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ_minus_20pct               (_RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ_minus_20pct << 19)     /**< Shifted mode Typ_minus_20pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ                           (_RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ << 19)                 /**< Shifted mode Typ for RAC_AUXADCTRIM         */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ_plus_20pct                (_RAC_AUXADCTRIM_AUXADCTRIMCURRTSENSE_Typ_plus_20pct << 19)      /**< Shifted mode Typ_plus_20pct for RAC_AUXADCTRIM*/
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_SHIFT                        21                                                               /**< Shift value for RAC_AUXADCTRIMCURRVCMBUF    */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_MASK                         0x600000UL                                                       /**< Bit mask for RAC_AUXADCTRIMCURRVCMBUF       */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_DEFAULT                      0x00000002UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ_minus_40pct              0x00000000UL                                                     /**< Mode Typ_minus_40pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ_minus_20pct              0x00000001UL                                                     /**< Mode Typ_minus_20pct for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ                          0x00000002UL                                                     /**< Mode Typ for RAC_AUXADCTRIM                 */
#define _RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ_plus_20pct               0x00000003UL                                                     /**< Mode Typ_plus_20pct for RAC_AUXADCTRIM      */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_DEFAULT                       (_RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_DEFAULT << 21)             /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ_minus_40pct               (_RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ_minus_40pct << 21)     /**< Shifted mode Typ_minus_40pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ_minus_20pct               (_RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ_minus_20pct << 21)     /**< Shifted mode Typ_minus_20pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ                           (_RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ << 21)                 /**< Shifted mode Typ for RAC_AUXADCTRIM         */
#define RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ_plus_20pct                (_RAC_AUXADCTRIM_AUXADCTRIMCURRVCMBUF_Typ_plus_20pct << 21)      /**< Shifted mode Typ_plus_20pct for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT                           (0x1UL << 23)                                                    /**< AUXADCTRIMLDOHIGHCURRENT                    */
#define _RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_SHIFT                    23                                                               /**< Shift value for RAC_AUXADCTRIMLDOHIGHCURRENT*/
#define _RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_MASK                     0x800000UL                                                       /**< Bit mask for RAC_AUXADCTRIMLDOHIGHCURRENT   */
#define _RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_DEFAULT                  0x00000001UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_LowCurrentMode           0x00000000UL                                                     /**< Mode LowCurrentMode for RAC_AUXADCTRIM      */
#define _RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_HighCurrentMode          0x00000001UL                                                     /**< Mode HighCurrentMode for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_DEFAULT                   (_RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_DEFAULT << 23)         /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_LowCurrentMode            (_RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_LowCurrentMode << 23)  /**< Shifted mode LowCurrentMode for RAC_AUXADCTRIM*/
#define RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_HighCurrentMode           (_RAC_AUXADCTRIM_AUXADCTRIMLDOHIGHCURRENT_HighCurrentMode << 23) /**< Shifted mode HighCurrentMode for RAC_AUXADCTRIM*/
#define _RAC_AUXADCTRIM_AUXADCTRIMREFP_SHIFT                              24                                                               /**< Shift value for RAC_AUXADCTRIMREFP          */
#define _RAC_AUXADCTRIM_AUXADCTRIMREFP_MASK                               0x3000000UL                                                      /**< Bit mask for RAC_AUXADCTRIMREFP             */
#define _RAC_AUXADCTRIM_AUXADCTRIMREFP_DEFAULT                            0x00000002UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p05                            0x00000000UL                                                     /**< Mode REF1p05 for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p16                            0x00000001UL                                                     /**< Mode REF1p16 for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p2                             0x00000002UL                                                     /**< Mode REF1p2 for RAC_AUXADCTRIM              */
#define _RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p25                            0x00000003UL                                                     /**< Mode REF1p25 for RAC_AUXADCTRIM             */
#define RAC_AUXADCTRIM_AUXADCTRIMREFP_DEFAULT                             (_RAC_AUXADCTRIM_AUXADCTRIMREFP_DEFAULT << 24)                   /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p05                             (_RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p05 << 24)                   /**< Shifted mode REF1p05 for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p16                             (_RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p16 << 24)                   /**< Shifted mode REF1p16 for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p2                              (_RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p2 << 24)                    /**< Shifted mode REF1p2 for RAC_AUXADCTRIM      */
#define RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p25                             (_RAC_AUXADCTRIM_AUXADCTRIMREFP_REF1p25 << 24)                   /**< Shifted mode REF1p25 for RAC_AUXADCTRIM     */
#define _RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_SHIFT                           26                                                               /**< Shift value for RAC_AUXADCTRIMVREFVCM       */
#define _RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_MASK                            0xC000000UL                                                      /**< Bit mask for RAC_AUXADCTRIMVREFVCM          */
#define _RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_DEFAULT                         0x00000001UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p6                         0x00000000UL                                                     /**< Mode Trim0p6 for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p65                        0x00000001UL                                                     /**< Mode Trim0p65 for RAC_AUXADCTRIM            */
#define _RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p7                         0x00000002UL                                                     /**< Mode Trim0p7 for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p75                        0x00000003UL                                                     /**< Mode Trim0p75 for RAC_AUXADCTRIM            */
#define RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_DEFAULT                          (_RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_DEFAULT << 26)                /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p6                          (_RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p6 << 26)                /**< Shifted mode Trim0p6 for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p65                         (_RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p65 << 26)               /**< Shifted mode Trim0p65 for RAC_AUXADCTRIM    */
#define RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p7                          (_RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p7 << 26)                /**< Shifted mode Trim0p7 for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p75                         (_RAC_AUXADCTRIM_AUXADCTRIMVREFVCM_Trim0p75 << 26)               /**< Shifted mode Trim0p75 for RAC_AUXADCTRIM    */
#define RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2                               (0x1UL << 28)                                                    /**< AUXADCTSENSETRIMVBE2                        */
#define _RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_SHIFT                        28                                                               /**< Shift value for RAC_AUXADCTSENSETRIMVBE2    */
#define _RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_MASK                         0x10000000UL                                                     /**< Bit mask for RAC_AUXADCTSENSETRIMVBE2       */
#define _RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_DEFAULT                      0x00000000UL                                                     /**< Mode DEFAULT for RAC_AUXADCTRIM             */
#define _RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_VBE_16uA                     0x00000000UL                                                     /**< Mode VBE_16uA for RAC_AUXADCTRIM            */
#define _RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_VBE_32uA                     0x00000001UL                                                     /**< Mode VBE_32uA for RAC_AUXADCTRIM            */
#define RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_DEFAULT                       (_RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_DEFAULT << 28)             /**< Shifted mode DEFAULT for RAC_AUXADCTRIM     */
#define RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_VBE_16uA                      (_RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_VBE_16uA << 28)            /**< Shifted mode VBE_16uA for RAC_AUXADCTRIM    */
#define RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_VBE_32uA                      (_RAC_AUXADCTRIM_AUXADCTSENSETRIMVBE2_VBE_32uA << 28)            /**< Shifted mode VBE_32uA for RAC_AUXADCTRIM    */

/* Bit fields for RAC AUXADCEN */
#define _RAC_AUXADCEN_RESETVALUE                                          0x00000000UL                                              /**< Default value for RAC_AUXADCEN              */
#define _RAC_AUXADCEN_MASK                                                0x000003FFUL                                              /**< Mask for RAC_AUXADCEN                       */
#define RAC_AUXADCEN_AUXADCENAUXADC                                       (0x1UL << 0)                                              /**< AUXADCENAUXADC                              */
#define _RAC_AUXADCEN_AUXADCENAUXADC_SHIFT                                0                                                         /**< Shift value for RAC_AUXADCENAUXADC          */
#define _RAC_AUXADCEN_AUXADCENAUXADC_MASK                                 0x1UL                                                     /**< Bit mask for RAC_AUXADCENAUXADC             */
#define _RAC_AUXADCEN_AUXADCENAUXADC_DEFAULT                              0x00000000UL                                              /**< Mode DEFAULT for RAC_AUXADCEN               */
#define _RAC_AUXADCEN_AUXADCENAUXADC_Disabled                             0x00000000UL                                              /**< Mode Disabled for RAC_AUXADCEN              */
#define _RAC_AUXADCEN_AUXADCENAUXADC_Enabled                              0x00000001UL                                              /**< Mode Enabled for RAC_AUXADCEN               */
#define RAC_AUXADCEN_AUXADCENAUXADC_DEFAULT                               (_RAC_AUXADCEN_AUXADCENAUXADC_DEFAULT << 0)               /**< Shifted mode DEFAULT for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENAUXADC_Disabled                              (_RAC_AUXADCEN_AUXADCENAUXADC_Disabled << 0)              /**< Shifted mode Disabled for RAC_AUXADCEN      */
#define RAC_AUXADCEN_AUXADCENAUXADC_Enabled                               (_RAC_AUXADCEN_AUXADCENAUXADC_Enabled << 0)               /**< Shifted mode Enabled for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENINPUTBUFFER                                  (0x1UL << 1)                                              /**< AUXADCENINPUTBUFFER                         */
#define _RAC_AUXADCEN_AUXADCENINPUTBUFFER_SHIFT                           1                                                         /**< Shift value for RAC_AUXADCENINPUTBUFFER     */
#define _RAC_AUXADCEN_AUXADCENINPUTBUFFER_MASK                            0x2UL                                                     /**< Bit mask for RAC_AUXADCENINPUTBUFFER        */
#define _RAC_AUXADCEN_AUXADCENINPUTBUFFER_DEFAULT                         0x00000000UL                                              /**< Mode DEFAULT for RAC_AUXADCEN               */
#define _RAC_AUXADCEN_AUXADCENINPUTBUFFER_Disabled                        0x00000000UL                                              /**< Mode Disabled for RAC_AUXADCEN              */
#define _RAC_AUXADCEN_AUXADCENINPUTBUFFER_Enabled                         0x00000001UL                                              /**< Mode Enabled for RAC_AUXADCEN               */
#define RAC_AUXADCEN_AUXADCENINPUTBUFFER_DEFAULT                          (_RAC_AUXADCEN_AUXADCENINPUTBUFFER_DEFAULT << 1)          /**< Shifted mode DEFAULT for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENINPUTBUFFER_Disabled                         (_RAC_AUXADCEN_AUXADCENINPUTBUFFER_Disabled << 1)         /**< Shifted mode Disabled for RAC_AUXADCEN      */
#define RAC_AUXADCEN_AUXADCENINPUTBUFFER_Enabled                          (_RAC_AUXADCEN_AUXADCENINPUTBUFFER_Enabled << 1)          /**< Shifted mode Enabled for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENLDO                                          (0x1UL << 2)                                              /**< AUXADCENLDO                                 */
#define _RAC_AUXADCEN_AUXADCENLDO_SHIFT                                   2                                                         /**< Shift value for RAC_AUXADCENLDO             */
#define _RAC_AUXADCEN_AUXADCENLDO_MASK                                    0x4UL                                                     /**< Bit mask for RAC_AUXADCENLDO                */
#define _RAC_AUXADCEN_AUXADCENLDO_DEFAULT                                 0x00000000UL                                              /**< Mode DEFAULT for RAC_AUXADCEN               */
#define _RAC_AUXADCEN_AUXADCENLDO_Disabled                                0x00000000UL                                              /**< Mode Disabled for RAC_AUXADCEN              */
#define _RAC_AUXADCEN_AUXADCENLDO_Enabled                                 0x00000001UL                                              /**< Mode Enabled for RAC_AUXADCEN               */
#define RAC_AUXADCEN_AUXADCENLDO_DEFAULT                                  (_RAC_AUXADCEN_AUXADCENLDO_DEFAULT << 2)                  /**< Shifted mode DEFAULT for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENLDO_Disabled                                 (_RAC_AUXADCEN_AUXADCENLDO_Disabled << 2)                 /**< Shifted mode Disabled for RAC_AUXADCEN      */
#define RAC_AUXADCEN_AUXADCENLDO_Enabled                                  (_RAC_AUXADCEN_AUXADCENLDO_Enabled << 2)                  /**< Shifted mode Enabled for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENOUTPUTDRV                                    (0x1UL << 3)                                              /**< AUXADCENOUTPUTDRV                           */
#define _RAC_AUXADCEN_AUXADCENOUTPUTDRV_SHIFT                             3                                                         /**< Shift value for RAC_AUXADCENOUTPUTDRV       */
#define _RAC_AUXADCEN_AUXADCENOUTPUTDRV_MASK                              0x8UL                                                     /**< Bit mask for RAC_AUXADCENOUTPUTDRV          */
#define _RAC_AUXADCEN_AUXADCENOUTPUTDRV_DEFAULT                           0x00000000UL                                              /**< Mode DEFAULT for RAC_AUXADCEN               */
#define _RAC_AUXADCEN_AUXADCENOUTPUTDRV_Disabled                          0x00000000UL                                              /**< Mode Disabled for RAC_AUXADCEN              */
#define _RAC_AUXADCEN_AUXADCENOUTPUTDRV_Enabled                           0x00000001UL                                              /**< Mode Enabled for RAC_AUXADCEN               */
#define RAC_AUXADCEN_AUXADCENOUTPUTDRV_DEFAULT                            (_RAC_AUXADCEN_AUXADCENOUTPUTDRV_DEFAULT << 3)            /**< Shifted mode DEFAULT for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENOUTPUTDRV_Disabled                           (_RAC_AUXADCEN_AUXADCENOUTPUTDRV_Disabled << 3)           /**< Shifted mode Disabled for RAC_AUXADCEN      */
#define RAC_AUXADCEN_AUXADCENOUTPUTDRV_Enabled                            (_RAC_AUXADCEN_AUXADCENOUTPUTDRV_Enabled << 3)            /**< Shifted mode Enabled for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENPMON                                         (0x1UL << 4)                                              /**< AUXADCENPMON                                */
#define _RAC_AUXADCEN_AUXADCENPMON_SHIFT                                  4                                                         /**< Shift value for RAC_AUXADCENPMON            */
#define _RAC_AUXADCEN_AUXADCENPMON_MASK                                   0x10UL                                                    /**< Bit mask for RAC_AUXADCENPMON               */
#define _RAC_AUXADCEN_AUXADCENPMON_DEFAULT                                0x00000000UL                                              /**< Mode DEFAULT for RAC_AUXADCEN               */
#define _RAC_AUXADCEN_AUXADCENPMON_Disabled                               0x00000000UL                                              /**< Mode Disabled for RAC_AUXADCEN              */
#define _RAC_AUXADCEN_AUXADCENPMON_Enabled                                0x00000001UL                                              /**< Mode Enabled for RAC_AUXADCEN               */
#define RAC_AUXADCEN_AUXADCENPMON_DEFAULT                                 (_RAC_AUXADCEN_AUXADCENPMON_DEFAULT << 4)                 /**< Shifted mode DEFAULT for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENPMON_Disabled                                (_RAC_AUXADCEN_AUXADCENPMON_Disabled << 4)                /**< Shifted mode Disabled for RAC_AUXADCEN      */
#define RAC_AUXADCEN_AUXADCENPMON_Enabled                                 (_RAC_AUXADCEN_AUXADCENPMON_Enabled << 4)                 /**< Shifted mode Enabled for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENRESONDIAGA                                   (0x1UL << 5)                                              /**< AUXADCENRESONDIAGA                          */
#define _RAC_AUXADCEN_AUXADCENRESONDIAGA_SHIFT                            5                                                         /**< Shift value for RAC_AUXADCENRESONDIAGA      */
#define _RAC_AUXADCEN_AUXADCENRESONDIAGA_MASK                             0x20UL                                                    /**< Bit mask for RAC_AUXADCENRESONDIAGA         */
#define _RAC_AUXADCEN_AUXADCENRESONDIAGA_DEFAULT                          0x00000000UL                                              /**< Mode DEFAULT for RAC_AUXADCEN               */
#define _RAC_AUXADCEN_AUXADCENRESONDIAGA_Disabled                         0x00000000UL                                              /**< Mode Disabled for RAC_AUXADCEN              */
#define _RAC_AUXADCEN_AUXADCENRESONDIAGA_Enabled                          0x00000001UL                                              /**< Mode Enabled for RAC_AUXADCEN               */
#define RAC_AUXADCEN_AUXADCENRESONDIAGA_DEFAULT                           (_RAC_AUXADCEN_AUXADCENRESONDIAGA_DEFAULT << 5)           /**< Shifted mode DEFAULT for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENRESONDIAGA_Disabled                          (_RAC_AUXADCEN_AUXADCENRESONDIAGA_Disabled << 5)          /**< Shifted mode Disabled for RAC_AUXADCEN      */
#define RAC_AUXADCEN_AUXADCENRESONDIAGA_Enabled                           (_RAC_AUXADCEN_AUXADCENRESONDIAGA_Enabled << 5)           /**< Shifted mode Enabled for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENTSENSE                                       (0x1UL << 6)                                              /**< AUXADCENTSENSE                              */
#define _RAC_AUXADCEN_AUXADCENTSENSE_SHIFT                                6                                                         /**< Shift value for RAC_AUXADCENTSENSE          */
#define _RAC_AUXADCEN_AUXADCENTSENSE_MASK                                 0x40UL                                                    /**< Bit mask for RAC_AUXADCENTSENSE             */
#define _RAC_AUXADCEN_AUXADCENTSENSE_DEFAULT                              0x00000000UL                                              /**< Mode DEFAULT for RAC_AUXADCEN               */
#define _RAC_AUXADCEN_AUXADCENTSENSE_Disabled                             0x00000000UL                                              /**< Mode Disabled for RAC_AUXADCEN              */
#define _RAC_AUXADCEN_AUXADCENTSENSE_Enabled                              0x00000001UL                                              /**< Mode Enabled for RAC_AUXADCEN               */
#define RAC_AUXADCEN_AUXADCENTSENSE_DEFAULT                               (_RAC_AUXADCEN_AUXADCENTSENSE_DEFAULT << 6)               /**< Shifted mode DEFAULT for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENTSENSE_Disabled                              (_RAC_AUXADCEN_AUXADCENTSENSE_Disabled << 6)              /**< Shifted mode Disabled for RAC_AUXADCEN      */
#define RAC_AUXADCEN_AUXADCENTSENSE_Enabled                               (_RAC_AUXADCEN_AUXADCENTSENSE_Enabled << 6)               /**< Shifted mode Enabled for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENTSENSECAL                                    (0x1UL << 7)                                              /**< AUXADCENTSENSECAL                           */
#define _RAC_AUXADCEN_AUXADCENTSENSECAL_SHIFT                             7                                                         /**< Shift value for RAC_AUXADCENTSENSECAL       */
#define _RAC_AUXADCEN_AUXADCENTSENSECAL_MASK                              0x80UL                                                    /**< Bit mask for RAC_AUXADCENTSENSECAL          */
#define _RAC_AUXADCEN_AUXADCENTSENSECAL_DEFAULT                           0x00000000UL                                              /**< Mode DEFAULT for RAC_AUXADCEN               */
#define _RAC_AUXADCEN_AUXADCENTSENSECAL_Disabled                          0x00000000UL                                              /**< Mode Disabled for RAC_AUXADCEN              */
#define _RAC_AUXADCEN_AUXADCENTSENSECAL_Enabled                           0x00000001UL                                              /**< Mode Enabled for RAC_AUXADCEN               */
#define RAC_AUXADCEN_AUXADCENTSENSECAL_DEFAULT                            (_RAC_AUXADCEN_AUXADCENTSENSECAL_DEFAULT << 7)            /**< Shifted mode DEFAULT for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENTSENSECAL_Disabled                           (_RAC_AUXADCEN_AUXADCENTSENSECAL_Disabled << 7)           /**< Shifted mode Disabled for RAC_AUXADCEN      */
#define RAC_AUXADCEN_AUXADCENTSENSECAL_Enabled                            (_RAC_AUXADCEN_AUXADCENTSENSECAL_Enabled << 7)            /**< Shifted mode Enabled for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS                              (0x1UL << 8)                                              /**< AUXADCINPUTBUFFERBYPASS                     */
#define _RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_SHIFT                       8                                                         /**< Shift value for RAC_AUXADCINPUTBUFFERBYPASS */
#define _RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_MASK                        0x100UL                                                   /**< Bit mask for RAC_AUXADCINPUTBUFFERBYPASS    */
#define _RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_DEFAULT                     0x00000000UL                                              /**< Mode DEFAULT for RAC_AUXADCEN               */
#define _RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_Not_Bypassed                0x00000000UL                                              /**< Mode Not_Bypassed for RAC_AUXADCEN          */
#define _RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_Bypassed                    0x00000001UL                                              /**< Mode Bypassed for RAC_AUXADCEN              */
#define RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_DEFAULT                      (_RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_DEFAULT << 8)      /**< Shifted mode DEFAULT for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_Not_Bypassed                 (_RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_Not_Bypassed << 8) /**< Shifted mode Not_Bypassed for RAC_AUXADCEN  */
#define RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_Bypassed                     (_RAC_AUXADCEN_AUXADCINPUTBUFFERBYPASS_Bypassed << 8)     /**< Shifted mode Bypassed for RAC_AUXADCEN      */
#define RAC_AUXADCEN_AUXADCENMEASTHERMISTOR                               (0x1UL << 9)                                              /**< AUXADCENMEASTHERMISTOR                      */
#define _RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_SHIFT                        9                                                         /**< Shift value for RAC_AUXADCENMEASTHERMISTOR  */
#define _RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_MASK                         0x200UL                                                   /**< Bit mask for RAC_AUXADCENMEASTHERMISTOR     */
#define _RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_DEFAULT                      0x00000000UL                                              /**< Mode DEFAULT for RAC_AUXADCEN               */
#define _RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_Disabled                     0x00000000UL                                              /**< Mode Disabled for RAC_AUXADCEN              */
#define _RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_Enabled                      0x00000001UL                                              /**< Mode Enabled for RAC_AUXADCEN               */
#define RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_DEFAULT                       (_RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_DEFAULT << 9)       /**< Shifted mode DEFAULT for RAC_AUXADCEN       */
#define RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_Disabled                      (_RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_Disabled << 9)      /**< Shifted mode Disabled for RAC_AUXADCEN      */
#define RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_Enabled                       (_RAC_AUXADCEN_AUXADCENMEASTHERMISTOR_Enabled << 9)       /**< Shifted mode Enabled for RAC_AUXADCEN       */

/* Bit fields for RAC AUXADCCTRL0 */
#define _RAC_AUXADCCTRL0_RESETVALUE                                       0x00000100UL                                /**< Default value for RAC_AUXADCCTRL0           */
#define _RAC_AUXADCCTRL0_MASK                                             0x00003FFFUL                                /**< Mask for RAC_AUXADCCTRL0                    */
#define _RAC_AUXADCCTRL0_CYCLES_SHIFT                                     0                                           /**< Shift value for RAC_CYCLES                  */
#define _RAC_AUXADCCTRL0_CYCLES_MASK                                      0x3FFUL                                     /**< Bit mask for RAC_CYCLES                     */
#define _RAC_AUXADCCTRL0_CYCLES_DEFAULT                                   0x00000100UL                                /**< Mode DEFAULT for RAC_AUXADCCTRL0            */
#define RAC_AUXADCCTRL0_CYCLES_DEFAULT                                    (_RAC_AUXADCCTRL0_CYCLES_DEFAULT << 0)      /**< Shifted mode DEFAULT for RAC_AUXADCCTRL0    */
#define _RAC_AUXADCCTRL0_MUXSEL_SHIFT                                     10                                          /**< Shift value for RAC_MUXSEL                  */
#define _RAC_AUXADCCTRL0_MUXSEL_MASK                                      0xC00UL                                     /**< Bit mask for RAC_MUXSEL                     */
#define _RAC_AUXADCCTRL0_MUXSEL_DEFAULT                                   0x00000000UL                                /**< Mode DEFAULT for RAC_AUXADCCTRL0            */
#define RAC_AUXADCCTRL0_MUXSEL_DEFAULT                                    (_RAC_AUXADCCTRL0_MUXSEL_DEFAULT << 10)     /**< Shifted mode DEFAULT for RAC_AUXADCCTRL0    */
#define RAC_AUXADCCTRL0_CLRCOUNTER                                        (0x1UL << 12)                               /**< Clear counter                               */
#define _RAC_AUXADCCTRL0_CLRCOUNTER_SHIFT                                 12                                          /**< Shift value for RAC_CLRCOUNTER              */
#define _RAC_AUXADCCTRL0_CLRCOUNTER_MASK                                  0x1000UL                                    /**< Bit mask for RAC_CLRCOUNTER                 */
#define _RAC_AUXADCCTRL0_CLRCOUNTER_DEFAULT                               0x00000000UL                                /**< Mode DEFAULT for RAC_AUXADCCTRL0            */
#define RAC_AUXADCCTRL0_CLRCOUNTER_DEFAULT                                (_RAC_AUXADCCTRL0_CLRCOUNTER_DEFAULT << 12) /**< Shifted mode DEFAULT for RAC_AUXADCCTRL0    */
#define RAC_AUXADCCTRL0_CLRFILTER                                         (0x1UL << 13)                               /**< Clear accumulators                          */
#define _RAC_AUXADCCTRL0_CLRFILTER_SHIFT                                  13                                          /**< Shift value for RAC_CLRFILTER               */
#define _RAC_AUXADCCTRL0_CLRFILTER_MASK                                   0x2000UL                                    /**< Bit mask for RAC_CLRFILTER                  */
#define _RAC_AUXADCCTRL0_CLRFILTER_DEFAULT                                0x00000000UL                                /**< Mode DEFAULT for RAC_AUXADCCTRL0            */
#define RAC_AUXADCCTRL0_CLRFILTER_DEFAULT                                 (_RAC_AUXADCCTRL0_CLRFILTER_DEFAULT << 13)  /**< Shifted mode DEFAULT for RAC_AUXADCCTRL0    */

/* Bit fields for RAC AUXADCCTRL1 */
#define _RAC_AUXADCCTRL1_RESETVALUE                                       0x00000000UL                                             /**< Default value for RAC_AUXADCCTRL1           */
#define _RAC_AUXADCCTRL1_MASK                                             0xF31F6FFFUL                                             /**< Mask for RAC_AUXADCCTRL1                    */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_SHIFT                          0                                                        /**< Shift value for RAC_AUXADCINPUTRESSEL       */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_MASK                           0xFUL                                                    /**< Bit mask for RAC_AUXADCINPUTRESSEL          */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_DEFAULT                        0x00000000UL                                             /**< Mode DEFAULT for RAC_AUXADCCTRL1            */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES640kOhm                     0x00000000UL                                             /**< Mode RES640kOhm for RAC_AUXADCCTRL1         */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES320kOhm                     0x00000001UL                                             /**< Mode RES320kOhm for RAC_AUXADCCTRL1         */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES160kOhm                     0x00000002UL                                             /**< Mode RES160kOhm for RAC_AUXADCCTRL1         */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES80kOhm                      0x00000003UL                                             /**< Mode RES80kOhm for RAC_AUXADCCTRL1          */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES40kOhm                      0x00000004UL                                             /**< Mode RES40kOhm for RAC_AUXADCCTRL1          */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES20kOhm                      0x00000005UL                                             /**< Mode RES20kOhm for RAC_AUXADCCTRL1          */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES10kOhm                      0x00000006UL                                             /**< Mode RES10kOhm for RAC_AUXADCCTRL1          */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES5kOhm                       0x00000007UL                                             /**< Mode RES5kOhm for RAC_AUXADCCTRL1           */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES2p5kOhm                     0x00000008UL                                             /**< Mode RES2p5kOhm for RAC_AUXADCCTRL1         */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES1p25kOhm                    0x00000009UL                                             /**< Mode RES1p25kOhm for RAC_AUXADCCTRL1        */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES0p6kOhm                     0x0000000AUL                                             /**< Mode RES0p6kOhm for RAC_AUXADCCTRL1         */
#define _RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES_switch                     0x0000000BUL                                             /**< Mode RES_switch for RAC_AUXADCCTRL1         */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_DEFAULT                         (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_DEFAULT << 0)        /**< Shifted mode DEFAULT for RAC_AUXADCCTRL1    */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES640kOhm                      (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES640kOhm << 0)     /**< Shifted mode RES640kOhm for RAC_AUXADCCTRL1 */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES320kOhm                      (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES320kOhm << 0)     /**< Shifted mode RES320kOhm for RAC_AUXADCCTRL1 */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES160kOhm                      (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES160kOhm << 0)     /**< Shifted mode RES160kOhm for RAC_AUXADCCTRL1 */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES80kOhm                       (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES80kOhm << 0)      /**< Shifted mode RES80kOhm for RAC_AUXADCCTRL1  */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES40kOhm                       (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES40kOhm << 0)      /**< Shifted mode RES40kOhm for RAC_AUXADCCTRL1  */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES20kOhm                       (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES20kOhm << 0)      /**< Shifted mode RES20kOhm for RAC_AUXADCCTRL1  */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES10kOhm                       (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES10kOhm << 0)      /**< Shifted mode RES10kOhm for RAC_AUXADCCTRL1  */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES5kOhm                        (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES5kOhm << 0)       /**< Shifted mode RES5kOhm for RAC_AUXADCCTRL1   */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES2p5kOhm                      (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES2p5kOhm << 0)     /**< Shifted mode RES2p5kOhm for RAC_AUXADCCTRL1 */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES1p25kOhm                     (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES1p25kOhm << 0)    /**< Shifted mode RES1p25kOhm for RAC_AUXADCCTRL1*/
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES0p6kOhm                      (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES0p6kOhm << 0)     /**< Shifted mode RES0p6kOhm for RAC_AUXADCCTRL1 */
#define RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES_switch                      (_RAC_AUXADCCTRL1_AUXADCINPUTRESSEL_RES_switch << 0)     /**< Shifted mode RES_switch for RAC_AUXADCCTRL1 */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SHIFT                          4                                                        /**< Shift value for RAC_AUXADCINPUTSELECT       */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_MASK                           0xF0UL                                                   /**< Bit mask for RAC_AUXADCINPUTSELECT          */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_DEFAULT                        0x00000000UL                                             /**< Mode DEFAULT for RAC_AUXADCCTRL1            */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL0                           0x00000000UL                                             /**< Mode SEL0 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL1                           0x00000001UL                                             /**< Mode SEL1 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL2                           0x00000002UL                                             /**< Mode SEL2 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL3                           0x00000003UL                                             /**< Mode SEL3 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL4                           0x00000004UL                                             /**< Mode SEL4 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL5                           0x00000005UL                                             /**< Mode SEL5 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL6                           0x00000006UL                                             /**< Mode SEL6 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL7                           0x00000007UL                                             /**< Mode SEL7 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL8                           0x00000008UL                                             /**< Mode SEL8 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL9                           0x00000009UL                                             /**< Mode SEL9 for RAC_AUXADCCTRL1               */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_DEFAULT                         (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_DEFAULT << 4)        /**< Shifted mode DEFAULT for RAC_AUXADCCTRL1    */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL0                            (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL0 << 4)           /**< Shifted mode SEL0 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL1                            (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL1 << 4)           /**< Shifted mode SEL1 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL2                            (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL2 << 4)           /**< Shifted mode SEL2 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL3                            (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL3 << 4)           /**< Shifted mode SEL3 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL4                            (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL4 << 4)           /**< Shifted mode SEL4 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL5                            (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL5 << 4)           /**< Shifted mode SEL5 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL6                            (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL6 << 4)           /**< Shifted mode SEL6 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL7                            (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL7 << 4)           /**< Shifted mode SEL7 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL8                            (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL8 << 4)           /**< Shifted mode SEL8 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL9                            (_RAC_AUXADCCTRL1_AUXADCINPUTSELECT_SEL9 << 4)           /**< Shifted mode SEL9 for RAC_AUXADCCTRL1       */
#define _RAC_AUXADCCTRL1_AUXADCPMONSELECT_SHIFT                           8                                                        /**< Shift value for RAC_AUXADCPMONSELECT        */
#define _RAC_AUXADCCTRL1_AUXADCPMONSELECT_MASK                            0xF00UL                                                  /**< Bit mask for RAC_AUXADCPMONSELECT           */
#define _RAC_AUXADCCTRL1_AUXADCPMONSELECT_DEFAULT                         0x00000000UL                                             /**< Mode DEFAULT for RAC_AUXADCCTRL1            */
#define RAC_AUXADCCTRL1_AUXADCPMONSELECT_DEFAULT                          (_RAC_AUXADCCTRL1_AUXADCPMONSELECT_DEFAULT << 8)         /**< Shifted mode DEFAULT for RAC_AUXADCCTRL1    */
#define RAC_AUXADCCTRL1_AUXADCIN6SHIMEN                                   (0x1UL << 13)                                            /**< AUXADCIN6SHIMEN                             */
#define _RAC_AUXADCCTRL1_AUXADCIN6SHIMEN_SHIFT                            13                                                       /**< Shift value for RAC_AUXADCIN6SHIMEN         */
#define _RAC_AUXADCCTRL1_AUXADCIN6SHIMEN_MASK                             0x2000UL                                                 /**< Bit mask for RAC_AUXADCIN6SHIMEN            */
#define _RAC_AUXADCCTRL1_AUXADCIN6SHIMEN_DEFAULT                          0x00000000UL                                             /**< Mode DEFAULT for RAC_AUXADCCTRL1            */
#define RAC_AUXADCCTRL1_AUXADCIN6SHIMEN_DEFAULT                           (_RAC_AUXADCCTRL1_AUXADCIN6SHIMEN_DEFAULT << 13)         /**< Shifted mode DEFAULT for RAC_AUXADCCTRL1    */
#define RAC_AUXADCCTRL1_AUXADCIN8SHIMEN                                   (0x1UL << 14)                                            /**< AUXADCIN8SHIMEN                             */
#define _RAC_AUXADCCTRL1_AUXADCIN8SHIMEN_SHIFT                            14                                                       /**< Shift value for RAC_AUXADCIN8SHIMEN         */
#define _RAC_AUXADCCTRL1_AUXADCIN8SHIMEN_MASK                             0x4000UL                                                 /**< Bit mask for RAC_AUXADCIN8SHIMEN            */
#define _RAC_AUXADCCTRL1_AUXADCIN8SHIMEN_DEFAULT                          0x00000000UL                                             /**< Mode DEFAULT for RAC_AUXADCCTRL1            */
#define RAC_AUXADCCTRL1_AUXADCIN8SHIMEN_DEFAULT                           (_RAC_AUXADCCTRL1_AUXADCIN8SHIMEN_DEFAULT << 14)         /**< Shifted mode DEFAULT for RAC_AUXADCCTRL1    */
#define _RAC_AUXADCCTRL1_AUXADCTSENSESELCURR_SHIFT                        16                                                       /**< Shift value for RAC_AUXADCTSENSESELCURR     */
#define _RAC_AUXADCCTRL1_AUXADCTSENSESELCURR_MASK                         0x1F0000UL                                               /**< Bit mask for RAC_AUXADCTSENSESELCURR        */
#define _RAC_AUXADCCTRL1_AUXADCTSENSESELCURR_DEFAULT                      0x00000000UL                                             /**< Mode DEFAULT for RAC_AUXADCCTRL1            */
#define RAC_AUXADCCTRL1_AUXADCTSENSESELCURR_DEFAULT                       (_RAC_AUXADCCTRL1_AUXADCTSENSESELCURR_DEFAULT << 16)     /**< Shifted mode DEFAULT for RAC_AUXADCCTRL1    */
#define RAC_AUXADCCTRL1_AUXADCRESET                                       (0x1UL << 24)                                            /**< AUXADCRESET                                 */
#define _RAC_AUXADCCTRL1_AUXADCRESET_SHIFT                                24                                                       /**< Shift value for RAC_AUXADCRESET             */
#define _RAC_AUXADCCTRL1_AUXADCRESET_MASK                                 0x1000000UL                                              /**< Bit mask for RAC_AUXADCRESET                */
#define _RAC_AUXADCCTRL1_AUXADCRESET_DEFAULT                              0x00000000UL                                             /**< Mode DEFAULT for RAC_AUXADCCTRL1            */
#define _RAC_AUXADCCTRL1_AUXADCRESET_Reset_Disabled                       0x00000000UL                                             /**< Mode Reset_Disabled for RAC_AUXADCCTRL1     */
#define _RAC_AUXADCCTRL1_AUXADCRESET_Reset_Enabled                        0x00000001UL                                             /**< Mode Reset_Enabled for RAC_AUXADCCTRL1      */
#define RAC_AUXADCCTRL1_AUXADCRESET_DEFAULT                               (_RAC_AUXADCCTRL1_AUXADCRESET_DEFAULT << 24)             /**< Shifted mode DEFAULT for RAC_AUXADCCTRL1    */
#define RAC_AUXADCCTRL1_AUXADCRESET_Reset_Disabled                        (_RAC_AUXADCCTRL1_AUXADCRESET_Reset_Disabled << 24)      /**< Shifted mode Reset_Disabled for RAC_AUXADCCTRL1*/
#define RAC_AUXADCCTRL1_AUXADCRESET_Reset_Enabled                         (_RAC_AUXADCCTRL1_AUXADCRESET_Reset_Enabled << 24)       /**< Shifted mode Reset_Enabled for RAC_AUXADCCTRL1*/
#define RAC_AUXADCCTRL1_AUXADCTSENSESELVBE                                (0x1UL << 25)                                            /**< AUXADCTSENSESELVBE                          */
#define _RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_SHIFT                         25                                                       /**< Shift value for RAC_AUXADCTSENSESELVBE      */
#define _RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_MASK                          0x2000000UL                                              /**< Bit mask for RAC_AUXADCTSENSESELVBE         */
#define _RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_DEFAULT                       0x00000000UL                                             /**< Mode DEFAULT for RAC_AUXADCCTRL1            */
#define _RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_VBE1                          0x00000000UL                                             /**< Mode VBE1 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_VBE2                          0x00000001UL                                             /**< Mode VBE2 for RAC_AUXADCCTRL1               */
#define RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_DEFAULT                        (_RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_DEFAULT << 25)      /**< Shifted mode DEFAULT for RAC_AUXADCCTRL1    */
#define RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_VBE1                           (_RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_VBE1 << 25)         /**< Shifted mode VBE1 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_VBE2                           (_RAC_AUXADCCTRL1_AUXADCTSENSESELVBE_VBE2 << 25)         /**< Shifted mode VBE2 for RAC_AUXADCCTRL1       */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_SHIFT                    28                                                       /**< Shift value for RAC_AUXADCTHERMISTORFREQSEL */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_MASK                     0xF0000000UL                                             /**< Bit mask for RAC_AUXADCTHERMISTORFREQSEL    */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DEFAULT                  0x00000000UL                                             /**< Mode DEFAULT for RAC_AUXADCCTRL1            */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV1                     0x00000000UL                                             /**< Mode DIV1 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV2                     0x00000001UL                                             /**< Mode DIV2 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV4                     0x00000002UL                                             /**< Mode DIV4 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV8                     0x00000003UL                                             /**< Mode DIV8 for RAC_AUXADCCTRL1               */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV16                    0x00000004UL                                             /**< Mode DIV16 for RAC_AUXADCCTRL1              */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV32                    0x00000005UL                                             /**< Mode DIV32 for RAC_AUXADCCTRL1              */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV64                    0x00000006UL                                             /**< Mode DIV64 for RAC_AUXADCCTRL1              */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV128                   0x00000007UL                                             /**< Mode DIV128 for RAC_AUXADCCTRL1             */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV256                   0x00000008UL                                             /**< Mode DIV256 for RAC_AUXADCCTRL1             */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV512                   0x00000009UL                                             /**< Mode DIV512 for RAC_AUXADCCTRL1             */
#define _RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV1024                  0x0000000AUL                                             /**< Mode DIV1024 for RAC_AUXADCCTRL1            */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DEFAULT                   (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DEFAULT << 28) /**< Shifted mode DEFAULT for RAC_AUXADCCTRL1    */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV1                      (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV1 << 28)    /**< Shifted mode DIV1 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV2                      (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV2 << 28)    /**< Shifted mode DIV2 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV4                      (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV4 << 28)    /**< Shifted mode DIV4 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV8                      (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV8 << 28)    /**< Shifted mode DIV8 for RAC_AUXADCCTRL1       */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV16                     (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV16 << 28)   /**< Shifted mode DIV16 for RAC_AUXADCCTRL1      */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV32                     (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV32 << 28)   /**< Shifted mode DIV32 for RAC_AUXADCCTRL1      */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV64                     (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV64 << 28)   /**< Shifted mode DIV64 for RAC_AUXADCCTRL1      */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV128                    (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV128 << 28)  /**< Shifted mode DIV128 for RAC_AUXADCCTRL1     */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV256                    (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV256 << 28)  /**< Shifted mode DIV256 for RAC_AUXADCCTRL1     */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV512                    (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV512 << 28)  /**< Shifted mode DIV512 for RAC_AUXADCCTRL1     */
#define RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV1024                   (_RAC_AUXADCCTRL1_AUXADCTHERMISTORFREQSEL_DIV1024 << 28) /**< Shifted mode DIV1024 for RAC_AUXADCCTRL1    */

/* Bit fields for RAC AUXADCOUT */
#define _RAC_AUXADCOUT_RESETVALUE                                         0x00000000UL                            /**< Default value for RAC_AUXADCOUT             */
#define _RAC_AUXADCOUT_MASK                                               0x0FFFFFFFUL                            /**< Mask for RAC_AUXADCOUT                      */
#define _RAC_AUXADCOUT_AUXADCOUT_SHIFT                                    0                                       /**< Shift value for RAC_AUXADCOUT               */
#define _RAC_AUXADCOUT_AUXADCOUT_MASK                                     0xFFFFFFFUL                             /**< Bit mask for RAC_AUXADCOUT                  */
#define _RAC_AUXADCOUT_AUXADCOUT_DEFAULT                                  0x00000000UL                            /**< Mode DEFAULT for RAC_AUXADCOUT              */
#define RAC_AUXADCOUT_AUXADCOUT_DEFAULT                                   (_RAC_AUXADCOUT_AUXADCOUT_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_AUXADCOUT      */

/* Bit fields for RAC CLKMULTEN0 */
#define _RAC_CLKMULTEN0_RESETVALUE                                        0xAA400005UL                                         /**< Default value for RAC_CLKMULTEN0            */
#define _RAC_CLKMULTEN0_MASK                                              0xFFDFFFFFUL                                         /**< Mask for RAC_CLKMULTEN0                     */
#define _RAC_CLKMULTEN0_CLKMULTBWCAL_SHIFT                                0                                                    /**< Shift value for RAC_CLKMULTBWCAL            */
#define _RAC_CLKMULTEN0_CLKMULTBWCAL_MASK                                 0x3UL                                                /**< Bit mask for RAC_CLKMULTBWCAL               */
#define _RAC_CLKMULTEN0_CLKMULTBWCAL_DEFAULT                              0x00000001UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTBWCAL_bw_1lsb                              0x00000000UL                                         /**< Mode bw_1lsb for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTBWCAL_bw_2lsb                              0x00000001UL                                         /**< Mode bw_2lsb for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTBWCAL_bw_3lsb                              0x00000002UL                                         /**< Mode bw_3lsb for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTBWCAL_bw_4lsb                              0x00000003UL                                         /**< Mode bw_4lsb for RAC_CLKMULTEN0             */
#define RAC_CLKMULTEN0_CLKMULTBWCAL_DEFAULT                               (_RAC_CLKMULTEN0_CLKMULTBWCAL_DEFAULT << 0)          /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTBWCAL_bw_1lsb                               (_RAC_CLKMULTEN0_CLKMULTBWCAL_bw_1lsb << 0)          /**< Shifted mode bw_1lsb for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTBWCAL_bw_2lsb                               (_RAC_CLKMULTEN0_CLKMULTBWCAL_bw_2lsb << 0)          /**< Shifted mode bw_2lsb for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTBWCAL_bw_3lsb                               (_RAC_CLKMULTEN0_CLKMULTBWCAL_bw_3lsb << 0)          /**< Shifted mode bw_3lsb for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTBWCAL_bw_4lsb                               (_RAC_CLKMULTEN0_CLKMULTBWCAL_bw_4lsb << 0)          /**< Shifted mode bw_4lsb for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTDISICO                                      (0x1UL << 2)                                         /**< CLKMULTDISICO                               */
#define _RAC_CLKMULTEN0_CLKMULTDISICO_SHIFT                               2                                                    /**< Shift value for RAC_CLKMULTDISICO           */
#define _RAC_CLKMULTEN0_CLKMULTDISICO_MASK                                0x4UL                                                /**< Bit mask for RAC_CLKMULTDISICO              */
#define _RAC_CLKMULTEN0_CLKMULTDISICO_DEFAULT                             0x00000001UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTDISICO_enable                              0x00000000UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define _RAC_CLKMULTEN0_CLKMULTDISICO_disable                             0x00000001UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define RAC_CLKMULTEN0_CLKMULTDISICO_DEFAULT                              (_RAC_CLKMULTEN0_CLKMULTDISICO_DEFAULT << 2)         /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTDISICO_enable                               (_RAC_CLKMULTEN0_CLKMULTDISICO_enable << 2)          /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTDISICO_disable                              (_RAC_CLKMULTEN0_CLKMULTDISICO_disable << 2)         /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENBBDET                                     (0x1UL << 3)                                         /**< CLKMULTENBBDET                              */
#define _RAC_CLKMULTEN0_CLKMULTENBBDET_SHIFT                              3                                                    /**< Shift value for RAC_CLKMULTENBBDET          */
#define _RAC_CLKMULTEN0_CLKMULTENBBDET_MASK                               0x8UL                                                /**< Bit mask for RAC_CLKMULTENBBDET             */
#define _RAC_CLKMULTEN0_CLKMULTENBBDET_DEFAULT                            0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENBBDET_disable                            0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENBBDET_enable                             0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENBBDET_DEFAULT                             (_RAC_CLKMULTEN0_CLKMULTENBBDET_DEFAULT << 3)        /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENBBDET_disable                             (_RAC_CLKMULTEN0_CLKMULTENBBDET_disable << 3)        /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENBBDET_enable                              (_RAC_CLKMULTEN0_CLKMULTENBBDET_enable << 3)         /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENBBXLDET                                   (0x1UL << 4)                                         /**< CLKMULTENBBXLDET                            */
#define _RAC_CLKMULTEN0_CLKMULTENBBXLDET_SHIFT                            4                                                    /**< Shift value for RAC_CLKMULTENBBXLDET        */
#define _RAC_CLKMULTEN0_CLKMULTENBBXLDET_MASK                             0x10UL                                               /**< Bit mask for RAC_CLKMULTENBBXLDET           */
#define _RAC_CLKMULTEN0_CLKMULTENBBXLDET_DEFAULT                          0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENBBXLDET_disable                          0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENBBXLDET_enable                           0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENBBXLDET_DEFAULT                           (_RAC_CLKMULTEN0_CLKMULTENBBXLDET_DEFAULT << 4)      /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENBBXLDET_disable                           (_RAC_CLKMULTEN0_CLKMULTENBBXLDET_disable << 4)      /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENBBXLDET_enable                            (_RAC_CLKMULTEN0_CLKMULTENBBXLDET_enable << 4)       /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENBBXMDET                                   (0x1UL << 5)                                         /**< CLKMULTENBBXMDET                            */
#define _RAC_CLKMULTEN0_CLKMULTENBBXMDET_SHIFT                            5                                                    /**< Shift value for RAC_CLKMULTENBBXMDET        */
#define _RAC_CLKMULTEN0_CLKMULTENBBXMDET_MASK                             0x20UL                                               /**< Bit mask for RAC_CLKMULTENBBXMDET           */
#define _RAC_CLKMULTEN0_CLKMULTENBBXMDET_DEFAULT                          0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENBBXMDET_disable                          0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENBBXMDET_enable                           0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENBBXMDET_DEFAULT                           (_RAC_CLKMULTEN0_CLKMULTENBBXMDET_DEFAULT << 5)      /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENBBXMDET_disable                           (_RAC_CLKMULTEN0_CLKMULTENBBXMDET_disable << 5)      /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENBBXMDET_enable                            (_RAC_CLKMULTEN0_CLKMULTENBBXMDET_enable << 5)       /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENCFDET                                     (0x1UL << 6)                                         /**< CLKMULTENCFDET                              */
#define _RAC_CLKMULTEN0_CLKMULTENCFDET_SHIFT                              6                                                    /**< Shift value for RAC_CLKMULTENCFDET          */
#define _RAC_CLKMULTEN0_CLKMULTENCFDET_MASK                               0x40UL                                               /**< Bit mask for RAC_CLKMULTENCFDET             */
#define _RAC_CLKMULTEN0_CLKMULTENCFDET_DEFAULT                            0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENCFDET_disable                            0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENCFDET_enable                             0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENCFDET_DEFAULT                             (_RAC_CLKMULTEN0_CLKMULTENCFDET_DEFAULT << 6)        /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENCFDET_disable                             (_RAC_CLKMULTEN0_CLKMULTENCFDET_disable << 6)        /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENCFDET_enable                              (_RAC_CLKMULTEN0_CLKMULTENCFDET_enable << 6)         /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENDITHER                                    (0x1UL << 7)                                         /**< CLKMULTENDITHER                             */
#define _RAC_CLKMULTEN0_CLKMULTENDITHER_SHIFT                             7                                                    /**< Shift value for RAC_CLKMULTENDITHER         */
#define _RAC_CLKMULTEN0_CLKMULTENDITHER_MASK                              0x80UL                                               /**< Bit mask for RAC_CLKMULTENDITHER            */
#define _RAC_CLKMULTEN0_CLKMULTENDITHER_DEFAULT                           0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENDITHER_disable                           0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENDITHER_enable                            0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENDITHER_DEFAULT                            (_RAC_CLKMULTEN0_CLKMULTENDITHER_DEFAULT << 7)       /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENDITHER_disable                            (_RAC_CLKMULTEN0_CLKMULTENDITHER_disable << 7)       /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENDITHER_enable                             (_RAC_CLKMULTEN0_CLKMULTENDITHER_enable << 7)        /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENDRVADC                                    (0x1UL << 8)                                         /**< CLKMULTENDRVADC                             */
#define _RAC_CLKMULTEN0_CLKMULTENDRVADC_SHIFT                             8                                                    /**< Shift value for RAC_CLKMULTENDRVADC         */
#define _RAC_CLKMULTEN0_CLKMULTENDRVADC_MASK                              0x100UL                                              /**< Bit mask for RAC_CLKMULTENDRVADC            */
#define _RAC_CLKMULTEN0_CLKMULTENDRVADC_DEFAULT                           0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENDRVADC_disable                           0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENDRVADC_enable                            0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENDRVADC_DEFAULT                            (_RAC_CLKMULTEN0_CLKMULTENDRVADC_DEFAULT << 8)       /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENDRVADC_disable                            (_RAC_CLKMULTEN0_CLKMULTENDRVADC_disable << 8)       /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENDRVADC_enable                             (_RAC_CLKMULTEN0_CLKMULTENDRVADC_enable << 8)        /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENDRVN                                      (0x1UL << 9)                                         /**< CLKMULTENDRVN                               */
#define _RAC_CLKMULTEN0_CLKMULTENDRVN_SHIFT                               9                                                    /**< Shift value for RAC_CLKMULTENDRVN           */
#define _RAC_CLKMULTEN0_CLKMULTENDRVN_MASK                                0x200UL                                              /**< Bit mask for RAC_CLKMULTENDRVN              */
#define _RAC_CLKMULTEN0_CLKMULTENDRVN_DEFAULT                             0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENDRVN_disable                             0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENDRVN_enable                              0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENDRVN_DEFAULT                              (_RAC_CLKMULTEN0_CLKMULTENDRVN_DEFAULT << 9)         /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENDRVN_disable                              (_RAC_CLKMULTEN0_CLKMULTENDRVN_disable << 9)         /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENDRVN_enable                               (_RAC_CLKMULTEN0_CLKMULTENDRVN_enable << 9)          /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENDRVP                                      (0x1UL << 10)                                        /**< CLKMULTENDRVP                               */
#define _RAC_CLKMULTEN0_CLKMULTENDRVP_SHIFT                               10                                                   /**< Shift value for RAC_CLKMULTENDRVP           */
#define _RAC_CLKMULTEN0_CLKMULTENDRVP_MASK                                0x400UL                                              /**< Bit mask for RAC_CLKMULTENDRVP              */
#define _RAC_CLKMULTEN0_CLKMULTENDRVP_DEFAULT                             0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENDRVP_disable                             0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENDRVP_enable                              0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENDRVP_DEFAULT                              (_RAC_CLKMULTEN0_CLKMULTENDRVP_DEFAULT << 10)        /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENDRVP_disable                              (_RAC_CLKMULTEN0_CLKMULTENDRVP_disable << 10)        /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENDRVP_enable                               (_RAC_CLKMULTEN0_CLKMULTENDRVP_enable << 10)         /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G                                 (0x1UL << 11)                                        /**< CLKMULTENDRVRX2P4G                          */
#define _RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_SHIFT                          11                                                   /**< Shift value for RAC_CLKMULTENDRVRX2P4G      */
#define _RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_MASK                           0x800UL                                              /**< Bit mask for RAC_CLKMULTENDRVRX2P4G         */
#define _RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_DEFAULT                        0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_disable                        0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_enable                         0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_DEFAULT                         (_RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_DEFAULT << 11)   /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_disable                         (_RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_disable << 11)   /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_enable                          (_RAC_CLKMULTEN0_CLKMULTENDRVRX2P4G_enable << 11)    /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENFBDIV                                     (0x1UL << 14)                                        /**< CLKMULTENFBDIV                              */
#define _RAC_CLKMULTEN0_CLKMULTENFBDIV_SHIFT                              14                                                   /**< Shift value for RAC_CLKMULTENFBDIV          */
#define _RAC_CLKMULTEN0_CLKMULTENFBDIV_MASK                               0x4000UL                                             /**< Bit mask for RAC_CLKMULTENFBDIV             */
#define _RAC_CLKMULTEN0_CLKMULTENFBDIV_DEFAULT                            0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENFBDIV_disable                            0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENFBDIV_enable                             0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENFBDIV_DEFAULT                             (_RAC_CLKMULTEN0_CLKMULTENFBDIV_DEFAULT << 14)       /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENFBDIV_disable                             (_RAC_CLKMULTEN0_CLKMULTENFBDIV_disable << 14)       /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENFBDIV_enable                              (_RAC_CLKMULTEN0_CLKMULTENFBDIV_enable << 14)        /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENREFDIV                                    (0x1UL << 15)                                        /**< CLKMULTENREFDIV                             */
#define _RAC_CLKMULTEN0_CLKMULTENREFDIV_SHIFT                             15                                                   /**< Shift value for RAC_CLKMULTENREFDIV         */
#define _RAC_CLKMULTEN0_CLKMULTENREFDIV_MASK                              0x8000UL                                             /**< Bit mask for RAC_CLKMULTENREFDIV            */
#define _RAC_CLKMULTEN0_CLKMULTENREFDIV_DEFAULT                           0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENREFDIV_disable                           0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENREFDIV_enable                            0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENREFDIV_DEFAULT                            (_RAC_CLKMULTEN0_CLKMULTENREFDIV_DEFAULT << 15)      /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENREFDIV_disable                            (_RAC_CLKMULTEN0_CLKMULTENREFDIV_disable << 15)      /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENREFDIV_enable                             (_RAC_CLKMULTEN0_CLKMULTENREFDIV_enable << 15)       /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENREG1                                      (0x1UL << 16)                                        /**< CLKMULTENREG1                               */
#define _RAC_CLKMULTEN0_CLKMULTENREG1_SHIFT                               16                                                   /**< Shift value for RAC_CLKMULTENREG1           */
#define _RAC_CLKMULTEN0_CLKMULTENREG1_MASK                                0x10000UL                                            /**< Bit mask for RAC_CLKMULTENREG1              */
#define _RAC_CLKMULTEN0_CLKMULTENREG1_DEFAULT                             0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENREG1_disable                             0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENREG1_enable                              0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENREG1_DEFAULT                              (_RAC_CLKMULTEN0_CLKMULTENREG1_DEFAULT << 16)        /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENREG1_disable                              (_RAC_CLKMULTEN0_CLKMULTENREG1_disable << 16)        /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENREG1_enable                               (_RAC_CLKMULTEN0_CLKMULTENREG1_enable << 16)         /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENREG2                                      (0x1UL << 17)                                        /**< CLKMULTENREG2                               */
#define _RAC_CLKMULTEN0_CLKMULTENREG2_SHIFT                               17                                                   /**< Shift value for RAC_CLKMULTENREG2           */
#define _RAC_CLKMULTEN0_CLKMULTENREG2_MASK                                0x20000UL                                            /**< Bit mask for RAC_CLKMULTENREG2              */
#define _RAC_CLKMULTEN0_CLKMULTENREG2_DEFAULT                             0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENREG2_disable                             0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENREG2_enable                              0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENREG2_DEFAULT                              (_RAC_CLKMULTEN0_CLKMULTENREG2_DEFAULT << 17)        /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENREG2_disable                              (_RAC_CLKMULTEN0_CLKMULTENREG2_disable << 17)        /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENREG2_enable                               (_RAC_CLKMULTEN0_CLKMULTENREG2_enable << 17)         /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENREG3                                      (0x1UL << 18)                                        /**< CLKMULTENREG3                               */
#define _RAC_CLKMULTEN0_CLKMULTENREG3_SHIFT                               18                                                   /**< Shift value for RAC_CLKMULTENREG3           */
#define _RAC_CLKMULTEN0_CLKMULTENREG3_MASK                                0x40000UL                                            /**< Bit mask for RAC_CLKMULTENREG3              */
#define _RAC_CLKMULTEN0_CLKMULTENREG3_DEFAULT                             0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENREG3_disable                             0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENREG3_enable                              0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENREG3_DEFAULT                              (_RAC_CLKMULTEN0_CLKMULTENREG3_DEFAULT << 18)        /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENREG3_disable                              (_RAC_CLKMULTEN0_CLKMULTENREG3_disable << 18)        /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENREG3_enable                               (_RAC_CLKMULTEN0_CLKMULTENREG3_enable << 18)         /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENROTDET                                    (0x1UL << 19)                                        /**< CLKMULTENROTDET                             */
#define _RAC_CLKMULTEN0_CLKMULTENROTDET_SHIFT                             19                                                   /**< Shift value for RAC_CLKMULTENROTDET         */
#define _RAC_CLKMULTEN0_CLKMULTENROTDET_MASK                              0x80000UL                                            /**< Bit mask for RAC_CLKMULTENROTDET            */
#define _RAC_CLKMULTEN0_CLKMULTENROTDET_DEFAULT                           0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENROTDET_disable                           0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENROTDET_enable                            0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENROTDET_DEFAULT                            (_RAC_CLKMULTEN0_CLKMULTENROTDET_DEFAULT << 19)      /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENROTDET_disable                            (_RAC_CLKMULTEN0_CLKMULTENROTDET_disable << 19)      /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENROTDET_enable                             (_RAC_CLKMULTEN0_CLKMULTENROTDET_enable << 19)       /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ                               (0x1UL << 20)                                        /**< CLKMULTENBYPASS40MHZ                        */
#define _RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_SHIFT                        20                                                   /**< Shift value for RAC_CLKMULTENBYPASS40MHZ    */
#define _RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_MASK                         0x100000UL                                           /**< Bit mask for RAC_CLKMULTENBYPASS40MHZ       */
#define _RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_DEFAULT                      0x00000000UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_disable                      0x00000000UL                                         /**< Mode disable for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_enable                       0x00000001UL                                         /**< Mode enable for RAC_CLKMULTEN0              */
#define RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_DEFAULT                       (_RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_DEFAULT << 20) /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_disable                       (_RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_disable << 20) /**< Shifted mode disable for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_enable                        (_RAC_CLKMULTEN0_CLKMULTENBYPASS40MHZ_enable << 20)  /**< Shifted mode enable for RAC_CLKMULTEN0      */
#define _RAC_CLKMULTEN0_CLKMULTFREQCAL_SHIFT                              22                                                   /**< Shift value for RAC_CLKMULTFREQCAL          */
#define _RAC_CLKMULTEN0_CLKMULTFREQCAL_MASK                               0xC00000UL                                           /**< Bit mask for RAC_CLKMULTFREQCAL             */
#define _RAC_CLKMULTEN0_CLKMULTFREQCAL_DEFAULT                            0x00000001UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_14uA                         0x00000000UL                                         /**< Mode pedes_14uA for RAC_CLKMULTEN0          */
#define _RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_22uA                         0x00000001UL                                         /**< Mode pedes_22uA for RAC_CLKMULTEN0          */
#define _RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_30uA                         0x00000002UL                                         /**< Mode pedes_30uA for RAC_CLKMULTEN0          */
#define _RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_38uA                         0x00000003UL                                         /**< Mode pedes_38uA for RAC_CLKMULTEN0          */
#define RAC_CLKMULTEN0_CLKMULTFREQCAL_DEFAULT                             (_RAC_CLKMULTEN0_CLKMULTFREQCAL_DEFAULT << 22)       /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_14uA                          (_RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_14uA << 22)    /**< Shifted mode pedes_14uA for RAC_CLKMULTEN0  */
#define RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_22uA                          (_RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_22uA << 22)    /**< Shifted mode pedes_22uA for RAC_CLKMULTEN0  */
#define RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_30uA                          (_RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_30uA << 22)    /**< Shifted mode pedes_30uA for RAC_CLKMULTEN0  */
#define RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_38uA                          (_RAC_CLKMULTEN0_CLKMULTFREQCAL_pedes_38uA << 22)    /**< Shifted mode pedes_38uA for RAC_CLKMULTEN0  */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJI_SHIFT                             24                                                   /**< Shift value for RAC_CLKMULTREG2ADJI         */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJI_MASK                              0x3000000UL                                          /**< Bit mask for RAC_CLKMULTREG2ADJI            */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJI_DEFAULT                           0x00000002UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_80uA                            0x00000000UL                                         /**< Mode I_80uA for RAC_CLKMULTEN0              */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_100uA                           0x00000001UL                                         /**< Mode I_100uA for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_120uA                           0x00000002UL                                         /**< Mode I_120uA for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_140uA                           0x00000003UL                                         /**< Mode I_140uA for RAC_CLKMULTEN0             */
#define RAC_CLKMULTEN0_CLKMULTREG2ADJI_DEFAULT                            (_RAC_CLKMULTEN0_CLKMULTREG2ADJI_DEFAULT << 24)      /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_80uA                             (_RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_80uA << 24)       /**< Shifted mode I_80uA for RAC_CLKMULTEN0      */
#define RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_100uA                            (_RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_100uA << 24)      /**< Shifted mode I_100uA for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_120uA                            (_RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_120uA << 24)      /**< Shifted mode I_120uA for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_140uA                            (_RAC_CLKMULTEN0_CLKMULTREG2ADJI_I_140uA << 24)      /**< Shifted mode I_140uA for RAC_CLKMULTEN0     */
#define _RAC_CLKMULTEN0_CLKMULTREG1ADJV_SHIFT                             26                                                   /**< Shift value for RAC_CLKMULTREG1ADJV         */
#define _RAC_CLKMULTEN0_CLKMULTREG1ADJV_MASK                              0xC000000UL                                          /**< Bit mask for RAC_CLKMULTREG1ADJV            */
#define _RAC_CLKMULTEN0_CLKMULTREG1ADJV_DEFAULT                           0x00000002UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p28                             0x00000000UL                                         /**< Mode v1p28 for RAC_CLKMULTEN0               */
#define _RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p32                             0x00000001UL                                         /**< Mode v1p32 for RAC_CLKMULTEN0               */
#define _RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p33                             0x00000002UL                                         /**< Mode v1p33 for RAC_CLKMULTEN0               */
#define _RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p38                             0x00000003UL                                         /**< Mode v1p38 for RAC_CLKMULTEN0               */
#define RAC_CLKMULTEN0_CLKMULTREG1ADJV_DEFAULT                            (_RAC_CLKMULTEN0_CLKMULTREG1ADJV_DEFAULT << 26)      /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p28                              (_RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p28 << 26)        /**< Shifted mode v1p28 for RAC_CLKMULTEN0       */
#define RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p32                              (_RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p32 << 26)        /**< Shifted mode v1p32 for RAC_CLKMULTEN0       */
#define RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p33                              (_RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p33 << 26)        /**< Shifted mode v1p33 for RAC_CLKMULTEN0       */
#define RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p38                              (_RAC_CLKMULTEN0_CLKMULTREG1ADJV_v1p38 << 26)        /**< Shifted mode v1p38 for RAC_CLKMULTEN0       */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJV_SHIFT                             28                                                   /**< Shift value for RAC_CLKMULTREG2ADJV         */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJV_MASK                              0x30000000UL                                         /**< Bit mask for RAC_CLKMULTREG2ADJV            */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJV_DEFAULT                           0x00000002UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p03                             0x00000000UL                                         /**< Mode v1p03 for RAC_CLKMULTEN0               */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p09                             0x00000001UL                                         /**< Mode v1p09 for RAC_CLKMULTEN0               */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p10                             0x00000002UL                                         /**< Mode v1p10 for RAC_CLKMULTEN0               */
#define _RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p16                             0x00000003UL                                         /**< Mode v1p16 for RAC_CLKMULTEN0               */
#define RAC_CLKMULTEN0_CLKMULTREG2ADJV_DEFAULT                            (_RAC_CLKMULTEN0_CLKMULTREG2ADJV_DEFAULT << 28)      /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p03                              (_RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p03 << 28)        /**< Shifted mode v1p03 for RAC_CLKMULTEN0       */
#define RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p09                              (_RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p09 << 28)        /**< Shifted mode v1p09 for RAC_CLKMULTEN0       */
#define RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p10                              (_RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p10 << 28)        /**< Shifted mode v1p10 for RAC_CLKMULTEN0       */
#define RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p16                              (_RAC_CLKMULTEN0_CLKMULTREG2ADJV_v1p16 << 28)        /**< Shifted mode v1p16 for RAC_CLKMULTEN0       */
#define _RAC_CLKMULTEN0_CLKMULTREG3ADJV_SHIFT                             30                                                   /**< Shift value for RAC_CLKMULTREG3ADJV         */
#define _RAC_CLKMULTEN0_CLKMULTREG3ADJV_MASK                              0xC0000000UL                                         /**< Bit mask for RAC_CLKMULTREG3ADJV            */
#define _RAC_CLKMULTEN0_CLKMULTREG3ADJV_DEFAULT                           0x00000002UL                                         /**< Mode DEFAULT for RAC_CLKMULTEN0             */
#define _RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p03                             0x00000000UL                                         /**< Mode v1p03 for RAC_CLKMULTEN0               */
#define _RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p06                             0x00000001UL                                         /**< Mode v1p06 for RAC_CLKMULTEN0               */
#define _RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p07                             0x00000002UL                                         /**< Mode v1p07 for RAC_CLKMULTEN0               */
#define _RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p09                             0x00000003UL                                         /**< Mode v1p09 for RAC_CLKMULTEN0               */
#define RAC_CLKMULTEN0_CLKMULTREG3ADJV_DEFAULT                            (_RAC_CLKMULTEN0_CLKMULTREG3ADJV_DEFAULT << 30)      /**< Shifted mode DEFAULT for RAC_CLKMULTEN0     */
#define RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p03                              (_RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p03 << 30)        /**< Shifted mode v1p03 for RAC_CLKMULTEN0       */
#define RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p06                              (_RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p06 << 30)        /**< Shifted mode v1p06 for RAC_CLKMULTEN0       */
#define RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p07                              (_RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p07 << 30)        /**< Shifted mode v1p07 for RAC_CLKMULTEN0       */
#define RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p09                              (_RAC_CLKMULTEN0_CLKMULTREG3ADJV_v1p09 << 30)        /**< Shifted mode v1p09 for RAC_CLKMULTEN0       */

/* Bit fields for RAC CLKMULTEN1 */
#define _RAC_CLKMULTEN1_RESETVALUE                                        0x00000188UL                                           /**< Default value for RAC_CLKMULTEN1            */
#define _RAC_CLKMULTEN1_MASK                                              0x0001FDEFUL                                           /**< Mask for RAC_CLKMULTEN1                     */
#define _RAC_CLKMULTEN1_CLKMULTINNIBBLE_SHIFT                             0                                                      /**< Shift value for RAC_CLKMULTINNIBBLE         */
#define _RAC_CLKMULTEN1_CLKMULTINNIBBLE_MASK                              0xFUL                                                  /**< Bit mask for RAC_CLKMULTINNIBBLE            */
#define _RAC_CLKMULTEN1_CLKMULTINNIBBLE_DEFAULT                           0x00000008UL                                           /**< Mode DEFAULT for RAC_CLKMULTEN1             */
#define RAC_CLKMULTEN1_CLKMULTINNIBBLE_DEFAULT                            (_RAC_CLKMULTEN1_CLKMULTINNIBBLE_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_CLKMULTEN1     */
#define RAC_CLKMULTEN1_CLKMULTLDFNIB                                      (0x1UL << 5)                                           /**< CLKMULTLDFNIB                               */
#define _RAC_CLKMULTEN1_CLKMULTLDFNIB_SHIFT                               5                                                      /**< Shift value for RAC_CLKMULTLDFNIB           */
#define _RAC_CLKMULTEN1_CLKMULTLDFNIB_MASK                                0x20UL                                                 /**< Bit mask for RAC_CLKMULTLDFNIB              */
#define _RAC_CLKMULTEN1_CLKMULTLDFNIB_DEFAULT                             0x00000000UL                                           /**< Mode DEFAULT for RAC_CLKMULTEN1             */
#define _RAC_CLKMULTEN1_CLKMULTLDFNIB_disable                             0x00000000UL                                           /**< Mode disable for RAC_CLKMULTEN1             */
#define _RAC_CLKMULTEN1_CLKMULTLDFNIB_enable                              0x00000001UL                                           /**< Mode enable for RAC_CLKMULTEN1              */
#define RAC_CLKMULTEN1_CLKMULTLDFNIB_DEFAULT                              (_RAC_CLKMULTEN1_CLKMULTLDFNIB_DEFAULT << 5)           /**< Shifted mode DEFAULT for RAC_CLKMULTEN1     */
#define RAC_CLKMULTEN1_CLKMULTLDFNIB_disable                              (_RAC_CLKMULTEN1_CLKMULTLDFNIB_disable << 5)           /**< Shifted mode disable for RAC_CLKMULTEN1     */
#define RAC_CLKMULTEN1_CLKMULTLDFNIB_enable                               (_RAC_CLKMULTEN1_CLKMULTLDFNIB_enable << 5)            /**< Shifted mode enable for RAC_CLKMULTEN1      */
#define RAC_CLKMULTEN1_CLKMULTLDMNIB                                      (0x1UL << 6)                                           /**< CLKMULTLDMNIB                               */
#define _RAC_CLKMULTEN1_CLKMULTLDMNIB_SHIFT                               6                                                      /**< Shift value for RAC_CLKMULTLDMNIB           */
#define _RAC_CLKMULTEN1_CLKMULTLDMNIB_MASK                                0x40UL                                                 /**< Bit mask for RAC_CLKMULTLDMNIB              */
#define _RAC_CLKMULTEN1_CLKMULTLDMNIB_DEFAULT                             0x00000000UL                                           /**< Mode DEFAULT for RAC_CLKMULTEN1             */
#define _RAC_CLKMULTEN1_CLKMULTLDMNIB_disable                             0x00000000UL                                           /**< Mode disable for RAC_CLKMULTEN1             */
#define _RAC_CLKMULTEN1_CLKMULTLDMNIB_enable                              0x00000001UL                                           /**< Mode enable for RAC_CLKMULTEN1              */
#define RAC_CLKMULTEN1_CLKMULTLDMNIB_DEFAULT                              (_RAC_CLKMULTEN1_CLKMULTLDMNIB_DEFAULT << 6)           /**< Shifted mode DEFAULT for RAC_CLKMULTEN1     */
#define RAC_CLKMULTEN1_CLKMULTLDMNIB_disable                              (_RAC_CLKMULTEN1_CLKMULTLDMNIB_disable << 6)           /**< Shifted mode disable for RAC_CLKMULTEN1     */
#define RAC_CLKMULTEN1_CLKMULTLDMNIB_enable                               (_RAC_CLKMULTEN1_CLKMULTLDMNIB_enable << 6)            /**< Shifted mode enable for RAC_CLKMULTEN1      */
#define _RAC_CLKMULTEN1_CLKMULTRDNIBBLE_SHIFT                             7                                                      /**< Shift value for RAC_CLKMULTRDNIBBLE         */
#define _RAC_CLKMULTEN1_CLKMULTRDNIBBLE_MASK                              0x180UL                                                /**< Bit mask for RAC_CLKMULTRDNIBBLE            */
#define _RAC_CLKMULTEN1_CLKMULTRDNIBBLE_DEFAULT                           0x00000003UL                                           /**< Mode DEFAULT for RAC_CLKMULTEN1             */
#define _RAC_CLKMULTEN1_CLKMULTRDNIBBLE_quarter_nibble                    0x00000000UL                                           /**< Mode quarter_nibble for RAC_CLKMULTEN1      */
#define _RAC_CLKMULTEN1_CLKMULTRDNIBBLE_fine_nibble                       0x00000001UL                                           /**< Mode fine_nibble for RAC_CLKMULTEN1         */
#define _RAC_CLKMULTEN1_CLKMULTRDNIBBLE_moderate_nibble                   0x00000002UL                                           /**< Mode moderate_nibble for RAC_CLKMULTEN1     */
#define _RAC_CLKMULTEN1_CLKMULTRDNIBBLE_coarse_nibble                     0x00000003UL                                           /**< Mode coarse_nibble for RAC_CLKMULTEN1       */
#define RAC_CLKMULTEN1_CLKMULTRDNIBBLE_DEFAULT                            (_RAC_CLKMULTEN1_CLKMULTRDNIBBLE_DEFAULT << 7)         /**< Shifted mode DEFAULT for RAC_CLKMULTEN1     */
#define RAC_CLKMULTEN1_CLKMULTRDNIBBLE_quarter_nibble                     (_RAC_CLKMULTEN1_CLKMULTRDNIBBLE_quarter_nibble << 7)  /**< Shifted mode quarter_nibble for RAC_CLKMULTEN1*/
#define RAC_CLKMULTEN1_CLKMULTRDNIBBLE_fine_nibble                        (_RAC_CLKMULTEN1_CLKMULTRDNIBBLE_fine_nibble << 7)     /**< Shifted mode fine_nibble for RAC_CLKMULTEN1 */
#define RAC_CLKMULTEN1_CLKMULTRDNIBBLE_moderate_nibble                    (_RAC_CLKMULTEN1_CLKMULTRDNIBBLE_moderate_nibble << 7) /**< Shifted mode moderate_nibble for RAC_CLKMULTEN1*/
#define RAC_CLKMULTEN1_CLKMULTRDNIBBLE_coarse_nibble                      (_RAC_CLKMULTEN1_CLKMULTRDNIBBLE_coarse_nibble << 7)   /**< Shifted mode coarse_nibble for RAC_CLKMULTEN1*/
#define RAC_CLKMULTEN1_CLKMULTLDCNIB                                      (0x1UL << 10)                                          /**< CLKMULTLDCNIB                               */
#define _RAC_CLKMULTEN1_CLKMULTLDCNIB_SHIFT                               10                                                     /**< Shift value for RAC_CLKMULTLDCNIB           */
#define _RAC_CLKMULTEN1_CLKMULTLDCNIB_MASK                                0x400UL                                                /**< Bit mask for RAC_CLKMULTLDCNIB              */
#define _RAC_CLKMULTEN1_CLKMULTLDCNIB_DEFAULT                             0x00000000UL                                           /**< Mode DEFAULT for RAC_CLKMULTEN1             */
#define _RAC_CLKMULTEN1_CLKMULTLDCNIB_disable                             0x00000000UL                                           /**< Mode disable for RAC_CLKMULTEN1             */
#define _RAC_CLKMULTEN1_CLKMULTLDCNIB_enable                              0x00000001UL                                           /**< Mode enable for RAC_CLKMULTEN1              */
#define RAC_CLKMULTEN1_CLKMULTLDCNIB_DEFAULT                              (_RAC_CLKMULTEN1_CLKMULTLDCNIB_DEFAULT << 10)          /**< Shifted mode DEFAULT for RAC_CLKMULTEN1     */
#define RAC_CLKMULTEN1_CLKMULTLDCNIB_disable                              (_RAC_CLKMULTEN1_CLKMULTLDCNIB_disable << 10)          /**< Shifted mode disable for RAC_CLKMULTEN1     */
#define RAC_CLKMULTEN1_CLKMULTLDCNIB_enable                               (_RAC_CLKMULTEN1_CLKMULTLDCNIB_enable << 10)           /**< Shifted mode enable for RAC_CLKMULTEN1      */
#define _RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_SHIFT                            11                                                     /**< Shift value for RAC_CLKMULTDRVAMPSEL        */
#define _RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_MASK                             0x1F800UL                                              /**< Bit mask for RAC_CLKMULTDRVAMPSEL           */
#define _RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_DEFAULT                          0x00000000UL                                           /**< Mode DEFAULT for RAC_CLKMULTEN1             */
#define _RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_off                              0x00000000UL                                           /**< Mode off for RAC_CLKMULTEN1                 */
#define _RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x1                         0x00000001UL                                           /**< Mode slide_x1 for RAC_CLKMULTEN1            */
#define _RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x2                         0x00000003UL                                           /**< Mode slide_x2 for RAC_CLKMULTEN1            */
#define _RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x3                         0x00000007UL                                           /**< Mode slide_x3 for RAC_CLKMULTEN1            */
#define _RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x4                         0x0000000FUL                                           /**< Mode slide_x4 for RAC_CLKMULTEN1            */
#define _RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x5                         0x0000001FUL                                           /**< Mode slide_x5 for RAC_CLKMULTEN1            */
#define _RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x6                         0x0000003FUL                                           /**< Mode slide_x6 for RAC_CLKMULTEN1            */
#define RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_DEFAULT                           (_RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_DEFAULT << 11)       /**< Shifted mode DEFAULT for RAC_CLKMULTEN1     */
#define RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_off                               (_RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_off << 11)           /**< Shifted mode off for RAC_CLKMULTEN1         */
#define RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x1                          (_RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x1 << 11)      /**< Shifted mode slide_x1 for RAC_CLKMULTEN1    */
#define RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x2                          (_RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x2 << 11)      /**< Shifted mode slide_x2 for RAC_CLKMULTEN1    */
#define RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x3                          (_RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x3 << 11)      /**< Shifted mode slide_x3 for RAC_CLKMULTEN1    */
#define RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x4                          (_RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x4 << 11)      /**< Shifted mode slide_x4 for RAC_CLKMULTEN1    */
#define RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x5                          (_RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x5 << 11)      /**< Shifted mode slide_x5 for RAC_CLKMULTEN1    */
#define RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x6                          (_RAC_CLKMULTEN1_CLKMULTDRVAMPSEL_slide_x6 << 11)      /**< Shifted mode slide_x6 for RAC_CLKMULTEN1    */

/* Bit fields for RAC CLKMULTCTRL */
#define _RAC_CLKMULTCTRL_RESETVALUE                                       0x000000C0UL                                          /**< Default value for RAC_CLKMULTCTRL           */
#define _RAC_CLKMULTCTRL_MASK                                             0x00007FFFUL                                          /**< Mask for RAC_CLKMULTCTRL                    */
#define _RAC_CLKMULTCTRL_CLKMULTDIVN_SHIFT                                0                                                     /**< Shift value for RAC_CLKMULTDIVN             */
#define _RAC_CLKMULTCTRL_CLKMULTDIVN_MASK                                 0x7FUL                                                /**< Bit mask for RAC_CLKMULTDIVN                */
#define _RAC_CLKMULTCTRL_CLKMULTDIVN_DEFAULT                              0x00000040UL                                          /**< Mode DEFAULT for RAC_CLKMULTCTRL            */
#define RAC_CLKMULTCTRL_CLKMULTDIVN_DEFAULT                               (_RAC_CLKMULTCTRL_CLKMULTDIVN_DEFAULT << 0)           /**< Shifted mode DEFAULT for RAC_CLKMULTCTRL    */
#define _RAC_CLKMULTCTRL_CLKMULTDIVR_SHIFT                                7                                                     /**< Shift value for RAC_CLKMULTDIVR             */
#define _RAC_CLKMULTCTRL_CLKMULTDIVR_MASK                                 0x380UL                                               /**< Bit mask for RAC_CLKMULTDIVR                */
#define _RAC_CLKMULTCTRL_CLKMULTDIVR_DEFAULT                              0x00000001UL                                          /**< Mode DEFAULT for RAC_CLKMULTCTRL            */
#define RAC_CLKMULTCTRL_CLKMULTDIVR_DEFAULT                               (_RAC_CLKMULTCTRL_CLKMULTDIVR_DEFAULT << 7)           /**< Shifted mode DEFAULT for RAC_CLKMULTCTRL    */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_SHIFT                                10                                                    /**< Shift value for RAC_CLKMULTDIVX             */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_MASK                                 0x1C00UL                                              /**< Bit mask for RAC_CLKMULTDIVX                */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_DEFAULT                              0x00000000UL                                          /**< Mode DEFAULT for RAC_CLKMULTCTRL            */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_div_1                                0x00000000UL                                          /**< Mode div_1 for RAC_CLKMULTCTRL              */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_div_2                                0x00000001UL                                          /**< Mode div_2 for RAC_CLKMULTCTRL              */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_div_4                                0x00000002UL                                          /**< Mode div_4 for RAC_CLKMULTCTRL              */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_div_6                                0x00000003UL                                          /**< Mode div_6 for RAC_CLKMULTCTRL              */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_div_8                                0x00000004UL                                          /**< Mode div_8 for RAC_CLKMULTCTRL              */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_div10                                0x00000005UL                                          /**< Mode div10 for RAC_CLKMULTCTRL              */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_div12                                0x00000006UL                                          /**< Mode div12 for RAC_CLKMULTCTRL              */
#define _RAC_CLKMULTCTRL_CLKMULTDIVX_div14                                0x00000007UL                                          /**< Mode div14 for RAC_CLKMULTCTRL              */
#define RAC_CLKMULTCTRL_CLKMULTDIVX_DEFAULT                               (_RAC_CLKMULTCTRL_CLKMULTDIVX_DEFAULT << 10)          /**< Shifted mode DEFAULT for RAC_CLKMULTCTRL    */
#define RAC_CLKMULTCTRL_CLKMULTDIVX_div_1                                 (_RAC_CLKMULTCTRL_CLKMULTDIVX_div_1 << 10)            /**< Shifted mode div_1 for RAC_CLKMULTCTRL      */
#define RAC_CLKMULTCTRL_CLKMULTDIVX_div_2                                 (_RAC_CLKMULTCTRL_CLKMULTDIVX_div_2 << 10)            /**< Shifted mode div_2 for RAC_CLKMULTCTRL      */
#define RAC_CLKMULTCTRL_CLKMULTDIVX_div_4                                 (_RAC_CLKMULTCTRL_CLKMULTDIVX_div_4 << 10)            /**< Shifted mode div_4 for RAC_CLKMULTCTRL      */
#define RAC_CLKMULTCTRL_CLKMULTDIVX_div_6                                 (_RAC_CLKMULTCTRL_CLKMULTDIVX_div_6 << 10)            /**< Shifted mode div_6 for RAC_CLKMULTCTRL      */
#define RAC_CLKMULTCTRL_CLKMULTDIVX_div_8                                 (_RAC_CLKMULTCTRL_CLKMULTDIVX_div_8 << 10)            /**< Shifted mode div_8 for RAC_CLKMULTCTRL      */
#define RAC_CLKMULTCTRL_CLKMULTDIVX_div10                                 (_RAC_CLKMULTCTRL_CLKMULTDIVX_div10 << 10)            /**< Shifted mode div10 for RAC_CLKMULTCTRL      */
#define RAC_CLKMULTCTRL_CLKMULTDIVX_div12                                 (_RAC_CLKMULTCTRL_CLKMULTDIVX_div12 << 10)            /**< Shifted mode div12 for RAC_CLKMULTCTRL      */
#define RAC_CLKMULTCTRL_CLKMULTDIVX_div14                                 (_RAC_CLKMULTCTRL_CLKMULTDIVX_div14 << 10)            /**< Shifted mode div14 for RAC_CLKMULTCTRL      */
#define RAC_CLKMULTCTRL_CLKMULTENRESYNC                                   (0x1UL << 13)                                         /**< CLKMULTENRESYNC                             */
#define _RAC_CLKMULTCTRL_CLKMULTENRESYNC_SHIFT                            13                                                    /**< Shift value for RAC_CLKMULTENRESYNC         */
#define _RAC_CLKMULTCTRL_CLKMULTENRESYNC_MASK                             0x2000UL                                              /**< Bit mask for RAC_CLKMULTENRESYNC            */
#define _RAC_CLKMULTCTRL_CLKMULTENRESYNC_DEFAULT                          0x00000000UL                                          /**< Mode DEFAULT for RAC_CLKMULTCTRL            */
#define _RAC_CLKMULTCTRL_CLKMULTENRESYNC_disable_sync                     0x00000000UL                                          /**< Mode disable_sync for RAC_CLKMULTCTRL       */
#define _RAC_CLKMULTCTRL_CLKMULTENRESYNC_enable_sync                      0x00000001UL                                          /**< Mode enable_sync for RAC_CLKMULTCTRL        */
#define RAC_CLKMULTCTRL_CLKMULTENRESYNC_DEFAULT                           (_RAC_CLKMULTCTRL_CLKMULTENRESYNC_DEFAULT << 13)      /**< Shifted mode DEFAULT for RAC_CLKMULTCTRL    */
#define RAC_CLKMULTCTRL_CLKMULTENRESYNC_disable_sync                      (_RAC_CLKMULTCTRL_CLKMULTENRESYNC_disable_sync << 13) /**< Shifted mode disable_sync for RAC_CLKMULTCTRL*/
#define RAC_CLKMULTCTRL_CLKMULTENRESYNC_enable_sync                       (_RAC_CLKMULTCTRL_CLKMULTENRESYNC_enable_sync << 13)  /**< Shifted mode enable_sync for RAC_CLKMULTCTRL*/
#define RAC_CLKMULTCTRL_CLKMULTVALID                                      (0x1UL << 14)                                         /**< CLKMULTVALID                                */
#define _RAC_CLKMULTCTRL_CLKMULTVALID_SHIFT                               14                                                    /**< Shift value for RAC_CLKMULTVALID            */
#define _RAC_CLKMULTCTRL_CLKMULTVALID_MASK                                0x4000UL                                              /**< Bit mask for RAC_CLKMULTVALID               */
#define _RAC_CLKMULTCTRL_CLKMULTVALID_DEFAULT                             0x00000000UL                                          /**< Mode DEFAULT for RAC_CLKMULTCTRL            */
#define _RAC_CLKMULTCTRL_CLKMULTVALID_invalid                             0x00000000UL                                          /**< Mode invalid for RAC_CLKMULTCTRL            */
#define _RAC_CLKMULTCTRL_CLKMULTVALID_valid                               0x00000001UL                                          /**< Mode valid for RAC_CLKMULTCTRL              */
#define RAC_CLKMULTCTRL_CLKMULTVALID_DEFAULT                              (_RAC_CLKMULTCTRL_CLKMULTVALID_DEFAULT << 14)         /**< Shifted mode DEFAULT for RAC_CLKMULTCTRL    */
#define RAC_CLKMULTCTRL_CLKMULTVALID_invalid                              (_RAC_CLKMULTCTRL_CLKMULTVALID_invalid << 14)         /**< Shifted mode invalid for RAC_CLKMULTCTRL    */
#define RAC_CLKMULTCTRL_CLKMULTVALID_valid                                (_RAC_CLKMULTCTRL_CLKMULTVALID_valid << 14)           /**< Shifted mode valid for RAC_CLKMULTCTRL      */

/* Bit fields for RAC CLKMULTSTATUS */
#define _RAC_CLKMULTSTATUS_RESETVALUE                                     0x00000000UL                                       /**< Default value for RAC_CLKMULTSTATUS         */
#define _RAC_CLKMULTSTATUS_MASK                                           0x0000001FUL                                       /**< Mask for RAC_CLKMULTSTATUS                  */
#define _RAC_CLKMULTSTATUS_CLKMULTOUTNIBBLE_SHIFT                         0                                                  /**< Shift value for RAC_CLKMULTOUTNIBBLE        */
#define _RAC_CLKMULTSTATUS_CLKMULTOUTNIBBLE_MASK                          0xFUL                                              /**< Bit mask for RAC_CLKMULTOUTNIBBLE           */
#define _RAC_CLKMULTSTATUS_CLKMULTOUTNIBBLE_DEFAULT                       0x00000000UL                                       /**< Mode DEFAULT for RAC_CLKMULTSTATUS          */
#define RAC_CLKMULTSTATUS_CLKMULTOUTNIBBLE_DEFAULT                        (_RAC_CLKMULTSTATUS_CLKMULTOUTNIBBLE_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_CLKMULTSTATUS  */
#define RAC_CLKMULTSTATUS_CLKMULTACKVALID                                 (0x1UL << 4)                                       /**< CLKMULTACKVALID                             */
#define _RAC_CLKMULTSTATUS_CLKMULTACKVALID_SHIFT                          4                                                  /**< Shift value for RAC_CLKMULTACKVALID         */
#define _RAC_CLKMULTSTATUS_CLKMULTACKVALID_MASK                           0x10UL                                             /**< Bit mask for RAC_CLKMULTACKVALID            */
#define _RAC_CLKMULTSTATUS_CLKMULTACKVALID_DEFAULT                        0x00000000UL                                       /**< Mode DEFAULT for RAC_CLKMULTSTATUS          */
#define _RAC_CLKMULTSTATUS_CLKMULTACKVALID_invalid                        0x00000000UL                                       /**< Mode invalid for RAC_CLKMULTSTATUS          */
#define _RAC_CLKMULTSTATUS_CLKMULTACKVALID_valid                          0x00000001UL                                       /**< Mode valid for RAC_CLKMULTSTATUS            */
#define RAC_CLKMULTSTATUS_CLKMULTACKVALID_DEFAULT                         (_RAC_CLKMULTSTATUS_CLKMULTACKVALID_DEFAULT << 4)  /**< Shifted mode DEFAULT for RAC_CLKMULTSTATUS  */
#define RAC_CLKMULTSTATUS_CLKMULTACKVALID_invalid                         (_RAC_CLKMULTSTATUS_CLKMULTACKVALID_invalid << 4)  /**< Shifted mode invalid for RAC_CLKMULTSTATUS  */
#define RAC_CLKMULTSTATUS_CLKMULTACKVALID_valid                           (_RAC_CLKMULTSTATUS_CLKMULTACKVALID_valid << 4)    /**< Shifted mode valid for RAC_CLKMULTSTATUS    */

/* Bit fields for RAC IFADCTRIM0 */
#define _RAC_IFADCTRIM0_RESETVALUE                                        0x11512C6CUL                                            /**< Default value for RAC_IFADCTRIM0            */
#define _RAC_IFADCTRIM0_MASK                                              0x7FFFFFFDUL                                            /**< Mask for RAC_IFADCTRIM0                     */
#define RAC_IFADCTRIM0_IFADCCLKSEL                                        (0x1UL << 0)                                            /**< IFADCCLKSEL                                 */
#define _RAC_IFADCTRIM0_IFADCCLKSEL_SHIFT                                 0                                                       /**< Shift value for RAC_IFADCCLKSEL             */
#define _RAC_IFADCTRIM0_IFADCCLKSEL_MASK                                  0x1UL                                                   /**< Bit mask for RAC_IFADCCLKSEL                */
#define _RAC_IFADCTRIM0_IFADCCLKSEL_DEFAULT                               0x00000000UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCCLKSEL_clk_synth                             0x00000000UL                                            /**< Mode clk_synth for RAC_IFADCTRIM0           */
#define _RAC_IFADCTRIM0_IFADCCLKSEL_clk_adcpll                            0x00000001UL                                            /**< Mode clk_adcpll for RAC_IFADCTRIM0          */
#define RAC_IFADCTRIM0_IFADCCLKSEL_DEFAULT                                (_RAC_IFADCTRIM0_IFADCCLKSEL_DEFAULT << 0)              /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCCLKSEL_clk_synth                              (_RAC_IFADCTRIM0_IFADCCLKSEL_clk_synth << 0)            /**< Shifted mode clk_synth for RAC_IFADCTRIM0   */
#define RAC_IFADCTRIM0_IFADCCLKSEL_clk_adcpll                             (_RAC_IFADCTRIM0_IFADCCLKSEL_clk_adcpll << 0)           /**< Shifted mode clk_adcpll for RAC_IFADCTRIM0  */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_SHIFT                        2                                                       /**< Shift value for RAC_IFADCLDOSERIESAMPLVL    */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_MASK                         0x1CUL                                                  /**< Bit mask for RAC_IFADCLDOSERIESAMPLVL       */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_DEFAULT                      0x00000003UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p225                       0x00000000UL                                            /**< Mode v1p225 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p250                       0x00000001UL                                            /**< Mode v1p250 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p275                       0x00000002UL                                            /**< Mode v1p275 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p300                       0x00000003UL                                            /**< Mode v1p300 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p325                       0x00000004UL                                            /**< Mode v1p325 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p350                       0x00000005UL                                            /**< Mode v1p350 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p375                       0x00000006UL                                            /**< Mode v1p375 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p400                       0x00000007UL                                            /**< Mode v1p400 for RAC_IFADCTRIM0              */
#define RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_DEFAULT                       (_RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_DEFAULT << 2)     /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p225                        (_RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p225 << 2)      /**< Shifted mode v1p225 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p250                        (_RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p250 << 2)      /**< Shifted mode v1p250 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p275                        (_RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p275 << 2)      /**< Shifted mode v1p275 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p300                        (_RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p300 << 2)      /**< Shifted mode v1p300 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p325                        (_RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p325 << 2)      /**< Shifted mode v1p325 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p350                        (_RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p350 << 2)      /**< Shifted mode v1p350 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p375                        (_RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p375 << 2)      /**< Shifted mode v1p375 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p400                        (_RAC_IFADCTRIM0_IFADCLDOSERIESAMPLVL_v1p400 << 2)      /**< Shifted mode v1p400 for RAC_IFADCTRIM0      */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_SHIFT                        5                                                       /**< Shift value for RAC_IFADCLDOSHUNTAMPLVL1    */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_MASK                         0xE0UL                                                  /**< Bit mask for RAC_IFADCLDOSHUNTAMPLVL1       */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_DEFAULT                      0x00000003UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p125                       0x00000000UL                                            /**< Mode v1p125 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p150                       0x00000001UL                                            /**< Mode v1p150 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p175                       0x00000002UL                                            /**< Mode v1p175 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p200                       0x00000003UL                                            /**< Mode v1p200 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p225                       0x00000004UL                                            /**< Mode v1p225 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p250                       0x00000005UL                                            /**< Mode v1p250 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p275                       0x00000006UL                                            /**< Mode v1p275 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p300                       0x00000007UL                                            /**< Mode v1p300 for RAC_IFADCTRIM0              */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_DEFAULT                       (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_DEFAULT << 5)     /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p125                        (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p125 << 5)      /**< Shifted mode v1p125 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p150                        (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p150 << 5)      /**< Shifted mode v1p150 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p175                        (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p175 << 5)      /**< Shifted mode v1p175 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p200                        (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p200 << 5)      /**< Shifted mode v1p200 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p225                        (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p225 << 5)      /**< Shifted mode v1p225 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p250                        (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p250 << 5)      /**< Shifted mode v1p250 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p275                        (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p275 << 5)      /**< Shifted mode v1p275 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p300                        (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL1_v1p300 << 5)      /**< Shifted mode v1p300 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2                               (0x1UL << 8)                                            /**< IFADCLDOSHUNTAMPLVL2                        */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_SHIFT                        8                                                       /**< Shift value for RAC_IFADCLDOSHUNTAMPLVL2    */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_MASK                         0x100UL                                                 /**< Bit mask for RAC_IFADCLDOSHUNTAMPLVL2       */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_DEFAULT                      0x00000000UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_disable                      0x00000000UL                                            /**< Mode disable for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_enable                       0x00000001UL                                            /**< Mode enable for RAC_IFADCTRIM0              */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_DEFAULT                       (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_DEFAULT << 8)     /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_disable                       (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_disable << 8)     /**< Shifted mode disable for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_enable                        (_RAC_IFADCTRIM0_IFADCLDOSHUNTAMPLVL2_enable << 8)      /**< Shifted mode enable for RAC_IFADCTRIM0      */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_SHIFT                        9                                                       /**< Shift value for RAC_IFADCLDOSHUNTCURLVL1    */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_MASK                         0xE00UL                                                 /**< Bit mask for RAC_IFADCLDOSHUNTCURLVL1       */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_DEFAULT                      0x00000006UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i55u                         0x00000000UL                                            /**< Mode i55u for RAC_IFADCTRIM0                */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i65u                         0x00000001UL                                            /**< Mode i65u for RAC_IFADCTRIM0                */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i70u                         0x00000002UL                                            /**< Mode i70u for RAC_IFADCTRIM0                */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i85u                         0x00000003UL                                            /**< Mode i85u for RAC_IFADCTRIM0                */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i85u2                        0x00000004UL                                            /**< Mode i85u2 for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i95u                         0x00000005UL                                            /**< Mode i95u for RAC_IFADCTRIM0                */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i100u                        0x00000006UL                                            /**< Mode i100u for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i110u                        0x00000007UL                                            /**< Mode i110u for RAC_IFADCTRIM0               */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_DEFAULT                       (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_DEFAULT << 9)     /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i55u                          (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i55u << 9)        /**< Shifted mode i55u for RAC_IFADCTRIM0        */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i65u                          (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i65u << 9)        /**< Shifted mode i65u for RAC_IFADCTRIM0        */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i70u                          (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i70u << 9)        /**< Shifted mode i70u for RAC_IFADCTRIM0        */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i85u                          (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i85u << 9)        /**< Shifted mode i85u for RAC_IFADCTRIM0        */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i85u2                         (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i85u2 << 9)       /**< Shifted mode i85u2 for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i95u                          (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i95u << 9)        /**< Shifted mode i95u for RAC_IFADCTRIM0        */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i100u                         (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i100u << 9)       /**< Shifted mode i100u for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i110u                         (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL1_i110u << 9)       /**< Shifted mode i110u for RAC_IFADCTRIM0       */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_SHIFT                        12                                                      /**< Shift value for RAC_IFADCLDOSHUNTCURLVL2    */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_MASK                         0x7000UL                                                /**< Bit mask for RAC_IFADCLDOSHUNTCURLVL2       */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_DEFAULT                      0x00000002UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i4u                          0x00000000UL                                            /**< Mode i4u for RAC_IFADCTRIM0                 */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i4p5u                        0x00000001UL                                            /**< Mode i4p5u for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5u                          0x00000002UL                                            /**< Mode i5u for RAC_IFADCTRIM0                 */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5p5u                        0x00000003UL                                            /**< Mode i5p5u for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5u2                         0x00000004UL                                            /**< Mode i5u2 for RAC_IFADCTRIM0                */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5p5u2                       0x00000005UL                                            /**< Mode i5p5u2 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i6u                          0x00000006UL                                            /**< Mode i6u for RAC_IFADCTRIM0                 */
#define _RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i6p5u                        0x00000007UL                                            /**< Mode i6p5u for RAC_IFADCTRIM0               */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_DEFAULT                       (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_DEFAULT << 12)    /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i4u                           (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i4u << 12)        /**< Shifted mode i4u for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i4p5u                         (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i4p5u << 12)      /**< Shifted mode i4p5u for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5u                           (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5u << 12)        /**< Shifted mode i5u for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5p5u                         (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5p5u << 12)      /**< Shifted mode i5p5u for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5u2                          (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5u2 << 12)       /**< Shifted mode i5u2 for RAC_IFADCTRIM0        */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5p5u2                        (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i5p5u2 << 12)     /**< Shifted mode i5p5u2 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i6u                           (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i6u << 12)        /**< Shifted mode i6u for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i6p5u                         (_RAC_IFADCTRIM0_IFADCLDOSHUNTCURLVL2_i6p5u << 12)      /**< Shifted mode i6p5u for RAC_IFADCTRIM0       */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_SHIFT                             15                                                      /**< Shift value for RAC_IFADCOTACURRENT         */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_MASK                              0x38000UL                                               /**< Bit mask for RAC_IFADCOTACURRENT            */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_DEFAULT                           0x00000002UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_i3u                               0x00000000UL                                            /**< Mode i3u for RAC_IFADCTRIM0                 */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_i3p5u                             0x00000001UL                                            /**< Mode i3p5u for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_i4u                               0x00000002UL                                            /**< Mode i4u for RAC_IFADCTRIM0                 */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_i4p5u                             0x00000003UL                                            /**< Mode i4p5u for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_i4u2                              0x00000004UL                                            /**< Mode i4u2 for RAC_IFADCTRIM0                */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_i4p5u2                            0x00000005UL                                            /**< Mode i4p5u2 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_i5u                               0x00000006UL                                            /**< Mode i5u for RAC_IFADCTRIM0                 */
#define _RAC_IFADCTRIM0_IFADCOTACURRENT_i5p5u                             0x00000007UL                                            /**< Mode i5p5u for RAC_IFADCTRIM0               */
#define RAC_IFADCTRIM0_IFADCOTACURRENT_DEFAULT                            (_RAC_IFADCTRIM0_IFADCOTACURRENT_DEFAULT << 15)         /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCOTACURRENT_i3u                                (_RAC_IFADCTRIM0_IFADCOTACURRENT_i3u << 15)             /**< Shifted mode i3u for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCOTACURRENT_i3p5u                              (_RAC_IFADCTRIM0_IFADCOTACURRENT_i3p5u << 15)           /**< Shifted mode i3p5u for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCOTACURRENT_i4u                                (_RAC_IFADCTRIM0_IFADCOTACURRENT_i4u << 15)             /**< Shifted mode i4u for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCOTACURRENT_i4p5u                              (_RAC_IFADCTRIM0_IFADCOTACURRENT_i4p5u << 15)           /**< Shifted mode i4p5u for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCOTACURRENT_i4u2                               (_RAC_IFADCTRIM0_IFADCOTACURRENT_i4u2 << 15)            /**< Shifted mode i4u2 for RAC_IFADCTRIM0        */
#define RAC_IFADCTRIM0_IFADCOTACURRENT_i4p5u2                             (_RAC_IFADCTRIM0_IFADCOTACURRENT_i4p5u2 << 15)          /**< Shifted mode i4p5u2 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCOTACURRENT_i5u                                (_RAC_IFADCTRIM0_IFADCOTACURRENT_i5u << 15)             /**< Shifted mode i5u for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCOTACURRENT_i5p5u                              (_RAC_IFADCTRIM0_IFADCOTACURRENT_i5p5u << 15)           /**< Shifted mode i5p5u for RAC_IFADCTRIM0       */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_SHIFT                           18                                                      /**< Shift value for RAC_IFADCREFBUFAMPLVL       */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_MASK                            0x1C0000UL                                              /**< Bit mask for RAC_IFADCREFBUFAMPLVL          */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_DEFAULT                         0x00000004UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p88                           0x00000000UL                                            /**< Mode v0p88 for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p91                           0x00000001UL                                            /**< Mode v0p91 for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p94                           0x00000002UL                                            /**< Mode v0p94 for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p97                           0x00000003UL                                            /**< Mode v0p97 for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p00                           0x00000004UL                                            /**< Mode v1p00 for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p03                           0x00000005UL                                            /**< Mode v1p03 for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p06                           0x00000006UL                                            /**< Mode v1p06 for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p09                           0x00000007UL                                            /**< Mode v1p09 for RAC_IFADCTRIM0               */
#define RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_DEFAULT                          (_RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_DEFAULT << 18)       /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p88                            (_RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p88 << 18)         /**< Shifted mode v0p88 for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p91                            (_RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p91 << 18)         /**< Shifted mode v0p91 for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p94                            (_RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p94 << 18)         /**< Shifted mode v0p94 for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p97                            (_RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v0p97 << 18)         /**< Shifted mode v0p97 for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p00                            (_RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p00 << 18)         /**< Shifted mode v1p00 for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p03                            (_RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p03 << 18)         /**< Shifted mode v1p03 for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p06                            (_RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p06 << 18)         /**< Shifted mode v1p06 for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p09                            (_RAC_IFADCTRIM0_IFADCREFBUFAMPLVL_v1p09 << 18)         /**< Shifted mode v1p09 for RAC_IFADCTRIM0       */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_SHIFT                           21                                                      /**< Shift value for RAC_IFADCREFBUFCURLVL       */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_MASK                            0xE00000UL                                              /**< Bit mask for RAC_IFADCREFBUFCURLVL          */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_DEFAULT                         0x00000002UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i4u                             0x00000000UL                                            /**< Mode i4u for RAC_IFADCTRIM0                 */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i4p5u                           0x00000001UL                                            /**< Mode i4p5u for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5u                             0x00000002UL                                            /**< Mode i5u for RAC_IFADCTRIM0                 */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5p5u                           0x00000003UL                                            /**< Mode i5p5u for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5u2                            0x00000004UL                                            /**< Mode i5u2 for RAC_IFADCTRIM0                */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5p5u2                          0x00000005UL                                            /**< Mode i5p5u2 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i6u                             0x00000006UL                                            /**< Mode i6u for RAC_IFADCTRIM0                 */
#define _RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i6p5u                           0x00000007UL                                            /**< Mode i6p5u for RAC_IFADCTRIM0               */
#define RAC_IFADCTRIM0_IFADCREFBUFCURLVL_DEFAULT                          (_RAC_IFADCTRIM0_IFADCREFBUFCURLVL_DEFAULT << 21)       /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i4u                              (_RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i4u << 21)           /**< Shifted mode i4u for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i4p5u                            (_RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i4p5u << 21)         /**< Shifted mode i4p5u for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5u                              (_RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5u << 21)           /**< Shifted mode i5u for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5p5u                            (_RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5p5u << 21)         /**< Shifted mode i5p5u for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5u2                             (_RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5u2 << 21)          /**< Shifted mode i5u2 for RAC_IFADCTRIM0        */
#define RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5p5u2                           (_RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i5p5u2 << 21)        /**< Shifted mode i5p5u2 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i6u                              (_RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i6u << 21)           /**< Shifted mode i6u for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i6p5u                            (_RAC_IFADCTRIM0_IFADCREFBUFCURLVL_i6p5u << 21)         /**< Shifted mode i6p5u for RAC_IFADCTRIM0       */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_SHIFT                            24                                                      /**< Shift value for RAC_IFADCSIDETONEAMP        */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_MASK                             0x7000000UL                                             /**< Bit mask for RAC_IFADCSIDETONEAMP           */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_DEFAULT                          0x00000001UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_5p68mV                      0x00000000UL                                            /**< Mode diff_5p68mV for RAC_IFADCTRIM0         */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_29p1mV                      0x00000001UL                                            /**< Mode diff_29p1mV for RAC_IFADCTRIM0         */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_9p73mV                      0x00000002UL                                            /**< Mode diff_9p73mV for RAC_IFADCTRIM0         */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_76p9mV                      0x00000003UL                                            /**< Mode diff_76p9mV for RAC_IFADCTRIM0         */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_9p68_mV                     0x00000004UL                                            /**< Mode diff_9p68_mV for RAC_IFADCTRIM0        */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_51_mV                       0x00000005UL                                            /**< Mode diff_51_mV for RAC_IFADCTRIM0          */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_17p2_mV                     0x00000006UL                                            /**< Mode diff_17p2_mV for RAC_IFADCTRIM0        */
#define _RAC_IFADCTRIM0_IFADCSIDETONEAMP_disable                          0x00000007UL                                            /**< Mode disable for RAC_IFADCTRIM0             */
#define RAC_IFADCTRIM0_IFADCSIDETONEAMP_DEFAULT                           (_RAC_IFADCTRIM0_IFADCSIDETONEAMP_DEFAULT << 24)        /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_5p68mV                       (_RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_5p68mV << 24)    /**< Shifted mode diff_5p68mV for RAC_IFADCTRIM0 */
#define RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_29p1mV                       (_RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_29p1mV << 24)    /**< Shifted mode diff_29p1mV for RAC_IFADCTRIM0 */
#define RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_9p73mV                       (_RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_9p73mV << 24)    /**< Shifted mode diff_9p73mV for RAC_IFADCTRIM0 */
#define RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_76p9mV                       (_RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_76p9mV << 24)    /**< Shifted mode diff_76p9mV for RAC_IFADCTRIM0 */
#define RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_9p68_mV                      (_RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_9p68_mV << 24)   /**< Shifted mode diff_9p68_mV for RAC_IFADCTRIM0*/
#define RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_51_mV                        (_RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_51_mV << 24)     /**< Shifted mode diff_51_mV for RAC_IFADCTRIM0  */
#define RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_17p2_mV                      (_RAC_IFADCTRIM0_IFADCSIDETONEAMP_diff_17p2_mV << 24)   /**< Shifted mode diff_17p2_mV for RAC_IFADCTRIM0*/
#define RAC_IFADCTRIM0_IFADCSIDETONEAMP_disable                           (_RAC_IFADCTRIM0_IFADCSIDETONEAMP_disable << 24)        /**< Shifted mode disable for RAC_IFADCTRIM0     */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_SHIFT                           27                                                      /**< Shift value for RAC_IFADCSIDETONEFREQ       */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_MASK                            0x38000000UL                                            /**< Bit mask for RAC_IFADCSIDETONEFREQ          */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_DEFAULT                         0x00000002UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_na0                             0x00000000UL                                            /**< Mode na0 for RAC_IFADCTRIM0                 */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_128                         0x00000001UL                                            /**< Mode div_128 for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_64                          0x00000002UL                                            /**< Mode div_64 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_32                          0x00000003UL                                            /**< Mode div_32 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_16                          0x00000004UL                                            /**< Mode div_16 for RAC_IFADCTRIM0              */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_8                           0x00000005UL                                            /**< Mode div_8 for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_4                           0x00000006UL                                            /**< Mode div_4 for RAC_IFADCTRIM0               */
#define _RAC_IFADCTRIM0_IFADCSIDETONEFREQ_na7                             0x00000007UL                                            /**< Mode na7 for RAC_IFADCTRIM0                 */
#define RAC_IFADCTRIM0_IFADCSIDETONEFREQ_DEFAULT                          (_RAC_IFADCTRIM0_IFADCSIDETONEFREQ_DEFAULT << 27)       /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCSIDETONEFREQ_na0                              (_RAC_IFADCTRIM0_IFADCSIDETONEFREQ_na0 << 27)           /**< Shifted mode na0 for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_128                          (_RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_128 << 27)       /**< Shifted mode div_128 for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_64                           (_RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_64 << 27)        /**< Shifted mode div_64 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_32                           (_RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_32 << 27)        /**< Shifted mode div_32 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_16                           (_RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_16 << 27)        /**< Shifted mode div_16 for RAC_IFADCTRIM0      */
#define RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_8                            (_RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_8 << 27)         /**< Shifted mode div_8 for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_4                            (_RAC_IFADCTRIM0_IFADCSIDETONEFREQ_div_4 << 27)         /**< Shifted mode div_4 for RAC_IFADCTRIM0       */
#define RAC_IFADCTRIM0_IFADCSIDETONEFREQ_na7                              (_RAC_IFADCTRIM0_IFADCSIDETONEFREQ_na7 << 27)           /**< Shifted mode na7 for RAC_IFADCTRIM0         */
#define RAC_IFADCTRIM0_IFADCENHALFMODE                                    (0x1UL << 30)                                           /**< IFADCENHALFMODE                             */
#define _RAC_IFADCTRIM0_IFADCENHALFMODE_SHIFT                             30                                                      /**< Shift value for RAC_IFADCENHALFMODE         */
#define _RAC_IFADCTRIM0_IFADCENHALFMODE_MASK                              0x40000000UL                                            /**< Bit mask for RAC_IFADCENHALFMODE            */
#define _RAC_IFADCTRIM0_IFADCENHALFMODE_DEFAULT                           0x00000000UL                                            /**< Mode DEFAULT for RAC_IFADCTRIM0             */
#define _RAC_IFADCTRIM0_IFADCENHALFMODE_full_speed_mode                   0x00000000UL                                            /**< Mode full_speed_mode for RAC_IFADCTRIM0     */
#define _RAC_IFADCTRIM0_IFADCENHALFMODE_half_speed_mode                   0x00000001UL                                            /**< Mode half_speed_mode for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCENHALFMODE_DEFAULT                            (_RAC_IFADCTRIM0_IFADCENHALFMODE_DEFAULT << 30)         /**< Shifted mode DEFAULT for RAC_IFADCTRIM0     */
#define RAC_IFADCTRIM0_IFADCENHALFMODE_full_speed_mode                    (_RAC_IFADCTRIM0_IFADCENHALFMODE_full_speed_mode << 30) /**< Shifted mode full_speed_mode for RAC_IFADCTRIM0*/
#define RAC_IFADCTRIM0_IFADCENHALFMODE_half_speed_mode                    (_RAC_IFADCTRIM0_IFADCENHALFMODE_half_speed_mode << 30) /**< Shifted mode half_speed_mode for RAC_IFADCTRIM0*/

/* Bit fields for RAC IFADCTRIM1 */
#define _RAC_IFADCTRIM1_RESETVALUE                                        0x00000123UL                                           /**< Default value for RAC_IFADCTRIM1            */
#define _RAC_IFADCTRIM1_MASK                                              0x00003FFFUL                                           /**< Mask for RAC_IFADCTRIM1                     */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_SHIFT                                 0                                                      /**< Shift value for RAC_IFADCVCMLVL             */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_MASK                                  0x7UL                                                  /**< Bit mask for RAC_IFADCVCMLVL                */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_DEFAULT                               0x00000003UL                                           /**< Mode DEFAULT for RAC_IFADCTRIM1             */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_vcm_475mV                             0x00000000UL                                           /**< Mode vcm_475mV for RAC_IFADCTRIM1           */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_vcm_500mV                             0x00000001UL                                           /**< Mode vcm_500mV for RAC_IFADCTRIM1           */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_vcm_525mV                             0x00000002UL                                           /**< Mode vcm_525mV for RAC_IFADCTRIM1           */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_vcm_550mV                             0x00000003UL                                           /**< Mode vcm_550mV for RAC_IFADCTRIM1           */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_vcm_575mV                             0x00000004UL                                           /**< Mode vcm_575mV for RAC_IFADCTRIM1           */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_vcm_600mV                             0x00000005UL                                           /**< Mode vcm_600mV for RAC_IFADCTRIM1           */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_vcm_625mV                             0x00000006UL                                           /**< Mode vcm_625mV for RAC_IFADCTRIM1           */
#define _RAC_IFADCTRIM1_IFADCVCMLVL_cm_650mV                              0x00000007UL                                           /**< Mode cm_650mV for RAC_IFADCTRIM1            */
#define RAC_IFADCTRIM1_IFADCVCMLVL_DEFAULT                                (_RAC_IFADCTRIM1_IFADCVCMLVL_DEFAULT << 0)             /**< Shifted mode DEFAULT for RAC_IFADCTRIM1     */
#define RAC_IFADCTRIM1_IFADCVCMLVL_vcm_475mV                              (_RAC_IFADCTRIM1_IFADCVCMLVL_vcm_475mV << 0)           /**< Shifted mode vcm_475mV for RAC_IFADCTRIM1   */
#define RAC_IFADCTRIM1_IFADCVCMLVL_vcm_500mV                              (_RAC_IFADCTRIM1_IFADCVCMLVL_vcm_500mV << 0)           /**< Shifted mode vcm_500mV for RAC_IFADCTRIM1   */
#define RAC_IFADCTRIM1_IFADCVCMLVL_vcm_525mV                              (_RAC_IFADCTRIM1_IFADCVCMLVL_vcm_525mV << 0)           /**< Shifted mode vcm_525mV for RAC_IFADCTRIM1   */
#define RAC_IFADCTRIM1_IFADCVCMLVL_vcm_550mV                              (_RAC_IFADCTRIM1_IFADCVCMLVL_vcm_550mV << 0)           /**< Shifted mode vcm_550mV for RAC_IFADCTRIM1   */
#define RAC_IFADCTRIM1_IFADCVCMLVL_vcm_575mV                              (_RAC_IFADCTRIM1_IFADCVCMLVL_vcm_575mV << 0)           /**< Shifted mode vcm_575mV for RAC_IFADCTRIM1   */
#define RAC_IFADCTRIM1_IFADCVCMLVL_vcm_600mV                              (_RAC_IFADCTRIM1_IFADCVCMLVL_vcm_600mV << 0)           /**< Shifted mode vcm_600mV for RAC_IFADCTRIM1   */
#define RAC_IFADCTRIM1_IFADCVCMLVL_vcm_625mV                              (_RAC_IFADCTRIM1_IFADCVCMLVL_vcm_625mV << 0)           /**< Shifted mode vcm_625mV for RAC_IFADCTRIM1   */
#define RAC_IFADCTRIM1_IFADCVCMLVL_cm_650mV                               (_RAC_IFADCTRIM1_IFADCVCMLVL_cm_650mV << 0)            /**< Shifted mode cm_650mV for RAC_IFADCTRIM1    */
#define RAC_IFADCTRIM1_IFADCENNEGRES                                      (0x1UL << 3)                                           /**< IFADCENNEGRES                               */
#define _RAC_IFADCTRIM1_IFADCENNEGRES_SHIFT                               3                                                      /**< Shift value for RAC_IFADCENNEGRES           */
#define _RAC_IFADCTRIM1_IFADCENNEGRES_MASK                                0x8UL                                                  /**< Bit mask for RAC_IFADCENNEGRES              */
#define _RAC_IFADCTRIM1_IFADCENNEGRES_DEFAULT                             0x00000000UL                                           /**< Mode DEFAULT for RAC_IFADCTRIM1             */
#define _RAC_IFADCTRIM1_IFADCENNEGRES_disable                             0x00000000UL                                           /**< Mode disable for RAC_IFADCTRIM1             */
#define _RAC_IFADCTRIM1_IFADCENNEGRES_enable                              0x00000001UL                                           /**< Mode enable for RAC_IFADCTRIM1              */
#define RAC_IFADCTRIM1_IFADCENNEGRES_DEFAULT                              (_RAC_IFADCTRIM1_IFADCENNEGRES_DEFAULT << 3)           /**< Shifted mode DEFAULT for RAC_IFADCTRIM1     */
#define RAC_IFADCTRIM1_IFADCENNEGRES_disable                              (_RAC_IFADCTRIM1_IFADCENNEGRES_disable << 3)           /**< Shifted mode disable for RAC_IFADCTRIM1     */
#define RAC_IFADCTRIM1_IFADCENNEGRES_enable                               (_RAC_IFADCTRIM1_IFADCENNEGRES_enable << 3)            /**< Shifted mode enable for RAC_IFADCTRIM1      */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_SHIFT                          4                                                      /**< Shift value for RAC_IFADCNEGRESCURRENT      */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_MASK                           0x70UL                                                 /**< Bit mask for RAC_IFADCNEGRESCURRENT         */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_DEFAULT                        0x00000002UL                                           /**< Mode DEFAULT for RAC_IFADCTRIM1             */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i1p0u                          0x00000000UL                                           /**< Mode i1p0u for RAC_IFADCTRIM1               */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i1p5u                          0x00000001UL                                           /**< Mode i1p5u for RAC_IFADCTRIM1               */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p0u                          0x00000002UL                                           /**< Mode i2p0u for RAC_IFADCTRIM1               */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p5u                          0x00000003UL                                           /**< Mode i2p5u for RAC_IFADCTRIM1               */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p0u2                         0x00000004UL                                           /**< Mode i2p0u2 for RAC_IFADCTRIM1              */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p5u2                         0x00000005UL                                           /**< Mode i2p5u2 for RAC_IFADCTRIM1              */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i3p0u                          0x00000006UL                                           /**< Mode i3p0u for RAC_IFADCTRIM1               */
#define _RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i3p5u                          0x00000007UL                                           /**< Mode i3p5u for RAC_IFADCTRIM1               */
#define RAC_IFADCTRIM1_IFADCNEGRESCURRENT_DEFAULT                         (_RAC_IFADCTRIM1_IFADCNEGRESCURRENT_DEFAULT << 4)      /**< Shifted mode DEFAULT for RAC_IFADCTRIM1     */
#define RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i1p0u                           (_RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i1p0u << 4)        /**< Shifted mode i1p0u for RAC_IFADCTRIM1       */
#define RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i1p5u                           (_RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i1p5u << 4)        /**< Shifted mode i1p5u for RAC_IFADCTRIM1       */
#define RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p0u                           (_RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p0u << 4)        /**< Shifted mode i2p0u for RAC_IFADCTRIM1       */
#define RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p5u                           (_RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p5u << 4)        /**< Shifted mode i2p5u for RAC_IFADCTRIM1       */
#define RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p0u2                          (_RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p0u2 << 4)       /**< Shifted mode i2p0u2 for RAC_IFADCTRIM1      */
#define RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p5u2                          (_RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i2p5u2 << 4)       /**< Shifted mode i2p5u2 for RAC_IFADCTRIM1      */
#define RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i3p0u                           (_RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i3p0u << 4)        /**< Shifted mode i3p0u for RAC_IFADCTRIM1       */
#define RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i3p5u                           (_RAC_IFADCTRIM1_IFADCNEGRESCURRENT_i3p5u << 4)        /**< Shifted mode i3p5u for RAC_IFADCTRIM1       */
#define _RAC_IFADCTRIM1_IFADCNEGRESVCM_SHIFT                              7                                                      /**< Shift value for RAC_IFADCNEGRESVCM          */
#define _RAC_IFADCTRIM1_IFADCNEGRESVCM_MASK                               0x180UL                                                /**< Bit mask for RAC_IFADCNEGRESVCM             */
#define _RAC_IFADCTRIM1_IFADCNEGRESVCM_DEFAULT                            0x00000002UL                                           /**< Mode DEFAULT for RAC_IFADCTRIM1             */
#define _RAC_IFADCTRIM1_IFADCNEGRESVCM_r210k_x_1uA                        0x00000000UL                                           /**< Mode r210k_x_1uA for RAC_IFADCTRIM1         */
#define _RAC_IFADCTRIM1_IFADCNEGRESVCM_r210k_x_1uA2                       0x00000001UL                                           /**< Mode r210k_x_1uA2 for RAC_IFADCTRIM1        */
#define _RAC_IFADCTRIM1_IFADCNEGRESVCM_r100k_x_2uA                        0x00000002UL                                           /**< Mode r100k_x_2uA for RAC_IFADCTRIM1         */
#define _RAC_IFADCTRIM1_IFADCNEGRESVCM_r50k_x_3uA                         0x00000003UL                                           /**< Mode r50k_x_3uA for RAC_IFADCTRIM1          */
#define RAC_IFADCTRIM1_IFADCNEGRESVCM_DEFAULT                             (_RAC_IFADCTRIM1_IFADCNEGRESVCM_DEFAULT << 7)          /**< Shifted mode DEFAULT for RAC_IFADCTRIM1     */
#define RAC_IFADCTRIM1_IFADCNEGRESVCM_r210k_x_1uA                         (_RAC_IFADCTRIM1_IFADCNEGRESVCM_r210k_x_1uA << 7)      /**< Shifted mode r210k_x_1uA for RAC_IFADCTRIM1 */
#define RAC_IFADCTRIM1_IFADCNEGRESVCM_r210k_x_1uA2                        (_RAC_IFADCTRIM1_IFADCNEGRESVCM_r210k_x_1uA2 << 7)     /**< Shifted mode r210k_x_1uA2 for RAC_IFADCTRIM1*/
#define RAC_IFADCTRIM1_IFADCNEGRESVCM_r100k_x_2uA                         (_RAC_IFADCTRIM1_IFADCNEGRESVCM_r100k_x_2uA << 7)      /**< Shifted mode r100k_x_2uA for RAC_IFADCTRIM1 */
#define RAC_IFADCTRIM1_IFADCNEGRESVCM_r50k_x_3uA                          (_RAC_IFADCTRIM1_IFADCNEGRESVCM_r50k_x_3uA << 7)       /**< Shifted mode r50k_x_3uA for RAC_IFADCTRIM1  */
#define RAC_IFADCTRIM1_IFADCENSUBGMODE                                    (0x1UL << 9)                                           /**< IFADCENSUBGMODELV                           */
#define _RAC_IFADCTRIM1_IFADCENSUBGMODE_SHIFT                             9                                                      /**< Shift value for RAC_IFADCENSUBGMODE         */
#define _RAC_IFADCTRIM1_IFADCENSUBGMODE_MASK                              0x200UL                                                /**< Bit mask for RAC_IFADCENSUBGMODE            */
#define _RAC_IFADCTRIM1_IFADCENSUBGMODE_DEFAULT                           0x00000000UL                                           /**< Mode DEFAULT for RAC_IFADCTRIM1             */
#define _RAC_IFADCTRIM1_IFADCENSUBGMODE_fullspeed_mode                    0x00000000UL                                           /**< Mode fullspeed_mode for RAC_IFADCTRIM1      */
#define _RAC_IFADCTRIM1_IFADCENSUBGMODE_subg_mode                         0x00000001UL                                           /**< Mode subg_mode for RAC_IFADCTRIM1           */
#define RAC_IFADCTRIM1_IFADCENSUBGMODE_DEFAULT                            (_RAC_IFADCTRIM1_IFADCENSUBGMODE_DEFAULT << 9)         /**< Shifted mode DEFAULT for RAC_IFADCTRIM1     */
#define RAC_IFADCTRIM1_IFADCENSUBGMODE_fullspeed_mode                     (_RAC_IFADCTRIM1_IFADCENSUBGMODE_fullspeed_mode << 9)  /**< Shifted mode fullspeed_mode for RAC_IFADCTRIM1*/
#define RAC_IFADCTRIM1_IFADCENSUBGMODE_subg_mode                          (_RAC_IFADCTRIM1_IFADCENSUBGMODE_subg_mode << 9)       /**< Shifted mode subg_mode for RAC_IFADCTRIM1   */
#define _RAC_IFADCTRIM1_IFADCTZ_SHIFT                                     10                                                     /**< Shift value for RAC_IFADCTZ                 */
#define _RAC_IFADCTRIM1_IFADCTZ_MASK                                      0x1C00UL                                               /**< Bit mask for RAC_IFADCTZ                    */
#define _RAC_IFADCTRIM1_IFADCTZ_DEFAULT                                   0x00000000UL                                           /**< Mode DEFAULT for RAC_IFADCTRIM1             */
#define _RAC_IFADCTRIM1_IFADCTZ_default_zero                              0x00000000UL                                           /**< Mode default_zero for RAC_IFADCTRIM1        */
#define _RAC_IFADCTRIM1_IFADCTZ_illegal_mode                              0x00000001UL                                           /**< Mode illegal_mode for RAC_IFADCTRIM1        */
#define _RAC_IFADCTRIM1_IFADCTZ_half_zero                                 0x00000002UL                                           /**< Mode half_zero for RAC_IFADCTRIM1           */
#define _RAC_IFADCTRIM1_IFADCTZ_illegal_mode2                             0x00000003UL                                           /**< Mode illegal_mode2 for RAC_IFADCTRIM1       */
#define _RAC_IFADCTRIM1_IFADCTZ_quarter_zero                              0x00000004UL                                           /**< Mode quarter_zero for RAC_IFADCTRIM1        */
#define _RAC_IFADCTRIM1_IFADCTZ_illegal_mode3                             0x00000005UL                                           /**< Mode illegal_mode3 for RAC_IFADCTRIM1       */
#define _RAC_IFADCTRIM1_IFADCTZ_illegal_mode4                             0x00000006UL                                           /**< Mode illegal_mode4 for RAC_IFADCTRIM1       */
#define _RAC_IFADCTRIM1_IFADCTZ_illegal_mode5                             0x00000007UL                                           /**< Mode illegal_mode5 for RAC_IFADCTRIM1       */
#define RAC_IFADCTRIM1_IFADCTZ_DEFAULT                                    (_RAC_IFADCTRIM1_IFADCTZ_DEFAULT << 10)                /**< Shifted mode DEFAULT for RAC_IFADCTRIM1     */
#define RAC_IFADCTRIM1_IFADCTZ_default_zero                               (_RAC_IFADCTRIM1_IFADCTZ_default_zero << 10)           /**< Shifted mode default_zero for RAC_IFADCTRIM1*/
#define RAC_IFADCTRIM1_IFADCTZ_illegal_mode                               (_RAC_IFADCTRIM1_IFADCTZ_illegal_mode << 10)           /**< Shifted mode illegal_mode for RAC_IFADCTRIM1*/
#define RAC_IFADCTRIM1_IFADCTZ_half_zero                                  (_RAC_IFADCTRIM1_IFADCTZ_half_zero << 10)              /**< Shifted mode half_zero for RAC_IFADCTRIM1   */
#define RAC_IFADCTRIM1_IFADCTZ_illegal_mode2                              (_RAC_IFADCTRIM1_IFADCTZ_illegal_mode2 << 10)          /**< Shifted mode illegal_mode2 for RAC_IFADCTRIM1*/
#define RAC_IFADCTRIM1_IFADCTZ_quarter_zero                               (_RAC_IFADCTRIM1_IFADCTZ_quarter_zero << 10)           /**< Shifted mode quarter_zero for RAC_IFADCTRIM1*/
#define RAC_IFADCTRIM1_IFADCTZ_illegal_mode3                              (_RAC_IFADCTRIM1_IFADCTZ_illegal_mode3 << 10)          /**< Shifted mode illegal_mode3 for RAC_IFADCTRIM1*/
#define RAC_IFADCTRIM1_IFADCTZ_illegal_mode4                              (_RAC_IFADCTRIM1_IFADCTZ_illegal_mode4 << 10)          /**< Shifted mode illegal_mode4 for RAC_IFADCTRIM1*/
#define RAC_IFADCTRIM1_IFADCTZ_illegal_mode5                              (_RAC_IFADCTRIM1_IFADCTZ_illegal_mode5 << 10)          /**< Shifted mode illegal_mode5 for RAC_IFADCTRIM1*/
#define RAC_IFADCTRIM1_IFADCENXOBYPASS                                    (0x1UL << 13)                                          /**< IFADCENXOBYPASS                             */
#define _RAC_IFADCTRIM1_IFADCENXOBYPASS_SHIFT                             13                                                     /**< Shift value for RAC_IFADCENXOBYPASS         */
#define _RAC_IFADCTRIM1_IFADCENXOBYPASS_MASK                              0x2000UL                                               /**< Bit mask for RAC_IFADCENXOBYPASS            */
#define _RAC_IFADCTRIM1_IFADCENXOBYPASS_DEFAULT                           0x00000000UL                                           /**< Mode DEFAULT for RAC_IFADCTRIM1             */
#define _RAC_IFADCTRIM1_IFADCENXOBYPASS_disable_bypass                    0x00000000UL                                           /**< Mode disable_bypass for RAC_IFADCTRIM1      */
#define _RAC_IFADCTRIM1_IFADCENXOBYPASS_enable_bypass                     0x00000001UL                                           /**< Mode enable_bypass for RAC_IFADCTRIM1       */
#define RAC_IFADCTRIM1_IFADCENXOBYPASS_DEFAULT                            (_RAC_IFADCTRIM1_IFADCENXOBYPASS_DEFAULT << 13)        /**< Shifted mode DEFAULT for RAC_IFADCTRIM1     */
#define RAC_IFADCTRIM1_IFADCENXOBYPASS_disable_bypass                     (_RAC_IFADCTRIM1_IFADCENXOBYPASS_disable_bypass << 13) /**< Shifted mode disable_bypass for RAC_IFADCTRIM1*/
#define RAC_IFADCTRIM1_IFADCENXOBYPASS_enable_bypass                      (_RAC_IFADCTRIM1_IFADCENXOBYPASS_enable_bypass << 13)  /**< Shifted mode enable_bypass for RAC_IFADCTRIM1*/

/* Bit fields for RAC IFADCCAL */
#define _RAC_IFADCCAL_RESETVALUE                                          0x00000C00UL                                            /**< Default value for RAC_IFADCCAL              */
#define _RAC_IFADCCAL_MASK                                                0x00FF1F03UL                                            /**< Mask for RAC_IFADCCAL                       */
#define RAC_IFADCCAL_IFADCENRCCAL                                         (0x1UL << 0)                                            /**< IFADCENRCCAL                                */
#define _RAC_IFADCCAL_IFADCENRCCAL_SHIFT                                  0                                                       /**< Shift value for RAC_IFADCENRCCAL            */
#define _RAC_IFADCCAL_IFADCENRCCAL_MASK                                   0x1UL                                                   /**< Bit mask for RAC_IFADCENRCCAL               */
#define _RAC_IFADCCAL_IFADCENRCCAL_DEFAULT                                0x00000000UL                                            /**< Mode DEFAULT for RAC_IFADCCAL               */
#define _RAC_IFADCCAL_IFADCENRCCAL_rccal_disable                          0x00000000UL                                            /**< Mode rccal_disable for RAC_IFADCCAL         */
#define _RAC_IFADCCAL_IFADCENRCCAL_rccal_enable                           0x00000001UL                                            /**< Mode rccal_enable for RAC_IFADCCAL          */
#define RAC_IFADCCAL_IFADCENRCCAL_DEFAULT                                 (_RAC_IFADCCAL_IFADCENRCCAL_DEFAULT << 0)               /**< Shifted mode DEFAULT for RAC_IFADCCAL       */
#define RAC_IFADCCAL_IFADCENRCCAL_rccal_disable                           (_RAC_IFADCCAL_IFADCENRCCAL_rccal_disable << 0)         /**< Shifted mode rccal_disable for RAC_IFADCCAL */
#define RAC_IFADCCAL_IFADCENRCCAL_rccal_enable                            (_RAC_IFADCCAL_IFADCENRCCAL_rccal_enable << 0)          /**< Shifted mode rccal_enable for RAC_IFADCCAL  */
#define RAC_IFADCCAL_IFADCTUNERCCALMODE                                   (0x1UL << 1)                                            /**< IFADCTUNERCCALMODE                          */
#define _RAC_IFADCCAL_IFADCTUNERCCALMODE_SHIFT                            1                                                       /**< Shift value for RAC_IFADCTUNERCCALMODE      */
#define _RAC_IFADCCAL_IFADCTUNERCCALMODE_MASK                             0x2UL                                                   /**< Bit mask for RAC_IFADCTUNERCCALMODE         */
#define _RAC_IFADCCAL_IFADCTUNERCCALMODE_DEFAULT                          0x00000000UL                                            /**< Mode DEFAULT for RAC_IFADCCAL               */
#define _RAC_IFADCCAL_IFADCTUNERCCALMODE_SYmode                           0x00000000UL                                            /**< Mode SYmode for RAC_IFADCCAL                */
#define _RAC_IFADCCAL_IFADCTUNERCCALMODE_ADCmode                          0x00000001UL                                            /**< Mode ADCmode for RAC_IFADCCAL               */
#define RAC_IFADCCAL_IFADCTUNERCCALMODE_DEFAULT                           (_RAC_IFADCCAL_IFADCTUNERCCALMODE_DEFAULT << 1)         /**< Shifted mode DEFAULT for RAC_IFADCCAL       */
#define RAC_IFADCCAL_IFADCTUNERCCALMODE_SYmode                            (_RAC_IFADCCAL_IFADCTUNERCCALMODE_SYmode << 1)          /**< Shifted mode SYmode for RAC_IFADCCAL        */
#define RAC_IFADCCAL_IFADCTUNERCCALMODE_ADCmode                           (_RAC_IFADCCAL_IFADCTUNERCCALMODE_ADCmode << 1)         /**< Shifted mode ADCmode for RAC_IFADCCAL       */
#define _RAC_IFADCCAL_IFADCTUNERC_SHIFT                                   8                                                       /**< Shift value for RAC_IFADCTUNERC             */
#define _RAC_IFADCCAL_IFADCTUNERC_MASK                                    0x1F00UL                                                /**< Bit mask for RAC_IFADCTUNERC                */
#define _RAC_IFADCCAL_IFADCTUNERC_DEFAULT                                 0x0000000CUL                                            /**< Mode DEFAULT for RAC_IFADCCAL               */
#define RAC_IFADCCAL_IFADCTUNERC_DEFAULT                                  (_RAC_IFADCCAL_IFADCTUNERC_DEFAULT << 8)                /**< Shifted mode DEFAULT for RAC_IFADCCAL       */
#define _RAC_IFADCCAL_IFADCRCCALCOUNTERSTARTVAL_SHIFT                     16                                                      /**< Shift value for RAC_IFADCRCCALCOUNTERSTARTVAL*/
#define _RAC_IFADCCAL_IFADCRCCALCOUNTERSTARTVAL_MASK                      0xFF0000UL                                              /**< Bit mask for RAC_IFADCRCCALCOUNTERSTARTVAL  */
#define _RAC_IFADCCAL_IFADCRCCALCOUNTERSTARTVAL_DEFAULT                   0x00000000UL                                            /**< Mode DEFAULT for RAC_IFADCCAL               */
#define RAC_IFADCCAL_IFADCRCCALCOUNTERSTARTVAL_DEFAULT                    (_RAC_IFADCCAL_IFADCRCCALCOUNTERSTARTVAL_DEFAULT << 16) /**< Shifted mode DEFAULT for RAC_IFADCCAL       */

/* Bit fields for RAC IFADCSTATUS */
#define _RAC_IFADCSTATUS_RESETVALUE                                       0x00000000UL                                  /**< Default value for RAC_IFADCSTATUS           */
#define _RAC_IFADCSTATUS_MASK                                             0x00000001UL                                  /**< Mask for RAC_IFADCSTATUS                    */
#define RAC_IFADCSTATUS_IFADCRCCALOUT                                     (0x1UL << 0)                                  /**< IFADCRCCALOUT                               */
#define _RAC_IFADCSTATUS_IFADCRCCALOUT_SHIFT                              0                                             /**< Shift value for RAC_IFADCRCCALOUT           */
#define _RAC_IFADCSTATUS_IFADCRCCALOUT_MASK                               0x1UL                                         /**< Bit mask for RAC_IFADCRCCALOUT              */
#define _RAC_IFADCSTATUS_IFADCRCCALOUT_DEFAULT                            0x00000000UL                                  /**< Mode DEFAULT for RAC_IFADCSTATUS            */
#define _RAC_IFADCSTATUS_IFADCRCCALOUT_lo                                 0x00000000UL                                  /**< Mode lo for RAC_IFADCSTATUS                 */
#define _RAC_IFADCSTATUS_IFADCRCCALOUT_hi                                 0x00000001UL                                  /**< Mode hi for RAC_IFADCSTATUS                 */
#define RAC_IFADCSTATUS_IFADCRCCALOUT_DEFAULT                             (_RAC_IFADCSTATUS_IFADCRCCALOUT_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_IFADCSTATUS    */
#define RAC_IFADCSTATUS_IFADCRCCALOUT_lo                                  (_RAC_IFADCSTATUS_IFADCRCCALOUT_lo << 0)      /**< Shifted mode lo for RAC_IFADCSTATUS         */
#define RAC_IFADCSTATUS_IFADCRCCALOUT_hi                                  (_RAC_IFADCSTATUS_IFADCRCCALOUT_hi << 0)      /**< Shifted mode hi for RAC_IFADCSTATUS         */

/* Bit fields for RAC LNAMIXTRIM0 */
#define _RAC_LNAMIXTRIM0_RESETVALUE                                       0x00000110UL                                     /**< Default value for RAC_LNAMIXTRIM0           */
#define _RAC_LNAMIXTRIM0_MASK                                             0x000001FFUL                                     /**< Mask for RAC_LNAMIXTRIM0                    */
#define _RAC_LNAMIXTRIM0_LNAMIXLNA0CAPSEL_SHIFT                           0                                                /**< Shift value for RAC_LNAMIXLNA0CAPSEL        */
#define _RAC_LNAMIXTRIM0_LNAMIXLNA0CAPSEL_MASK                            0x7UL                                            /**< Bit mask for RAC_LNAMIXLNA0CAPSEL           */
#define _RAC_LNAMIXTRIM0_LNAMIXLNA0CAPSEL_DEFAULT                         0x00000000UL                                     /**< Mode DEFAULT for RAC_LNAMIXTRIM0            */
#define RAC_LNAMIXTRIM0_LNAMIXLNA0CAPSEL_DEFAULT                          (_RAC_LNAMIXTRIM0_LNAMIXLNA0CAPSEL_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM0    */
#define _RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_SHIFT                             3                                                /**< Shift value for RAC_LNAMIXMXRBIAS0          */
#define _RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_MASK                              0x18UL                                           /**< Bit mask for RAC_LNAMIXMXRBIAS0             */
#define _RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_DEFAULT                           0x00000002UL                                     /**< Mode DEFAULT for RAC_LNAMIXTRIM0            */
#define _RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_bias_1V                           0x00000000UL                                     /**< Mode bias_1V for RAC_LNAMIXTRIM0            */
#define _RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_unused                            0x00000001UL                                     /**< Mode unused for RAC_LNAMIXTRIM0             */
#define _RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_bias_900m                         0x00000002UL                                     /**< Mode bias_900m for RAC_LNAMIXTRIM0          */
#define _RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_bias_800m                         0x00000003UL                                     /**< Mode bias_800m for RAC_LNAMIXTRIM0          */
#define RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_DEFAULT                            (_RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_DEFAULT << 3)   /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM0    */
#define RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_bias_1V                            (_RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_bias_1V << 3)   /**< Shifted mode bias_1V for RAC_LNAMIXTRIM0    */
#define RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_unused                             (_RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_unused << 3)    /**< Shifted mode unused for RAC_LNAMIXTRIM0     */
#define RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_bias_900m                          (_RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_bias_900m << 3) /**< Shifted mode bias_900m for RAC_LNAMIXTRIM0  */
#define RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_bias_800m                          (_RAC_LNAMIXTRIM0_LNAMIXMXRBIAS0_bias_800m << 3) /**< Shifted mode bias_800m for RAC_LNAMIXTRIM0  */
#define _RAC_LNAMIXTRIM0_LNAMIXVOUT0ADJ_SHIFT                             5                                                /**< Shift value for RAC_LNAMIXVOUT0ADJ          */
#define _RAC_LNAMIXTRIM0_LNAMIXVOUT0ADJ_MASK                              0x1E0UL                                          /**< Bit mask for RAC_LNAMIXVOUT0ADJ             */
#define _RAC_LNAMIXTRIM0_LNAMIXVOUT0ADJ_DEFAULT                           0x00000008UL                                     /**< Mode DEFAULT for RAC_LNAMIXTRIM0            */
#define RAC_LNAMIXTRIM0_LNAMIXVOUT0ADJ_DEFAULT                            (_RAC_LNAMIXTRIM0_LNAMIXVOUT0ADJ_DEFAULT << 5)   /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM0    */

/* Bit fields for RAC LNAMIXTRIM1 */
#define _RAC_LNAMIXTRIM1_RESETVALUE                                       0x00000110UL                                     /**< Default value for RAC_LNAMIXTRIM1           */
#define _RAC_LNAMIXTRIM1_MASK                                             0x000001FFUL                                     /**< Mask for RAC_LNAMIXTRIM1                    */
#define _RAC_LNAMIXTRIM1_LNAMIXLNA1CAPSEL_SHIFT                           0                                                /**< Shift value for RAC_LNAMIXLNA1CAPSEL        */
#define _RAC_LNAMIXTRIM1_LNAMIXLNA1CAPSEL_MASK                            0x7UL                                            /**< Bit mask for RAC_LNAMIXLNA1CAPSEL           */
#define _RAC_LNAMIXTRIM1_LNAMIXLNA1CAPSEL_DEFAULT                         0x00000000UL                                     /**< Mode DEFAULT for RAC_LNAMIXTRIM1            */
#define RAC_LNAMIXTRIM1_LNAMIXLNA1CAPSEL_DEFAULT                          (_RAC_LNAMIXTRIM1_LNAMIXLNA1CAPSEL_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM1    */
#define _RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_SHIFT                             3                                                /**< Shift value for RAC_LNAMIXMXRBIAS1          */
#define _RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_MASK                              0x18UL                                           /**< Bit mask for RAC_LNAMIXMXRBIAS1             */
#define _RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_DEFAULT                           0x00000002UL                                     /**< Mode DEFAULT for RAC_LNAMIXTRIM1            */
#define _RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_bias_1V                           0x00000000UL                                     /**< Mode bias_1V for RAC_LNAMIXTRIM1            */
#define _RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_unused                            0x00000001UL                                     /**< Mode unused for RAC_LNAMIXTRIM1             */
#define _RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_bias_900m                         0x00000002UL                                     /**< Mode bias_900m for RAC_LNAMIXTRIM1          */
#define _RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_bias_800m                         0x00000003UL                                     /**< Mode bias_800m for RAC_LNAMIXTRIM1          */
#define RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_DEFAULT                            (_RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_DEFAULT << 3)   /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM1    */
#define RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_bias_1V                            (_RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_bias_1V << 3)   /**< Shifted mode bias_1V for RAC_LNAMIXTRIM1    */
#define RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_unused                             (_RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_unused << 3)    /**< Shifted mode unused for RAC_LNAMIXTRIM1     */
#define RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_bias_900m                          (_RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_bias_900m << 3) /**< Shifted mode bias_900m for RAC_LNAMIXTRIM1  */
#define RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_bias_800m                          (_RAC_LNAMIXTRIM1_LNAMIXMXRBIAS1_bias_800m << 3) /**< Shifted mode bias_800m for RAC_LNAMIXTRIM1  */
#define _RAC_LNAMIXTRIM1_LNAMIXVOUT1ADJ_SHIFT                             5                                                /**< Shift value for RAC_LNAMIXVOUT1ADJ          */
#define _RAC_LNAMIXTRIM1_LNAMIXVOUT1ADJ_MASK                              0x1E0UL                                          /**< Bit mask for RAC_LNAMIXVOUT1ADJ             */
#define _RAC_LNAMIXTRIM1_LNAMIXVOUT1ADJ_DEFAULT                           0x00000008UL                                     /**< Mode DEFAULT for RAC_LNAMIXTRIM1            */
#define RAC_LNAMIXTRIM1_LNAMIXVOUT1ADJ_DEFAULT                            (_RAC_LNAMIXTRIM1_LNAMIXVOUT1ADJ_DEFAULT << 5)   /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM1    */

/* Bit fields for RAC LNAMIXTRIM2 */
#define _RAC_LNAMIXTRIM2_RESETVALUE                                       0x0115E3D0UL                                         /**< Default value for RAC_LNAMIXTRIM2           */
#define _RAC_LNAMIXTRIM2_MASK                                             0x01FFFFF0UL                                         /**< Mask for RAC_LNAMIXTRIM2                    */
#define _RAC_LNAMIXTRIM2_LNAMIXCURCTRL_SHIFT                              4                                                    /**< Shift value for RAC_LNAMIXCURCTRL           */
#define _RAC_LNAMIXTRIM2_LNAMIXCURCTRL_MASK                               0x3F0UL                                              /**< Bit mask for RAC_LNAMIXCURCTRL              */
#define _RAC_LNAMIXTRIM2_LNAMIXCURCTRL_DEFAULT                            0x0000003DUL                                         /**< Mode DEFAULT for RAC_LNAMIXTRIM2            */
#define RAC_LNAMIXTRIM2_LNAMIXCURCTRL_DEFAULT                             (_RAC_LNAMIXTRIM2_LNAMIXCURCTRL_DEFAULT << 4)        /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM2    */
#define _RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_SHIFT                              10                                                   /**< Shift value for RAC_LNAMIXHIGHCUR           */
#define _RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_MASK                               0xC00UL                                              /**< Bit mask for RAC_LNAMIXHIGHCUR              */
#define _RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_DEFAULT                            0x00000000UL                                         /**< Mode DEFAULT for RAC_LNAMIXTRIM2            */
#define _RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_current_470uA                      0x00000000UL                                         /**< Mode current_470uA for RAC_LNAMIXTRIM2      */
#define _RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_current_530uA                      0x00000001UL                                         /**< Mode current_530uA for RAC_LNAMIXTRIM2      */
#define _RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_unused                             0x00000002UL                                         /**< Mode unused for RAC_LNAMIXTRIM2             */
#define _RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_current_590uA                      0x00000003UL                                         /**< Mode current_590uA for RAC_LNAMIXTRIM2      */
#define RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_DEFAULT                             (_RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_DEFAULT << 10)       /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM2    */
#define RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_current_470uA                       (_RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_current_470uA << 10) /**< Shifted mode current_470uA for RAC_LNAMIXTRIM2*/
#define RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_current_530uA                       (_RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_current_530uA << 10) /**< Shifted mode current_530uA for RAC_LNAMIXTRIM2*/
#define RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_unused                              (_RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_unused << 10)        /**< Shifted mode unused for RAC_LNAMIXTRIM2     */
#define RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_current_590uA                       (_RAC_LNAMIXTRIM2_LNAMIXHIGHCUR_current_590uA << 10) /**< Shifted mode current_590uA for RAC_LNAMIXTRIM2*/
#define _RAC_LNAMIXTRIM2_LNAMIXLOWCUR_SHIFT                               12                                                   /**< Shift value for RAC_LNAMIXLOWCUR            */
#define _RAC_LNAMIXTRIM2_LNAMIXLOWCUR_MASK                                0x3000UL                                             /**< Bit mask for RAC_LNAMIXLOWCUR               */
#define _RAC_LNAMIXTRIM2_LNAMIXLOWCUR_DEFAULT                             0x00000002UL                                         /**< Mode DEFAULT for RAC_LNAMIXTRIM2            */
#define _RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_60per                       0x00000000UL                                         /**< Mode current_60per for RAC_LNAMIXTRIM2      */
#define _RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_80per                       0x00000001UL                                         /**< Mode current_80per for RAC_LNAMIXTRIM2      */
#define _RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_100per                      0x00000002UL                                         /**< Mode current_100per for RAC_LNAMIXTRIM2     */
#define _RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_150per                      0x00000003UL                                         /**< Mode current_150per for RAC_LNAMIXTRIM2     */
#define RAC_LNAMIXTRIM2_LNAMIXLOWCUR_DEFAULT                              (_RAC_LNAMIXTRIM2_LNAMIXLOWCUR_DEFAULT << 12)        /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM2    */
#define RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_60per                        (_RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_60per << 12)  /**< Shifted mode current_60per for RAC_LNAMIXTRIM2*/
#define RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_80per                        (_RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_80per << 12)  /**< Shifted mode current_80per for RAC_LNAMIXTRIM2*/
#define RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_100per                       (_RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_100per << 12) /**< Shifted mode current_100per for RAC_LNAMIXTRIM2*/
#define RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_150per                       (_RAC_LNAMIXTRIM2_LNAMIXLOWCUR_current_150per << 12) /**< Shifted mode current_150per for RAC_LNAMIXTRIM2*/
#define _RAC_LNAMIXTRIM2_LNAMIXLNARESADJ_SHIFT                            14                                                   /**< Shift value for RAC_LNAMIXLNARESADJ         */
#define _RAC_LNAMIXTRIM2_LNAMIXLNARESADJ_MASK                             0x1C000UL                                            /**< Bit mask for RAC_LNAMIXLNARESADJ            */
#define _RAC_LNAMIXTRIM2_LNAMIXLNARESADJ_DEFAULT                          0x00000007UL                                         /**< Mode DEFAULT for RAC_LNAMIXTRIM2            */
#define RAC_LNAMIXTRIM2_LNAMIXLNARESADJ_DEFAULT                           (_RAC_LNAMIXTRIM2_LNAMIXLNARESADJ_DEFAULT << 14)     /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM2    */
#define _RAC_LNAMIXTRIM2_LNAMIXNCASADJ_SHIFT                              17                                                   /**< Shift value for RAC_LNAMIXNCASADJ           */
#define _RAC_LNAMIXTRIM2_LNAMIXNCASADJ_MASK                               0x60000UL                                            /**< Bit mask for RAC_LNAMIXNCASADJ              */
#define _RAC_LNAMIXTRIM2_LNAMIXNCASADJ_DEFAULT                            0x00000002UL                                         /**< Mode DEFAULT for RAC_LNAMIXTRIM2            */
#define RAC_LNAMIXTRIM2_LNAMIXNCASADJ_DEFAULT                             (_RAC_LNAMIXTRIM2_LNAMIXNCASADJ_DEFAULT << 17)       /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM2    */
#define _RAC_LNAMIXTRIM2_LNAMIXPCASADJ_SHIFT                              19                                                   /**< Shift value for RAC_LNAMIXPCASADJ           */
#define _RAC_LNAMIXTRIM2_LNAMIXPCASADJ_MASK                               0x180000UL                                           /**< Bit mask for RAC_LNAMIXPCASADJ              */
#define _RAC_LNAMIXTRIM2_LNAMIXPCASADJ_DEFAULT                            0x00000002UL                                         /**< Mode DEFAULT for RAC_LNAMIXTRIM2            */
#define RAC_LNAMIXTRIM2_LNAMIXPCASADJ_DEFAULT                             (_RAC_LNAMIXTRIM2_LNAMIXPCASADJ_DEFAULT << 19)       /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM2    */
#define _RAC_LNAMIXTRIM2_LNAMIXTRIMVREG_SHIFT                             21                                                   /**< Shift value for RAC_LNAMIXTRIMVREG          */
#define _RAC_LNAMIXTRIM2_LNAMIXTRIMVREG_MASK                              0x1E00000UL                                          /**< Bit mask for RAC_LNAMIXTRIMVREG             */
#define _RAC_LNAMIXTRIM2_LNAMIXTRIMVREG_DEFAULT                           0x00000008UL                                         /**< Mode DEFAULT for RAC_LNAMIXTRIM2            */
#define RAC_LNAMIXTRIM2_LNAMIXTRIMVREG_DEFAULT                            (_RAC_LNAMIXTRIM2_LNAMIXTRIMVREG_DEFAULT << 21)      /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM2    */

/* Bit fields for RAC LNAMIXTRIM3 */
#define _RAC_LNAMIXTRIM3_RESETVALUE                                       0x00002A10UL                                                   /**< Default value for RAC_LNAMIXTRIM3           */
#define _RAC_LNAMIXTRIM3_MASK                                             0x00003FFFUL                                                   /**< Mask for RAC_LNAMIXTRIM3                    */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASADJN_SHIFT                            0                                                              /**< Shift value for RAC_LNAMIXIBIASADJN         */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASADJN_MASK                             0x1FUL                                                         /**< Bit mask for RAC_LNAMIXIBIASADJN            */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASADJN_DEFAULT                          0x00000010UL                                                   /**< Mode DEFAULT for RAC_LNAMIXTRIM3            */
#define RAC_LNAMIXTRIM3_LNAMIXIBIASADJN_DEFAULT                           (_RAC_LNAMIXTRIM3_LNAMIXIBIASADJN_DEFAULT << 0)                /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM3    */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASADJP_SHIFT                            5                                                              /**< Shift value for RAC_LNAMIXIBIASADJP         */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASADJP_MASK                             0x3E0UL                                                        /**< Bit mask for RAC_LNAMIXIBIASADJP            */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASADJP_DEFAULT                          0x00000010UL                                                   /**< Mode DEFAULT for RAC_LNAMIXTRIM3            */
#define RAC_LNAMIXTRIM3_LNAMIXIBIASADJP_DEFAULT                           (_RAC_LNAMIXTRIM3_LNAMIXIBIASADJP_DEFAULT << 5)                /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM3    */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_SHIFT                       10                                                             /**< Shift value for RAC_LNAMIXIBIASRANGEADJN    */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_MASK                        0xC00UL                                                        /**< Bit mask for RAC_LNAMIXIBIASRANGEADJN       */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_DEFAULT                     0x00000002UL                                                   /**< Mode DEFAULT for RAC_LNAMIXTRIM3            */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_Shift_range_low             0x00000000UL                                                   /**< Mode Shift_range_low for RAC_LNAMIXTRIM3    */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_default                     0x00000002UL                                                   /**< Mode default for RAC_LNAMIXTRIM3            */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_Shift_range_high            0x00000003UL                                                   /**< Mode Shift_range_high for RAC_LNAMIXTRIM3   */
#define RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_DEFAULT                      (_RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_DEFAULT << 10)          /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM3    */
#define RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_Shift_range_low              (_RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_Shift_range_low << 10)  /**< Shifted mode Shift_range_low for RAC_LNAMIXTRIM3*/
#define RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_default                      (_RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_default << 10)          /**< Shifted mode default for RAC_LNAMIXTRIM3    */
#define RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_Shift_range_high             (_RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJN_Shift_range_high << 10) /**< Shifted mode Shift_range_high for RAC_LNAMIXTRIM3*/
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_SHIFT                       12                                                             /**< Shift value for RAC_LNAMIXIBIASRANGEADJP    */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_MASK                        0x3000UL                                                       /**< Bit mask for RAC_LNAMIXIBIASRANGEADJP       */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_DEFAULT                     0x00000002UL                                                   /**< Mode DEFAULT for RAC_LNAMIXTRIM3            */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_Shift_range_low             0x00000000UL                                                   /**< Mode Shift_range_low for RAC_LNAMIXTRIM3    */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_default                     0x00000002UL                                                   /**< Mode default for RAC_LNAMIXTRIM3            */
#define _RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_Shift_range_high            0x00000003UL                                                   /**< Mode Shift_range_high for RAC_LNAMIXTRIM3   */
#define RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_DEFAULT                      (_RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_DEFAULT << 12)          /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM3    */
#define RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_Shift_range_low              (_RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_Shift_range_low << 12)  /**< Shifted mode Shift_range_low for RAC_LNAMIXTRIM3*/
#define RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_default                      (_RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_default << 12)          /**< Shifted mode default for RAC_LNAMIXTRIM3    */
#define RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_Shift_range_high             (_RAC_LNAMIXTRIM3_LNAMIXIBIASRANGEADJP_Shift_range_high << 12) /**< Shifted mode Shift_range_high for RAC_LNAMIXTRIM3*/

/* Bit fields for RAC LNAMIXTRIM4 */
#define _RAC_LNAMIXTRIM4_RESETVALUE                                       0x52082002UL                                                /**< Default value for RAC_LNAMIXTRIM4           */
#define _RAC_LNAMIXTRIM4_MASK                                             0xFF0FFF03UL                                                /**< Mask for RAC_LNAMIXTRIM4                    */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDBWSEL_SHIFT                           0                                                           /**< Shift value for RAC_LNAMIXRFPKDBWSEL        */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDBWSEL_MASK                            0x3UL                                                       /**< Bit mask for RAC_LNAMIXRFPKDBWSEL           */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDBWSEL_DEFAULT                         0x00000002UL                                                /**< Mode DEFAULT for RAC_LNAMIXTRIM4            */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDBWSEL_DEFAULT                          (_RAC_LNAMIXTRIM4_LNAMIXRFPKDBWSEL_DEFAULT << 0)            /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM4    */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDCALCMLO_SHIFT                         8                                                           /**< Shift value for RAC_LNAMIXRFPKDCALCMLO      */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDCALCMLO_MASK                          0x3F00UL                                                    /**< Bit mask for RAC_LNAMIXRFPKDCALCMLO         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDCALCMLO_DEFAULT                       0x00000020UL                                                /**< Mode DEFAULT for RAC_LNAMIXTRIM4            */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDCALCMLO_DEFAULT                        (_RAC_LNAMIXTRIM4_LNAMIXRFPKDCALCMLO_DEFAULT << 8)          /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM4    */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDCALCMHI_SHIFT                         14                                                          /**< Shift value for RAC_LNAMIXRFPKDCALCMHI      */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDCALCMHI_MASK                          0xFC000UL                                                   /**< Bit mask for RAC_LNAMIXRFPKDCALCMHI         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDCALCMHI_DEFAULT                       0x00000020UL                                                /**< Mode DEFAULT for RAC_LNAMIXTRIM4            */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDCALCMHI_DEFAULT                        (_RAC_LNAMIXTRIM4_LNAMIXRFPKDCALCMHI_DEFAULT << 14)         /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM4    */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_SHIFT                     24                                                          /**< Shift value for RAC_LNAMIXRFPKDTHRESHSELLO  */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_MASK                      0xF000000UL                                                 /**< Bit mask for RAC_LNAMIXRFPKDTHRESHSELLO     */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_DEFAULT                   0x00000002UL                                                /**< Mode DEFAULT for RAC_LNAMIXTRIM4            */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_0                  0x00000000UL                                                /**< Mode thresh_0 for RAC_LNAMIXTRIM4           */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_20m                0x00000001UL                                                /**< Mode thresh_20m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_30m                0x00000002UL                                                /**< Mode thresh_30m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_40m                0x00000003UL                                                /**< Mode thresh_40m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_50m                0x00000004UL                                                /**< Mode thresh_50m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_60m                0x00000005UL                                                /**< Mode thresh_60m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_70m                0x00000006UL                                                /**< Mode thresh_70m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_80m                0x00000007UL                                                /**< Mode thresh_80m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_90m                0x00000008UL                                                /**< Mode thresh_90m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_100m               0x00000009UL                                                /**< Mode thresh_100m for RAC_LNAMIXTRIM4        */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_DEFAULT                    (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_DEFAULT << 24)     /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM4    */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_0                   (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_0 << 24)    /**< Shifted mode thresh_0 for RAC_LNAMIXTRIM4   */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_20m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_20m << 24)  /**< Shifted mode thresh_20m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_30m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_30m << 24)  /**< Shifted mode thresh_30m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_40m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_40m << 24)  /**< Shifted mode thresh_40m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_50m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_50m << 24)  /**< Shifted mode thresh_50m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_60m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_60m << 24)  /**< Shifted mode thresh_60m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_70m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_70m << 24)  /**< Shifted mode thresh_70m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_80m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_80m << 24)  /**< Shifted mode thresh_80m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_90m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_90m << 24)  /**< Shifted mode thresh_90m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_100m                (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELLO_thresh_100m << 24) /**< Shifted mode thresh_100m for RAC_LNAMIXTRIM4*/
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_SHIFT                     28                                                          /**< Shift value for RAC_LNAMIXRFPKDTHRESHSELHI  */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_MASK                      0xF0000000UL                                                /**< Bit mask for RAC_LNAMIXRFPKDTHRESHSELHI     */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_DEFAULT                   0x00000005UL                                                /**< Mode DEFAULT for RAC_LNAMIXTRIM4            */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_0                  0x00000000UL                                                /**< Mode thresh_0 for RAC_LNAMIXTRIM4           */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_20m                0x00000001UL                                                /**< Mode thresh_20m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_30m                0x00000002UL                                                /**< Mode thresh_30m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_40m                0x00000003UL                                                /**< Mode thresh_40m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_50m                0x00000004UL                                                /**< Mode thresh_50m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_60m                0x00000005UL                                                /**< Mode thresh_60m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_70m                0x00000006UL                                                /**< Mode thresh_70m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_80m                0x00000007UL                                                /**< Mode thresh_80m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_90m                0x00000008UL                                                /**< Mode thresh_90m for RAC_LNAMIXTRIM4         */
#define _RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_100m               0x00000009UL                                                /**< Mode thresh_100m for RAC_LNAMIXTRIM4        */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_DEFAULT                    (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_DEFAULT << 28)     /**< Shifted mode DEFAULT for RAC_LNAMIXTRIM4    */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_0                   (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_0 << 28)    /**< Shifted mode thresh_0 for RAC_LNAMIXTRIM4   */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_20m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_20m << 28)  /**< Shifted mode thresh_20m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_30m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_30m << 28)  /**< Shifted mode thresh_30m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_40m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_40m << 28)  /**< Shifted mode thresh_40m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_50m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_50m << 28)  /**< Shifted mode thresh_50m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_60m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_60m << 28)  /**< Shifted mode thresh_60m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_70m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_70m << 28)  /**< Shifted mode thresh_70m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_80m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_80m << 28)  /**< Shifted mode thresh_80m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_90m                 (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_90m << 28)  /**< Shifted mode thresh_90m for RAC_LNAMIXTRIM4 */
#define RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_100m                (_RAC_LNAMIXTRIM4_LNAMIXRFPKDTHRESHSELHI_thresh_100m << 28) /**< Shifted mode thresh_100m for RAC_LNAMIXTRIM4*/

/* Bit fields for RAC LNAMIXCAL */
#define _RAC_LNAMIXCAL_RESETVALUE                                         0x000007E0UL                                      /**< Default value for RAC_LNAMIXCAL             */
#define _RAC_LNAMIXCAL_MASK                                               0x000007FFUL                                      /**< Mask for RAC_LNAMIXCAL                      */
#define RAC_LNAMIXCAL_LNAMIXCALPMOSEN                                     (0x1UL << 0)                                      /**< LNAMIXCALPMOSEN                             */
#define _RAC_LNAMIXCAL_LNAMIXCALPMOSEN_SHIFT                              0                                                 /**< Shift value for RAC_LNAMIXCALPMOSEN         */
#define _RAC_LNAMIXCAL_LNAMIXCALPMOSEN_MASK                               0x1UL                                             /**< Bit mask for RAC_LNAMIXCALPMOSEN            */
#define _RAC_LNAMIXCAL_LNAMIXCALPMOSEN_DEFAULT                            0x00000000UL                                      /**< Mode DEFAULT for RAC_LNAMIXCAL              */
#define _RAC_LNAMIXCAL_LNAMIXCALPMOSEN_cal_disable                        0x00000000UL                                      /**< Mode cal_disable for RAC_LNAMIXCAL          */
#define _RAC_LNAMIXCAL_LNAMIXCALPMOSEN_cal_enable                         0x00000001UL                                      /**< Mode cal_enable for RAC_LNAMIXCAL           */
#define RAC_LNAMIXCAL_LNAMIXCALPMOSEN_DEFAULT                             (_RAC_LNAMIXCAL_LNAMIXCALPMOSEN_DEFAULT << 0)     /**< Shifted mode DEFAULT for RAC_LNAMIXCAL      */
#define RAC_LNAMIXCAL_LNAMIXCALPMOSEN_cal_disable                         (_RAC_LNAMIXCAL_LNAMIXCALPMOSEN_cal_disable << 0) /**< Shifted mode cal_disable for RAC_LNAMIXCAL  */
#define RAC_LNAMIXCAL_LNAMIXCALPMOSEN_cal_enable                          (_RAC_LNAMIXCAL_LNAMIXCALPMOSEN_cal_enable << 0)  /**< Shifted mode cal_enable for RAC_LNAMIXCAL   */
#define RAC_LNAMIXCAL_LNAMIXCALNMOSEN                                     (0x1UL << 1)                                      /**< LNAMIXCALNMOSEN                             */
#define _RAC_LNAMIXCAL_LNAMIXCALNMOSEN_SHIFT                              1                                                 /**< Shift value for RAC_LNAMIXCALNMOSEN         */
#define _RAC_LNAMIXCAL_LNAMIXCALNMOSEN_MASK                               0x2UL                                             /**< Bit mask for RAC_LNAMIXCALNMOSEN            */
#define _RAC_LNAMIXCAL_LNAMIXCALNMOSEN_DEFAULT                            0x00000000UL                                      /**< Mode DEFAULT for RAC_LNAMIXCAL              */
#define _RAC_LNAMIXCAL_LNAMIXCALNMOSEN_cal_disable                        0x00000000UL                                      /**< Mode cal_disable for RAC_LNAMIXCAL          */
#define _RAC_LNAMIXCAL_LNAMIXCALNMOSEN_cal_enable                         0x00000001UL                                      /**< Mode cal_enable for RAC_LNAMIXCAL           */
#define RAC_LNAMIXCAL_LNAMIXCALNMOSEN_DEFAULT                             (_RAC_LNAMIXCAL_LNAMIXCALNMOSEN_DEFAULT << 1)     /**< Shifted mode DEFAULT for RAC_LNAMIXCAL      */
#define RAC_LNAMIXCAL_LNAMIXCALNMOSEN_cal_disable                         (_RAC_LNAMIXCAL_LNAMIXCALNMOSEN_cal_disable << 1) /**< Shifted mode cal_disable for RAC_LNAMIXCAL  */
#define RAC_LNAMIXCAL_LNAMIXCALNMOSEN_cal_enable                          (_RAC_LNAMIXCAL_LNAMIXCALNMOSEN_cal_enable << 1)  /**< Shifted mode cal_enable for RAC_LNAMIXCAL   */
#define RAC_LNAMIXCAL_LNAMIXCALVMODE                                      (0x1UL << 2)                                      /**< LNAMIXCALVMODE                              */
#define _RAC_LNAMIXCAL_LNAMIXCALVMODE_SHIFT                               2                                                 /**< Shift value for RAC_LNAMIXCALVMODE          */
#define _RAC_LNAMIXCAL_LNAMIXCALVMODE_MASK                                0x4UL                                             /**< Bit mask for RAC_LNAMIXCALVMODE             */
#define _RAC_LNAMIXCAL_LNAMIXCALVMODE_DEFAULT                             0x00000000UL                                      /**< Mode DEFAULT for RAC_LNAMIXCAL              */
#define _RAC_LNAMIXCAL_LNAMIXCALVMODE_current_mode                        0x00000000UL                                      /**< Mode current_mode for RAC_LNAMIXCAL         */
#define _RAC_LNAMIXCAL_LNAMIXCALVMODE_voltage_mode                        0x00000001UL                                      /**< Mode voltage_mode for RAC_LNAMIXCAL         */
#define RAC_LNAMIXCAL_LNAMIXCALVMODE_DEFAULT                              (_RAC_LNAMIXCAL_LNAMIXCALVMODE_DEFAULT << 2)      /**< Shifted mode DEFAULT for RAC_LNAMIXCAL      */
#define RAC_LNAMIXCAL_LNAMIXCALVMODE_current_mode                         (_RAC_LNAMIXCAL_LNAMIXCALVMODE_current_mode << 2) /**< Shifted mode current_mode for RAC_LNAMIXCAL */
#define RAC_LNAMIXCAL_LNAMIXCALVMODE_voltage_mode                         (_RAC_LNAMIXCAL_LNAMIXCALVMODE_voltage_mode << 2) /**< Shifted mode voltage_mode for RAC_LNAMIXCAL */
#define RAC_LNAMIXCAL_LNAMIXENIRCAL0                                      (0x1UL << 3)                                      /**< LNAMIXENIRCAL0                              */
#define _RAC_LNAMIXCAL_LNAMIXENIRCAL0_SHIFT                               3                                                 /**< Shift value for RAC_LNAMIXENIRCAL0          */
#define _RAC_LNAMIXCAL_LNAMIXENIRCAL0_MASK                                0x8UL                                             /**< Bit mask for RAC_LNAMIXENIRCAL0             */
#define _RAC_LNAMIXCAL_LNAMIXENIRCAL0_DEFAULT                             0x00000000UL                                      /**< Mode DEFAULT for RAC_LNAMIXCAL              */
#define _RAC_LNAMIXCAL_LNAMIXENIRCAL0_disable                             0x00000000UL                                      /**< Mode disable for RAC_LNAMIXCAL              */
#define _RAC_LNAMIXCAL_LNAMIXENIRCAL0_enable                              0x00000001UL                                      /**< Mode enable for RAC_LNAMIXCAL               */
#define RAC_LNAMIXCAL_LNAMIXENIRCAL0_DEFAULT                              (_RAC_LNAMIXCAL_LNAMIXENIRCAL0_DEFAULT << 3)      /**< Shifted mode DEFAULT for RAC_LNAMIXCAL      */
#define RAC_LNAMIXCAL_LNAMIXENIRCAL0_disable                              (_RAC_LNAMIXCAL_LNAMIXENIRCAL0_disable << 3)      /**< Shifted mode disable for RAC_LNAMIXCAL      */
#define RAC_LNAMIXCAL_LNAMIXENIRCAL0_enable                               (_RAC_LNAMIXCAL_LNAMIXENIRCAL0_enable << 3)       /**< Shifted mode enable for RAC_LNAMIXCAL       */
#define RAC_LNAMIXCAL_LNAMIXENIRCAL1                                      (0x1UL << 4)                                      /**< LNAMIXENIRCAL1                              */
#define _RAC_LNAMIXCAL_LNAMIXENIRCAL1_SHIFT                               4                                                 /**< Shift value for RAC_LNAMIXENIRCAL1          */
#define _RAC_LNAMIXCAL_LNAMIXENIRCAL1_MASK                                0x10UL                                            /**< Bit mask for RAC_LNAMIXENIRCAL1             */
#define _RAC_LNAMIXCAL_LNAMIXENIRCAL1_DEFAULT                             0x00000000UL                                      /**< Mode DEFAULT for RAC_LNAMIXCAL              */
#define _RAC_LNAMIXCAL_LNAMIXENIRCAL1_disable                             0x00000000UL                                      /**< Mode disable for RAC_LNAMIXCAL              */
#define _RAC_LNAMIXCAL_LNAMIXENIRCAL1_enable                              0x00000001UL                                      /**< Mode enable for RAC_LNAMIXCAL               */
#define RAC_LNAMIXCAL_LNAMIXENIRCAL1_DEFAULT                              (_RAC_LNAMIXCAL_LNAMIXENIRCAL1_DEFAULT << 4)      /**< Shifted mode DEFAULT for RAC_LNAMIXCAL      */
#define RAC_LNAMIXCAL_LNAMIXENIRCAL1_disable                              (_RAC_LNAMIXCAL_LNAMIXENIRCAL1_disable << 4)      /**< Shifted mode disable for RAC_LNAMIXCAL      */
#define RAC_LNAMIXCAL_LNAMIXENIRCAL1_enable                               (_RAC_LNAMIXCAL_LNAMIXENIRCAL1_enable << 4)       /**< Shifted mode enable for RAC_LNAMIXCAL       */
#define _RAC_LNAMIXCAL_LNAMIXIRCAL0AMP_SHIFT                              5                                                 /**< Shift value for RAC_LNAMIXIRCAL0AMP         */
#define _RAC_LNAMIXCAL_LNAMIXIRCAL0AMP_MASK                               0xE0UL                                            /**< Bit mask for RAC_LNAMIXIRCAL0AMP            */
#define _RAC_LNAMIXCAL_LNAMIXIRCAL0AMP_DEFAULT                            0x00000007UL                                      /**< Mode DEFAULT for RAC_LNAMIXCAL              */
#define RAC_LNAMIXCAL_LNAMIXIRCAL0AMP_DEFAULT                             (_RAC_LNAMIXCAL_LNAMIXIRCAL0AMP_DEFAULT << 5)     /**< Shifted mode DEFAULT for RAC_LNAMIXCAL      */
#define _RAC_LNAMIXCAL_LNAMIXIRCAL1AMP_SHIFT                              8                                                 /**< Shift value for RAC_LNAMIXIRCAL1AMP         */
#define _RAC_LNAMIXCAL_LNAMIXIRCAL1AMP_MASK                               0x700UL                                           /**< Bit mask for RAC_LNAMIXIRCAL1AMP            */
#define _RAC_LNAMIXCAL_LNAMIXIRCAL1AMP_DEFAULT                            0x00000007UL                                      /**< Mode DEFAULT for RAC_LNAMIXCAL              */
#define RAC_LNAMIXCAL_LNAMIXIRCAL1AMP_DEFAULT                             (_RAC_LNAMIXCAL_LNAMIXIRCAL1AMP_DEFAULT << 8)     /**< Shifted mode DEFAULT for RAC_LNAMIXCAL      */

/* Bit fields for RAC LNAMIXEN */
#define _RAC_LNAMIXEN_RESETVALUE                                          0x00000000UL                              /**< Default value for RAC_LNAMIXEN              */
#define _RAC_LNAMIXEN_MASK                                                0x0000000FUL                              /**< Mask for RAC_LNAMIXEN                       */
#define RAC_LNAMIXEN_LNAMIXENAMP0                                         (0x1UL << 0)                              /**< LNAMIXENAMP0                                */
#define _RAC_LNAMIXEN_LNAMIXENAMP0_SHIFT                                  0                                         /**< Shift value for RAC_LNAMIXENAMP0            */
#define _RAC_LNAMIXEN_LNAMIXENAMP0_MASK                                   0x1UL                                     /**< Bit mask for RAC_LNAMIXENAMP0               */
#define _RAC_LNAMIXEN_LNAMIXENAMP0_DEFAULT                                0x00000000UL                              /**< Mode DEFAULT for RAC_LNAMIXEN               */
#define _RAC_LNAMIXEN_LNAMIXENAMP0_disable                                0x00000000UL                              /**< Mode disable for RAC_LNAMIXEN               */
#define _RAC_LNAMIXEN_LNAMIXENAMP0_enable                                 0x00000001UL                              /**< Mode enable for RAC_LNAMIXEN                */
#define RAC_LNAMIXEN_LNAMIXENAMP0_DEFAULT                                 (_RAC_LNAMIXEN_LNAMIXENAMP0_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_LNAMIXEN       */
#define RAC_LNAMIXEN_LNAMIXENAMP0_disable                                 (_RAC_LNAMIXEN_LNAMIXENAMP0_disable << 0) /**< Shifted mode disable for RAC_LNAMIXEN       */
#define RAC_LNAMIXEN_LNAMIXENAMP0_enable                                  (_RAC_LNAMIXEN_LNAMIXENAMP0_enable << 0)  /**< Shifted mode enable for RAC_LNAMIXEN        */
#define RAC_LNAMIXEN_LNAMIXENAMP1                                         (0x1UL << 1)                              /**< LNAMIXENAMP1                                */
#define _RAC_LNAMIXEN_LNAMIXENAMP1_SHIFT                                  1                                         /**< Shift value for RAC_LNAMIXENAMP1            */
#define _RAC_LNAMIXEN_LNAMIXENAMP1_MASK                                   0x2UL                                     /**< Bit mask for RAC_LNAMIXENAMP1               */
#define _RAC_LNAMIXEN_LNAMIXENAMP1_DEFAULT                                0x00000000UL                              /**< Mode DEFAULT for RAC_LNAMIXEN               */
#define _RAC_LNAMIXEN_LNAMIXENAMP1_disable                                0x00000000UL                              /**< Mode disable for RAC_LNAMIXEN               */
#define _RAC_LNAMIXEN_LNAMIXENAMP1_enable                                 0x00000001UL                              /**< Mode enable for RAC_LNAMIXEN                */
#define RAC_LNAMIXEN_LNAMIXENAMP1_DEFAULT                                 (_RAC_LNAMIXEN_LNAMIXENAMP1_DEFAULT << 1) /**< Shifted mode DEFAULT for RAC_LNAMIXEN       */
#define RAC_LNAMIXEN_LNAMIXENAMP1_disable                                 (_RAC_LNAMIXEN_LNAMIXENAMP1_disable << 1) /**< Shifted mode disable for RAC_LNAMIXEN       */
#define RAC_LNAMIXEN_LNAMIXENAMP1_enable                                  (_RAC_LNAMIXEN_LNAMIXENAMP1_enable << 1)  /**< Shifted mode enable for RAC_LNAMIXEN        */
#define RAC_LNAMIXEN_LNAMIXENBIAS                                         (0x1UL << 2)                              /**< LNAMIXENBIAS                                */
#define _RAC_LNAMIXEN_LNAMIXENBIAS_SHIFT                                  2                                         /**< Shift value for RAC_LNAMIXENBIAS            */
#define _RAC_LNAMIXEN_LNAMIXENBIAS_MASK                                   0x4UL                                     /**< Bit mask for RAC_LNAMIXENBIAS               */
#define _RAC_LNAMIXEN_LNAMIXENBIAS_DEFAULT                                0x00000000UL                              /**< Mode DEFAULT for RAC_LNAMIXEN               */
#define _RAC_LNAMIXEN_LNAMIXENBIAS_disable                                0x00000000UL                              /**< Mode disable for RAC_LNAMIXEN               */
#define _RAC_LNAMIXEN_LNAMIXENBIAS_enable                                 0x00000001UL                              /**< Mode enable for RAC_LNAMIXEN                */
#define RAC_LNAMIXEN_LNAMIXENBIAS_DEFAULT                                 (_RAC_LNAMIXEN_LNAMIXENBIAS_DEFAULT << 2) /**< Shifted mode DEFAULT for RAC_LNAMIXEN       */
#define RAC_LNAMIXEN_LNAMIXENBIAS_disable                                 (_RAC_LNAMIXEN_LNAMIXENBIAS_disable << 2) /**< Shifted mode disable for RAC_LNAMIXEN       */
#define RAC_LNAMIXEN_LNAMIXENBIAS_enable                                  (_RAC_LNAMIXEN_LNAMIXENBIAS_enable << 2)  /**< Shifted mode enable for RAC_LNAMIXEN        */
#define RAC_LNAMIXEN_LNAMIXENLDO                                          (0x1UL << 3)                              /**< LNAMIXENLDO                                 */
#define _RAC_LNAMIXEN_LNAMIXENLDO_SHIFT                                   3                                         /**< Shift value for RAC_LNAMIXENLDO             */
#define _RAC_LNAMIXEN_LNAMIXENLDO_MASK                                    0x8UL                                     /**< Bit mask for RAC_LNAMIXENLDO                */
#define _RAC_LNAMIXEN_LNAMIXENLDO_DEFAULT                                 0x00000000UL                              /**< Mode DEFAULT for RAC_LNAMIXEN               */
#define _RAC_LNAMIXEN_LNAMIXENLDO_disable                                 0x00000000UL                              /**< Mode disable for RAC_LNAMIXEN               */
#define _RAC_LNAMIXEN_LNAMIXENLDO_enable                                  0x00000001UL                              /**< Mode enable for RAC_LNAMIXEN                */
#define RAC_LNAMIXEN_LNAMIXENLDO_DEFAULT                                  (_RAC_LNAMIXEN_LNAMIXENLDO_DEFAULT << 3)  /**< Shifted mode DEFAULT for RAC_LNAMIXEN       */
#define RAC_LNAMIXEN_LNAMIXENLDO_disable                                  (_RAC_LNAMIXEN_LNAMIXENLDO_disable << 3)  /**< Shifted mode disable for RAC_LNAMIXEN       */
#define RAC_LNAMIXEN_LNAMIXENLDO_enable                                   (_RAC_LNAMIXEN_LNAMIXENLDO_enable << 3)   /**< Shifted mode enable for RAC_LNAMIXEN        */

/* Bit fields for RAC PRECTRL */
#define _RAC_PRECTRL_RESETVALUE                                           0x00000026UL                               /**< Default value for RAC_PRECTRL               */
#define _RAC_PRECTRL_MASK                                                 0x0000003FUL                               /**< Mask for RAC_PRECTRL                        */
#define RAC_PRECTRL_PREBYPFORCE                                           (0x1UL << 0)                               /**< PREBYPFORCE                                 */
#define _RAC_PRECTRL_PREBYPFORCE_SHIFT                                    0                                          /**< Shift value for RAC_PREBYPFORCE             */
#define _RAC_PRECTRL_PREBYPFORCE_MASK                                     0x1UL                                      /**< Bit mask for RAC_PREBYPFORCE                */
#define _RAC_PRECTRL_PREBYPFORCE_DEFAULT                                  0x00000000UL                               /**< Mode DEFAULT for RAC_PRECTRL                */
#define _RAC_PRECTRL_PREBYPFORCE_not_forced                               0x00000000UL                               /**< Mode not_forced for RAC_PRECTRL             */
#define _RAC_PRECTRL_PREBYPFORCE_forced                                   0x00000001UL                               /**< Mode forced for RAC_PRECTRL                 */
#define RAC_PRECTRL_PREBYPFORCE_DEFAULT                                   (_RAC_PRECTRL_PREBYPFORCE_DEFAULT << 0)    /**< Shifted mode DEFAULT for RAC_PRECTRL        */
#define RAC_PRECTRL_PREBYPFORCE_not_forced                                (_RAC_PRECTRL_PREBYPFORCE_not_forced << 0) /**< Shifted mode not_forced for RAC_PRECTRL     */
#define RAC_PRECTRL_PREBYPFORCE_forced                                    (_RAC_PRECTRL_PREBYPFORCE_forced << 0)     /**< Shifted mode forced for RAC_PRECTRL         */
#define _RAC_PRECTRL_PREREGTRIM_SHIFT                                     1                                          /**< Shift value for RAC_PREREGTRIM              */
#define _RAC_PRECTRL_PREREGTRIM_MASK                                      0xEUL                                      /**< Bit mask for RAC_PREREGTRIM                 */
#define _RAC_PRECTRL_PREREGTRIM_DEFAULT                                   0x00000003UL                               /**< Mode DEFAULT for RAC_PRECTRL                */
#define _RAC_PRECTRL_PREREGTRIM_v1p61                                     0x00000000UL                               /**< Mode v1p61 for RAC_PRECTRL                  */
#define _RAC_PRECTRL_PREREGTRIM_v1p68                                     0x00000001UL                               /**< Mode v1p68 for RAC_PRECTRL                  */
#define _RAC_PRECTRL_PREREGTRIM_v1p74                                     0x00000002UL                               /**< Mode v1p74 for RAC_PRECTRL                  */
#define _RAC_PRECTRL_PREREGTRIM_v1p80                                     0x00000003UL                               /**< Mode v1p80 for RAC_PRECTRL                  */
#define _RAC_PRECTRL_PREREGTRIM_v1p86                                     0x00000004UL                               /**< Mode v1p86 for RAC_PRECTRL                  */
#define _RAC_PRECTRL_PREREGTRIM_v1p91                                     0x00000005UL                               /**< Mode v1p91 for RAC_PRECTRL                  */
#define _RAC_PRECTRL_PREREGTRIM_v1p96                                     0x00000006UL                               /**< Mode v1p96 for RAC_PRECTRL                  */
#define _RAC_PRECTRL_PREREGTRIM_v2p00                                     0x00000007UL                               /**< Mode v2p00 for RAC_PRECTRL                  */
#define RAC_PRECTRL_PREREGTRIM_DEFAULT                                    (_RAC_PRECTRL_PREREGTRIM_DEFAULT << 1)     /**< Shifted mode DEFAULT for RAC_PRECTRL        */
#define RAC_PRECTRL_PREREGTRIM_v1p61                                      (_RAC_PRECTRL_PREREGTRIM_v1p61 << 1)       /**< Shifted mode v1p61 for RAC_PRECTRL          */
#define RAC_PRECTRL_PREREGTRIM_v1p68                                      (_RAC_PRECTRL_PREREGTRIM_v1p68 << 1)       /**< Shifted mode v1p68 for RAC_PRECTRL          */
#define RAC_PRECTRL_PREREGTRIM_v1p74                                      (_RAC_PRECTRL_PREREGTRIM_v1p74 << 1)       /**< Shifted mode v1p74 for RAC_PRECTRL          */
#define RAC_PRECTRL_PREREGTRIM_v1p80                                      (_RAC_PRECTRL_PREREGTRIM_v1p80 << 1)       /**< Shifted mode v1p80 for RAC_PRECTRL          */
#define RAC_PRECTRL_PREREGTRIM_v1p86                                      (_RAC_PRECTRL_PREREGTRIM_v1p86 << 1)       /**< Shifted mode v1p86 for RAC_PRECTRL          */
#define RAC_PRECTRL_PREREGTRIM_v1p91                                      (_RAC_PRECTRL_PREREGTRIM_v1p91 << 1)       /**< Shifted mode v1p91 for RAC_PRECTRL          */
#define RAC_PRECTRL_PREREGTRIM_v1p96                                      (_RAC_PRECTRL_PREREGTRIM_v1p96 << 1)       /**< Shifted mode v1p96 for RAC_PRECTRL          */
#define RAC_PRECTRL_PREREGTRIM_v2p00                                      (_RAC_PRECTRL_PREREGTRIM_v2p00 << 1)       /**< Shifted mode v2p00 for RAC_PRECTRL          */
#define _RAC_PRECTRL_PREVREFTRIM_SHIFT                                    4                                          /**< Shift value for RAC_PREVREFTRIM             */
#define _RAC_PRECTRL_PREVREFTRIM_MASK                                     0x30UL                                     /**< Bit mask for RAC_PREVREFTRIM                */
#define _RAC_PRECTRL_PREVREFTRIM_DEFAULT                                  0x00000002UL                               /**< Mode DEFAULT for RAC_PRECTRL                */
#define _RAC_PRECTRL_PREVREFTRIM_v0p675                                   0x00000000UL                               /**< Mode v0p675 for RAC_PRECTRL                 */
#define _RAC_PRECTRL_PREVREFTRIM_v0p688                                   0x00000001UL                               /**< Mode v0p688 for RAC_PRECTRL                 */
#define _RAC_PRECTRL_PREVREFTRIM_v0p700                                   0x00000002UL                               /**< Mode v0p700 for RAC_PRECTRL                 */
#define _RAC_PRECTRL_PREVREFTRIM_v0p713                                   0x00000003UL                               /**< Mode v0p713 for RAC_PRECTRL                 */
#define RAC_PRECTRL_PREVREFTRIM_DEFAULT                                   (_RAC_PRECTRL_PREVREFTRIM_DEFAULT << 4)    /**< Shifted mode DEFAULT for RAC_PRECTRL        */
#define RAC_PRECTRL_PREVREFTRIM_v0p675                                    (_RAC_PRECTRL_PREVREFTRIM_v0p675 << 4)     /**< Shifted mode v0p675 for RAC_PRECTRL         */
#define RAC_PRECTRL_PREVREFTRIM_v0p688                                    (_RAC_PRECTRL_PREVREFTRIM_v0p688 << 4)     /**< Shifted mode v0p688 for RAC_PRECTRL         */
#define RAC_PRECTRL_PREVREFTRIM_v0p700                                    (_RAC_PRECTRL_PREVREFTRIM_v0p700 << 4)     /**< Shifted mode v0p700 for RAC_PRECTRL         */
#define RAC_PRECTRL_PREVREFTRIM_v0p713                                    (_RAC_PRECTRL_PREVREFTRIM_v0p713 << 4)     /**< Shifted mode v0p713 for RAC_PRECTRL         */

/* Bit fields for RAC PATRIM1 */
#define _RAC_PATRIM1_RESETVALUE                                           0x00234387UL                                       /**< Default value for RAC_PATRIM1               */
#define _RAC_PATRIM1_MASK                                                 0x00FFC78FUL                                       /**< Mask for RAC_PATRIM1                        */
#define _RAC_PATRIM1_TXTRIMXPAVNB_SHIFT                                   0                                                  /**< Shift value for RAC_TXTRIMXPAVNB            */
#define _RAC_PATRIM1_TXTRIMXPAVNB_MASK                                    0xFUL                                              /**< Bit mask for RAC_TXTRIMXPAVNB               */
#define _RAC_PATRIM1_TXTRIMXPAVNB_DEFAULT                                 0x00000007UL                                       /**< Mode DEFAULT for RAC_PATRIM1                */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p425                               0x00000000UL                                       /**< Mode ognd0p425 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p450                               0x00000001UL                                       /**< Mode ognd0p450 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p475                               0x00000002UL                                       /**< Mode ognd0p475 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p500                               0x00000003UL                                       /**< Mode ognd0p500 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p525                               0x00000004UL                                       /**< Mode ognd0p525 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p550                               0x00000005UL                                       /**< Mode ognd0p550 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p575                               0x00000006UL                                       /**< Mode ognd0p575 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p600                               0x00000007UL                                       /**< Mode ognd0p600 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p625                               0x00000008UL                                       /**< Mode ognd0p625 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p650                               0x00000009UL                                       /**< Mode ognd0p650 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p675                               0x0000000AUL                                       /**< Mode ognd0p675 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p700                               0x0000000BUL                                       /**< Mode ognd0p700 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p725                               0x0000000CUL                                       /**< Mode ognd0p725 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p750                               0x0000000DUL                                       /**< Mode ognd0p750 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p775                               0x0000000EUL                                       /**< Mode ognd0p775 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVNB_ognd0p800                               0x0000000FUL                                       /**< Mode ognd0p800 for RAC_PATRIM1              */
#define RAC_PATRIM1_TXTRIMXPAVNB_DEFAULT                                  (_RAC_PATRIM1_TXTRIMXPAVNB_DEFAULT << 0)           /**< Shifted mode DEFAULT for RAC_PATRIM1        */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p425                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p425 << 0)         /**< Shifted mode ognd0p425 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p450                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p450 << 0)         /**< Shifted mode ognd0p450 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p475                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p475 << 0)         /**< Shifted mode ognd0p475 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p500                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p500 << 0)         /**< Shifted mode ognd0p500 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p525                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p525 << 0)         /**< Shifted mode ognd0p525 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p550                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p550 << 0)         /**< Shifted mode ognd0p550 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p575                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p575 << 0)         /**< Shifted mode ognd0p575 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p600                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p600 << 0)         /**< Shifted mode ognd0p600 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p625                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p625 << 0)         /**< Shifted mode ognd0p625 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p650                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p650 << 0)         /**< Shifted mode ognd0p650 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p675                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p675 << 0)         /**< Shifted mode ognd0p675 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p700                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p700 << 0)         /**< Shifted mode ognd0p700 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p725                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p725 << 0)         /**< Shifted mode ognd0p725 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p750                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p750 << 0)         /**< Shifted mode ognd0p750 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p775                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p775 << 0)         /**< Shifted mode ognd0p775 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVNB_ognd0p800                                (_RAC_PATRIM1_TXTRIMXPAVNB_ognd0p800 << 0)         /**< Shifted mode ognd0p800 for RAC_PATRIM1      */
#define _RAC_PATRIM1_TXTRIMXPAVPB_SHIFT                                   7                                                  /**< Shift value for RAC_TXTRIMXPAVPB            */
#define _RAC_PATRIM1_TXTRIMXPAVPB_MASK                                    0x780UL                                            /**< Bit mask for RAC_TXTRIMXPAVPB               */
#define _RAC_PATRIM1_TXTRIMXPAVPB_DEFAULT                                 0x00000007UL                                       /**< Mode DEFAULT for RAC_PATRIM1                */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p425                               0x00000000UL                                       /**< Mode ovdd0p425 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p450                               0x00000001UL                                       /**< Mode ovdd0p450 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p475                               0x00000002UL                                       /**< Mode ovdd0p475 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p500                               0x00000003UL                                       /**< Mode ovdd0p500 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p525                               0x00000004UL                                       /**< Mode ovdd0p525 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p550                               0x00000005UL                                       /**< Mode ovdd0p550 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p575                               0x00000006UL                                       /**< Mode ovdd0p575 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p600                               0x00000007UL                                       /**< Mode ovdd0p600 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p625                               0x00000008UL                                       /**< Mode ovdd0p625 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p650                               0x00000009UL                                       /**< Mode ovdd0p650 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p675                               0x0000000AUL                                       /**< Mode ovdd0p675 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p700                               0x0000000BUL                                       /**< Mode ovdd0p700 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p725                               0x0000000CUL                                       /**< Mode ovdd0p725 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p750                               0x0000000DUL                                       /**< Mode ovdd0p750 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p775                               0x0000000EUL                                       /**< Mode ovdd0p775 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p800                               0x0000000FUL                                       /**< Mode ovdd0p800 for RAC_PATRIM1              */
#define RAC_PATRIM1_TXTRIMXPAVPB_DEFAULT                                  (_RAC_PATRIM1_TXTRIMXPAVPB_DEFAULT << 7)           /**< Shifted mode DEFAULT for RAC_PATRIM1        */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p425                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p425 << 7)         /**< Shifted mode ovdd0p425 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p450                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p450 << 7)         /**< Shifted mode ovdd0p450 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p475                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p475 << 7)         /**< Shifted mode ovdd0p475 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p500                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p500 << 7)         /**< Shifted mode ovdd0p500 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p525                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p525 << 7)         /**< Shifted mode ovdd0p525 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p550                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p550 << 7)         /**< Shifted mode ovdd0p550 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p575                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p575 << 7)         /**< Shifted mode ovdd0p575 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p600                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p600 << 7)         /**< Shifted mode ovdd0p600 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p625                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p625 << 7)         /**< Shifted mode ovdd0p625 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p650                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p650 << 7)         /**< Shifted mode ovdd0p650 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p675                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p675 << 7)         /**< Shifted mode ovdd0p675 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p700                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p700 << 7)         /**< Shifted mode ovdd0p700 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p725                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p725 << 7)         /**< Shifted mode ovdd0p725 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p750                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p750 << 7)         /**< Shifted mode ovdd0p750 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p775                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p775 << 7)         /**< Shifted mode ovdd0p775 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p800                                (_RAC_PATRIM1_TXTRIMXPAVPB_ovdd0p800 << 7)         /**< Shifted mode ovdd0p800 for RAC_PATRIM1      */
#define _RAC_PATRIM1_TXTRIMHPAVMID_SHIFT                                  14                                                 /**< Shift value for RAC_TXTRIMHPAVMID           */
#define _RAC_PATRIM1_TXTRIMHPAVMID_MASK                                   0xC000UL                                           /**< Bit mask for RAC_TXTRIMHPAVMID              */
#define _RAC_PATRIM1_TXTRIMHPAVMID_DEFAULT                                0x00000001UL                                       /**< Mode DEFAULT for RAC_PATRIM1                */
#define _RAC_PATRIM1_TXTRIMHPAVMID_noeffect0                              0x00000000UL                                       /**< Mode noeffect0 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMHPAVMID_noeffect1                              0x00000001UL                                       /**< Mode noeffect1 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMHPAVMID_noeffect2                              0x00000002UL                                       /**< Mode noeffect2 for RAC_PATRIM1              */
#define _RAC_PATRIM1_TXTRIMHPAVMID_noeffect3                              0x00000003UL                                       /**< Mode noeffect3 for RAC_PATRIM1              */
#define RAC_PATRIM1_TXTRIMHPAVMID_DEFAULT                                 (_RAC_PATRIM1_TXTRIMHPAVMID_DEFAULT << 14)         /**< Shifted mode DEFAULT for RAC_PATRIM1        */
#define RAC_PATRIM1_TXTRIMHPAVMID_noeffect0                               (_RAC_PATRIM1_TXTRIMHPAVMID_noeffect0 << 14)       /**< Shifted mode noeffect0 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMHPAVMID_noeffect1                               (_RAC_PATRIM1_TXTRIMHPAVMID_noeffect1 << 14)       /**< Shifted mode noeffect1 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMHPAVMID_noeffect2                               (_RAC_PATRIM1_TXTRIMHPAVMID_noeffect2 << 14)       /**< Shifted mode noeffect2 for RAC_PATRIM1      */
#define RAC_PATRIM1_TXTRIMHPAVMID_noeffect3                               (_RAC_PATRIM1_TXTRIMHPAVMID_noeffect3 << 14)       /**< Shifted mode noeffect3 for RAC_PATRIM1      */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_SHIFT                                 16                                                 /**< Shift value for RAC_TXTRIMHPAVNCAS          */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_MASK                                  0x70000UL                                          /**< Bit mask for RAC_TXTRIMHPAVNCAS             */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_DEFAULT                               0x00000003UL                                       /**< Mode DEFAULT for RAC_PATRIM1                */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p50                              0x00000000UL                                       /**< Mode ognd1p50 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p55                              0x00000001UL                                       /**< Mode ognd1p55 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p60                              0x00000002UL                                       /**< Mode ognd1p60 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p65                              0x00000003UL                                       /**< Mode ognd1p65 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p70                              0x00000004UL                                       /**< Mode ognd1p70 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p75                              0x00000005UL                                       /**< Mode ognd1p75 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p80                              0x00000006UL                                       /**< Mode ognd1p80 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p85                              0x00000007UL                                       /**< Mode ognd1p85 for RAC_PATRIM1               */
#define RAC_PATRIM1_TXTRIMHPAVNCAS_DEFAULT                                (_RAC_PATRIM1_TXTRIMHPAVNCAS_DEFAULT << 16)        /**< Shifted mode DEFAULT for RAC_PATRIM1        */
#define RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p50                               (_RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p50 << 16)       /**< Shifted mode ognd1p50 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p55                               (_RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p55 << 16)       /**< Shifted mode ognd1p55 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p60                               (_RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p60 << 16)       /**< Shifted mode ognd1p60 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p65                               (_RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p65 << 16)       /**< Shifted mode ognd1p65 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p70                               (_RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p70 << 16)       /**< Shifted mode ognd1p70 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p75                               (_RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p75 << 16)       /**< Shifted mode ognd1p75 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p80                               (_RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p80 << 16)       /**< Shifted mode ognd1p80 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p85                               (_RAC_PATRIM1_TXTRIMHPAVNCAS_ognd1p85 << 16)       /**< Shifted mode ognd1p85 for RAC_PATRIM1       */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_SHIFT                                 19                                                 /**< Shift value for RAC_TXTRIMHPAVPCAS          */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_MASK                                  0x380000UL                                         /**< Bit mask for RAC_TXTRIMHPAVPCAS             */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_DEFAULT                               0x00000004UL                                       /**< Mode DEFAULT for RAC_PATRIM1                */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p30                              0x00000000UL                                       /**< Mode ovdd1p30 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p35                              0x00000001UL                                       /**< Mode ovdd1p35 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p40                              0x00000002UL                                       /**< Mode ovdd1p40 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p45                              0x00000003UL                                       /**< Mode ovdd1p45 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p50                              0x00000004UL                                       /**< Mode ovdd1p50 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p55                              0x00000005UL                                       /**< Mode ovdd1p55 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p60                              0x00000006UL                                       /**< Mode ovdd1p60 for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p65                              0x00000007UL                                       /**< Mode ovdd1p65 for RAC_PATRIM1               */
#define RAC_PATRIM1_TXTRIMHPAVPCAS_DEFAULT                                (_RAC_PATRIM1_TXTRIMHPAVPCAS_DEFAULT << 19)        /**< Shifted mode DEFAULT for RAC_PATRIM1        */
#define RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p30                               (_RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p30 << 19)       /**< Shifted mode ovdd1p30 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p35                               (_RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p35 << 19)       /**< Shifted mode ovdd1p35 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p40                               (_RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p40 << 19)       /**< Shifted mode ovdd1p40 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p45                               (_RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p45 << 19)       /**< Shifted mode ovdd1p45 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p50                               (_RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p50 << 19)       /**< Shifted mode ovdd1p50 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p55                               (_RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p55 << 19)       /**< Shifted mode ovdd1p55 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p60                               (_RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p60 << 19)       /**< Shifted mode ovdd1p60 for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p65                               (_RAC_PATRIM1_TXTRIMHPAVPCAS_ovdd1p65 << 19)       /**< Shifted mode ovdd1p65 for RAC_PATRIM1       */
#define _RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_SHIFT                           22                                                 /**< Shift value for RAC_TXTRIMHPAVMIDCURRENT    */
#define _RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_MASK                            0xC00000UL                                         /**< Bit mask for RAC_TXTRIMHPAVMIDCURRENT       */
#define _RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_DEFAULT                         0x00000000UL                                       /**< Mode DEFAULT for RAC_PATRIM1                */
#define _RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_0p75mA                        0x00000000UL                                       /**< Mode I_0p75mA for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_1p50mA                        0x00000001UL                                       /**< Mode I_1p50mA for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_2p25mA                        0x00000002UL                                       /**< Mode I_2p25mA for RAC_PATRIM1               */
#define _RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_3p00mA                        0x00000003UL                                       /**< Mode I_3p00mA for RAC_PATRIM1               */
#define RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_DEFAULT                          (_RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_DEFAULT << 22)  /**< Shifted mode DEFAULT for RAC_PATRIM1        */
#define RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_0p75mA                         (_RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_0p75mA << 22) /**< Shifted mode I_0p75mA for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_1p50mA                         (_RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_1p50mA << 22) /**< Shifted mode I_1p50mA for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_2p25mA                         (_RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_2p25mA << 22) /**< Shifted mode I_2p25mA for RAC_PATRIM1       */
#define RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_3p00mA                         (_RAC_PATRIM1_TXTRIMHPAVMIDCURRENT_I_3p00mA << 22) /**< Shifted mode I_3p00mA for RAC_PATRIM1       */

/* Bit fields for RAC PATRIM2 */
#define _RAC_PATRIM2_RESETVALUE                                           0x00007777UL                                           /**< Default value for RAC_PATRIM2               */
#define _RAC_PATRIM2_MASK                                                 0xFFFFFFFFUL                                           /**< Mask for RAC_PATRIM2                        */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_SHIFT                              0                                                      /**< Shift value for RAC_TXTRIMCLKGENDUTYN       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_MASK                               0xFUL                                                  /**< Bit mask for RAC_TXTRIMCLKGENDUTYN          */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_DEFAULT                            0x00000007UL                                           /**< Mode DEFAULT for RAC_PATRIM2                */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0000ps                   0x00000000UL                                           /**< Mode pc50_plus_0000ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_2p40ps                   0x00000001UL                                           /**< Mode pc50_plus_2p40ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_5p00ps                   0x00000002UL                                           /**< Mode pc50_plus_5p00ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_7p20ps                   0x00000003UL                                           /**< Mode pc50_plus_7p20ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_10p8ps                   0x00000004UL                                           /**< Mode pc50_plus_10p8ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_13p6ps                   0x00000005UL                                           /**< Mode pc50_plus_13p6ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_17p1ps                   0x00000006UL                                           /**< Mode pc50_plus_17p1ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_21p9ps                   0x00000007UL                                           /**< Mode pc50_plus_21p9ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_28p1ps                   0x00000008UL                                           /**< Mode pc50_plus_28p1ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_36p3ps                   0x00000009UL                                           /**< Mode pc50_plus_36p3ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_47p3ps                   0x0000000AUL                                           /**< Mode pc50_plus_47p3ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_62p0ps                   0x0000000BUL                                           /**< Mode pc50_plus_62p0ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0110ps                   0x0000000CUL                                           /**< Mode pc50_plus_0110ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0211ps                   0x0000000DUL                                           /**< Mode pc50_plus_0211ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0304ps                   0x0000000EUL                                           /**< Mode pc50_plus_0304ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0450ps                   0x0000000FUL                                           /**< Mode pc50_plus_0450ps for RAC_PATRIM2       */
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_DEFAULT                             (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_DEFAULT << 0)          /**< Shifted mode DEFAULT for RAC_PATRIM2        */
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0000ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0000ps << 0) /**< Shifted mode pc50_plus_0000ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_2p40ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_2p40ps << 0) /**< Shifted mode pc50_plus_2p40ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_5p00ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_5p00ps << 0) /**< Shifted mode pc50_plus_5p00ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_7p20ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_7p20ps << 0) /**< Shifted mode pc50_plus_7p20ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_10p8ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_10p8ps << 0) /**< Shifted mode pc50_plus_10p8ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_13p6ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_13p6ps << 0) /**< Shifted mode pc50_plus_13p6ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_17p1ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_17p1ps << 0) /**< Shifted mode pc50_plus_17p1ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_21p9ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_21p9ps << 0) /**< Shifted mode pc50_plus_21p9ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_28p1ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_28p1ps << 0) /**< Shifted mode pc50_plus_28p1ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_36p3ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_36p3ps << 0) /**< Shifted mode pc50_plus_36p3ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_47p3ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_47p3ps << 0) /**< Shifted mode pc50_plus_47p3ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_62p0ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_62p0ps << 0) /**< Shifted mode pc50_plus_62p0ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0110ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0110ps << 0) /**< Shifted mode pc50_plus_0110ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0211ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0211ps << 0) /**< Shifted mode pc50_plus_0211ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0304ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0304ps << 0) /**< Shifted mode pc50_plus_0304ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0450ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYN_pc50_plus_0450ps << 0) /**< Shifted mode pc50_plus_0450ps for RAC_PATRIM2*/
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_SHIFT                              4                                                      /**< Shift value for RAC_TXTRIMCLKGENDUTYP       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_MASK                               0xF0UL                                                 /**< Bit mask for RAC_TXTRIMCLKGENDUTYP          */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_DEFAULT                            0x00000007UL                                           /**< Mode DEFAULT for RAC_PATRIM2                */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_0000ps                   0x00000000UL                                           /**< Mode pc50_plus_0000ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_2p40ps                   0x00000001UL                                           /**< Mode pc50_plus_2p40ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_5p00ps                   0x00000002UL                                           /**< Mode pc50_plus_5p00ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_7p20ps                   0x00000003UL                                           /**< Mode pc50_plus_7p20ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_10p8ps                   0x00000004UL                                           /**< Mode pc50_plus_10p8ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_13p6ps                   0x00000005UL                                           /**< Mode pc50_plus_13p6ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_17p1ps                   0x00000006UL                                           /**< Mode pc50_plus_17p1ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_21p9ps                   0x00000007UL                                           /**< Mode pc50_plus_21p9ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_28p1ps                   0x00000008UL                                           /**< Mode pc50_plus_28p1ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_36p3ps                   0x00000009UL                                           /**< Mode pc50_plus_36p3ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_47p3ps                   0x0000000AUL                                           /**< Mode pc50_plus_47p3ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_62p0ps                   0x0000000BUL                                           /**< Mode pc50_plus_62p0ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_0110ps                   0x0000000CUL                                           /**< Mode pc50_plus_0110ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_0211ps                   0x0000000DUL                                           /**< Mode pc50_plus_0211ps for RAC_PATRIM2       */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_304ps                    0x0000000EUL                                           /**< Mode pc50_plus_304ps for RAC_PATRIM2        */
#define _RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_450ps                    0x0000000FUL                                           /**< Mode pc50_plus_450ps for RAC_PATRIM2        */
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_DEFAULT                             (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_DEFAULT << 4)          /**< Shifted mode DEFAULT for RAC_PATRIM2        */
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_0000ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_0000ps << 4) /**< Shifted mode pc50_plus_0000ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_2p40ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_2p40ps << 4) /**< Shifted mode pc50_plus_2p40ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_5p00ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_5p00ps << 4) /**< Shifted mode pc50_plus_5p00ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_7p20ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_7p20ps << 4) /**< Shifted mode pc50_plus_7p20ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_10p8ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_10p8ps << 4) /**< Shifted mode pc50_plus_10p8ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_13p6ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_13p6ps << 4) /**< Shifted mode pc50_plus_13p6ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_17p1ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_17p1ps << 4) /**< Shifted mode pc50_plus_17p1ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_21p9ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_21p9ps << 4) /**< Shifted mode pc50_plus_21p9ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_28p1ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_28p1ps << 4) /**< Shifted mode pc50_plus_28p1ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_36p3ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_36p3ps << 4) /**< Shifted mode pc50_plus_36p3ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_47p3ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_47p3ps << 4) /**< Shifted mode pc50_plus_47p3ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_62p0ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_62p0ps << 4) /**< Shifted mode pc50_plus_62p0ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_0110ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_0110ps << 4) /**< Shifted mode pc50_plus_0110ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_0211ps                    (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_0211ps << 4) /**< Shifted mode pc50_plus_0211ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_304ps                     (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_304ps << 4)  /**< Shifted mode pc50_plus_304ps for RAC_PATRIM2*/
#define RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_450ps                     (_RAC_PATRIM2_TXTRIMCLKGENDUTYP_pc50_plus_450ps << 4)  /**< Shifted mode pc50_plus_450ps for RAC_PATRIM2*/
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_SHIFT                            8                                                      /**< Shift value for RAC_TXTRIMCLKGENNOVFALL     */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_MASK                             0xF00UL                                                /**< Bit mask for RAC_TXTRIMCLKGENNOVFALL        */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_DEFAULT                          0x00000007UL                                           /**< Mode DEFAULT for RAC_PATRIM2                */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0052ps                      0x00000000UL                                           /**< Mode tnov_0052ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0070ps                      0x00000001UL                                           /**< Mode tnov_0070ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0097ps                      0x00000002UL                                           /**< Mode tnov_0097ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0111ps                      0x00000003UL                                           /**< Mode tnov_0111ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0120ps                      0x00000004UL                                           /**< Mode tnov_0120ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0131ps                      0x00000005UL                                           /**< Mode tnov_0131ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0143ps                      0x00000006UL                                           /**< Mode tnov_0143ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0158ps                      0x00000007UL                                           /**< Mode tnov_0158ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0175ps                      0x00000008UL                                           /**< Mode tnov_0175ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0196ps                      0x00000009UL                                           /**< Mode tnov_0196ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0221ps                      0x0000000AUL                                           /**< Mode tnov_0221ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0251ps                      0x0000000BUL                                           /**< Mode tnov_0251ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0335ps                      0x0000000CUL                                           /**< Mode tnov_0335ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0466ps                      0x0000000DUL                                           /**< Mode tnov_0466ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0677ps                      0x0000000EUL                                           /**< Mode tnov_0677ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_1025ps                      0x0000000FUL                                           /**< Mode tnov_1025ps for RAC_PATRIM2            */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_DEFAULT                           (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_DEFAULT << 8)        /**< Shifted mode DEFAULT for RAC_PATRIM2        */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0052ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0052ps << 8)    /**< Shifted mode tnov_0052ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0070ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0070ps << 8)    /**< Shifted mode tnov_0070ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0097ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0097ps << 8)    /**< Shifted mode tnov_0097ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0111ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0111ps << 8)    /**< Shifted mode tnov_0111ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0120ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0120ps << 8)    /**< Shifted mode tnov_0120ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0131ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0131ps << 8)    /**< Shifted mode tnov_0131ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0143ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0143ps << 8)    /**< Shifted mode tnov_0143ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0158ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0158ps << 8)    /**< Shifted mode tnov_0158ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0175ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0175ps << 8)    /**< Shifted mode tnov_0175ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0196ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0196ps << 8)    /**< Shifted mode tnov_0196ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0221ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0221ps << 8)    /**< Shifted mode tnov_0221ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0251ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0251ps << 8)    /**< Shifted mode tnov_0251ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0335ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0335ps << 8)    /**< Shifted mode tnov_0335ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0466ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0466ps << 8)    /**< Shifted mode tnov_0466ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0677ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_0677ps << 8)    /**< Shifted mode tnov_0677ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_1025ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVFALL_tnov_1025ps << 8)    /**< Shifted mode tnov_1025ps for RAC_PATRIM2    */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_SHIFT                            12                                                     /**< Shift value for RAC_TXTRIMCLKGENNOVRISE     */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_MASK                             0xF000UL                                               /**< Bit mask for RAC_TXTRIMCLKGENNOVRISE        */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_DEFAULT                          0x00000007UL                                           /**< Mode DEFAULT for RAC_PATRIM2                */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0053ps                      0x00000000UL                                           /**< Mode tnov_0053ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0073ps                      0x00000001UL                                           /**< Mode tnov_0073ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0102ps                      0x00000002UL                                           /**< Mode tnov_0102ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0116ps                      0x00000003UL                                           /**< Mode tnov_0116ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0125ps                      0x00000004UL                                           /**< Mode tnov_0125ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0136ps                      0x00000005UL                                           /**< Mode tnov_0136ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0149ps                      0x00000006UL                                           /**< Mode tnov_0149ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0164ps                      0x00000007UL                                           /**< Mode tnov_0164ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0181ps                      0x00000008UL                                           /**< Mode tnov_0181ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0203ps                      0x00000009UL                                           /**< Mode tnov_0203ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0230ps                      0x0000000AUL                                           /**< Mode tnov_0230ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0262ps                      0x0000000BUL                                           /**< Mode tnov_0262ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0353ps                      0x0000000CUL                                           /**< Mode tnov_0353ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0495ps                      0x0000000DUL                                           /**< Mode tnov_0495ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0723ps                      0x0000000EUL                                           /**< Mode tnov_0723ps for RAC_PATRIM2            */
#define _RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_1099ps                      0x0000000FUL                                           /**< Mode tnov_1099ps for RAC_PATRIM2            */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_DEFAULT                           (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_DEFAULT << 12)       /**< Shifted mode DEFAULT for RAC_PATRIM2        */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0053ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0053ps << 12)   /**< Shifted mode tnov_0053ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0073ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0073ps << 12)   /**< Shifted mode tnov_0073ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0102ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0102ps << 12)   /**< Shifted mode tnov_0102ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0116ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0116ps << 12)   /**< Shifted mode tnov_0116ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0125ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0125ps << 12)   /**< Shifted mode tnov_0125ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0136ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0136ps << 12)   /**< Shifted mode tnov_0136ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0149ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0149ps << 12)   /**< Shifted mode tnov_0149ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0164ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0164ps << 12)   /**< Shifted mode tnov_0164ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0181ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0181ps << 12)   /**< Shifted mode tnov_0181ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0203ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0203ps << 12)   /**< Shifted mode tnov_0203ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0230ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0230ps << 12)   /**< Shifted mode tnov_0230ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0262ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0262ps << 12)   /**< Shifted mode tnov_0262ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0353ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0353ps << 12)   /**< Shifted mode tnov_0353ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0495ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0495ps << 12)   /**< Shifted mode tnov_0495ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0723ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_0723ps << 12)   /**< Shifted mode tnov_0723ps for RAC_PATRIM2    */
#define RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_1099ps                       (_RAC_PATRIM2_TXTRIMCLKGENNOVRISE_tnov_1099ps << 12)   /**< Shifted mode tnov_1099ps for RAC_PATRIM2    */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_SHIFT                                16                                                     /**< Shift value for RAC_TXTRIMDRVEDGENN         */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_MASK                                 0xF0000UL                                              /**< Bit mask for RAC_TXTRIMDRVEDGENN            */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_DEFAULT                              0x00000000UL                                           /**< Mode DEFAULT for RAC_PATRIM2                */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0103ps                         0x00000000UL                                           /**< Mode tedge_0103ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0110ps                         0x00000001UL                                           /**< Mode tedge_0110ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0118ps                         0x00000002UL                                           /**< Mode tedge_0118ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0125ps                         0x00000003UL                                           /**< Mode tedge_0125ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0137ps                         0x00000004UL                                           /**< Mode tedge_0137ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0159ps                         0x00000005UL                                           /**< Mode tedge_0159ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0178ps                         0x00000006UL                                           /**< Mode tedge_0178ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0203ps                         0x00000007UL                                           /**< Mode tedge_0203ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0238ps                         0x00000008UL                                           /**< Mode tedge_0238ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0288ps                         0x00000009UL                                           /**< Mode tedge_0288ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0357ps                         0x0000000AUL                                           /**< Mode tedge_0357ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0457ps                         0x0000000BUL                                           /**< Mode tedge_0457ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0604ps                         0x0000000CUL                                           /**< Mode tedge_0604ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0828ps                         0x0000000DUL                                           /**< Mode tedge_0828ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_1186ps                         0x0000000EUL                                           /**< Mode tedge_1186ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_1793ps                         0x0000000FUL                                           /**< Mode tedge_1793ps for RAC_PATRIM2           */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_DEFAULT                               (_RAC_PATRIM2_TXTRIMDRVEDGENN_DEFAULT << 16)           /**< Shifted mode DEFAULT for RAC_PATRIM2        */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0103ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0103ps << 16)      /**< Shifted mode tedge_0103ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0110ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0110ps << 16)      /**< Shifted mode tedge_0110ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0118ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0118ps << 16)      /**< Shifted mode tedge_0118ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0125ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0125ps << 16)      /**< Shifted mode tedge_0125ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0137ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0137ps << 16)      /**< Shifted mode tedge_0137ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0159ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0159ps << 16)      /**< Shifted mode tedge_0159ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0178ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0178ps << 16)      /**< Shifted mode tedge_0178ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0203ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0203ps << 16)      /**< Shifted mode tedge_0203ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0238ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0238ps << 16)      /**< Shifted mode tedge_0238ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0288ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0288ps << 16)      /**< Shifted mode tedge_0288ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0357ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0357ps << 16)      /**< Shifted mode tedge_0357ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0457ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0457ps << 16)      /**< Shifted mode tedge_0457ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0604ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0604ps << 16)      /**< Shifted mode tedge_0604ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0828ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_0828ps << 16)      /**< Shifted mode tedge_0828ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_1186ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_1186ps << 16)      /**< Shifted mode tedge_1186ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_1793ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENN_tedge_1793ps << 16)      /**< Shifted mode tedge_1793ps for RAC_PATRIM2   */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_SHIFT                                20                                                     /**< Shift value for RAC_TXTRIMDRVEDGENP         */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_MASK                                 0xF00000UL                                             /**< Bit mask for RAC_TXTRIMDRVEDGENP            */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_DEFAULT                              0x00000000UL                                           /**< Mode DEFAULT for RAC_PATRIM2                */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0103ps                         0x00000000UL                                           /**< Mode tedge_0103ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0110ps                         0x00000001UL                                           /**< Mode tedge_0110ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0118ps                         0x00000002UL                                           /**< Mode tedge_0118ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0125ps                         0x00000003UL                                           /**< Mode tedge_0125ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0137ps                         0x00000004UL                                           /**< Mode tedge_0137ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0159ps                         0x00000005UL                                           /**< Mode tedge_0159ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0178ps                         0x00000006UL                                           /**< Mode tedge_0178ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0203ps                         0x00000007UL                                           /**< Mode tedge_0203ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0238ps                         0x00000008UL                                           /**< Mode tedge_0238ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0288ps                         0x00000009UL                                           /**< Mode tedge_0288ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0357ps                         0x0000000AUL                                           /**< Mode tedge_0357ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0457ps                         0x0000000BUL                                           /**< Mode tedge_0457ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0604ps                         0x0000000CUL                                           /**< Mode tedge_0604ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0828ps                         0x0000000DUL                                           /**< Mode tedge_0828ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_1186ps                         0x0000000EUL                                           /**< Mode tedge_1186ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_1793ps                         0x0000000FUL                                           /**< Mode tedge_1793ps for RAC_PATRIM2           */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_DEFAULT                               (_RAC_PATRIM2_TXTRIMDRVEDGENP_DEFAULT << 20)           /**< Shifted mode DEFAULT for RAC_PATRIM2        */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0103ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0103ps << 20)      /**< Shifted mode tedge_0103ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0110ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0110ps << 20)      /**< Shifted mode tedge_0110ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0118ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0118ps << 20)      /**< Shifted mode tedge_0118ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0125ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0125ps << 20)      /**< Shifted mode tedge_0125ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0137ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0137ps << 20)      /**< Shifted mode tedge_0137ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0159ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0159ps << 20)      /**< Shifted mode tedge_0159ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0178ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0178ps << 20)      /**< Shifted mode tedge_0178ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0203ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0203ps << 20)      /**< Shifted mode tedge_0203ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0238ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0238ps << 20)      /**< Shifted mode tedge_0238ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0288ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0288ps << 20)      /**< Shifted mode tedge_0288ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0357ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0357ps << 20)      /**< Shifted mode tedge_0357ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0457ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0457ps << 20)      /**< Shifted mode tedge_0457ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0604ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0604ps << 20)      /**< Shifted mode tedge_0604ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0828ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_0828ps << 20)      /**< Shifted mode tedge_0828ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_1186ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_1186ps << 20)      /**< Shifted mode tedge_1186ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_1793ps                          (_RAC_PATRIM2_TXTRIMDRVEDGENP_tedge_1793ps << 20)      /**< Shifted mode tedge_1793ps for RAC_PATRIM2   */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_SHIFT                                24                                                     /**< Shift value for RAC_TXTRIMDRVEDGEPN         */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_MASK                                 0xF000000UL                                            /**< Bit mask for RAC_TXTRIMDRVEDGEPN            */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_DEFAULT                              0x00000000UL                                           /**< Mode DEFAULT for RAC_PATRIM2                */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0103ps                         0x00000000UL                                           /**< Mode tedge_0103ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0110ps                         0x00000001UL                                           /**< Mode tedge_0110ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0118ps                         0x00000002UL                                           /**< Mode tedge_0118ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0125ps                         0x00000003UL                                           /**< Mode tedge_0125ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0137ps                         0x00000004UL                                           /**< Mode tedge_0137ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0159ps                         0x00000005UL                                           /**< Mode tedge_0159ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0178ps                         0x00000006UL                                           /**< Mode tedge_0178ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0203ps                         0x00000007UL                                           /**< Mode tedge_0203ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0238ps                         0x00000008UL                                           /**< Mode tedge_0238ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0288ps                         0x00000009UL                                           /**< Mode tedge_0288ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0357ps                         0x0000000AUL                                           /**< Mode tedge_0357ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0457ps                         0x0000000BUL                                           /**< Mode tedge_0457ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0604ps                         0x0000000CUL                                           /**< Mode tedge_0604ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0828ps                         0x0000000DUL                                           /**< Mode tedge_0828ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_1186ps                         0x0000000EUL                                           /**< Mode tedge_1186ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_1793ps                         0x0000000FUL                                           /**< Mode tedge_1793ps for RAC_PATRIM2           */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_DEFAULT                               (_RAC_PATRIM2_TXTRIMDRVEDGEPN_DEFAULT << 24)           /**< Shifted mode DEFAULT for RAC_PATRIM2        */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0103ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0103ps << 24)      /**< Shifted mode tedge_0103ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0110ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0110ps << 24)      /**< Shifted mode tedge_0110ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0118ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0118ps << 24)      /**< Shifted mode tedge_0118ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0125ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0125ps << 24)      /**< Shifted mode tedge_0125ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0137ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0137ps << 24)      /**< Shifted mode tedge_0137ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0159ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0159ps << 24)      /**< Shifted mode tedge_0159ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0178ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0178ps << 24)      /**< Shifted mode tedge_0178ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0203ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0203ps << 24)      /**< Shifted mode tedge_0203ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0238ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0238ps << 24)      /**< Shifted mode tedge_0238ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0288ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0288ps << 24)      /**< Shifted mode tedge_0288ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0357ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0357ps << 24)      /**< Shifted mode tedge_0357ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0457ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0457ps << 24)      /**< Shifted mode tedge_0457ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0604ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0604ps << 24)      /**< Shifted mode tedge_0604ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0828ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_0828ps << 24)      /**< Shifted mode tedge_0828ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_1186ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_1186ps << 24)      /**< Shifted mode tedge_1186ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_1793ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPN_tedge_1793ps << 24)      /**< Shifted mode tedge_1793ps for RAC_PATRIM2   */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_SHIFT                                28                                                     /**< Shift value for RAC_TXTRIMDRVEDGEPP         */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_MASK                                 0xF0000000UL                                           /**< Bit mask for RAC_TXTRIMDRVEDGEPP            */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_DEFAULT                              0x00000000UL                                           /**< Mode DEFAULT for RAC_PATRIM2                */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0103ps                         0x00000000UL                                           /**< Mode tedge_0103ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0110ps                         0x00000001UL                                           /**< Mode tedge_0110ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0118ps                         0x00000002UL                                           /**< Mode tedge_0118ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0125ps                         0x00000003UL                                           /**< Mode tedge_0125ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0137ps                         0x00000004UL                                           /**< Mode tedge_0137ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0159ps                         0x00000005UL                                           /**< Mode tedge_0159ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0179ps                         0x00000006UL                                           /**< Mode tedge_0179ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0203ps                         0x00000007UL                                           /**< Mode tedge_0203ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0238ps                         0x00000008UL                                           /**< Mode tedge_0238ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0288ps                         0x00000009UL                                           /**< Mode tedge_0288ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0357ps                         0x0000000AUL                                           /**< Mode tedge_0357ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0457ps                         0x0000000BUL                                           /**< Mode tedge_0457ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0604ps                         0x0000000CUL                                           /**< Mode tedge_0604ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0828ps                         0x0000000DUL                                           /**< Mode tedge_0828ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_1186ps                         0x0000000EUL                                           /**< Mode tedge_1186ps for RAC_PATRIM2           */
#define _RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_1793ps                         0x0000000FUL                                           /**< Mode tedge_1793ps for RAC_PATRIM2           */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_DEFAULT                               (_RAC_PATRIM2_TXTRIMDRVEDGEPP_DEFAULT << 28)           /**< Shifted mode DEFAULT for RAC_PATRIM2        */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0103ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0103ps << 28)      /**< Shifted mode tedge_0103ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0110ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0110ps << 28)      /**< Shifted mode tedge_0110ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0118ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0118ps << 28)      /**< Shifted mode tedge_0118ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0125ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0125ps << 28)      /**< Shifted mode tedge_0125ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0137ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0137ps << 28)      /**< Shifted mode tedge_0137ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0159ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0159ps << 28)      /**< Shifted mode tedge_0159ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0179ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0179ps << 28)      /**< Shifted mode tedge_0179ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0203ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0203ps << 28)      /**< Shifted mode tedge_0203ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0238ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0238ps << 28)      /**< Shifted mode tedge_0238ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0288ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0288ps << 28)      /**< Shifted mode tedge_0288ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0357ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0357ps << 28)      /**< Shifted mode tedge_0357ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0457ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0457ps << 28)      /**< Shifted mode tedge_0457ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0604ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0604ps << 28)      /**< Shifted mode tedge_0604ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0828ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_0828ps << 28)      /**< Shifted mode tedge_0828ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_1186ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_1186ps << 28)      /**< Shifted mode tedge_1186ps for RAC_PATRIM2   */
#define RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_1793ps                          (_RAC_PATRIM2_TXTRIMDRVEDGEPP_tedge_1793ps << 28)      /**< Shifted mode tedge_1793ps for RAC_PATRIM2   */

/* Bit fields for RAC PATRIM3 */
#define _RAC_PATRIM3_RESETVALUE                                           0x008F0EE9UL                                                 /**< Default value for RAC_PATRIM3               */
#define _RAC_PATRIM3_MASK                                                 0x7FFFFFFFUL                                                 /**< Mask for RAC_PATRIM3                        */
#define _RAC_PATRIM3_TXTRIMDREGBLEED_SHIFT                                0                                                            /**< Shift value for RAC_TXTRIMDREGBLEED         */
#define _RAC_PATRIM3_TXTRIMDREGBLEED_MASK                                 0x3UL                                                        /**< Bit mask for RAC_TXTRIMDREGBLEED            */
#define _RAC_PATRIM3_TXTRIMDREGBLEED_DEFAULT                              0x00000001UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMDREGBLEED_bleed_0uA                            0x00000000UL                                                 /**< Mode bleed_0uA for RAC_PATRIM3              */
#define _RAC_PATRIM3_TXTRIMDREGBLEED_bleed_140uA                          0x00000001UL                                                 /**< Mode bleed_140uA for RAC_PATRIM3            */
#define _RAC_PATRIM3_TXTRIMDREGBLEED_bleed_280uA                          0x00000002UL                                                 /**< Mode bleed_280uA for RAC_PATRIM3            */
#define _RAC_PATRIM3_TXTRIMDREGBLEED_bleed_420uA                          0x00000003UL                                                 /**< Mode bleed_420uA for RAC_PATRIM3            */
#define RAC_PATRIM3_TXTRIMDREGBLEED_DEFAULT                               (_RAC_PATRIM3_TXTRIMDREGBLEED_DEFAULT << 0)                  /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMDREGBLEED_bleed_0uA                             (_RAC_PATRIM3_TXTRIMDREGBLEED_bleed_0uA << 0)                /**< Shifted mode bleed_0uA for RAC_PATRIM3      */
#define RAC_PATRIM3_TXTRIMDREGBLEED_bleed_140uA                           (_RAC_PATRIM3_TXTRIMDREGBLEED_bleed_140uA << 0)              /**< Shifted mode bleed_140uA for RAC_PATRIM3    */
#define RAC_PATRIM3_TXTRIMDREGBLEED_bleed_280uA                           (_RAC_PATRIM3_TXTRIMDREGBLEED_bleed_280uA << 0)              /**< Shifted mode bleed_280uA for RAC_PATRIM3    */
#define RAC_PATRIM3_TXTRIMDREGBLEED_bleed_420uA                           (_RAC_PATRIM3_TXTRIMDREGBLEED_bleed_420uA << 0)              /**< Shifted mode bleed_420uA for RAC_PATRIM3    */
#define RAC_PATRIM3_TXTRIMDREGBLEEDAUTO                                   (0x1UL << 2)                                                 /**< TXTRIMDREGBLEEDAUTO                         */
#define _RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_SHIFT                            2                                                            /**< Shift value for RAC_TXTRIMDREGBLEEDAUTO     */
#define _RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_MASK                             0x4UL                                                        /**< Bit mask for RAC_TXTRIMDREGBLEEDAUTO        */
#define _RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_DEFAULT                          0x00000000UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_disable                          0x00000000UL                                                 /**< Mode disable for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_enable                           0x00000001UL                                                 /**< Mode enable for RAC_PATRIM3                 */
#define RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_DEFAULT                           (_RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_DEFAULT << 2)              /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_disable                           (_RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_disable << 2)              /**< Shifted mode disable for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_enable                            (_RAC_PATRIM3_TXTRIMDREGBLEEDAUTO_enable << 2)               /**< Shifted mode enable for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGBLEEDAUTO                                   (0x1UL << 3)                                                 /**< TXTRIMOREGBLEEDAUTO                         */
#define _RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_SHIFT                            3                                                            /**< Shift value for RAC_TXTRIMOREGBLEEDAUTO     */
#define _RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_MASK                             0x8UL                                                        /**< Bit mask for RAC_TXTRIMOREGBLEEDAUTO        */
#define _RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_DEFAULT                          0x00000001UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_disable_bleed_auto               0x00000000UL                                                 /**< Mode disable_bleed_auto for RAC_PATRIM3     */
#define _RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_enable_bleed_auto                0x00000001UL                                                 /**< Mode enable_bleed_auto for RAC_PATRIM3      */
#define RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_DEFAULT                           (_RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_DEFAULT << 3)              /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_disable_bleed_auto                (_RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_disable_bleed_auto << 3)   /**< Shifted mode disable_bleed_auto for RAC_PATRIM3*/
#define RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_enable_bleed_auto                 (_RAC_PATRIM3_TXTRIMOREGBLEEDAUTO_enable_bleed_auto << 3)    /**< Shifted mode enable_bleed_auto for RAC_PATRIM3*/
#define _RAC_PATRIM3_TXTRIMDREGFB_SHIFT                                   4                                                            /**< Shift value for RAC_TXTRIMDREGFB            */
#define _RAC_PATRIM3_TXTRIMDREGFB_MASK                                    0x30UL                                                       /**< Bit mask for RAC_TXTRIMDREGFB               */
#define _RAC_PATRIM3_TXTRIMDREGFB_DEFAULT                                 0x00000002UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMDREGFB_v1p222                                  0x00000000UL                                                 /**< Mode v1p222 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMDREGFB_v1p276                                  0x00000001UL                                                 /**< Mode v1p276 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMDREGFB_v1p346                                  0x00000002UL                                                 /**< Mode v1p346 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMDREGFB_v1p436                                  0x00000003UL                                                 /**< Mode v1p436 for RAC_PATRIM3                 */
#define RAC_PATRIM3_TXTRIMDREGFB_DEFAULT                                  (_RAC_PATRIM3_TXTRIMDREGFB_DEFAULT << 4)                     /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMDREGFB_v1p222                                   (_RAC_PATRIM3_TXTRIMDREGFB_v1p222 << 4)                      /**< Shifted mode v1p222 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREGFB_v1p276                                   (_RAC_PATRIM3_TXTRIMDREGFB_v1p276 << 4)                      /**< Shifted mode v1p276 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREGFB_v1p346                                   (_RAC_PATRIM3_TXTRIMDREGFB_v1p346 << 4)                      /**< Shifted mode v1p346 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREGFB_v1p436                                   (_RAC_PATRIM3_TXTRIMDREGFB_v1p436 << 4)                      /**< Shifted mode v1p436 for RAC_PATRIM3         */
#define _RAC_PATRIM3_TXTRIMOREGFB_SHIFT                                   6                                                            /**< Shift value for RAC_TXTRIMOREGFB            */
#define _RAC_PATRIM3_TXTRIMOREGFB_MASK                                    0x3C0UL                                                      /**< Bit mask for RAC_TXTRIMOREGFB               */
#define _RAC_PATRIM3_TXTRIMOREGFB_DEFAULT                                 0x0000000BUL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMOREGFB_v1p340                                  0x00000000UL                                                 /**< Mode v1p340 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v1p491                                  0x00000001UL                                                 /**< Mode v1p491 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v1p641                                  0x00000002UL                                                 /**< Mode v1p641 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v1p791                                  0x00000003UL                                                 /**< Mode v1p791 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v1p941                                  0x00000004UL                                                 /**< Mode v1p941 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v2p091                                  0x00000005UL                                                 /**< Mode v2p091 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v2p241                                  0x00000006UL                                                 /**< Mode v2p241 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v2p391                                  0x00000007UL                                                 /**< Mode v2p391 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v2p541                                  0x00000008UL                                                 /**< Mode v2p541 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v2p691                                  0x00000009UL                                                 /**< Mode v2p691 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v2p841                                  0x0000000AUL                                                 /**< Mode v2p841 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v2p991                                  0x0000000BUL                                                 /**< Mode v2p991 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREGFB_v3p141                                  0x0000000CUL                                                 /**< Mode v3p141 for RAC_PATRIM3                 */
#define RAC_PATRIM3_TXTRIMOREGFB_DEFAULT                                  (_RAC_PATRIM3_TXTRIMOREGFB_DEFAULT << 6)                     /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMOREGFB_v1p340                                   (_RAC_PATRIM3_TXTRIMOREGFB_v1p340 << 6)                      /**< Shifted mode v1p340 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v1p491                                   (_RAC_PATRIM3_TXTRIMOREGFB_v1p491 << 6)                      /**< Shifted mode v1p491 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v1p641                                   (_RAC_PATRIM3_TXTRIMOREGFB_v1p641 << 6)                      /**< Shifted mode v1p641 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v1p791                                   (_RAC_PATRIM3_TXTRIMOREGFB_v1p791 << 6)                      /**< Shifted mode v1p791 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v1p941                                   (_RAC_PATRIM3_TXTRIMOREGFB_v1p941 << 6)                      /**< Shifted mode v1p941 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v2p091                                   (_RAC_PATRIM3_TXTRIMOREGFB_v2p091 << 6)                      /**< Shifted mode v2p091 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v2p241                                   (_RAC_PATRIM3_TXTRIMOREGFB_v2p241 << 6)                      /**< Shifted mode v2p241 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v2p391                                   (_RAC_PATRIM3_TXTRIMOREGFB_v2p391 << 6)                      /**< Shifted mode v2p391 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v2p541                                   (_RAC_PATRIM3_TXTRIMOREGFB_v2p541 << 6)                      /**< Shifted mode v2p541 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v2p691                                   (_RAC_PATRIM3_TXTRIMOREGFB_v2p691 << 6)                      /**< Shifted mode v2p691 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v2p841                                   (_RAC_PATRIM3_TXTRIMOREGFB_v2p841 << 6)                      /**< Shifted mode v2p841 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v2p991                                   (_RAC_PATRIM3_TXTRIMOREGFB_v2p991 << 6)                      /**< Shifted mode v2p991 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREGFB_v3p141                                   (_RAC_PATRIM3_TXTRIMOREGFB_v3p141 << 6)                      /**< Shifted mode v3p141 for RAC_PATRIM3         */
#define _RAC_PATRIM3_TXTRIMDREG_SHIFT                                     10                                                           /**< Shift value for RAC_TXTRIMDREG              */
#define _RAC_PATRIM3_TXTRIMDREG_MASK                                      0x1C00UL                                                     /**< Bit mask for RAC_TXTRIMDREG                 */
#define _RAC_PATRIM3_TXTRIMDREG_DEFAULT                                   0x00000003UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMDREG_v1p212                                    0x00000000UL                                                 /**< Mode v1p212 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMDREG_v1p257                                    0x00000001UL                                                 /**< Mode v1p257 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMDREG_v1p301                                    0x00000002UL                                                 /**< Mode v1p301 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMDREG_v1p346                                    0x00000003UL                                                 /**< Mode v1p346 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMDREG_v1p391                                    0x00000004UL                                                 /**< Mode v1p391 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMDREG_v1p436                                    0x00000005UL                                                 /**< Mode v1p436 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMDREG_v1p481                                    0x00000006UL                                                 /**< Mode v1p481 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMDREG_v1p526                                    0x00000007UL                                                 /**< Mode v1p526 for RAC_PATRIM3                 */
#define RAC_PATRIM3_TXTRIMDREG_DEFAULT                                    (_RAC_PATRIM3_TXTRIMDREG_DEFAULT << 10)                      /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMDREG_v1p212                                     (_RAC_PATRIM3_TXTRIMDREG_v1p212 << 10)                       /**< Shifted mode v1p212 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREG_v1p257                                     (_RAC_PATRIM3_TXTRIMDREG_v1p257 << 10)                       /**< Shifted mode v1p257 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREG_v1p301                                     (_RAC_PATRIM3_TXTRIMDREG_v1p301 << 10)                       /**< Shifted mode v1p301 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREG_v1p346                                     (_RAC_PATRIM3_TXTRIMDREG_v1p346 << 10)                       /**< Shifted mode v1p346 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREG_v1p391                                     (_RAC_PATRIM3_TXTRIMDREG_v1p391 << 10)                       /**< Shifted mode v1p391 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREG_v1p436                                     (_RAC_PATRIM3_TXTRIMDREG_v1p436 << 10)                       /**< Shifted mode v1p436 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREG_v1p481                                     (_RAC_PATRIM3_TXTRIMDREG_v1p481 << 10)                       /**< Shifted mode v1p481 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREG_v1p526                                     (_RAC_PATRIM3_TXTRIMDREG_v1p526 << 10)                       /**< Shifted mode v1p526 for RAC_PATRIM3         */
#define _RAC_PATRIM3_TXTRIMOREG_SHIFT                                     13                                                           /**< Shift value for RAC_TXTRIMOREG              */
#define _RAC_PATRIM3_TXTRIMOREG_MASK                                      0x1E000UL                                                    /**< Bit mask for RAC_TXTRIMOREG                 */
#define _RAC_PATRIM3_TXTRIMOREG_DEFAULT                                   0x00000008UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMOREG_v1p420                                    0x00000000UL                                                 /**< Mode v1p420 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p448                                    0x00000001UL                                                 /**< Mode v1p448 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p475                                    0x00000002UL                                                 /**< Mode v1p475 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p503                                    0x00000003UL                                                 /**< Mode v1p503 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p531                                    0x00000004UL                                                 /**< Mode v1p531 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p558                                    0x00000005UL                                                 /**< Mode v1p558 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p586                                    0x00000006UL                                                 /**< Mode v1p586 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p613                                    0x00000007UL                                                 /**< Mode v1p613 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p641                                    0x00000008UL                                                 /**< Mode v1p641 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p668                                    0x00000009UL                                                 /**< Mode v1p668 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p696                                    0x0000000AUL                                                 /**< Mode v1p696 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p723                                    0x0000000BUL                                                 /**< Mode v1p723 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p751                                    0x0000000CUL                                                 /**< Mode v1p751 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p778                                    0x0000000DUL                                                 /**< Mode v1p778 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p806                                    0x0000000EUL                                                 /**< Mode v1p806 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMOREG_v1p833                                    0x0000000FUL                                                 /**< Mode v1p833 for RAC_PATRIM3                 */
#define RAC_PATRIM3_TXTRIMOREG_DEFAULT                                    (_RAC_PATRIM3_TXTRIMOREG_DEFAULT << 13)                      /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMOREG_v1p420                                     (_RAC_PATRIM3_TXTRIMOREG_v1p420 << 13)                       /**< Shifted mode v1p420 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p448                                     (_RAC_PATRIM3_TXTRIMOREG_v1p448 << 13)                       /**< Shifted mode v1p448 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p475                                     (_RAC_PATRIM3_TXTRIMOREG_v1p475 << 13)                       /**< Shifted mode v1p475 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p503                                     (_RAC_PATRIM3_TXTRIMOREG_v1p503 << 13)                       /**< Shifted mode v1p503 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p531                                     (_RAC_PATRIM3_TXTRIMOREG_v1p531 << 13)                       /**< Shifted mode v1p531 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p558                                     (_RAC_PATRIM3_TXTRIMOREG_v1p558 << 13)                       /**< Shifted mode v1p558 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p586                                     (_RAC_PATRIM3_TXTRIMOREG_v1p586 << 13)                       /**< Shifted mode v1p586 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p613                                     (_RAC_PATRIM3_TXTRIMOREG_v1p613 << 13)                       /**< Shifted mode v1p613 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p641                                     (_RAC_PATRIM3_TXTRIMOREG_v1p641 << 13)                       /**< Shifted mode v1p641 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p668                                     (_RAC_PATRIM3_TXTRIMOREG_v1p668 << 13)                       /**< Shifted mode v1p668 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p696                                     (_RAC_PATRIM3_TXTRIMOREG_v1p696 << 13)                       /**< Shifted mode v1p696 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p723                                     (_RAC_PATRIM3_TXTRIMOREG_v1p723 << 13)                       /**< Shifted mode v1p723 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p751                                     (_RAC_PATRIM3_TXTRIMOREG_v1p751 << 13)                       /**< Shifted mode v1p751 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p778                                     (_RAC_PATRIM3_TXTRIMOREG_v1p778 << 13)                       /**< Shifted mode v1p778 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p806                                     (_RAC_PATRIM3_TXTRIMOREG_v1p806 << 13)                       /**< Shifted mode v1p806 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMOREG_v1p833                                     (_RAC_PATRIM3_TXTRIMOREG_v1p833 << 13)                       /**< Shifted mode v1p833 for RAC_PATRIM3         */
#define _RAC_PATRIM3_TXTRIMRREG_SHIFT                                     17                                                           /**< Shift value for RAC_TXTRIMRREG              */
#define _RAC_PATRIM3_TXTRIMRREG_MASK                                      0x1E0000UL                                                   /**< Bit mask for RAC_TXTRIMRREG                 */
#define _RAC_PATRIM3_TXTRIMRREG_DEFAULT                                   0x00000007UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMRREG_v1p354                                    0x00000000UL                                                 /**< Mode v1p354 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p380                                    0x00000001UL                                                 /**< Mode v1p380 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p406                                    0x00000002UL                                                 /**< Mode v1p406 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p432                                    0x00000003UL                                                 /**< Mode v1p432 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p458                                    0x00000004UL                                                 /**< Mode v1p458 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p484                                    0x00000005UL                                                 /**< Mode v1p484 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p510                                    0x00000006UL                                                 /**< Mode v1p510 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p536                                    0x00000007UL                                                 /**< Mode v1p536 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p562                                    0x00000008UL                                                 /**< Mode v1p562 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p588                                    0x00000009UL                                                 /**< Mode v1p588 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p614                                    0x0000000AUL                                                 /**< Mode v1p614 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p640                                    0x0000000BUL                                                 /**< Mode v1p640 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p666                                    0x0000000CUL                                                 /**< Mode v1p666 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p692                                    0x0000000DUL                                                 /**< Mode v1p692 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p707                                    0x0000000EUL                                                 /**< Mode v1p707 for RAC_PATRIM3                 */
#define _RAC_PATRIM3_TXTRIMRREG_v1p708                                    0x0000000FUL                                                 /**< Mode v1p708 for RAC_PATRIM3                 */
#define RAC_PATRIM3_TXTRIMRREG_DEFAULT                                    (_RAC_PATRIM3_TXTRIMRREG_DEFAULT << 17)                      /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMRREG_v1p354                                     (_RAC_PATRIM3_TXTRIMRREG_v1p354 << 17)                       /**< Shifted mode v1p354 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p380                                     (_RAC_PATRIM3_TXTRIMRREG_v1p380 << 17)                       /**< Shifted mode v1p380 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p406                                     (_RAC_PATRIM3_TXTRIMRREG_v1p406 << 17)                       /**< Shifted mode v1p406 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p432                                     (_RAC_PATRIM3_TXTRIMRREG_v1p432 << 17)                       /**< Shifted mode v1p432 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p458                                     (_RAC_PATRIM3_TXTRIMRREG_v1p458 << 17)                       /**< Shifted mode v1p458 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p484                                     (_RAC_PATRIM3_TXTRIMRREG_v1p484 << 17)                       /**< Shifted mode v1p484 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p510                                     (_RAC_PATRIM3_TXTRIMRREG_v1p510 << 17)                       /**< Shifted mode v1p510 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p536                                     (_RAC_PATRIM3_TXTRIMRREG_v1p536 << 17)                       /**< Shifted mode v1p536 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p562                                     (_RAC_PATRIM3_TXTRIMRREG_v1p562 << 17)                       /**< Shifted mode v1p562 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p588                                     (_RAC_PATRIM3_TXTRIMRREG_v1p588 << 17)                       /**< Shifted mode v1p588 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p614                                     (_RAC_PATRIM3_TXTRIMRREG_v1p614 << 17)                       /**< Shifted mode v1p614 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p640                                     (_RAC_PATRIM3_TXTRIMRREG_v1p640 << 17)                       /**< Shifted mode v1p640 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p666                                     (_RAC_PATRIM3_TXTRIMRREG_v1p666 << 17)                       /**< Shifted mode v1p666 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p692                                     (_RAC_PATRIM3_TXTRIMRREG_v1p692 << 17)                       /**< Shifted mode v1p692 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p707                                     (_RAC_PATRIM3_TXTRIMRREG_v1p707 << 17)                       /**< Shifted mode v1p707 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMRREG_v1p708                                     (_RAC_PATRIM3_TXTRIMRREG_v1p708 << 17)                       /**< Shifted mode v1p708 for RAC_PATRIM3         */
#define RAC_PATRIM3_TXTRIMDREGPSR                                         (0x1UL << 21)                                                /**< TXTRIMDREGPSR                               */
#define _RAC_PATRIM3_TXTRIMDREGPSR_SHIFT                                  21                                                           /**< Shift value for RAC_TXTRIMDREGPSR           */
#define _RAC_PATRIM3_TXTRIMDREGPSR_MASK                                   0x200000UL                                                   /**< Bit mask for RAC_TXTRIMDREGPSR              */
#define _RAC_PATRIM3_TXTRIMDREGPSR_DEFAULT                                0x00000000UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMDREGPSR_disable_psrr_boost                     0x00000000UL                                                 /**< Mode disable_psrr_boost for RAC_PATRIM3     */
#define _RAC_PATRIM3_TXTRIMDREGPSR_enable_psrr_boost                      0x00000001UL                                                 /**< Mode enable_psrr_boost for RAC_PATRIM3      */
#define RAC_PATRIM3_TXTRIMDREGPSR_DEFAULT                                 (_RAC_PATRIM3_TXTRIMDREGPSR_DEFAULT << 21)                   /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMDREGPSR_disable_psrr_boost                      (_RAC_PATRIM3_TXTRIMDREGPSR_disable_psrr_boost << 21)        /**< Shifted mode disable_psrr_boost for RAC_PATRIM3*/
#define RAC_PATRIM3_TXTRIMDREGPSR_enable_psrr_boost                       (_RAC_PATRIM3_TXTRIMDREGPSR_enable_psrr_boost << 21)         /**< Shifted mode enable_psrr_boost for RAC_PATRIM3*/
#define RAC_PATRIM3_TXTRIMOREGPSR                                         (0x1UL << 22)                                                /**< TXTRIMOREGPSR                               */
#define _RAC_PATRIM3_TXTRIMOREGPSR_SHIFT                                  22                                                           /**< Shift value for RAC_TXTRIMOREGPSR           */
#define _RAC_PATRIM3_TXTRIMOREGPSR_MASK                                   0x400000UL                                                   /**< Bit mask for RAC_TXTRIMOREGPSR              */
#define _RAC_PATRIM3_TXTRIMOREGPSR_DEFAULT                                0x00000000UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMOREGPSR_disable_psrr_cancellation              0x00000000UL                                                 /**< Mode disable_psrr_cancellation for RAC_PATRIM3*/
#define _RAC_PATRIM3_TXTRIMOREGPSR_enable_psrr_cancellation               0x00000001UL                                                 /**< Mode enable_psrr_cancellation for RAC_PATRIM3*/
#define RAC_PATRIM3_TXTRIMOREGPSR_DEFAULT                                 (_RAC_PATRIM3_TXTRIMOREGPSR_DEFAULT << 22)                   /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMOREGPSR_disable_psrr_cancellation               (_RAC_PATRIM3_TXTRIMOREGPSR_disable_psrr_cancellation << 22) /**< Shifted mode disable_psrr_cancellation for RAC_PATRIM3*/
#define RAC_PATRIM3_TXTRIMOREGPSR_enable_psrr_cancellation                (_RAC_PATRIM3_TXTRIMOREGPSR_enable_psrr_cancellation << 22)  /**< Shifted mode enable_psrr_cancellation for RAC_PATRIM3*/
#define _RAC_PATRIM3_TXTRIMDREGSLICES_SHIFT                               23                                                           /**< Shift value for RAC_TXTRIMDREGSLICES        */
#define _RAC_PATRIM3_TXTRIMDREGSLICES_MASK                                0x1800000UL                                                  /**< Bit mask for RAC_TXTRIMDREGSLICES           */
#define _RAC_PATRIM3_TXTRIMDREGSLICES_DEFAULT                             0x00000001UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMDREGSLICES_slice_1x                            0x00000000UL                                                 /**< Mode slice_1x for RAC_PATRIM3               */
#define _RAC_PATRIM3_TXTRIMDREGSLICES_slice_2x                            0x00000001UL                                                 /**< Mode slice_2x for RAC_PATRIM3               */
#define _RAC_PATRIM3_TXTRIMDREGSLICES_slice_3x                            0x00000002UL                                                 /**< Mode slice_3x for RAC_PATRIM3               */
#define _RAC_PATRIM3_TXTRIMDREGSLICES_slice_4x                            0x00000003UL                                                 /**< Mode slice_4x for RAC_PATRIM3               */
#define RAC_PATRIM3_TXTRIMDREGSLICES_DEFAULT                              (_RAC_PATRIM3_TXTRIMDREGSLICES_DEFAULT << 23)                /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMDREGSLICES_slice_1x                             (_RAC_PATRIM3_TXTRIMDREGSLICES_slice_1x << 23)               /**< Shifted mode slice_1x for RAC_PATRIM3       */
#define RAC_PATRIM3_TXTRIMDREGSLICES_slice_2x                             (_RAC_PATRIM3_TXTRIMDREGSLICES_slice_2x << 23)               /**< Shifted mode slice_2x for RAC_PATRIM3       */
#define RAC_PATRIM3_TXTRIMDREGSLICES_slice_3x                             (_RAC_PATRIM3_TXTRIMDREGSLICES_slice_3x << 23)               /**< Shifted mode slice_3x for RAC_PATRIM3       */
#define RAC_PATRIM3_TXTRIMDREGSLICES_slice_4x                             (_RAC_PATRIM3_TXTRIMDREGSLICES_slice_4x << 23)               /**< Shifted mode slice_4x for RAC_PATRIM3       */
#define _RAC_PATRIM3_TXTRIMOREGSLICES_SHIFT                               25                                                           /**< Shift value for RAC_TXTRIMOREGSLICES        */
#define _RAC_PATRIM3_TXTRIMOREGSLICES_MASK                                0x6000000UL                                                  /**< Bit mask for RAC_TXTRIMOREGSLICES           */
#define _RAC_PATRIM3_TXTRIMOREGSLICES_DEFAULT                             0x00000000UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMOREGSLICES_enable_oreg                         0x00000000UL                                                 /**< Mode enable_oreg for RAC_PATRIM3            */
#define _RAC_PATRIM3_TXTRIMOREGSLICES_not_valid1                          0x00000001UL                                                 /**< Mode not_valid1 for RAC_PATRIM3             */
#define _RAC_PATRIM3_TXTRIMOREGSLICES_not_valid2                          0x00000002UL                                                 /**< Mode not_valid2 for RAC_PATRIM3             */
#define _RAC_PATRIM3_TXTRIMOREGSLICES_not_valid3                          0x00000003UL                                                 /**< Mode not_valid3 for RAC_PATRIM3             */
#define RAC_PATRIM3_TXTRIMOREGSLICES_DEFAULT                              (_RAC_PATRIM3_TXTRIMOREGSLICES_DEFAULT << 25)                /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMOREGSLICES_enable_oreg                          (_RAC_PATRIM3_TXTRIMOREGSLICES_enable_oreg << 25)            /**< Shifted mode enable_oreg for RAC_PATRIM3    */
#define RAC_PATRIM3_TXTRIMOREGSLICES_not_valid1                           (_RAC_PATRIM3_TXTRIMOREGSLICES_not_valid1 << 25)             /**< Shifted mode not_valid1 for RAC_PATRIM3     */
#define RAC_PATRIM3_TXTRIMOREGSLICES_not_valid2                           (_RAC_PATRIM3_TXTRIMOREGSLICES_not_valid2 << 25)             /**< Shifted mode not_valid2 for RAC_PATRIM3     */
#define RAC_PATRIM3_TXTRIMOREGSLICES_not_valid3                           (_RAC_PATRIM3_TXTRIMOREGSLICES_not_valid3 << 25)             /**< Shifted mode not_valid3 for RAC_PATRIM3     */
#define RAC_PATRIM3_TXTRIMDREGMOREBW                                      (0x1UL << 27)                                                /**< TXTRIMDREGMOREBW                            */
#define _RAC_PATRIM3_TXTRIMDREGMOREBW_SHIFT                               27                                                           /**< Shift value for RAC_TXTRIMDREGMOREBW        */
#define _RAC_PATRIM3_TXTRIMDREGMOREBW_MASK                                0x8000000UL                                                  /**< Bit mask for RAC_TXTRIMDREGMOREBW           */
#define _RAC_PATRIM3_TXTRIMDREGMOREBW_DEFAULT                             0x00000000UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMDREGMOREBW_disable_extra_bw                    0x00000000UL                                                 /**< Mode disable_extra_bw for RAC_PATRIM3       */
#define _RAC_PATRIM3_TXTRIMDREGMOREBW_enable_extra_bw                     0x00000001UL                                                 /**< Mode enable_extra_bw for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMDREGMOREBW_DEFAULT                              (_RAC_PATRIM3_TXTRIMDREGMOREBW_DEFAULT << 27)                /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMDREGMOREBW_disable_extra_bw                     (_RAC_PATRIM3_TXTRIMDREGMOREBW_disable_extra_bw << 27)       /**< Shifted mode disable_extra_bw for RAC_PATRIM3*/
#define RAC_PATRIM3_TXTRIMDREGMOREBW_enable_extra_bw                      (_RAC_PATRIM3_TXTRIMDREGMOREBW_enable_extra_bw << 27)        /**< Shifted mode enable_extra_bw for RAC_PATRIM3*/
#define RAC_PATRIM3_TXTRIMOREGMOREBW                                      (0x1UL << 28)                                                /**< TXTRIMOREGMOREBW                            */
#define _RAC_PATRIM3_TXTRIMOREGMOREBW_SHIFT                               28                                                           /**< Shift value for RAC_TXTRIMOREGMOREBW        */
#define _RAC_PATRIM3_TXTRIMOREGMOREBW_MASK                                0x10000000UL                                                 /**< Bit mask for RAC_TXTRIMOREGMOREBW           */
#define _RAC_PATRIM3_TXTRIMOREGMOREBW_DEFAULT                             0x00000000UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMOREGMOREBW_disable                             0x00000000UL                                                 /**< Mode disable for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMOREGMOREBW_enable                              0x00000001UL                                                 /**< Mode enable for RAC_PATRIM3                 */
#define RAC_PATRIM3_TXTRIMOREGMOREBW_DEFAULT                              (_RAC_PATRIM3_TXTRIMOREGMOREBW_DEFAULT << 28)                /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMOREGMOREBW_disable                              (_RAC_PATRIM3_TXTRIMOREGMOREBW_disable << 28)                /**< Shifted mode disable for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMOREGMOREBW_enable                               (_RAC_PATRIM3_TXTRIMOREGMOREBW_enable << 28)                 /**< Shifted mode enable for RAC_PATRIM3         */
#define _RAC_PATRIM3_TXTRIMRREGCN_SHIFT                                   29                                                           /**< Shift value for RAC_TXTRIMRREGCN            */
#define _RAC_PATRIM3_TXTRIMRREGCN_MASK                                    0x60000000UL                                                 /**< Bit mask for RAC_TXTRIMRREGCN               */
#define _RAC_PATRIM3_TXTRIMRREGCN_DEFAULT                                 0x00000000UL                                                 /**< Mode DEFAULT for RAC_PATRIM3                */
#define _RAC_PATRIM3_TXTRIMRREGCN_lessthan2v                              0x00000000UL                                                 /**< Mode lessthan2v for RAC_PATRIM3             */
#define _RAC_PATRIM3_TXTRIMRREGCN_lessthan2p8                             0x00000001UL                                                 /**< Mode lessthan2p8 for RAC_PATRIM3            */
#define _RAC_PATRIM3_TXTRIMRREGCN_lessthan3v                              0x00000002UL                                                 /**< Mode lessthan3v for RAC_PATRIM3             */
#define _RAC_PATRIM3_TXTRIMRREGCN_lessthan3p6                             0x00000003UL                                                 /**< Mode lessthan3p6 for RAC_PATRIM3            */
#define RAC_PATRIM3_TXTRIMRREGCN_DEFAULT                                  (_RAC_PATRIM3_TXTRIMRREGCN_DEFAULT << 29)                    /**< Shifted mode DEFAULT for RAC_PATRIM3        */
#define RAC_PATRIM3_TXTRIMRREGCN_lessthan2v                               (_RAC_PATRIM3_TXTRIMRREGCN_lessthan2v << 29)                 /**< Shifted mode lessthan2v for RAC_PATRIM3     */
#define RAC_PATRIM3_TXTRIMRREGCN_lessthan2p8                              (_RAC_PATRIM3_TXTRIMRREGCN_lessthan2p8 << 29)                /**< Shifted mode lessthan2p8 for RAC_PATRIM3    */
#define RAC_PATRIM3_TXTRIMRREGCN_lessthan3v                               (_RAC_PATRIM3_TXTRIMRREGCN_lessthan3v << 29)                 /**< Shifted mode lessthan3v for RAC_PATRIM3     */
#define RAC_PATRIM3_TXTRIMRREGCN_lessthan3p6                              (_RAC_PATRIM3_TXTRIMRREGCN_lessthan3p6 << 29)                /**< Shifted mode lessthan3p6 for RAC_PATRIM3    */

/* Bit fields for RAC PATRIM4 */
#define _RAC_PATRIM4_RESETVALUE                                           0x00FA0075UL                                           /**< Default value for RAC_PATRIM4               */
#define _RAC_PATRIM4_MASK                                                 0x00FFFFFFUL                                           /**< Mask for RAC_PATRIM4                        */
#define _RAC_PATRIM4_TXTRIMXPAVNBDRV_SHIFT                                0                                                      /**< Shift value for RAC_TXTRIMXPAVNBDRV         */
#define _RAC_PATRIM4_TXTRIMXPAVNBDRV_MASK                                 0x3UL                                                  /**< Bit mask for RAC_TXTRIMXPAVNBDRV            */
#define _RAC_PATRIM4_TXTRIMXPAVNBDRV_DEFAULT                              0x00000001UL                                           /**< Mode DEFAULT for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p60                        0x00000000UL                                           /**< Mode vnb_plus_0p60 for RAC_PATRIM4          */
#define _RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p65                        0x00000001UL                                           /**< Mode vnb_plus_0p65 for RAC_PATRIM4          */
#define _RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p70                        0x00000002UL                                           /**< Mode vnb_plus_0p70 for RAC_PATRIM4          */
#define _RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p75                        0x00000003UL                                           /**< Mode vnb_plus_0p75 for RAC_PATRIM4          */
#define RAC_PATRIM4_TXTRIMXPAVNBDRV_DEFAULT                               (_RAC_PATRIM4_TXTRIMXPAVNBDRV_DEFAULT << 0)            /**< Shifted mode DEFAULT for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p60                         (_RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p60 << 0)      /**< Shifted mode vnb_plus_0p60 for RAC_PATRIM4  */
#define RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p65                         (_RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p65 << 0)      /**< Shifted mode vnb_plus_0p65 for RAC_PATRIM4  */
#define RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p70                         (_RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p70 << 0)      /**< Shifted mode vnb_plus_0p70 for RAC_PATRIM4  */
#define RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p75                         (_RAC_PATRIM4_TXTRIMXPAVNBDRV_vnb_plus_0p75 << 0)      /**< Shifted mode vnb_plus_0p75 for RAC_PATRIM4  */
#define _RAC_PATRIM4_TXTRIMXPAVPBDRV_SHIFT                                2                                                      /**< Shift value for RAC_TXTRIMXPAVPBDRV         */
#define _RAC_PATRIM4_TXTRIMXPAVPBDRV_MASK                                 0xCUL                                                  /**< Bit mask for RAC_TXTRIMXPAVPBDRV            */
#define _RAC_PATRIM4_TXTRIMXPAVPBDRV_DEFAULT                              0x00000001UL                                           /**< Mode DEFAULT for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p60                        0x00000000UL                                           /**< Mode vpb_plus_0p60 for RAC_PATRIM4          */
#define _RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p65                        0x00000001UL                                           /**< Mode vpb_plus_0p65 for RAC_PATRIM4          */
#define _RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p70                        0x00000002UL                                           /**< Mode vpb_plus_0p70 for RAC_PATRIM4          */
#define _RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p75                        0x00000003UL                                           /**< Mode vpb_plus_0p75 for RAC_PATRIM4          */
#define RAC_PATRIM4_TXTRIMXPAVPBDRV_DEFAULT                               (_RAC_PATRIM4_TXTRIMXPAVPBDRV_DEFAULT << 2)            /**< Shifted mode DEFAULT for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p60                         (_RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p60 << 2)      /**< Shifted mode vpb_plus_0p60 for RAC_PATRIM4  */
#define RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p65                         (_RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p65 << 2)      /**< Shifted mode vpb_plus_0p65 for RAC_PATRIM4  */
#define RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p70                         (_RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p70 << 2)      /**< Shifted mode vpb_plus_0p70 for RAC_PATRIM4  */
#define RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p75                         (_RAC_PATRIM4_TXTRIMXPAVPBDRV_vpb_plus_0p75 << 2)      /**< Shifted mode vpb_plus_0p75 for RAC_PATRIM4  */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_SHIFT                            4                                                      /**< Shift value for RAC_TXTRIMXPAVXSCURRENT     */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_MASK                             0xF0UL                                                 /**< Bit mask for RAC_TXTRIMXPAVXSCURRENT        */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_DEFAULT                          0x00000007UL                                           /**< Mode DEFAULT for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p75db                          0x00000000UL                                           /**< Mode m1p75db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p50db                          0x00000001UL                                           /**< Mode m1p50db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p25db                          0x00000002UL                                           /**< Mode m1p25db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p00db                          0x00000003UL                                           /**< Mode m1p00db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m0p75db                          0x00000004UL                                           /**< Mode m0p75db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m0p50db                          0x00000005UL                                           /**< Mode m0p50db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m0p25db                          0x00000006UL                                           /**< Mode m0p25db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p00db                            0x00000007UL                                           /**< Mode p00db for RAC_PATRIM4                  */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p0p25db                          0x00000008UL                                           /**< Mode p0p25db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p0p50db                          0x00000009UL                                           /**< Mode p0p50db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p0p75db                          0x0000000AUL                                           /**< Mode p0p75db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p00db                          0x0000000BUL                                           /**< Mode p1p00db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p25db                          0x0000000CUL                                           /**< Mode p1p25db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p50db                          0x0000000DUL                                           /**< Mode p1p50db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p75db                          0x0000000EUL                                           /**< Mode p1p75db for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p2p00db                          0x0000000FUL                                           /**< Mode p2p00db for RAC_PATRIM4                */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_DEFAULT                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_DEFAULT << 4)        /**< Shifted mode DEFAULT for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p75db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p75db << 4)        /**< Shifted mode m1p75db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p50db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p50db << 4)        /**< Shifted mode m1p50db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p25db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p25db << 4)        /**< Shifted mode m1p25db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p00db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m1p00db << 4)        /**< Shifted mode m1p00db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m0p75db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m0p75db << 4)        /**< Shifted mode m0p75db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m0p50db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m0p50db << 4)        /**< Shifted mode m0p50db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m0p25db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_m0p25db << 4)        /**< Shifted mode m0p25db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p00db                             (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p00db << 4)          /**< Shifted mode p00db for RAC_PATRIM4          */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p0p25db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p0p25db << 4)        /**< Shifted mode p0p25db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p0p50db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p0p50db << 4)        /**< Shifted mode p0p50db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p0p75db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p0p75db << 4)        /**< Shifted mode p0p75db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p00db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p00db << 4)        /**< Shifted mode p1p00db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p25db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p25db << 4)        /**< Shifted mode p1p25db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p50db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p50db << 4)        /**< Shifted mode p1p50db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p75db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p1p75db << 4)        /**< Shifted mode p1p75db for RAC_PATRIM4        */
#define RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p2p00db                           (_RAC_PATRIM4_TXTRIMXPAVXSCURRENT_p2p00db << 4)        /**< Shifted mode p2p00db for RAC_PATRIM4        */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_SHIFT                          8                                                      /**< Shift value for RAC_TXXPAVXSCURRENTCOARSE   */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_MASK                           0x1F00UL                                               /**< Bit mask for RAC_TXXPAVXSCURRENTCOARSE      */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_DEFAULT                        0x00000000UL                                           /**< Mode DEFAULT for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep01x                         0x00000000UL                                           /**< Mode rep01x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep02x                         0x00000001UL                                           /**< Mode rep02x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep03x                         0x00000002UL                                           /**< Mode rep03x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep04x                         0x00000003UL                                           /**< Mode rep04x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep05x                         0x00000004UL                                           /**< Mode rep05x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep06x                         0x00000005UL                                           /**< Mode rep06x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep07x                         0x00000006UL                                           /**< Mode rep07x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep08x                         0x00000007UL                                           /**< Mode rep08x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep09x                         0x00000008UL                                           /**< Mode rep09x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep10x                         0x00000009UL                                           /**< Mode rep10x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep11x                         0x0000000AUL                                           /**< Mode rep11x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep12x                         0x0000000BUL                                           /**< Mode rep12x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep13x                         0x0000000CUL                                           /**< Mode rep13x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep14x                         0x0000000DUL                                           /**< Mode rep14x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep15x                         0x0000000EUL                                           /**< Mode rep15x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep16x                         0x0000000FUL                                           /**< Mode rep16x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep17x                         0x00000010UL                                           /**< Mode rep17x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep18x                         0x00000011UL                                           /**< Mode rep18x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep19x                         0x00000012UL                                           /**< Mode rep19x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep20x                         0x00000013UL                                           /**< Mode rep20x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep21x                         0x00000014UL                                           /**< Mode rep21x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep22x                         0x00000015UL                                           /**< Mode rep22x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep23x                         0x00000016UL                                           /**< Mode rep23x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep24x                         0x00000017UL                                           /**< Mode rep24x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep25x                         0x00000018UL                                           /**< Mode rep25x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep26x                         0x00000019UL                                           /**< Mode rep26x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep27x                         0x0000001AUL                                           /**< Mode rep27x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep28x                         0x0000001BUL                                           /**< Mode rep28x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep29x                         0x0000001CUL                                           /**< Mode rep29x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep30x                         0x0000001DUL                                           /**< Mode rep30x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep31x                         0x0000001EUL                                           /**< Mode rep31x for RAC_PATRIM4                 */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep32x                         0x0000001FUL                                           /**< Mode rep32x for RAC_PATRIM4                 */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_DEFAULT                         (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_DEFAULT << 8)      /**< Shifted mode DEFAULT for RAC_PATRIM4        */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep01x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep01x << 8)       /**< Shifted mode rep01x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep02x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep02x << 8)       /**< Shifted mode rep02x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep03x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep03x << 8)       /**< Shifted mode rep03x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep04x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep04x << 8)       /**< Shifted mode rep04x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep05x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep05x << 8)       /**< Shifted mode rep05x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep06x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep06x << 8)       /**< Shifted mode rep06x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep07x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep07x << 8)       /**< Shifted mode rep07x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep08x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep08x << 8)       /**< Shifted mode rep08x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep09x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep09x << 8)       /**< Shifted mode rep09x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep10x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep10x << 8)       /**< Shifted mode rep10x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep11x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep11x << 8)       /**< Shifted mode rep11x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep12x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep12x << 8)       /**< Shifted mode rep12x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep13x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep13x << 8)       /**< Shifted mode rep13x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep14x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep14x << 8)       /**< Shifted mode rep14x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep15x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep15x << 8)       /**< Shifted mode rep15x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep16x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep16x << 8)       /**< Shifted mode rep16x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep17x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep17x << 8)       /**< Shifted mode rep17x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep18x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep18x << 8)       /**< Shifted mode rep18x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep19x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep19x << 8)       /**< Shifted mode rep19x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep20x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep20x << 8)       /**< Shifted mode rep20x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep21x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep21x << 8)       /**< Shifted mode rep21x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep22x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep22x << 8)       /**< Shifted mode rep22x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep23x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep23x << 8)       /**< Shifted mode rep23x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep24x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep24x << 8)       /**< Shifted mode rep24x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep25x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep25x << 8)       /**< Shifted mode rep25x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep26x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep26x << 8)       /**< Shifted mode rep26x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep27x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep27x << 8)       /**< Shifted mode rep27x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep28x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep28x << 8)       /**< Shifted mode rep28x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep29x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep29x << 8)       /**< Shifted mode rep29x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep30x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep30x << 8)       /**< Shifted mode rep30x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep31x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep31x << 8)       /**< Shifted mode rep31x for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep32x                          (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSE_rep32x << 8)       /**< Shifted mode rep32x for RAC_PATRIM4         */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_SHIFT                       13                                                     /**< Shift value for RAC_TXXPAVXSCURRENTCOARSEMIN*/
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_MASK                        0x6000UL                                               /**< Bit mask for RAC_TXXPAVXSCURRENTCOARSEMIN   */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_DEFAULT                     0x00000000UL                                           /**< Mode DEFAULT for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin20u                     0x00000000UL                                           /**< Mode imin20u for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin10u                     0x00000001UL                                           /**< Mode imin10u for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin05u                     0x00000002UL                                           /**< Mode imin05u for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin2p5u                    0x00000003UL                                           /**< Mode imin2p5u for RAC_PATRIM4               */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_DEFAULT                      (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_DEFAULT << 13)  /**< Shifted mode DEFAULT for RAC_PATRIM4        */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin20u                      (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin20u << 13)  /**< Shifted mode imin20u for RAC_PATRIM4        */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin10u                      (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin10u << 13)  /**< Shifted mode imin10u for RAC_PATRIM4        */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin05u                      (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin05u << 13)  /**< Shifted mode imin05u for RAC_PATRIM4        */
#define RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin2p5u                     (_RAC_PATRIM4_TXXPAVXSCURRENTCOARSEMIN_imin2p5u << 13) /**< Shifted mode imin2p5u for RAC_PATRIM4       */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_SHIFT                            15                                                     /**< Shift value for RAC_TXXPAVXSCURRENTFINE     */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_MASK                             0x78000UL                                              /**< Bit mask for RAC_TXXPAVXSCURRENTFINE        */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_DEFAULT                          0x00000004UL                                           /**< Mode DEFAULT for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax200u                         0x00000000UL                                           /**< Mode imax200u for RAC_PATRIM4               */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax245u                         0x00000001UL                                           /**< Mode imax245u for RAC_PATRIM4               */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax293u                         0x00000002UL                                           /**< Mode imax293u for RAC_PATRIM4               */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax360u                         0x00000003UL                                           /**< Mode imax360u for RAC_PATRIM4               */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax400u                         0x00000004UL                                           /**< Mode imax400u for RAC_PATRIM4               */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax800u                         0x00000005UL                                           /**< Mode imax800u for RAC_PATRIM4               */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax1200u                        0x00000006UL                                           /**< Mode imax1200u for RAC_PATRIM4              */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax1600u                        0x00000007UL                                           /**< Mode imax1600u for RAC_PATRIM4              */
#define _RAC_PATRIM4_TXXPAVXSCURRENTFINE_classd                           0x00000008UL                                           /**< Mode classd for RAC_PATRIM4                 */
#define RAC_PATRIM4_TXXPAVXSCURRENTFINE_DEFAULT                           (_RAC_PATRIM4_TXXPAVXSCURRENTFINE_DEFAULT << 15)       /**< Shifted mode DEFAULT for RAC_PATRIM4        */
#define RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax200u                          (_RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax200u << 15)      /**< Shifted mode imax200u for RAC_PATRIM4       */
#define RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax245u                          (_RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax245u << 15)      /**< Shifted mode imax245u for RAC_PATRIM4       */
#define RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax293u                          (_RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax293u << 15)      /**< Shifted mode imax293u for RAC_PATRIM4       */
#define RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax360u                          (_RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax360u << 15)      /**< Shifted mode imax360u for RAC_PATRIM4       */
#define RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax400u                          (_RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax400u << 15)      /**< Shifted mode imax400u for RAC_PATRIM4       */
#define RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax800u                          (_RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax800u << 15)      /**< Shifted mode imax800u for RAC_PATRIM4       */
#define RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax1200u                         (_RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax1200u << 15)     /**< Shifted mode imax1200u for RAC_PATRIM4      */
#define RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax1600u                         (_RAC_PATRIM4_TXXPAVXSCURRENTFINE_imax1600u << 15)     /**< Shifted mode imax1600u for RAC_PATRIM4      */
#define RAC_PATRIM4_TXXPAVXSCURRENTFINE_classd                            (_RAC_PATRIM4_TXXPAVXSCURRENTFINE_classd << 15)        /**< Shifted mode classd for RAC_PATRIM4         */
#define RAC_PATRIM4_TXXPAVXSCURRENTSELHPA                                 (0x1UL << 19)                                          /**< TXXPAVXSCURRENTSELHPA                       */
#define _RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_SHIFT                          19                                                     /**< Shift value for RAC_TXXPAVXSCURRENTSELHPA   */
#define _RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_MASK                           0x80000UL                                              /**< Bit mask for RAC_TXXPAVXSCURRENTSELHPA      */
#define _RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_DEFAULT                        0x00000001UL                                           /**< Mode DEFAULT for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_lpa                            0x00000000UL                                           /**< Mode lpa for RAC_PATRIM4                    */
#define _RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_hpa                            0x00000001UL                                           /**< Mode hpa for RAC_PATRIM4                    */
#define RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_DEFAULT                         (_RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_DEFAULT << 19)     /**< Shifted mode DEFAULT for RAC_PATRIM4        */
#define RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_lpa                             (_RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_lpa << 19)         /**< Shifted mode lpa for RAC_PATRIM4            */
#define RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_hpa                             (_RAC_PATRIM4_TXXPAVXSCURRENTSELHPA_hpa << 19)         /**< Shifted mode hpa for RAC_PATRIM4            */
#define _RAC_PATRIM4_TXVXSCURRENTVREFN_SHIFT                              20                                                     /**< Shift value for RAC_TXVXSCURRENTVREFN       */
#define _RAC_PATRIM4_TXVXSCURRENTVREFN_MASK                               0x300000UL                                             /**< Bit mask for RAC_TXVXSCURRENTVREFN          */
#define _RAC_PATRIM4_TXVXSCURRENTVREFN_DEFAULT                            0x00000003UL                                           /**< Mode DEFAULT for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXVXSCURRENTVREFN_ognd0p825                          0x00000000UL                                           /**< Mode ognd0p825 for RAC_PATRIM4              */
#define _RAC_PATRIM4_TXVXSCURRENTVREFN_ognd1p075                          0x00000001UL                                           /**< Mode ognd1p075 for RAC_PATRIM4              */
#define _RAC_PATRIM4_TXVXSCURRENTVREFN_ognd1p325                          0x00000002UL                                           /**< Mode ognd1p325 for RAC_PATRIM4              */
#define _RAC_PATRIM4_TXVXSCURRENTVREFN_ognd1p575                          0x00000003UL                                           /**< Mode ognd1p575 for RAC_PATRIM4              */
#define RAC_PATRIM4_TXVXSCURRENTVREFN_DEFAULT                             (_RAC_PATRIM4_TXVXSCURRENTVREFN_DEFAULT << 20)         /**< Shifted mode DEFAULT for RAC_PATRIM4        */
#define RAC_PATRIM4_TXVXSCURRENTVREFN_ognd0p825                           (_RAC_PATRIM4_TXVXSCURRENTVREFN_ognd0p825 << 20)       /**< Shifted mode ognd0p825 for RAC_PATRIM4      */
#define RAC_PATRIM4_TXVXSCURRENTVREFN_ognd1p075                           (_RAC_PATRIM4_TXVXSCURRENTVREFN_ognd1p075 << 20)       /**< Shifted mode ognd1p075 for RAC_PATRIM4      */
#define RAC_PATRIM4_TXVXSCURRENTVREFN_ognd1p325                           (_RAC_PATRIM4_TXVXSCURRENTVREFN_ognd1p325 << 20)       /**< Shifted mode ognd1p325 for RAC_PATRIM4      */
#define RAC_PATRIM4_TXVXSCURRENTVREFN_ognd1p575                           (_RAC_PATRIM4_TXVXSCURRENTVREFN_ognd1p575 << 20)       /**< Shifted mode ognd1p575 for RAC_PATRIM4      */
#define _RAC_PATRIM4_TXVXSCURRENTVREFP_SHIFT                              22                                                     /**< Shift value for RAC_TXVXSCURRENTVREFP       */
#define _RAC_PATRIM4_TXVXSCURRENTVREFP_MASK                               0xC00000UL                                             /**< Bit mask for RAC_TXVXSCURRENTVREFP          */
#define _RAC_PATRIM4_TXVXSCURRENTVREFP_DEFAULT                            0x00000003UL                                           /**< Mode DEFAULT for RAC_PATRIM4                */
#define _RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd0p825                          0x00000000UL                                           /**< Mode ovdd0p825 for RAC_PATRIM4              */
#define _RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd1p075                          0x00000001UL                                           /**< Mode ovdd1p075 for RAC_PATRIM4              */
#define _RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd1p325                          0x00000002UL                                           /**< Mode ovdd1p325 for RAC_PATRIM4              */
#define _RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd1p575                          0x00000003UL                                           /**< Mode ovdd1p575 for RAC_PATRIM4              */
#define RAC_PATRIM4_TXVXSCURRENTVREFP_DEFAULT                             (_RAC_PATRIM4_TXVXSCURRENTVREFP_DEFAULT << 22)         /**< Shifted mode DEFAULT for RAC_PATRIM4        */
#define RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd0p825                           (_RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd0p825 << 22)       /**< Shifted mode ovdd0p825 for RAC_PATRIM4      */
#define RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd1p075                           (_RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd1p075 << 22)       /**< Shifted mode ovdd1p075 for RAC_PATRIM4      */
#define RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd1p325                           (_RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd1p325 << 22)       /**< Shifted mode ovdd1p325 for RAC_PATRIM4      */
#define RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd1p575                           (_RAC_PATRIM4_TXVXSCURRENTVREFP_ovdd1p575 << 22)       /**< Shifted mode ovdd1p575 for RAC_PATRIM4      */

/* Bit fields for RAC PATRIM5 */
#define _RAC_PATRIM5_RESETVALUE                                           0x000003F0UL                              /**< Default value for RAC_PATRIM5               */
#define _RAC_PATRIM5_MASK                                                 0x000003F7UL                              /**< Mask for RAC_PATRIM5                        */
#define RAC_PATRIM5_TXVNSRAIL                                             (0x1UL << 0)                              /**< TXVNSRAIL                                   */
#define _RAC_PATRIM5_TXVNSRAIL_SHIFT                                      0                                         /**< Shift value for RAC_TXVNSRAIL               */
#define _RAC_PATRIM5_TXVNSRAIL_MASK                                       0x1UL                                     /**< Bit mask for RAC_TXVNSRAIL                  */
#define _RAC_PATRIM5_TXVNSRAIL_DEFAULT                                    0x00000000UL                              /**< Mode DEFAULT for RAC_PATRIM5                */
#define _RAC_PATRIM5_TXVNSRAIL_disable                                    0x00000000UL                              /**< Mode disable for RAC_PATRIM5                */
#define _RAC_PATRIM5_TXVNSRAIL_enable                                     0x00000001UL                              /**< Mode enable for RAC_PATRIM5                 */
#define RAC_PATRIM5_TXVNSRAIL_DEFAULT                                     (_RAC_PATRIM5_TXVNSRAIL_DEFAULT << 0)     /**< Shifted mode DEFAULT for RAC_PATRIM5        */
#define RAC_PATRIM5_TXVNSRAIL_disable                                     (_RAC_PATRIM5_TXVNSRAIL_disable << 0)     /**< Shifted mode disable for RAC_PATRIM5        */
#define RAC_PATRIM5_TXVNSRAIL_enable                                      (_RAC_PATRIM5_TXVNSRAIL_enable << 0)      /**< Shifted mode enable for RAC_PATRIM5         */
#define RAC_PATRIM5_TXVPSRAIL                                             (0x1UL << 1)                              /**< TXVPSRAIL                                   */
#define _RAC_PATRIM5_TXVPSRAIL_SHIFT                                      1                                         /**< Shift value for RAC_TXVPSRAIL               */
#define _RAC_PATRIM5_TXVPSRAIL_MASK                                       0x2UL                                     /**< Bit mask for RAC_TXVPSRAIL                  */
#define _RAC_PATRIM5_TXVPSRAIL_DEFAULT                                    0x00000000UL                              /**< Mode DEFAULT for RAC_PATRIM5                */
#define _RAC_PATRIM5_TXVPSRAIL_disable                                    0x00000000UL                              /**< Mode disable for RAC_PATRIM5                */
#define _RAC_PATRIM5_TXVPSRAIL_enable                                     0x00000001UL                              /**< Mode enable for RAC_PATRIM5                 */
#define RAC_PATRIM5_TXVPSRAIL_DEFAULT                                     (_RAC_PATRIM5_TXVPSRAIL_DEFAULT << 1)     /**< Shifted mode DEFAULT for RAC_PATRIM5        */
#define RAC_PATRIM5_TXVPSRAIL_disable                                     (_RAC_PATRIM5_TXVPSRAIL_disable << 1)     /**< Shifted mode disable for RAC_PATRIM5        */
#define RAC_PATRIM5_TXVPSRAIL_enable                                      (_RAC_PATRIM5_TXVPSRAIL_enable << 1)      /**< Shifted mode enable for RAC_PATRIM5         */
#define RAC_PATRIM5_TXVCASRAIL                                            (0x1UL << 2)                              /**< TXVCASRAIL                                  */
#define _RAC_PATRIM5_TXVCASRAIL_SHIFT                                     2                                         /**< Shift value for RAC_TXVCASRAIL              */
#define _RAC_PATRIM5_TXVCASRAIL_MASK                                      0x4UL                                     /**< Bit mask for RAC_TXVCASRAIL                 */
#define _RAC_PATRIM5_TXVCASRAIL_DEFAULT                                   0x00000000UL                              /**< Mode DEFAULT for RAC_PATRIM5                */
#define _RAC_PATRIM5_TXVCASRAIL_default                                   0x00000000UL                              /**< Mode default for RAC_PATRIM5                */
#define _RAC_PATRIM5_TXVCASRAIL_settorail                                 0x00000001UL                              /**< Mode settorail for RAC_PATRIM5              */
#define RAC_PATRIM5_TXVCASRAIL_DEFAULT                                    (_RAC_PATRIM5_TXVCASRAIL_DEFAULT << 2)    /**< Shifted mode DEFAULT for RAC_PATRIM5        */
#define RAC_PATRIM5_TXVCASRAIL_default                                    (_RAC_PATRIM5_TXVCASRAIL_default << 2)    /**< Shifted mode default for RAC_PATRIM5        */
#define RAC_PATRIM5_TXVCASRAIL_settorail                                  (_RAC_PATRIM5_TXVCASRAIL_settorail << 2)  /**< Shifted mode settorail for RAC_PATRIM5      */
#define _RAC_PATRIM5_TXTRIMXPAVNS_SHIFT                                   4                                         /**< Shift value for RAC_TXTRIMXPAVNS            */
#define _RAC_PATRIM5_TXTRIMXPAVNS_MASK                                    0x70UL                                    /**< Bit mask for RAC_TXTRIMXPAVNS               */
#define _RAC_PATRIM5_TXTRIMXPAVNS_DEFAULT                                 0x00000007UL                              /**< Mode DEFAULT for RAC_PATRIM5                */
#define _RAC_PATRIM5_TXTRIMXPAVNS_ognd1p07                                0x00000000UL                              /**< Mode ognd1p07 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVNS_ognd1p12                                0x00000001UL                              /**< Mode ognd1p12 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVNS_ognd1p18                                0x00000002UL                              /**< Mode ognd1p18 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVNS_ognd1p25                                0x00000003UL                              /**< Mode ognd1p25 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVNS_ognd1p34                                0x00000004UL                              /**< Mode ognd1p34 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVNS_ognd1p43                                0x00000005UL                              /**< Mode ognd1p43 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVNS_ognd1p53                                0x00000006UL                              /**< Mode ognd1p53 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVNS_ognd1p63                                0x00000007UL                              /**< Mode ognd1p63 for RAC_PATRIM5               */
#define RAC_PATRIM5_TXTRIMXPAVNS_DEFAULT                                  (_RAC_PATRIM5_TXTRIMXPAVNS_DEFAULT << 4)  /**< Shifted mode DEFAULT for RAC_PATRIM5        */
#define RAC_PATRIM5_TXTRIMXPAVNS_ognd1p07                                 (_RAC_PATRIM5_TXTRIMXPAVNS_ognd1p07 << 4) /**< Shifted mode ognd1p07 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVNS_ognd1p12                                 (_RAC_PATRIM5_TXTRIMXPAVNS_ognd1p12 << 4) /**< Shifted mode ognd1p12 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVNS_ognd1p18                                 (_RAC_PATRIM5_TXTRIMXPAVNS_ognd1p18 << 4) /**< Shifted mode ognd1p18 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVNS_ognd1p25                                 (_RAC_PATRIM5_TXTRIMXPAVNS_ognd1p25 << 4) /**< Shifted mode ognd1p25 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVNS_ognd1p34                                 (_RAC_PATRIM5_TXTRIMXPAVNS_ognd1p34 << 4) /**< Shifted mode ognd1p34 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVNS_ognd1p43                                 (_RAC_PATRIM5_TXTRIMXPAVNS_ognd1p43 << 4) /**< Shifted mode ognd1p43 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVNS_ognd1p53                                 (_RAC_PATRIM5_TXTRIMXPAVNS_ognd1p53 << 4) /**< Shifted mode ognd1p53 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVNS_ognd1p63                                 (_RAC_PATRIM5_TXTRIMXPAVNS_ognd1p63 << 4) /**< Shifted mode ognd1p63 for RAC_PATRIM5       */
#define _RAC_PATRIM5_TXTRIMXPAVPS_SHIFT                                   7                                         /**< Shift value for RAC_TXTRIMXPAVPS            */
#define _RAC_PATRIM5_TXTRIMXPAVPS_MASK                                    0x380UL                                   /**< Bit mask for RAC_TXTRIMXPAVPS               */
#define _RAC_PATRIM5_TXTRIMXPAVPS_DEFAULT                                 0x00000007UL                              /**< Mode DEFAULT for RAC_PATRIM5                */
#define _RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p03                                0x00000000UL                              /**< Mode ovdd1p03 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p08                                0x00000001UL                              /**< Mode ovdd1p08 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p14                                0x00000002UL                              /**< Mode ovdd1p14 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p19                                0x00000003UL                              /**< Mode ovdd1p19 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p24                                0x00000004UL                              /**< Mode ovdd1p24 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p30                                0x00000005UL                              /**< Mode ovdd1p30 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p40                                0x00000006UL                              /**< Mode ovdd1p40 for RAC_PATRIM5               */
#define _RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p50                                0x00000007UL                              /**< Mode ovdd1p50 for RAC_PATRIM5               */
#define RAC_PATRIM5_TXTRIMXPAVPS_DEFAULT                                  (_RAC_PATRIM5_TXTRIMXPAVPS_DEFAULT << 7)  /**< Shifted mode DEFAULT for RAC_PATRIM5        */
#define RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p03                                 (_RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p03 << 7) /**< Shifted mode ovdd1p03 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p08                                 (_RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p08 << 7) /**< Shifted mode ovdd1p08 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p14                                 (_RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p14 << 7) /**< Shifted mode ovdd1p14 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p19                                 (_RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p19 << 7) /**< Shifted mode ovdd1p19 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p24                                 (_RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p24 << 7) /**< Shifted mode ovdd1p24 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p30                                 (_RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p30 << 7) /**< Shifted mode ovdd1p30 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p40                                 (_RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p40 << 7) /**< Shifted mode ovdd1p40 for RAC_PATRIM5       */
#define RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p50                                 (_RAC_PATRIM5_TXTRIMXPAVPS_ovdd1p50 << 7) /**< Shifted mode ovdd1p50 for RAC_PATRIM5       */

/* Bit fields for RAC PADEBUG0 */
#define _RAC_PADEBUG0_RESETVALUE                                          0x00000000UL                                       /**< Default value for RAC_PADEBUG0              */
#define _RAC_PADEBUG0_MASK                                                0x0000000FUL                                       /**< Mask for RAC_PADEBUG0                       */
#define RAC_PADEBUG0_TXOREGBYPASS                                         (0x1UL << 0)                                       /**< TXOREGBYPASS                                */
#define _RAC_PADEBUG0_TXOREGBYPASS_SHIFT                                  0                                                  /**< Shift value for RAC_TXOREGBYPASS            */
#define _RAC_PADEBUG0_TXOREGBYPASS_MASK                                   0x1UL                                              /**< Bit mask for RAC_TXOREGBYPASS               */
#define _RAC_PADEBUG0_TXOREGBYPASS_DEFAULT                                0x00000000UL                                       /**< Mode DEFAULT for RAC_PADEBUG0               */
#define _RAC_PADEBUG0_TXOREGBYPASS_disable                                0x00000000UL                                       /**< Mode disable for RAC_PADEBUG0               */
#define _RAC_PADEBUG0_TXOREGBYPASS_enable                                 0x00000001UL                                       /**< Mode enable for RAC_PADEBUG0                */
#define RAC_PADEBUG0_TXOREGBYPASS_DEFAULT                                 (_RAC_PADEBUG0_TXOREGBYPASS_DEFAULT << 0)          /**< Shifted mode DEFAULT for RAC_PADEBUG0       */
#define RAC_PADEBUG0_TXOREGBYPASS_disable                                 (_RAC_PADEBUG0_TXOREGBYPASS_disable << 0)          /**< Shifted mode disable for RAC_PADEBUG0       */
#define RAC_PADEBUG0_TXOREGBYPASS_enable                                  (_RAC_PADEBUG0_TXOREGBYPASS_enable << 0)           /**< Shifted mode enable for RAC_PADEBUG0        */
#define RAC_PADEBUG0_TXDREGBYPASS                                         (0x1UL << 1)                                       /**< TXDREGBYPASS                                */
#define _RAC_PADEBUG0_TXDREGBYPASS_SHIFT                                  1                                                  /**< Shift value for RAC_TXDREGBYPASS            */
#define _RAC_PADEBUG0_TXDREGBYPASS_MASK                                   0x2UL                                              /**< Bit mask for RAC_TXDREGBYPASS               */
#define _RAC_PADEBUG0_TXDREGBYPASS_DEFAULT                                0x00000000UL                                       /**< Mode DEFAULT for RAC_PADEBUG0               */
#define _RAC_PADEBUG0_TXDREGBYPASS_disable_bypass                         0x00000000UL                                       /**< Mode disable_bypass for RAC_PADEBUG0        */
#define _RAC_PADEBUG0_TXDREGBYPASS_enable_bypass                          0x00000001UL                                       /**< Mode enable_bypass for RAC_PADEBUG0         */
#define RAC_PADEBUG0_TXDREGBYPASS_DEFAULT                                 (_RAC_PADEBUG0_TXDREGBYPASS_DEFAULT << 1)          /**< Shifted mode DEFAULT for RAC_PADEBUG0       */
#define RAC_PADEBUG0_TXDREGBYPASS_disable_bypass                          (_RAC_PADEBUG0_TXDREGBYPASS_disable_bypass << 1)   /**< Shifted mode disable_bypass for RAC_PADEBUG0*/
#define RAC_PADEBUG0_TXDREGBYPASS_enable_bypass                           (_RAC_PADEBUG0_TXDREGBYPASS_enable_bypass << 1)    /**< Shifted mode enable_bypass for RAC_PADEBUG0 */
#define RAC_PADEBUG0_TXRREGBYPASS                                         (0x1UL << 2)                                       /**< TXRREGBYPASS                                */
#define _RAC_PADEBUG0_TXRREGBYPASS_SHIFT                                  2                                                  /**< Shift value for RAC_TXRREGBYPASS            */
#define _RAC_PADEBUG0_TXRREGBYPASS_MASK                                   0x4UL                                              /**< Bit mask for RAC_TXRREGBYPASS               */
#define _RAC_PADEBUG0_TXRREGBYPASS_DEFAULT                                0x00000000UL                                       /**< Mode DEFAULT for RAC_PADEBUG0               */
#define _RAC_PADEBUG0_TXRREGBYPASS_not_bypass                             0x00000000UL                                       /**< Mode not_bypass for RAC_PADEBUG0            */
#define _RAC_PADEBUG0_TXRREGBYPASS_bypass                                 0x00000001UL                                       /**< Mode bypass for RAC_PADEBUG0                */
#define RAC_PADEBUG0_TXRREGBYPASS_DEFAULT                                 (_RAC_PADEBUG0_TXRREGBYPASS_DEFAULT << 2)          /**< Shifted mode DEFAULT for RAC_PADEBUG0       */
#define RAC_PADEBUG0_TXRREGBYPASS_not_bypass                              (_RAC_PADEBUG0_TXRREGBYPASS_not_bypass << 2)       /**< Shifted mode not_bypass for RAC_PADEBUG0    */
#define RAC_PADEBUG0_TXRREGBYPASS_bypass                                  (_RAC_PADEBUG0_TXRREGBYPASS_bypass << 2)           /**< Shifted mode bypass for RAC_PADEBUG0        */
#define RAC_PADEBUG0_TXPDNVDDPA                                           (0x1UL << 3)                                       /**< TXPDNVDDPA                                  */
#define _RAC_PADEBUG0_TXPDNVDDPA_SHIFT                                    3                                                  /**< Shift value for RAC_TXPDNVDDPA              */
#define _RAC_PADEBUG0_TXPDNVDDPA_MASK                                     0x8UL                                              /**< Bit mask for RAC_TXPDNVDDPA                 */
#define _RAC_PADEBUG0_TXPDNVDDPA_DEFAULT                                  0x00000000UL                                       /**< Mode DEFAULT for RAC_PADEBUG0               */
#define _RAC_PADEBUG0_TXPDNVDDPA_not_pull_down_ovdd                       0x00000000UL                                       /**< Mode not_pull_down_ovdd for RAC_PADEBUG0    */
#define _RAC_PADEBUG0_TXPDNVDDPA_pull_down_ovdd                           0x00000001UL                                       /**< Mode pull_down_ovdd for RAC_PADEBUG0        */
#define RAC_PADEBUG0_TXPDNVDDPA_DEFAULT                                   (_RAC_PADEBUG0_TXPDNVDDPA_DEFAULT << 3)            /**< Shifted mode DEFAULT for RAC_PADEBUG0       */
#define RAC_PADEBUG0_TXPDNVDDPA_not_pull_down_ovdd                        (_RAC_PADEBUG0_TXPDNVDDPA_not_pull_down_ovdd << 3) /**< Shifted mode not_pull_down_ovdd for RAC_PADEBUG0*/
#define RAC_PADEBUG0_TXPDNVDDPA_pull_down_ovdd                            (_RAC_PADEBUG0_TXPDNVDDPA_pull_down_ovdd << 3)     /**< Shifted mode pull_down_ovdd for RAC_PADEBUG0*/

/* Bit fields for RAC TXPOWER */
#define _RAC_TXPOWER_RESETVALUE                                           0x007FE000UL                                /**< Default value for RAC_TXPOWER               */
#define _RAC_TXPOWER_MASK                                                 0x007FEEFFUL                                /**< Mask for RAC_TXPOWER                        */
#define _RAC_TXPOWER_TXSTRIPE_SHIFT                                       0                                           /**< Shift value for RAC_TXSTRIPE                */
#define _RAC_TXPOWER_TXSTRIPE_MASK                                        0x1FUL                                      /**< Bit mask for RAC_TXSTRIPE                   */
#define _RAC_TXPOWER_TXSTRIPE_DEFAULT                                     0x00000000UL                                /**< Mode DEFAULT for RAC_TXPOWER                */
#define _RAC_TXPOWER_TXSTRIPE_tbd_0                                       0x00000000UL                                /**< Mode tbd_0 for RAC_TXPOWER                  */
#define _RAC_TXPOWER_TXSTRIPE_tbd_1                                       0x00000001UL                                /**< Mode tbd_1 for RAC_TXPOWER                  */
#define _RAC_TXPOWER_TXSTRIPE_tbd_2                                       0x00000002UL                                /**< Mode tbd_2 for RAC_TXPOWER                  */
#define _RAC_TXPOWER_TXSTRIPE_tbd_3                                       0x00000003UL                                /**< Mode tbd_3 for RAC_TXPOWER                  */
#define _RAC_TXPOWER_TXSTRIPE_tbd_4                                       0x00000004UL                                /**< Mode tbd_4 for RAC_TXPOWER                  */
#define _RAC_TXPOWER_TXSTRIPE_tbd_5                                       0x00000005UL                                /**< Mode tbd_5 for RAC_TXPOWER                  */
#define _RAC_TXPOWER_TXSTRIPE_tbd_6                                       0x00000006UL                                /**< Mode tbd_6 for RAC_TXPOWER                  */
#define _RAC_TXPOWER_TXSTRIPE_tbd_7                                       0x00000007UL                                /**< Mode tbd_7 for RAC_TXPOWER                  */
#define _RAC_TXPOWER_TXSTRIPE_tbd_8                                       0x00000008UL                                /**< Mode tbd_8 for RAC_TXPOWER                  */
#define _RAC_TXPOWER_TXSTRIPE_tbd_9                                       0x00000009UL                                /**< Mode tbd_9 for RAC_TXPOWER                  */
#define _RAC_TXPOWER_TXSTRIPE_tbd_10                                      0x0000000AUL                                /**< Mode tbd_10 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_11                                      0x0000000BUL                                /**< Mode tbd_11 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_12                                      0x0000000CUL                                /**< Mode tbd_12 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_13                                      0x0000000DUL                                /**< Mode tbd_13 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_14                                      0x0000000EUL                                /**< Mode tbd_14 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_15                                      0x0000000FUL                                /**< Mode tbd_15 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_16                                      0x00000010UL                                /**< Mode tbd_16 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_17                                      0x00000011UL                                /**< Mode tbd_17 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_18                                      0x00000012UL                                /**< Mode tbd_18 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_19                                      0x00000013UL                                /**< Mode tbd_19 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_20                                      0x00000014UL                                /**< Mode tbd_20 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_21                                      0x00000015UL                                /**< Mode tbd_21 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_22                                      0x00000016UL                                /**< Mode tbd_22 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_23                                      0x00000017UL                                /**< Mode tbd_23 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_24                                      0x00000018UL                                /**< Mode tbd_24 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_25                                      0x00000019UL                                /**< Mode tbd_25 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_26                                      0x0000001AUL                                /**< Mode tbd_26 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_27                                      0x0000001BUL                                /**< Mode tbd_27 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_28                                      0x0000001CUL                                /**< Mode tbd_28 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_29                                      0x0000001DUL                                /**< Mode tbd_29 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_30                                      0x0000001EUL                                /**< Mode tbd_30 for RAC_TXPOWER                 */
#define _RAC_TXPOWER_TXSTRIPE_tbd_31                                      0x0000001FUL                                /**< Mode tbd_31 for RAC_TXPOWER                 */
#define RAC_TXPOWER_TXSTRIPE_DEFAULT                                      (_RAC_TXPOWER_TXSTRIPE_DEFAULT << 0)        /**< Shifted mode DEFAULT for RAC_TXPOWER        */
#define RAC_TXPOWER_TXSTRIPE_tbd_0                                        (_RAC_TXPOWER_TXSTRIPE_tbd_0 << 0)          /**< Shifted mode tbd_0 for RAC_TXPOWER          */
#define RAC_TXPOWER_TXSTRIPE_tbd_1                                        (_RAC_TXPOWER_TXSTRIPE_tbd_1 << 0)          /**< Shifted mode tbd_1 for RAC_TXPOWER          */
#define RAC_TXPOWER_TXSTRIPE_tbd_2                                        (_RAC_TXPOWER_TXSTRIPE_tbd_2 << 0)          /**< Shifted mode tbd_2 for RAC_TXPOWER          */
#define RAC_TXPOWER_TXSTRIPE_tbd_3                                        (_RAC_TXPOWER_TXSTRIPE_tbd_3 << 0)          /**< Shifted mode tbd_3 for RAC_TXPOWER          */
#define RAC_TXPOWER_TXSTRIPE_tbd_4                                        (_RAC_TXPOWER_TXSTRIPE_tbd_4 << 0)          /**< Shifted mode tbd_4 for RAC_TXPOWER          */
#define RAC_TXPOWER_TXSTRIPE_tbd_5                                        (_RAC_TXPOWER_TXSTRIPE_tbd_5 << 0)          /**< Shifted mode tbd_5 for RAC_TXPOWER          */
#define RAC_TXPOWER_TXSTRIPE_tbd_6                                        (_RAC_TXPOWER_TXSTRIPE_tbd_6 << 0)          /**< Shifted mode tbd_6 for RAC_TXPOWER          */
#define RAC_TXPOWER_TXSTRIPE_tbd_7                                        (_RAC_TXPOWER_TXSTRIPE_tbd_7 << 0)          /**< Shifted mode tbd_7 for RAC_TXPOWER          */
#define RAC_TXPOWER_TXSTRIPE_tbd_8                                        (_RAC_TXPOWER_TXSTRIPE_tbd_8 << 0)          /**< Shifted mode tbd_8 for RAC_TXPOWER          */
#define RAC_TXPOWER_TXSTRIPE_tbd_9                                        (_RAC_TXPOWER_TXSTRIPE_tbd_9 << 0)          /**< Shifted mode tbd_9 for RAC_TXPOWER          */
#define RAC_TXPOWER_TXSTRIPE_tbd_10                                       (_RAC_TXPOWER_TXSTRIPE_tbd_10 << 0)         /**< Shifted mode tbd_10 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_11                                       (_RAC_TXPOWER_TXSTRIPE_tbd_11 << 0)         /**< Shifted mode tbd_11 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_12                                       (_RAC_TXPOWER_TXSTRIPE_tbd_12 << 0)         /**< Shifted mode tbd_12 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_13                                       (_RAC_TXPOWER_TXSTRIPE_tbd_13 << 0)         /**< Shifted mode tbd_13 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_14                                       (_RAC_TXPOWER_TXSTRIPE_tbd_14 << 0)         /**< Shifted mode tbd_14 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_15                                       (_RAC_TXPOWER_TXSTRIPE_tbd_15 << 0)         /**< Shifted mode tbd_15 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_16                                       (_RAC_TXPOWER_TXSTRIPE_tbd_16 << 0)         /**< Shifted mode tbd_16 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_17                                       (_RAC_TXPOWER_TXSTRIPE_tbd_17 << 0)         /**< Shifted mode tbd_17 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_18                                       (_RAC_TXPOWER_TXSTRIPE_tbd_18 << 0)         /**< Shifted mode tbd_18 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_19                                       (_RAC_TXPOWER_TXSTRIPE_tbd_19 << 0)         /**< Shifted mode tbd_19 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_20                                       (_RAC_TXPOWER_TXSTRIPE_tbd_20 << 0)         /**< Shifted mode tbd_20 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_21                                       (_RAC_TXPOWER_TXSTRIPE_tbd_21 << 0)         /**< Shifted mode tbd_21 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_22                                       (_RAC_TXPOWER_TXSTRIPE_tbd_22 << 0)         /**< Shifted mode tbd_22 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_23                                       (_RAC_TXPOWER_TXSTRIPE_tbd_23 << 0)         /**< Shifted mode tbd_23 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_24                                       (_RAC_TXPOWER_TXSTRIPE_tbd_24 << 0)         /**< Shifted mode tbd_24 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_25                                       (_RAC_TXPOWER_TXSTRIPE_tbd_25 << 0)         /**< Shifted mode tbd_25 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_26                                       (_RAC_TXPOWER_TXSTRIPE_tbd_26 << 0)         /**< Shifted mode tbd_26 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_27                                       (_RAC_TXPOWER_TXSTRIPE_tbd_27 << 0)         /**< Shifted mode tbd_27 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_28                                       (_RAC_TXPOWER_TXSTRIPE_tbd_28 << 0)         /**< Shifted mode tbd_28 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_29                                       (_RAC_TXPOWER_TXSTRIPE_tbd_29 << 0)         /**< Shifted mode tbd_29 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_30                                       (_RAC_TXPOWER_TXSTRIPE_tbd_30 << 0)         /**< Shifted mode tbd_30 for RAC_TXPOWER         */
#define RAC_TXPOWER_TXSTRIPE_tbd_31                                       (_RAC_TXPOWER_TXSTRIPE_tbd_31 << 0)         /**< Shifted mode tbd_31 for RAC_TXPOWER         */
#define _RAC_TXPOWER_TXSLICE_SHIFT                                        5                                           /**< Shift value for RAC_TXSLICE                 */
#define _RAC_TXPOWER_TXSLICE_MASK                                         0xE0UL                                      /**< Bit mask for RAC_TXSLICE                    */
#define _RAC_TXPOWER_TXSLICE_DEFAULT                                      0x00000000UL                                /**< Mode DEFAULT for RAC_TXPOWER                */
#define _RAC_TXPOWER_TXSLICE_on_0_slice                                   0x00000000UL                                /**< Mode on_0_slice for RAC_TXPOWER             */
#define _RAC_TXPOWER_TXSLICE_on_1_slices                                  0x00000001UL                                /**< Mode on_1_slices for RAC_TXPOWER            */
#define _RAC_TXPOWER_TXSLICE_on_2_slices                                  0x00000002UL                                /**< Mode on_2_slices for RAC_TXPOWER            */
#define _RAC_TXPOWER_TXSLICE_NA                                           0x00000003UL                                /**< Mode NA for RAC_TXPOWER                     */
#define RAC_TXPOWER_TXSLICE_DEFAULT                                       (_RAC_TXPOWER_TXSLICE_DEFAULT << 5)         /**< Shifted mode DEFAULT for RAC_TXPOWER        */
#define RAC_TXPOWER_TXSLICE_on_0_slice                                    (_RAC_TXPOWER_TXSLICE_on_0_slice << 5)      /**< Shifted mode on_0_slice for RAC_TXPOWER     */
#define RAC_TXPOWER_TXSLICE_on_1_slices                                   (_RAC_TXPOWER_TXSLICE_on_1_slices << 5)     /**< Shifted mode on_1_slices for RAC_TXPOWER    */
#define RAC_TXPOWER_TXSLICE_on_2_slices                                   (_RAC_TXPOWER_TXSLICE_on_2_slices << 5)     /**< Shifted mode on_2_slices for RAC_TXPOWER    */
#define RAC_TXPOWER_TXSLICE_NA                                            (_RAC_TXPOWER_TXSLICE_NA << 5)              /**< Shifted mode NA for RAC_TXPOWER             */
#define _RAC_TXPOWER_TXDRVSLICE_SHIFT                                     9                                           /**< Shift value for RAC_TXDRVSLICE              */
#define _RAC_TXPOWER_TXDRVSLICE_MASK                                      0xE00UL                                     /**< Bit mask for RAC_TXDRVSLICE                 */
#define _RAC_TXPOWER_TXDRVSLICE_DEFAULT                                   0x00000000UL                                /**< Mode DEFAULT for RAC_TXPOWER                */
#define RAC_TXPOWER_TXDRVSLICE_DEFAULT                                    (_RAC_TXPOWER_TXDRVSLICE_DEFAULT << 9)      /**< Shifted mode DEFAULT for RAC_TXPOWER        */
#define _RAC_TXPOWER_TXANARAMPODEV_SHIFT                                  13                                          /**< Shift value for RAC_TXANARAMPODEV           */
#define _RAC_TXPOWER_TXANARAMPODEV_MASK                                   0x3E000UL                                   /**< Bit mask for RAC_TXANARAMPODEV              */
#define _RAC_TXPOWER_TXANARAMPODEV_DEFAULT                                0x0000001FUL                                /**< Mode DEFAULT for RAC_TXPOWER                */
#define RAC_TXPOWER_TXANARAMPODEV_DEFAULT                                 (_RAC_TXPOWER_TXANARAMPODEV_DEFAULT << 13)  /**< Shifted mode DEFAULT for RAC_TXPOWER        */
#define _RAC_TXPOWER_TXANARAMPDRVFF_SHIFT                                 18                                          /**< Shift value for RAC_TXANARAMPDRVFF          */
#define _RAC_TXPOWER_TXANARAMPDRVFF_MASK                                  0x7C0000UL                                  /**< Bit mask for RAC_TXANARAMPDRVFF             */
#define _RAC_TXPOWER_TXANARAMPDRVFF_DEFAULT                               0x0000001FUL                                /**< Mode DEFAULT for RAC_TXPOWER                */
#define RAC_TXPOWER_TXANARAMPDRVFF_DEFAULT                                (_RAC_TXPOWER_TXANARAMPDRVFF_DEFAULT << 18) /**< Shifted mode DEFAULT for RAC_TXPOWER        */

/* Bit fields for RAC TXRAMP */
#define _RAC_TXRAMP_RESETVALUE                                            0x0000003FUL                                         /**< Default value for RAC_TXRAMP                */
#define _RAC_TXRAMP_MASK                                                  0x000C0FFFUL                                         /**< Mask for RAC_TXRAMP                         */
#define _RAC_TXRAMP_TXANARAMPDRVBW_SHIFT                                  0                                                    /**< Shift value for RAC_TXANARAMPDRVBW          */
#define _RAC_TXRAMP_TXANARAMPDRVBW_MASK                                   0x3UL                                                /**< Bit mask for RAC_TXANARAMPDRVBW             */
#define _RAC_TXRAMP_TXANARAMPDRVBW_DEFAULT                                0x00000003UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_500k                       0x00000000UL                                         /**< Mode drv_ramp_bw_500k for RAC_TXRAMP        */
#define _RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_1meg                       0x00000001UL                                         /**< Mode drv_ramp_bw_1meg for RAC_TXRAMP        */
#define _RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_2meg                       0x00000002UL                                         /**< Mode drv_ramp_bw_2meg for RAC_TXRAMP        */
#define _RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_4meg                       0x00000003UL                                         /**< Mode drv_ramp_bw_4meg for RAC_TXRAMP        */
#define RAC_TXRAMP_TXANARAMPDRVBW_DEFAULT                                 (_RAC_TXRAMP_TXANARAMPDRVBW_DEFAULT << 0)            /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_500k                        (_RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_500k << 0)   /**< Shifted mode drv_ramp_bw_500k for RAC_TXRAMP*/
#define RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_1meg                        (_RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_1meg << 0)   /**< Shifted mode drv_ramp_bw_1meg for RAC_TXRAMP*/
#define RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_2meg                        (_RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_2meg << 0)   /**< Shifted mode drv_ramp_bw_2meg for RAC_TXRAMP*/
#define RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_4meg                        (_RAC_TXRAMP_TXANARAMPDRVBW_drv_ramp_bw_4meg << 0)   /**< Shifted mode drv_ramp_bw_4meg for RAC_TXRAMP*/
#define RAC_TXRAMP_TXANARAMPDRVEN                                         (0x1UL << 2)                                         /**< TXANARAMPDRVEN                              */
#define _RAC_TXRAMP_TXANARAMPDRVEN_SHIFT                                  2                                                    /**< Shift value for RAC_TXANARAMPDRVEN          */
#define _RAC_TXRAMP_TXANARAMPDRVEN_MASK                                   0x4UL                                                /**< Bit mask for RAC_TXANARAMPDRVEN             */
#define _RAC_TXRAMP_TXANARAMPDRVEN_DEFAULT                                0x00000001UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXANARAMPDRVEN_ana_ramp_drv_off                       0x00000000UL                                         /**< Mode ana_ramp_drv_off for RAC_TXRAMP        */
#define _RAC_TXRAMP_TXANARAMPDRVEN_tana_ramp_drv_on                       0x00000001UL                                         /**< Mode tana_ramp_drv_on for RAC_TXRAMP        */
#define RAC_TXRAMP_TXANARAMPDRVEN_DEFAULT                                 (_RAC_TXRAMP_TXANARAMPDRVEN_DEFAULT << 2)            /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXANARAMPDRVEN_ana_ramp_drv_off                        (_RAC_TXRAMP_TXANARAMPDRVEN_ana_ramp_drv_off << 2)   /**< Shifted mode ana_ramp_drv_off for RAC_TXRAMP*/
#define RAC_TXRAMP_TXANARAMPDRVEN_tana_ramp_drv_on                        (_RAC_TXRAMP_TXANARAMPDRVEN_tana_ramp_drv_on << 2)   /**< Shifted mode tana_ramp_drv_on for RAC_TXRAMP*/
#define _RAC_TXRAMP_TXANARAMPODEVBW_SHIFT                                 3                                                    /**< Shift value for RAC_TXANARAMPODEVBW         */
#define _RAC_TXRAMP_TXANARAMPODEVBW_MASK                                  0x18UL                                               /**< Bit mask for RAC_TXANARAMPODEVBW            */
#define _RAC_TXRAMP_TXANARAMPODEVBW_DEFAULT                               0x00000003UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res105k                     0x00000000UL                                         /**< Mode odev_ramp_res105k for RAC_TXRAMP       */
#define _RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res035k                     0x00000001UL                                         /**< Mode odev_ramp_res035k for RAC_TXRAMP       */
#define _RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res015k                     0x00000002UL                                         /**< Mode odev_ramp_res015k for RAC_TXRAMP       */
#define _RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res005k                     0x00000003UL                                         /**< Mode odev_ramp_res005k for RAC_TXRAMP       */
#define RAC_TXRAMP_TXANARAMPODEVBW_DEFAULT                                (_RAC_TXRAMP_TXANARAMPODEVBW_DEFAULT << 3)           /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res105k                      (_RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res105k << 3) /**< Shifted mode odev_ramp_res105k for RAC_TXRAMP*/
#define RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res035k                      (_RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res035k << 3) /**< Shifted mode odev_ramp_res035k for RAC_TXRAMP*/
#define RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res015k                      (_RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res015k << 3) /**< Shifted mode odev_ramp_res015k for RAC_TXRAMP*/
#define RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res005k                      (_RAC_TXRAMP_TXANARAMPODEVBW_odev_ramp_res005k << 3) /**< Shifted mode odev_ramp_res005k for RAC_TXRAMP*/
#define RAC_TXRAMP_TXANARAMPODEVEN                                        (0x1UL << 5)                                         /**< TXANARAMPODEVEN                             */
#define _RAC_TXRAMP_TXANARAMPODEVEN_SHIFT                                 5                                                    /**< Shift value for RAC_TXANARAMPODEVEN         */
#define _RAC_TXRAMP_TXANARAMPODEVEN_MASK                                  0x20UL                                               /**< Bit mask for RAC_TXANARAMPODEVEN            */
#define _RAC_TXRAMP_TXANARAMPODEVEN_DEFAULT                               0x00000001UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXANARAMPODEVEN_ana_ramp_odev_off                     0x00000000UL                                         /**< Mode ana_ramp_odev_off for RAC_TXRAMP       */
#define _RAC_TXRAMP_TXANARAMPODEVEN_ana_ramp_odev_on                      0x00000001UL                                         /**< Mode ana_ramp_odev_on for RAC_TXRAMP        */
#define RAC_TXRAMP_TXANARAMPODEVEN_DEFAULT                                (_RAC_TXRAMP_TXANARAMPODEVEN_DEFAULT << 5)           /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXANARAMPODEVEN_ana_ramp_odev_off                      (_RAC_TXRAMP_TXANARAMPODEVEN_ana_ramp_odev_off << 5) /**< Shifted mode ana_ramp_odev_off for RAC_TXRAMP*/
#define RAC_TXRAMP_TXANARAMPODEVEN_ana_ramp_odev_on                       (_RAC_TXRAMP_TXANARAMPODEVEN_ana_ramp_odev_on << 5)  /**< Shifted mode ana_ramp_odev_on for RAC_TXRAMP*/
#define RAC_TXRAMP_TXBYPASSRAMPCLK                                        (0x1UL << 6)                                         /**< TXBYPASSRAMPCLK                             */
#define _RAC_TXRAMP_TXBYPASSRAMPCLK_SHIFT                                 6                                                    /**< Shift value for RAC_TXBYPASSRAMPCLK         */
#define _RAC_TXRAMP_TXBYPASSRAMPCLK_MASK                                  0x40UL                                               /**< Bit mask for RAC_TXBYPASSRAMPCLK            */
#define _RAC_TXRAMP_TXBYPASSRAMPCLK_DEFAULT                               0x00000000UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXBYPASSRAMPCLK_use_ramp_clk                          0x00000000UL                                         /**< Mode use_ramp_clk for RAC_TXRAMP            */
#define _RAC_TXRAMP_TXBYPASSRAMPCLK_bypass_ramp_clk                       0x00000001UL                                         /**< Mode bypass_ramp_clk for RAC_TXRAMP         */
#define RAC_TXRAMP_TXBYPASSRAMPCLK_DEFAULT                                (_RAC_TXRAMP_TXBYPASSRAMPCLK_DEFAULT << 6)           /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXBYPASSRAMPCLK_use_ramp_clk                           (_RAC_TXRAMP_TXBYPASSRAMPCLK_use_ramp_clk << 6)      /**< Shifted mode use_ramp_clk for RAC_TXRAMP    */
#define RAC_TXRAMP_TXBYPASSRAMPCLK_bypass_ramp_clk                        (_RAC_TXRAMP_TXBYPASSRAMPCLK_bypass_ramp_clk << 6)   /**< Shifted mode bypass_ramp_clk for RAC_TXRAMP */
#define RAC_TXRAMP_TXMODEPHASEFLIP                                        (0x1UL << 7)                                         /**< TXMODEPHASEFLIP                             */
#define _RAC_TXRAMP_TXMODEPHASEFLIP_SHIFT                                 7                                                    /**< Shift value for RAC_TXMODEPHASEFLIP         */
#define _RAC_TXRAMP_TXMODEPHASEFLIP_MASK                                  0x80UL                                               /**< Bit mask for RAC_TXMODEPHASEFLIP            */
#define _RAC_TXRAMP_TXMODEPHASEFLIP_DEFAULT                               0x00000000UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXMODEPHASEFLIP_disable                               0x00000000UL                                         /**< Mode disable for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXMODEPHASEFLIP_enable                                0x00000001UL                                         /**< Mode enable for RAC_TXRAMP                  */
#define RAC_TXRAMP_TXMODEPHASEFLIP_DEFAULT                                (_RAC_TXRAMP_TXMODEPHASEFLIP_DEFAULT << 7)           /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXMODEPHASEFLIP_disable                                (_RAC_TXRAMP_TXMODEPHASEFLIP_disable << 7)           /**< Shifted mode disable for RAC_TXRAMP         */
#define RAC_TXRAMP_TXMODEPHASEFLIP_enable                                 (_RAC_TXRAMP_TXMODEPHASEFLIP_enable << 7)            /**< Shifted mode enable for RAC_TXRAMP          */
#define RAC_TXRAMP_TXPHASEDIGITAL                                         (0x1UL << 8)                                         /**< TXPHASEDIGITAL                              */
#define _RAC_TXRAMP_TXPHASEDIGITAL_SHIFT                                  8                                                    /**< Shift value for RAC_TXPHASEDIGITAL          */
#define _RAC_TXRAMP_TXPHASEDIGITAL_MASK                                   0x100UL                                              /**< Bit mask for RAC_TXPHASEDIGITAL             */
#define _RAC_TXRAMP_TXPHASEDIGITAL_DEFAULT                                0x00000000UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXPHASEDIGITAL_phase0                                 0x00000000UL                                         /**< Mode phase0 for RAC_TXRAMP                  */
#define _RAC_TXRAMP_TXPHASEDIGITAL_phase180                               0x00000001UL                                         /**< Mode phase180 for RAC_TXRAMP                */
#define RAC_TXRAMP_TXPHASEDIGITAL_DEFAULT                                 (_RAC_TXRAMP_TXPHASEDIGITAL_DEFAULT << 8)            /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXPHASEDIGITAL_phase0                                  (_RAC_TXRAMP_TXPHASEDIGITAL_phase0 << 8)             /**< Shifted mode phase0 for RAC_TXRAMP          */
#define RAC_TXRAMP_TXPHASEDIGITAL_phase180                                (_RAC_TXRAMP_TXPHASEDIGITAL_phase180 << 8)           /**< Shifted mode phase180 for RAC_TXRAMP        */
#define RAC_TXRAMP_TXRESETPAPOWER                                         (0x1UL << 9)                                         /**< TXRESETPAPOWER                              */
#define _RAC_TXRAMP_TXRESETPAPOWER_SHIFT                                  9                                                    /**< Shift value for RAC_TXRESETPAPOWER          */
#define _RAC_TXRAMP_TXRESETPAPOWER_MASK                                   0x200UL                                              /**< Bit mask for RAC_TXRESETPAPOWER             */
#define _RAC_TXRAMP_TXRESETPAPOWER_DEFAULT                                0x00000000UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXRESETPAPOWER_no_reset                               0x00000000UL                                         /**< Mode no_reset for RAC_TXRAMP                */
#define _RAC_TXRAMP_TXRESETPAPOWER_reset                                  0x00000001UL                                         /**< Mode reset for RAC_TXRAMP                   */
#define RAC_TXRAMP_TXRESETPAPOWER_DEFAULT                                 (_RAC_TXRAMP_TXRESETPAPOWER_DEFAULT << 9)            /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXRESETPAPOWER_no_reset                                (_RAC_TXRAMP_TXRESETPAPOWER_no_reset << 9)           /**< Shifted mode no_reset for RAC_TXRAMP        */
#define RAC_TXRAMP_TXRESETPAPOWER_reset                                   (_RAC_TXRAMP_TXRESETPAPOWER_reset << 9)              /**< Shifted mode reset for RAC_TXRAMP           */
#define RAC_TXRAMP_TXUNMUTEENDRVFF                                        (0x1UL << 10)                                        /**< TXUNMUTEENDRVFF                             */
#define _RAC_TXRAMP_TXUNMUTEENDRVFF_SHIFT                                 10                                                   /**< Shift value for RAC_TXUNMUTEENDRVFF         */
#define _RAC_TXRAMP_TXUNMUTEENDRVFF_MASK                                  0x400UL                                              /**< Bit mask for RAC_TXUNMUTEENDRVFF            */
#define _RAC_TXRAMP_TXUNMUTEENDRVFF_DEFAULT                               0x00000000UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXUNMUTEENDRVFF_driver_off                            0x00000000UL                                         /**< Mode driver_off for RAC_TXRAMP              */
#define _RAC_TXRAMP_TXUNMUTEENDRVFF_driver_on                             0x00000001UL                                         /**< Mode driver_on for RAC_TXRAMP               */
#define RAC_TXRAMP_TXUNMUTEENDRVFF_DEFAULT                                (_RAC_TXRAMP_TXUNMUTEENDRVFF_DEFAULT << 10)          /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXUNMUTEENDRVFF_driver_off                             (_RAC_TXRAMP_TXUNMUTEENDRVFF_driver_off << 10)       /**< Shifted mode driver_off for RAC_TXRAMP      */
#define RAC_TXRAMP_TXUNMUTEENDRVFF_driver_on                              (_RAC_TXRAMP_TXUNMUTEENDRVFF_driver_on << 10)        /**< Shifted mode driver_on for RAC_TXRAMP       */
#define RAC_TXRAMP_TXBYPASSBBDIGREG                                       (0x1UL << 11)                                        /**< TXBYPASSBBDIGREG                            */
#define _RAC_TXRAMP_TXBYPASSBBDIGREG_SHIFT                                11                                                   /**< Shift value for RAC_TXBYPASSBBDIGREG        */
#define _RAC_TXRAMP_TXBYPASSBBDIGREG_MASK                                 0x800UL                                              /**< Bit mask for RAC_TXBYPASSBBDIGREG           */
#define _RAC_TXRAMP_TXBYPASSBBDIGREG_DEFAULT                              0x00000000UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXBYPASSBBDIGREG_disabled                             0x00000000UL                                         /**< Mode disabled for RAC_TXRAMP                */
#define _RAC_TXRAMP_TXBYPASSBBDIGREG_enabled                              0x00000001UL                                         /**< Mode enabled for RAC_TXRAMP                 */
#define RAC_TXRAMP_TXBYPASSBBDIGREG_DEFAULT                               (_RAC_TXRAMP_TXBYPASSBBDIGREG_DEFAULT << 11)         /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXBYPASSBBDIGREG_disabled                              (_RAC_TXRAMP_TXBYPASSBBDIGREG_disabled << 11)        /**< Shifted mode disabled for RAC_TXRAMP        */
#define RAC_TXRAMP_TXBYPASSBBDIGREG_enabled                               (_RAC_TXRAMP_TXBYPASSBBDIGREG_enabled << 11)         /**< Shifted mode enabled for RAC_TXRAMP         */
#define RAC_TXRAMP_TXBYPASSBUFREG                                         (0x1UL << 18)                                        /**< TXBYPASSBUFREG                              */
#define _RAC_TXRAMP_TXBYPASSBUFREG_SHIFT                                  18                                                   /**< Shift value for RAC_TXBYPASSBUFREG          */
#define _RAC_TXRAMP_TXBYPASSBUFREG_MASK                                   0x40000UL                                            /**< Bit mask for RAC_TXBYPASSBUFREG             */
#define _RAC_TXRAMP_TXBYPASSBUFREG_DEFAULT                                0x00000000UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXBYPASSBUFREG_not_bypass                             0x00000000UL                                         /**< Mode not_bypass for RAC_TXRAMP              */
#define _RAC_TXRAMP_TXBYPASSBUFREG_bypass                                 0x00000001UL                                         /**< Mode bypass for RAC_TXRAMP                  */
#define RAC_TXRAMP_TXBYPASSBUFREG_DEFAULT                                 (_RAC_TXRAMP_TXBYPASSBUFREG_DEFAULT << 18)           /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXBYPASSBUFREG_not_bypass                              (_RAC_TXRAMP_TXBYPASSBUFREG_not_bypass << 18)        /**< Shifted mode not_bypass for RAC_TXRAMP      */
#define RAC_TXRAMP_TXBYPASSBUFREG_bypass                                  (_RAC_TXRAMP_TXBYPASSBUFREG_bypass << 18)            /**< Shifted mode bypass for RAC_TXRAMP          */
#define RAC_TXRAMP_TXSTARTUPITCCORE                                       (0x1UL << 19)                                        /**< TXSTARTUPITCCORE                            */
#define _RAC_TXRAMP_TXSTARTUPITCCORE_SHIFT                                19                                                   /**< Shift value for RAC_TXSTARTUPITCCORE        */
#define _RAC_TXRAMP_TXSTARTUPITCCORE_MASK                                 0x80000UL                                            /**< Bit mask for RAC_TXSTARTUPITCCORE           */
#define _RAC_TXRAMP_TXSTARTUPITCCORE_DEFAULT                              0x00000000UL                                         /**< Mode DEFAULT for RAC_TXRAMP                 */
#define _RAC_TXRAMP_TXSTARTUPITCCORE_disabled                             0x00000000UL                                         /**< Mode disabled for RAC_TXRAMP                */
#define _RAC_TXRAMP_TXSTARTUPITCCORE_enabled                              0x00000001UL                                         /**< Mode enabled for RAC_TXRAMP                 */
#define RAC_TXRAMP_TXSTARTUPITCCORE_DEFAULT                               (_RAC_TXRAMP_TXSTARTUPITCCORE_DEFAULT << 19)         /**< Shifted mode DEFAULT for RAC_TXRAMP         */
#define RAC_TXRAMP_TXSTARTUPITCCORE_disabled                              (_RAC_TXRAMP_TXSTARTUPITCCORE_disabled << 19)        /**< Shifted mode disabled for RAC_TXRAMP        */
#define RAC_TXRAMP_TXSTARTUPITCCORE_enabled                               (_RAC_TXRAMP_TXSTARTUPITCCORE_enabled << 19)         /**< Shifted mode enabled for RAC_TXRAMP         */

/* Bit fields for RAC PGATRIM */
#define _RAC_PGATRIM_RESETVALUE                                           0x00000A87UL                                   /**< Default value for RAC_PGATRIM               */
#define _RAC_PGATRIM_MASK                                                 0x00000FDFUL                                   /**< Mask for RAC_PGATRIM                        */
#define _RAC_PGATRIM_PGACTUNE_SHIFT                                       0                                              /**< Shift value for RAC_PGACTUNE                */
#define _RAC_PGATRIM_PGACTUNE_MASK                                        0x1FUL                                         /**< Bit mask for RAC_PGACTUNE                   */
#define _RAC_PGATRIM_PGACTUNE_DEFAULT                                     0x00000007UL                                   /**< Mode DEFAULT for RAC_PGATRIM                */
#define _RAC_PGATRIM_PGACTUNE_cfb_0p7                                     0x00000000UL                                   /**< Mode cfb_0p7 for RAC_PGATRIM                */
#define _RAC_PGATRIM_PGACTUNE_cfb_nominal                                 0x00000007UL                                   /**< Mode cfb_nominal for RAC_PGATRIM            */
#define _RAC_PGATRIM_PGACTUNE_cfb_1p32                                    0x0000000FUL                                   /**< Mode cfb_1p32 for RAC_PGATRIM               */
#define RAC_PGATRIM_PGACTUNE_DEFAULT                                      (_RAC_PGATRIM_PGACTUNE_DEFAULT << 0)           /**< Shifted mode DEFAULT for RAC_PGATRIM        */
#define RAC_PGATRIM_PGACTUNE_cfb_0p7                                      (_RAC_PGATRIM_PGACTUNE_cfb_0p7 << 0)           /**< Shifted mode cfb_0p7 for RAC_PGATRIM        */
#define RAC_PGATRIM_PGACTUNE_cfb_nominal                                  (_RAC_PGATRIM_PGACTUNE_cfb_nominal << 0)       /**< Shifted mode cfb_nominal for RAC_PGATRIM    */
#define RAC_PGATRIM_PGACTUNE_cfb_1p32                                     (_RAC_PGATRIM_PGACTUNE_cfb_1p32 << 0)          /**< Shifted mode cfb_1p32 for RAC_PGATRIM       */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_SHIFT                                  6                                              /**< Shift value for RAC_PGAVCMOUTTRIM           */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_MASK                                   0x1C0UL                                        /**< Bit mask for RAC_PGAVCMOUTTRIM              */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_DEFAULT                                0x00000002UL                                   /**< Mode DEFAULT for RAC_PGATRIM                */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p4                            0x00000000UL                                   /**< Mode vcm_out_0p4 for RAC_PGATRIM            */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p45                           0x00000001UL                                   /**< Mode vcm_out_0p45 for RAC_PGATRIM           */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p5                            0x00000002UL                                   /**< Mode vcm_out_0p5 for RAC_PGATRIM            */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p55                           0x00000003UL                                   /**< Mode vcm_out_0p55 for RAC_PGATRIM           */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p6                            0x00000004UL                                   /**< Mode vcm_out_0p6 for RAC_PGATRIM            */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p65                           0x00000005UL                                   /**< Mode vcm_out_0p65 for RAC_PGATRIM           */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p7                            0x00000006UL                                   /**< Mode vcm_out_0p7 for RAC_PGATRIM            */
#define _RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p75                           0x00000007UL                                   /**< Mode vcm_out_0p75 for RAC_PGATRIM           */
#define RAC_PGATRIM_PGAVCMOUTTRIM_DEFAULT                                 (_RAC_PGATRIM_PGAVCMOUTTRIM_DEFAULT << 6)      /**< Shifted mode DEFAULT for RAC_PGATRIM        */
#define RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p4                             (_RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p4 << 6)  /**< Shifted mode vcm_out_0p4 for RAC_PGATRIM    */
#define RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p45                            (_RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p45 << 6) /**< Shifted mode vcm_out_0p45 for RAC_PGATRIM   */
#define RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p5                             (_RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p5 << 6)  /**< Shifted mode vcm_out_0p5 for RAC_PGATRIM    */
#define RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p55                            (_RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p55 << 6) /**< Shifted mode vcm_out_0p55 for RAC_PGATRIM   */
#define RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p6                             (_RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p6 << 6)  /**< Shifted mode vcm_out_0p6 for RAC_PGATRIM    */
#define RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p65                            (_RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p65 << 6) /**< Shifted mode vcm_out_0p65 for RAC_PGATRIM   */
#define RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p7                             (_RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p7 << 6)  /**< Shifted mode vcm_out_0p7 for RAC_PGATRIM    */
#define RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p75                            (_RAC_PGATRIM_PGAVCMOUTTRIM_vcm_out_0p75 << 6) /**< Shifted mode vcm_out_0p75 for RAC_PGATRIM   */
#define _RAC_PGATRIM_PGAVLDOTRIM_SHIFT                                    9                                              /**< Shift value for RAC_PGAVLDOTRIM             */
#define _RAC_PGATRIM_PGAVLDOTRIM_MASK                                     0xE00UL                                        /**< Bit mask for RAC_PGAVLDOTRIM                */
#define _RAC_PGATRIM_PGAVLDOTRIM_DEFAULT                                  0x00000005UL                                   /**< Mode DEFAULT for RAC_PGATRIM                */
#define _RAC_PGATRIM_PGAVLDOTRIM_vdda_1p15                                0x00000000UL                                   /**< Mode vdda_1p15 for RAC_PGATRIM              */
#define _RAC_PGATRIM_PGAVLDOTRIM_vdda_1p2                                 0x00000001UL                                   /**< Mode vdda_1p2 for RAC_PGATRIM               */
#define _RAC_PGATRIM_PGAVLDOTRIM_vdda_1p25                                0x00000002UL                                   /**< Mode vdda_1p25 for RAC_PGATRIM              */
#define _RAC_PGATRIM_PGAVLDOTRIM_vdda_1p3                                 0x00000003UL                                   /**< Mode vdda_1p3 for RAC_PGATRIM               */
#define _RAC_PGATRIM_PGAVLDOTRIM_vdda_1p35                                0x00000004UL                                   /**< Mode vdda_1p35 for RAC_PGATRIM              */
#define _RAC_PGATRIM_PGAVLDOTRIM_vdda_1p4                                 0x00000005UL                                   /**< Mode vdda_1p4 for RAC_PGATRIM               */
#define _RAC_PGATRIM_PGAVLDOTRIM_vdda_1p5                                 0x00000006UL                                   /**< Mode vdda_1p5 for RAC_PGATRIM               */
#define _RAC_PGATRIM_PGAVLDOTRIM_vdda_1p55                                0x00000007UL                                   /**< Mode vdda_1p55 for RAC_PGATRIM              */
#define RAC_PGATRIM_PGAVLDOTRIM_DEFAULT                                   (_RAC_PGATRIM_PGAVLDOTRIM_DEFAULT << 9)        /**< Shifted mode DEFAULT for RAC_PGATRIM        */
#define RAC_PGATRIM_PGAVLDOTRIM_vdda_1p15                                 (_RAC_PGATRIM_PGAVLDOTRIM_vdda_1p15 << 9)      /**< Shifted mode vdda_1p15 for RAC_PGATRIM      */
#define RAC_PGATRIM_PGAVLDOTRIM_vdda_1p2                                  (_RAC_PGATRIM_PGAVLDOTRIM_vdda_1p2 << 9)       /**< Shifted mode vdda_1p2 for RAC_PGATRIM       */
#define RAC_PGATRIM_PGAVLDOTRIM_vdda_1p25                                 (_RAC_PGATRIM_PGAVLDOTRIM_vdda_1p25 << 9)      /**< Shifted mode vdda_1p25 for RAC_PGATRIM      */
#define RAC_PGATRIM_PGAVLDOTRIM_vdda_1p3                                  (_RAC_PGATRIM_PGAVLDOTRIM_vdda_1p3 << 9)       /**< Shifted mode vdda_1p3 for RAC_PGATRIM       */
#define RAC_PGATRIM_PGAVLDOTRIM_vdda_1p35                                 (_RAC_PGATRIM_PGAVLDOTRIM_vdda_1p35 << 9)      /**< Shifted mode vdda_1p35 for RAC_PGATRIM      */
#define RAC_PGATRIM_PGAVLDOTRIM_vdda_1p4                                  (_RAC_PGATRIM_PGAVLDOTRIM_vdda_1p4 << 9)       /**< Shifted mode vdda_1p4 for RAC_PGATRIM       */
#define RAC_PGATRIM_PGAVLDOTRIM_vdda_1p5                                  (_RAC_PGATRIM_PGAVLDOTRIM_vdda_1p5 << 9)       /**< Shifted mode vdda_1p5 for RAC_PGATRIM       */
#define RAC_PGATRIM_PGAVLDOTRIM_vdda_1p55                                 (_RAC_PGATRIM_PGAVLDOTRIM_vdda_1p55 << 9)      /**< Shifted mode vdda_1p55 for RAC_PGATRIM      */

/* Bit fields for RAC PGACAL */
#define _RAC_PGACAL_RESETVALUE                                            0x20200000UL                                  /**< Default value for RAC_PGACAL                */
#define _RAC_PGACAL_MASK                                                  0x3F3F0000UL                                  /**< Mask for RAC_PGACAL                         */
#define _RAC_PGACAL_PGAOFFCALI_SHIFT                                      16                                            /**< Shift value for RAC_PGAOFFCALI              */
#define _RAC_PGACAL_PGAOFFCALI_MASK                                       0x3F0000UL                                    /**< Bit mask for RAC_PGAOFFCALI                 */
#define _RAC_PGACAL_PGAOFFCALI_DEFAULT                                    0x00000020UL                                  /**< Mode DEFAULT for RAC_PGACAL                 */
#define _RAC_PGACAL_PGAOFFCALI_offset_m_300mv                             0x00000000UL                                  /**< Mode offset_m_300mv for RAC_PGACAL          */
#define _RAC_PGACAL_PGAOFFCALI_offset_p_300mv                             0x0000003FUL                                  /**< Mode offset_p_300mv for RAC_PGACAL          */
#define RAC_PGACAL_PGAOFFCALI_DEFAULT                                     (_RAC_PGACAL_PGAOFFCALI_DEFAULT << 16)        /**< Shifted mode DEFAULT for RAC_PGACAL         */
#define RAC_PGACAL_PGAOFFCALI_offset_m_300mv                              (_RAC_PGACAL_PGAOFFCALI_offset_m_300mv << 16) /**< Shifted mode offset_m_300mv for RAC_PGACAL  */
#define RAC_PGACAL_PGAOFFCALI_offset_p_300mv                              (_RAC_PGACAL_PGAOFFCALI_offset_p_300mv << 16) /**< Shifted mode offset_p_300mv for RAC_PGACAL  */
#define _RAC_PGACAL_PGAOFFCALQ_SHIFT                                      24                                            /**< Shift value for RAC_PGAOFFCALQ              */
#define _RAC_PGACAL_PGAOFFCALQ_MASK                                       0x3F000000UL                                  /**< Bit mask for RAC_PGAOFFCALQ                 */
#define _RAC_PGACAL_PGAOFFCALQ_DEFAULT                                    0x00000020UL                                  /**< Mode DEFAULT for RAC_PGACAL                 */
#define _RAC_PGACAL_PGAOFFCALQ_offset_m_300mv                             0x00000000UL                                  /**< Mode offset_m_300mv for RAC_PGACAL          */
#define _RAC_PGACAL_PGAOFFCALQ_offset_p_300mv                             0x0000003FUL                                  /**< Mode offset_p_300mv for RAC_PGACAL          */
#define RAC_PGACAL_PGAOFFCALQ_DEFAULT                                     (_RAC_PGACAL_PGAOFFCALQ_DEFAULT << 24)        /**< Shifted mode DEFAULT for RAC_PGACAL         */
#define RAC_PGACAL_PGAOFFCALQ_offset_m_300mv                              (_RAC_PGACAL_PGAOFFCALQ_offset_m_300mv << 24) /**< Shifted mode offset_m_300mv for RAC_PGACAL  */
#define RAC_PGACAL_PGAOFFCALQ_offset_p_300mv                              (_RAC_PGACAL_PGAOFFCALQ_offset_p_300mv << 24) /**< Shifted mode offset_p_300mv for RAC_PGACAL  */

/* Bit fields for RAC PGACTRL */
#define _RAC_PGACTRL_RESETVALUE                                           0x00000003UL                                        /**< Default value for RAC_PGACTRL               */
#define _RAC_PGACTRL_MASK                                                 0x01FFEFFFUL                                        /**< Mask for RAC_PGACTRL                        */
#define _RAC_PGACTRL_PGABWMODE_SHIFT                                      0                                                   /**< Shift value for RAC_PGABWMODE               */
#define _RAC_PGACTRL_PGABWMODE_MASK                                       0xFUL                                               /**< Bit mask for RAC_PGABWMODE                  */
#define _RAC_PGACTRL_PGABWMODE_DEFAULT                                    0x00000003UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGABWMODE_bw_5MHz                                    0x00000000UL                                        /**< Mode bw_5MHz for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGABWMODE_bw_2p5MHz                                  0x00000001UL                                        /**< Mode bw_2p5MHz for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGABWMODE_bw_625kHz                                  0x00000002UL                                        /**< Mode bw_625kHz for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGABWMODE_bw_1p25MHz                                 0x00000003UL                                        /**< Mode bw_1p25MHz for RAC_PGACTRL             */
#define RAC_PGACTRL_PGABWMODE_DEFAULT                                     (_RAC_PGACTRL_PGABWMODE_DEFAULT << 0)               /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGABWMODE_bw_5MHz                                     (_RAC_PGACTRL_PGABWMODE_bw_5MHz << 0)               /**< Shifted mode bw_5MHz for RAC_PGACTRL        */
#define RAC_PGACTRL_PGABWMODE_bw_2p5MHz                                   (_RAC_PGACTRL_PGABWMODE_bw_2p5MHz << 0)             /**< Shifted mode bw_2p5MHz for RAC_PGACTRL      */
#define RAC_PGACTRL_PGABWMODE_bw_625kHz                                   (_RAC_PGACTRL_PGABWMODE_bw_625kHz << 0)             /**< Shifted mode bw_625kHz for RAC_PGACTRL      */
#define RAC_PGACTRL_PGABWMODE_bw_1p25MHz                                  (_RAC_PGACTRL_PGABWMODE_bw_1p25MHz << 0)            /**< Shifted mode bw_1p25MHz for RAC_PGACTRL     */
#define RAC_PGACTRL_PGAENBIAS                                             (0x1UL << 4)                                        /**< PGAENBIAS                                   */
#define _RAC_PGACTRL_PGAENBIAS_SHIFT                                      4                                                   /**< Shift value for RAC_PGAENBIAS               */
#define _RAC_PGACTRL_PGAENBIAS_MASK                                       0x10UL                                              /**< Bit mask for RAC_PGAENBIAS                  */
#define _RAC_PGACTRL_PGAENBIAS_DEFAULT                                    0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGAENBIAS_bias_disable                               0x00000000UL                                        /**< Mode bias_disable for RAC_PGACTRL           */
#define _RAC_PGACTRL_PGAENBIAS_bias_enable                                0x00000001UL                                        /**< Mode bias_enable for RAC_PGACTRL            */
#define RAC_PGACTRL_PGAENBIAS_DEFAULT                                     (_RAC_PGACTRL_PGAENBIAS_DEFAULT << 4)               /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGAENBIAS_bias_disable                                (_RAC_PGACTRL_PGAENBIAS_bias_disable << 4)          /**< Shifted mode bias_disable for RAC_PGACTRL   */
#define RAC_PGACTRL_PGAENBIAS_bias_enable                                 (_RAC_PGACTRL_PGAENBIAS_bias_enable << 4)           /**< Shifted mode bias_enable for RAC_PGACTRL    */
#define RAC_PGACTRL_PGAENGHZ                                              (0x1UL << 5)                                        /**< PGAENGHZ                                    */
#define _RAC_PGACTRL_PGAENGHZ_SHIFT                                       5                                                   /**< Shift value for RAC_PGAENGHZ                */
#define _RAC_PGACTRL_PGAENGHZ_MASK                                        0x20UL                                              /**< Bit mask for RAC_PGAENGHZ                   */
#define _RAC_PGACTRL_PGAENGHZ_DEFAULT                                     0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGAENGHZ_ghz_disable                                 0x00000000UL                                        /**< Mode ghz_disable for RAC_PGACTRL            */
#define _RAC_PGACTRL_PGAENGHZ_ghz_enable                                  0x00000001UL                                        /**< Mode ghz_enable for RAC_PGACTRL             */
#define RAC_PGACTRL_PGAENGHZ_DEFAULT                                      (_RAC_PGACTRL_PGAENGHZ_DEFAULT << 5)                /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGAENGHZ_ghz_disable                                  (_RAC_PGACTRL_PGAENGHZ_ghz_disable << 5)            /**< Shifted mode ghz_disable for RAC_PGACTRL    */
#define RAC_PGACTRL_PGAENGHZ_ghz_enable                                   (_RAC_PGACTRL_PGAENGHZ_ghz_enable << 5)             /**< Shifted mode ghz_enable for RAC_PGACTRL     */
#define RAC_PGACTRL_PGAENLATCHI                                           (0x1UL << 6)                                        /**< PGAENLATCHI                                 */
#define _RAC_PGACTRL_PGAENLATCHI_SHIFT                                    6                                                   /**< Shift value for RAC_PGAENLATCHI             */
#define _RAC_PGACTRL_PGAENLATCHI_MASK                                     0x40UL                                              /**< Bit mask for RAC_PGAENLATCHI                */
#define _RAC_PGACTRL_PGAENLATCHI_DEFAULT                                  0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGAENLATCHI_pkd_latch_i_disable                      0x00000000UL                                        /**< Mode pkd_latch_i_disable for RAC_PGACTRL    */
#define _RAC_PGACTRL_PGAENLATCHI_pkd_latch_i_enable                       0x00000001UL                                        /**< Mode pkd_latch_i_enable for RAC_PGACTRL     */
#define RAC_PGACTRL_PGAENLATCHI_DEFAULT                                   (_RAC_PGACTRL_PGAENLATCHI_DEFAULT << 6)             /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGAENLATCHI_pkd_latch_i_disable                       (_RAC_PGACTRL_PGAENLATCHI_pkd_latch_i_disable << 6) /**< Shifted mode pkd_latch_i_disable for RAC_PGACTRL*/
#define RAC_PGACTRL_PGAENLATCHI_pkd_latch_i_enable                        (_RAC_PGACTRL_PGAENLATCHI_pkd_latch_i_enable << 6)  /**< Shifted mode pkd_latch_i_enable for RAC_PGACTRL*/
#define RAC_PGACTRL_PGAENLATCHQ                                           (0x1UL << 7)                                        /**< PGAENLATCHQ                                 */
#define _RAC_PGACTRL_PGAENLATCHQ_SHIFT                                    7                                                   /**< Shift value for RAC_PGAENLATCHQ             */
#define _RAC_PGACTRL_PGAENLATCHQ_MASK                                     0x80UL                                              /**< Bit mask for RAC_PGAENLATCHQ                */
#define _RAC_PGACTRL_PGAENLATCHQ_DEFAULT                                  0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGAENLATCHQ_pkd_latch_q_disable                      0x00000000UL                                        /**< Mode pkd_latch_q_disable for RAC_PGACTRL    */
#define _RAC_PGACTRL_PGAENLATCHQ_pkd_latch_q_enable                       0x00000001UL                                        /**< Mode pkd_latch_q_enable for RAC_PGACTRL     */
#define RAC_PGACTRL_PGAENLATCHQ_DEFAULT                                   (_RAC_PGACTRL_PGAENLATCHQ_DEFAULT << 7)             /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGAENLATCHQ_pkd_latch_q_disable                       (_RAC_PGACTRL_PGAENLATCHQ_pkd_latch_q_disable << 7) /**< Shifted mode pkd_latch_q_disable for RAC_PGACTRL*/
#define RAC_PGACTRL_PGAENLATCHQ_pkd_latch_q_enable                        (_RAC_PGACTRL_PGAENLATCHQ_pkd_latch_q_enable << 7)  /**< Shifted mode pkd_latch_q_enable for RAC_PGACTRL*/
#define RAC_PGACTRL_PGAENLDOLOAD                                          (0x1UL << 8)                                        /**< PGAENLDOLOAD                                */
#define _RAC_PGACTRL_PGAENLDOLOAD_SHIFT                                   8                                                   /**< Shift value for RAC_PGAENLDOLOAD            */
#define _RAC_PGACTRL_PGAENLDOLOAD_MASK                                    0x100UL                                             /**< Bit mask for RAC_PGAENLDOLOAD               */
#define _RAC_PGACTRL_PGAENLDOLOAD_DEFAULT                                 0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGAENLDOLOAD_disable_ldo_load                        0x00000000UL                                        /**< Mode disable_ldo_load for RAC_PGACTRL       */
#define _RAC_PGACTRL_PGAENLDOLOAD_enable_ldo_load                         0x00000001UL                                        /**< Mode enable_ldo_load for RAC_PGACTRL        */
#define RAC_PGACTRL_PGAENLDOLOAD_DEFAULT                                  (_RAC_PGACTRL_PGAENLDOLOAD_DEFAULT << 8)            /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGAENLDOLOAD_disable_ldo_load                         (_RAC_PGACTRL_PGAENLDOLOAD_disable_ldo_load << 8)   /**< Shifted mode disable_ldo_load for RAC_PGACTRL*/
#define RAC_PGACTRL_PGAENLDOLOAD_enable_ldo_load                          (_RAC_PGACTRL_PGAENLDOLOAD_enable_ldo_load << 8)    /**< Shifted mode enable_ldo_load for RAC_PGACTRL*/
#define RAC_PGACTRL_PGAENPGAI                                             (0x1UL << 9)                                        /**< PGAENPGAI                                   */
#define _RAC_PGACTRL_PGAENPGAI_SHIFT                                      9                                                   /**< Shift value for RAC_PGAENPGAI               */
#define _RAC_PGACTRL_PGAENPGAI_MASK                                       0x200UL                                             /**< Bit mask for RAC_PGAENPGAI                  */
#define _RAC_PGACTRL_PGAENPGAI_DEFAULT                                    0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGAENPGAI_pgai_disable                               0x00000000UL                                        /**< Mode pgai_disable for RAC_PGACTRL           */
#define _RAC_PGACTRL_PGAENPGAI_pgai_enable                                0x00000001UL                                        /**< Mode pgai_enable for RAC_PGACTRL            */
#define RAC_PGACTRL_PGAENPGAI_DEFAULT                                     (_RAC_PGACTRL_PGAENPGAI_DEFAULT << 9)               /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGAENPGAI_pgai_disable                                (_RAC_PGACTRL_PGAENPGAI_pgai_disable << 9)          /**< Shifted mode pgai_disable for RAC_PGACTRL   */
#define RAC_PGACTRL_PGAENPGAI_pgai_enable                                 (_RAC_PGACTRL_PGAENPGAI_pgai_enable << 9)           /**< Shifted mode pgai_enable for RAC_PGACTRL    */
#define RAC_PGACTRL_PGAENPGAQ                                             (0x1UL << 10)                                       /**< PGAENPGAQ                                   */
#define _RAC_PGACTRL_PGAENPGAQ_SHIFT                                      10                                                  /**< Shift value for RAC_PGAENPGAQ               */
#define _RAC_PGACTRL_PGAENPGAQ_MASK                                       0x400UL                                             /**< Bit mask for RAC_PGAENPGAQ                  */
#define _RAC_PGACTRL_PGAENPGAQ_DEFAULT                                    0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGAENPGAQ_pgaq_disable                               0x00000000UL                                        /**< Mode pgaq_disable for RAC_PGACTRL           */
#define _RAC_PGACTRL_PGAENPGAQ_pgaq_enable                                0x00000001UL                                        /**< Mode pgaq_enable for RAC_PGACTRL            */
#define RAC_PGACTRL_PGAENPGAQ_DEFAULT                                     (_RAC_PGACTRL_PGAENPGAQ_DEFAULT << 10)              /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGAENPGAQ_pgaq_disable                                (_RAC_PGACTRL_PGAENPGAQ_pgaq_disable << 10)         /**< Shifted mode pgaq_disable for RAC_PGACTRL   */
#define RAC_PGACTRL_PGAENPGAQ_pgaq_enable                                 (_RAC_PGACTRL_PGAENPGAQ_pgaq_enable << 10)          /**< Shifted mode pgaq_enable for RAC_PGACTRL    */
#define RAC_PGACTRL_PGAENPKD                                              (0x1UL << 11)                                       /**< PGAENPKD                                    */
#define _RAC_PGACTRL_PGAENPKD_SHIFT                                       11                                                  /**< Shift value for RAC_PGAENPKD                */
#define _RAC_PGACTRL_PGAENPKD_MASK                                        0x800UL                                             /**< Bit mask for RAC_PGAENPKD                   */
#define _RAC_PGACTRL_PGAENPKD_DEFAULT                                     0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGAENPKD_pkd_disable                                 0x00000000UL                                        /**< Mode pkd_disable for RAC_PGACTRL            */
#define _RAC_PGACTRL_PGAENPKD_pkd_enable                                  0x00000001UL                                        /**< Mode pkd_enable for RAC_PGACTRL             */
#define RAC_PGACTRL_PGAENPKD_DEFAULT                                      (_RAC_PGACTRL_PGAENPKD_DEFAULT << 11)               /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGAENPKD_pkd_disable                                  (_RAC_PGACTRL_PGAENPKD_pkd_disable << 11)           /**< Shifted mode pkd_disable for RAC_PGACTRL    */
#define RAC_PGACTRL_PGAENPKD_pkd_enable                                   (_RAC_PGACTRL_PGAENPKD_pkd_enable << 11)            /**< Shifted mode pkd_enable for RAC_PGACTRL     */
#define _RAC_PGACTRL_PGAPOWERMODE_SHIFT                                   14                                                  /**< Shift value for RAC_PGAPOWERMODE            */
#define _RAC_PGACTRL_PGAPOWERMODE_MASK                                    0x1C000UL                                           /**< Bit mask for RAC_PGAPOWERMODE               */
#define _RAC_PGACTRL_PGAPOWERMODE_DEFAULT                                 0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGAPOWERMODE_pm_typ                                  0x00000000UL                                        /**< Mode pm_typ for RAC_PGACTRL                 */
#define _RAC_PGACTRL_PGAPOWERMODE_pm_0p9                                  0x00000001UL                                        /**< Mode pm_0p9 for RAC_PGACTRL                 */
#define _RAC_PGACTRL_PGAPOWERMODE_pm_1p2                                  0x00000002UL                                        /**< Mode pm_1p2 for RAC_PGACTRL                 */
#define _RAC_PGACTRL_PGAPOWERMODE_pm_0p8                                  0x00000003UL                                        /**< Mode pm_0p8 for RAC_PGACTRL                 */
#define RAC_PGACTRL_PGAPOWERMODE_DEFAULT                                  (_RAC_PGACTRL_PGAPOWERMODE_DEFAULT << 14)           /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGAPOWERMODE_pm_typ                                   (_RAC_PGACTRL_PGAPOWERMODE_pm_typ << 14)            /**< Shifted mode pm_typ for RAC_PGACTRL         */
#define RAC_PGACTRL_PGAPOWERMODE_pm_0p9                                   (_RAC_PGACTRL_PGAPOWERMODE_pm_0p9 << 14)            /**< Shifted mode pm_0p9 for RAC_PGACTRL         */
#define RAC_PGACTRL_PGAPOWERMODE_pm_1p2                                   (_RAC_PGACTRL_PGAPOWERMODE_pm_1p2 << 14)            /**< Shifted mode pm_1p2 for RAC_PGACTRL         */
#define RAC_PGACTRL_PGAPOWERMODE_pm_0p8                                   (_RAC_PGACTRL_PGAPOWERMODE_pm_0p8 << 14)            /**< Shifted mode pm_0p8 for RAC_PGACTRL         */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_SHIFT                                 17                                                  /**< Shift value for RAC_PGATHRPKDLOSEL          */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_MASK                                  0x1E0000UL                                          /**< Bit mask for RAC_PGATHRPKDLOSEL             */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_DEFAULT                               0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref50mv                              0x00000000UL                                        /**< Mode vref50mv for RAC_PGACTRL               */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref75mv                              0x00000001UL                                        /**< Mode vref75mv for RAC_PGACTRL               */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref100mv                             0x00000002UL                                        /**< Mode vref100mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref125mv                             0x00000003UL                                        /**< Mode vref125mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref150mv                             0x00000004UL                                        /**< Mode vref150mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref175mv                             0x00000005UL                                        /**< Mode vref175mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref200mv                             0x00000006UL                                        /**< Mode vref200mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref225mv                             0x00000007UL                                        /**< Mode vref225mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref250mv                             0x00000008UL                                        /**< Mode vref250mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref275mv                             0x00000009UL                                        /**< Mode vref275mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDLOSEL_vref300mv                             0x0000000AUL                                        /**< Mode vref300mv for RAC_PGACTRL              */
#define RAC_PGACTRL_PGATHRPKDLOSEL_DEFAULT                                (_RAC_PGACTRL_PGATHRPKDLOSEL_DEFAULT << 17)         /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref50mv                               (_RAC_PGACTRL_PGATHRPKDLOSEL_vref50mv << 17)        /**< Shifted mode vref50mv for RAC_PGACTRL       */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref75mv                               (_RAC_PGACTRL_PGATHRPKDLOSEL_vref75mv << 17)        /**< Shifted mode vref75mv for RAC_PGACTRL       */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref100mv                              (_RAC_PGACTRL_PGATHRPKDLOSEL_vref100mv << 17)       /**< Shifted mode vref100mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref125mv                              (_RAC_PGACTRL_PGATHRPKDLOSEL_vref125mv << 17)       /**< Shifted mode vref125mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref150mv                              (_RAC_PGACTRL_PGATHRPKDLOSEL_vref150mv << 17)       /**< Shifted mode vref150mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref175mv                              (_RAC_PGACTRL_PGATHRPKDLOSEL_vref175mv << 17)       /**< Shifted mode vref175mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref200mv                              (_RAC_PGACTRL_PGATHRPKDLOSEL_vref200mv << 17)       /**< Shifted mode vref200mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref225mv                              (_RAC_PGACTRL_PGATHRPKDLOSEL_vref225mv << 17)       /**< Shifted mode vref225mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref250mv                              (_RAC_PGACTRL_PGATHRPKDLOSEL_vref250mv << 17)       /**< Shifted mode vref250mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref275mv                              (_RAC_PGACTRL_PGATHRPKDLOSEL_vref275mv << 17)       /**< Shifted mode vref275mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDLOSEL_vref300mv                              (_RAC_PGACTRL_PGATHRPKDLOSEL_vref300mv << 17)       /**< Shifted mode vref300mv for RAC_PGACTRL      */
#define _RAC_PGACTRL_PGATHRPKDHISEL_SHIFT                                 21                                                  /**< Shift value for RAC_PGATHRPKDHISEL          */
#define _RAC_PGACTRL_PGATHRPKDHISEL_MASK                                  0x1E00000UL                                         /**< Bit mask for RAC_PGATHRPKDHISEL             */
#define _RAC_PGACTRL_PGATHRPKDHISEL_DEFAULT                               0x00000000UL                                        /**< Mode DEFAULT for RAC_PGACTRL                */
#define _RAC_PGACTRL_PGATHRPKDHISEL_vref50mv                              0x00000000UL                                        /**< Mode vref50mv for RAC_PGACTRL               */
#define _RAC_PGACTRL_PGATHRPKDHISEL_vref75mv                              0x00000001UL                                        /**< Mode vref75mv for RAC_PGACTRL               */
#define _RAC_PGACTRL_PGATHRPKDHISEL_vref100mv                             0x00000002UL                                        /**< Mode vref100mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDHISEL_vref125mv                             0x00000003UL                                        /**< Mode vref125mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDHISEL_verf150mv                             0x00000004UL                                        /**< Mode verf150mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDHISEL_vref175mv                             0x00000005UL                                        /**< Mode vref175mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDHISEL_vref200mv                             0x00000006UL                                        /**< Mode vref200mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDHISEL_vref225mv                             0x00000007UL                                        /**< Mode vref225mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDHISEL_vref250mv                             0x00000008UL                                        /**< Mode vref250mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDHISEL_vref275mv                             0x00000009UL                                        /**< Mode vref275mv for RAC_PGACTRL              */
#define _RAC_PGACTRL_PGATHRPKDHISEL_vref300mv                             0x0000000AUL                                        /**< Mode vref300mv for RAC_PGACTRL              */
#define RAC_PGACTRL_PGATHRPKDHISEL_DEFAULT                                (_RAC_PGACTRL_PGATHRPKDHISEL_DEFAULT << 21)         /**< Shifted mode DEFAULT for RAC_PGACTRL        */
#define RAC_PGACTRL_PGATHRPKDHISEL_vref50mv                               (_RAC_PGACTRL_PGATHRPKDHISEL_vref50mv << 21)        /**< Shifted mode vref50mv for RAC_PGACTRL       */
#define RAC_PGACTRL_PGATHRPKDHISEL_vref75mv                               (_RAC_PGACTRL_PGATHRPKDHISEL_vref75mv << 21)        /**< Shifted mode vref75mv for RAC_PGACTRL       */
#define RAC_PGACTRL_PGATHRPKDHISEL_vref100mv                              (_RAC_PGACTRL_PGATHRPKDHISEL_vref100mv << 21)       /**< Shifted mode vref100mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDHISEL_vref125mv                              (_RAC_PGACTRL_PGATHRPKDHISEL_vref125mv << 21)       /**< Shifted mode vref125mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDHISEL_verf150mv                              (_RAC_PGACTRL_PGATHRPKDHISEL_verf150mv << 21)       /**< Shifted mode verf150mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDHISEL_vref175mv                              (_RAC_PGACTRL_PGATHRPKDHISEL_vref175mv << 21)       /**< Shifted mode vref175mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDHISEL_vref200mv                              (_RAC_PGACTRL_PGATHRPKDHISEL_vref200mv << 21)       /**< Shifted mode vref200mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDHISEL_vref225mv                              (_RAC_PGACTRL_PGATHRPKDHISEL_vref225mv << 21)       /**< Shifted mode vref225mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDHISEL_vref250mv                              (_RAC_PGACTRL_PGATHRPKDHISEL_vref250mv << 21)       /**< Shifted mode vref250mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDHISEL_vref275mv                              (_RAC_PGACTRL_PGATHRPKDHISEL_vref275mv << 21)       /**< Shifted mode vref275mv for RAC_PGACTRL      */
#define RAC_PGACTRL_PGATHRPKDHISEL_vref300mv                              (_RAC_PGACTRL_PGATHRPKDHISEL_vref300mv << 21)       /**< Shifted mode vref300mv for RAC_PGACTRL      */

/* Bit fields for RAC RFBIASCAL */
#define _RAC_RFBIASCAL_RESETVALUE                                         0x30203020UL                                        /**< Default value for RAC_RFBIASCAL             */
#define _RAC_RFBIASCAL_MASK                                               0x3F3F3F3FUL                                        /**< Mask for RAC_RFBIASCAL                      */
#define _RAC_RFBIASCAL_RFBIASCALBIAS_SHIFT                                0                                                   /**< Shift value for RAC_RFBIASCALBIAS           */
#define _RAC_RFBIASCAL_RFBIASCALBIAS_MASK                                 0x3FUL                                              /**< Bit mask for RAC_RFBIASCALBIAS              */
#define _RAC_RFBIASCAL_RFBIASCALBIAS_DEFAULT                              0x00000020UL                                        /**< Mode DEFAULT for RAC_RFBIASCAL              */
#define RAC_RFBIASCAL_RFBIASCALBIAS_DEFAULT                               (_RAC_RFBIASCAL_RFBIASCALBIAS_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_RFBIASCAL      */
#define _RAC_RFBIASCAL_RFBIASCALTC_SHIFT                                  8                                                   /**< Shift value for RAC_RFBIASCALTC             */
#define _RAC_RFBIASCAL_RFBIASCALTC_MASK                                   0x3F00UL                                            /**< Bit mask for RAC_RFBIASCALTC                */
#define _RAC_RFBIASCAL_RFBIASCALTC_DEFAULT                                0x00000030UL                                        /**< Mode DEFAULT for RAC_RFBIASCAL              */
#define RAC_RFBIASCAL_RFBIASCALTC_DEFAULT                                 (_RAC_RFBIASCAL_RFBIASCALTC_DEFAULT << 8)           /**< Shifted mode DEFAULT for RAC_RFBIASCAL      */
#define _RAC_RFBIASCAL_RFBIASCALVREF_SHIFT                                16                                                  /**< Shift value for RAC_RFBIASCALVREF           */
#define _RAC_RFBIASCAL_RFBIASCALVREF_MASK                                 0x3F0000UL                                          /**< Bit mask for RAC_RFBIASCALVREF              */
#define _RAC_RFBIASCAL_RFBIASCALVREF_DEFAULT                              0x00000020UL                                        /**< Mode DEFAULT for RAC_RFBIASCAL              */
#define RAC_RFBIASCAL_RFBIASCALVREF_DEFAULT                               (_RAC_RFBIASCAL_RFBIASCALVREF_DEFAULT << 16)        /**< Shifted mode DEFAULT for RAC_RFBIASCAL      */
#define _RAC_RFBIASCAL_RFBIASCALVREFSTARTUP_SHIFT                         24                                                  /**< Shift value for RAC_RFBIASCALVREFSTARTUP    */
#define _RAC_RFBIASCAL_RFBIASCALVREFSTARTUP_MASK                          0x3F000000UL                                        /**< Bit mask for RAC_RFBIASCALVREFSTARTUP       */
#define _RAC_RFBIASCAL_RFBIASCALVREFSTARTUP_DEFAULT                       0x00000030UL                                        /**< Mode DEFAULT for RAC_RFBIASCAL              */
#define RAC_RFBIASCAL_RFBIASCALVREFSTARTUP_DEFAULT                        (_RAC_RFBIASCAL_RFBIASCALVREFSTARTUP_DEFAULT << 24) /**< Shifted mode DEFAULT for RAC_RFBIASCAL      */

/* Bit fields for RAC RFBIASCTRL */
#define _RAC_RFBIASCTRL_RESETVALUE                                        0x00040000UL                                                  /**< Default value for RAC_RFBIASCTRL            */
#define _RAC_RFBIASCTRL_MASK                                              0x000F001FUL                                                  /**< Mask for RAC_RFBIASCTRL                     */
#define RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP                             (0x1UL << 0)                                                  /**< RFBIASDISABLEBOOTSTRAP                      */
#define _RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_SHIFT                      0                                                             /**< Shift value for RAC_RFBIASDISABLEBOOTSTRAP  */
#define _RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_MASK                       0x1UL                                                         /**< Bit mask for RAC_RFBIASDISABLEBOOTSTRAP     */
#define _RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_DEFAULT                    0x00000000UL                                                  /**< Mode DEFAULT for RAC_RFBIASCTRL             */
#define _RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_enable_startup             0x00000000UL                                                  /**< Mode enable_startup for RAC_RFBIASCTRL      */
#define _RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_disable_startup            0x00000001UL                                                  /**< Mode disable_startup for RAC_RFBIASCTRL     */
#define RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_DEFAULT                     (_RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_RFBIASCTRL     */
#define RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_enable_startup              (_RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_enable_startup << 0)  /**< Shifted mode enable_startup for RAC_RFBIASCTRL*/
#define RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_disable_startup             (_RAC_RFBIASCTRL_RFBIASDISABLEBOOTSTRAP_disable_startup << 0) /**< Shifted mode disable_startup for RAC_RFBIASCTRL*/
#define RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT                               (0x1UL << 1)                                                  /**< RFBIASLDOHIGHCURRENT                        */
#define _RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_SHIFT                        1                                                             /**< Shift value for RAC_RFBIASLDOHIGHCURRENT    */
#define _RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_MASK                         0x2UL                                                         /**< Bit mask for RAC_RFBIASLDOHIGHCURRENT       */
#define _RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_DEFAULT                      0x00000000UL                                                  /**< Mode DEFAULT for RAC_RFBIASCTRL             */
#define _RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_low_current                  0x00000000UL                                                  /**< Mode low_current for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_high_current                 0x00000001UL                                                  /**< Mode high_current for RAC_RFBIASCTRL        */
#define RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_DEFAULT                       (_RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_DEFAULT << 1)           /**< Shifted mode DEFAULT for RAC_RFBIASCTRL     */
#define RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_low_current                   (_RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_low_current << 1)       /**< Shifted mode low_current for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_high_current                  (_RAC_RFBIASCTRL_RFBIASLDOHIGHCURRENT_high_current << 1)      /**< Shifted mode high_current for RAC_RFBIASCTRL*/
#define RAC_RFBIASCTRL_RFBIASNONFLASHMODE                                 (0x1UL << 2)                                                  /**< RFBIASNONFLASHMODE                          */
#define _RAC_RFBIASCTRL_RFBIASNONFLASHMODE_SHIFT                          2                                                             /**< Shift value for RAC_RFBIASNONFLASHMODE      */
#define _RAC_RFBIASCTRL_RFBIASNONFLASHMODE_MASK                           0x4UL                                                         /**< Bit mask for RAC_RFBIASNONFLASHMODE         */
#define _RAC_RFBIASCTRL_RFBIASNONFLASHMODE_DEFAULT                        0x00000000UL                                                  /**< Mode DEFAULT for RAC_RFBIASCTRL             */
#define _RAC_RFBIASCTRL_RFBIASNONFLASHMODE_flash_process                  0x00000000UL                                                  /**< Mode flash_process for RAC_RFBIASCTRL       */
#define _RAC_RFBIASCTRL_RFBIASNONFLASHMODE_non_flash_process              0x00000001UL                                                  /**< Mode non_flash_process for RAC_RFBIASCTRL   */
#define RAC_RFBIASCTRL_RFBIASNONFLASHMODE_DEFAULT                         (_RAC_RFBIASCTRL_RFBIASNONFLASHMODE_DEFAULT << 2)             /**< Shifted mode DEFAULT for RAC_RFBIASCTRL     */
#define RAC_RFBIASCTRL_RFBIASNONFLASHMODE_flash_process                   (_RAC_RFBIASCTRL_RFBIASNONFLASHMODE_flash_process << 2)       /**< Shifted mode flash_process for RAC_RFBIASCTRL*/
#define RAC_RFBIASCTRL_RFBIASNONFLASHMODE_non_flash_process               (_RAC_RFBIASCTRL_RFBIASNONFLASHMODE_non_flash_process << 2)   /**< Shifted mode non_flash_process for RAC_RFBIASCTRL*/
#define RAC_RFBIASCTRL_RFBIASSTARTUPCORE                                  (0x1UL << 3)                                                  /**< RFBIASSTARTUPCORE                           */
#define _RAC_RFBIASCTRL_RFBIASSTARTUPCORE_SHIFT                           3                                                             /**< Shift value for RAC_RFBIASSTARTUPCORE       */
#define _RAC_RFBIASCTRL_RFBIASSTARTUPCORE_MASK                            0x8UL                                                         /**< Bit mask for RAC_RFBIASSTARTUPCORE          */
#define _RAC_RFBIASCTRL_RFBIASSTARTUPCORE_DEFAULT                         0x00000000UL                                                  /**< Mode DEFAULT for RAC_RFBIASCTRL             */
#define _RAC_RFBIASCTRL_RFBIASSTARTUPCORE_default                         0x00000000UL                                                  /**< Mode default for RAC_RFBIASCTRL             */
#define _RAC_RFBIASCTRL_RFBIASSTARTUPCORE_force_start                     0x00000001UL                                                  /**< Mode force_start for RAC_RFBIASCTRL         */
#define RAC_RFBIASCTRL_RFBIASSTARTUPCORE_DEFAULT                          (_RAC_RFBIASCTRL_RFBIASSTARTUPCORE_DEFAULT << 3)              /**< Shifted mode DEFAULT for RAC_RFBIASCTRL     */
#define RAC_RFBIASCTRL_RFBIASSTARTUPCORE_default                          (_RAC_RFBIASCTRL_RFBIASSTARTUPCORE_default << 3)              /**< Shifted mode default for RAC_RFBIASCTRL     */
#define RAC_RFBIASCTRL_RFBIASSTARTUPCORE_force_start                      (_RAC_RFBIASCTRL_RFBIASSTARTUPCORE_force_start << 3)          /**< Shifted mode force_start for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY                                (0x1UL << 4)                                                  /**< RFBIASSTARTUPSUPPLY                         */
#define _RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_SHIFT                         4                                                             /**< Shift value for RAC_RFBIASSTARTUPSUPPLY     */
#define _RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_MASK                          0x10UL                                                        /**< Bit mask for RAC_RFBIASSTARTUPSUPPLY        */
#define _RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_DEFAULT                       0x00000000UL                                                  /**< Mode DEFAULT for RAC_RFBIASCTRL             */
#define _RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_default                       0x00000000UL                                                  /**< Mode default for RAC_RFBIASCTRL             */
#define _RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_forc_start                    0x00000001UL                                                  /**< Mode forc_start for RAC_RFBIASCTRL          */
#define RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_DEFAULT                        (_RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_DEFAULT << 4)            /**< Shifted mode DEFAULT for RAC_RFBIASCTRL     */
#define RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_default                        (_RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_default << 4)            /**< Shifted mode default for RAC_RFBIASCTRL     */
#define RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_forc_start                     (_RAC_RFBIASCTRL_RFBIASSTARTUPSUPPLY_forc_start << 4)         /**< Shifted mode forc_start for RAC_RFBIASCTRL  */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_SHIFT                           16                                                            /**< Shift value for RAC_RFBIASLDOVREFTRIM       */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_MASK                            0xF0000UL                                                     /**< Bit mask for RAC_RFBIASLDOVREFTRIM          */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_DEFAULT                         0x00000004UL                                                  /**< Mode DEFAULT for RAC_RFBIASCTRL             */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p800                     0x00000000UL                                                  /**< Mode vref_v0p800 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p813                     0x00000001UL                                                  /**< Mode vref_v0p813 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p825                     0x00000002UL                                                  /**< Mode vref_v0p825 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p837                     0x00000003UL                                                  /**< Mode vref_v0p837 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p850                     0x00000004UL                                                  /**< Mode vref_v0p850 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p863                     0x00000005UL                                                  /**< Mode vref_v0p863 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p875                     0x00000006UL                                                  /**< Mode vref_v0p875 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p887                     0x00000007UL                                                  /**< Mode vref_v0p887 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p900                     0x00000008UL                                                  /**< Mode vref_v0p900 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p913                     0x00000009UL                                                  /**< Mode vref_v0p913 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p925                     0x0000000AUL                                                  /**< Mode vref_v0p925 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p938                     0x0000000BUL                                                  /**< Mode vref_v0p938 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p950                     0x0000000CUL                                                  /**< Mode vref_v0p950 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p963                     0x0000000DUL                                                  /**< Mode vref_v0p963 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p975                     0x0000000EUL                                                  /**< Mode vref_v0p975 for RAC_RFBIASCTRL         */
#define _RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p988                     0x0000000FUL                                                  /**< Mode vref_v0p988 for RAC_RFBIASCTRL         */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_DEFAULT                          (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_DEFAULT << 16)             /**< Shifted mode DEFAULT for RAC_RFBIASCTRL     */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p800                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p800 << 16)         /**< Shifted mode vref_v0p800 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p813                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p813 << 16)         /**< Shifted mode vref_v0p813 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p825                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p825 << 16)         /**< Shifted mode vref_v0p825 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p837                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p837 << 16)         /**< Shifted mode vref_v0p837 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p850                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p850 << 16)         /**< Shifted mode vref_v0p850 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p863                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p863 << 16)         /**< Shifted mode vref_v0p863 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p875                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p875 << 16)         /**< Shifted mode vref_v0p875 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p887                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p887 << 16)         /**< Shifted mode vref_v0p887 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p900                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p900 << 16)         /**< Shifted mode vref_v0p900 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p913                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p913 << 16)         /**< Shifted mode vref_v0p913 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p925                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p925 << 16)         /**< Shifted mode vref_v0p925 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p938                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p938 << 16)         /**< Shifted mode vref_v0p938 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p950                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p950 << 16)         /**< Shifted mode vref_v0p950 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p963                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p963 << 16)         /**< Shifted mode vref_v0p963 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p975                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p975 << 16)         /**< Shifted mode vref_v0p975 for RAC_RFBIASCTRL */
#define RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p988                      (_RAC_RFBIASCTRL_RFBIASLDOVREFTRIM_vref_v0p988 << 16)         /**< Shifted mode vref_v0p988 for RAC_RFBIASCTRL */

/* Bit fields for RAC RADIOEN */
#define _RAC_RADIOEN_RESETVALUE                                           0x00000000UL                                      /**< Default value for RAC_RADIOEN               */
#define _RAC_RADIOEN_MASK                                                 0x00000007UL                                      /**< Mask for RAC_RADIOEN                        */
#define RAC_RADIOEN_PREEN                                                 (0x1UL << 0)                                      /**< PREEN                                       */
#define _RAC_RADIOEN_PREEN_SHIFT                                          0                                                 /**< Shift value for RAC_PREEN                   */
#define _RAC_RADIOEN_PREEN_MASK                                           0x1UL                                             /**< Bit mask for RAC_PREEN                      */
#define _RAC_RADIOEN_PREEN_DEFAULT                                        0x00000000UL                                      /**< Mode DEFAULT for RAC_RADIOEN                */
#define _RAC_RADIOEN_PREEN_powered_off                                    0x00000000UL                                      /**< Mode powered_off for RAC_RADIOEN            */
#define _RAC_RADIOEN_PREEN_powered_on                                     0x00000001UL                                      /**< Mode powered_on for RAC_RADIOEN             */
#define RAC_RADIOEN_PREEN_DEFAULT                                         (_RAC_RADIOEN_PREEN_DEFAULT << 0)                 /**< Shifted mode DEFAULT for RAC_RADIOEN        */
#define RAC_RADIOEN_PREEN_powered_off                                     (_RAC_RADIOEN_PREEN_powered_off << 0)             /**< Shifted mode powered_off for RAC_RADIOEN    */
#define RAC_RADIOEN_PREEN_powered_on                                      (_RAC_RADIOEN_PREEN_powered_on << 0)              /**< Shifted mode powered_on for RAC_RADIOEN     */
#define RAC_RADIOEN_PRESTB100UDIS                                         (0x1UL << 1)                                      /**< PRESTB100UDIS                               */
#define _RAC_RADIOEN_PRESTB100UDIS_SHIFT                                  1                                                 /**< Shift value for RAC_PRESTB100UDIS           */
#define _RAC_RADIOEN_PRESTB100UDIS_MASK                                   0x2UL                                             /**< Bit mask for RAC_PRESTB100UDIS              */
#define _RAC_RADIOEN_PRESTB100UDIS_DEFAULT                                0x00000000UL                                      /**< Mode DEFAULT for RAC_RADIOEN                */
#define _RAC_RADIOEN_PRESTB100UDIS_i100ua_enabled                         0x00000000UL                                      /**< Mode i100ua_enabled for RAC_RADIOEN         */
#define _RAC_RADIOEN_PRESTB100UDIS_i100ua_disabled                        0x00000001UL                                      /**< Mode i100ua_disabled for RAC_RADIOEN        */
#define RAC_RADIOEN_PRESTB100UDIS_DEFAULT                                 (_RAC_RADIOEN_PRESTB100UDIS_DEFAULT << 1)         /**< Shifted mode DEFAULT for RAC_RADIOEN        */
#define RAC_RADIOEN_PRESTB100UDIS_i100ua_enabled                          (_RAC_RADIOEN_PRESTB100UDIS_i100ua_enabled << 1)  /**< Shifted mode i100ua_enabled for RAC_RADIOEN */
#define RAC_RADIOEN_PRESTB100UDIS_i100ua_disabled                         (_RAC_RADIOEN_PRESTB100UDIS_i100ua_disabled << 1) /**< Shifted mode i100ua_disabled for RAC_RADIOEN*/
#define RAC_RADIOEN_RFBIASEN                                              (0x1UL << 2)                                      /**< RFBIASEN                                    */
#define _RAC_RADIOEN_RFBIASEN_SHIFT                                       2                                                 /**< Shift value for RAC_RFBIASEN                */
#define _RAC_RADIOEN_RFBIASEN_MASK                                        0x4UL                                             /**< Bit mask for RAC_RFBIASEN                   */
#define _RAC_RADIOEN_RFBIASEN_DEFAULT                                     0x00000000UL                                      /**< Mode DEFAULT for RAC_RADIOEN                */
#define _RAC_RADIOEN_RFBIASEN_disable_rfis_vtr                            0x00000000UL                                      /**< Mode disable_rfis_vtr for RAC_RADIOEN       */
#define _RAC_RADIOEN_RFBIASEN_enable_rfis_vtr                             0x00000001UL                                      /**< Mode enable_rfis_vtr for RAC_RADIOEN        */
#define RAC_RADIOEN_RFBIASEN_DEFAULT                                      (_RAC_RADIOEN_RFBIASEN_DEFAULT << 2)              /**< Shifted mode DEFAULT for RAC_RADIOEN        */
#define RAC_RADIOEN_RFBIASEN_disable_rfis_vtr                             (_RAC_RADIOEN_RFBIASEN_disable_rfis_vtr << 2)     /**< Shifted mode disable_rfis_vtr for RAC_RADIOEN*/
#define RAC_RADIOEN_RFBIASEN_enable_rfis_vtr                              (_RAC_RADIOEN_RFBIASEN_enable_rfis_vtr << 2)      /**< Shifted mode enable_rfis_vtr for RAC_RADIOEN*/

/* Bit fields for RAC RFPATHEN0 */
#define _RAC_RFPATHEN0_RESETVALUE                                         0x00000042UL                                        /**< Default value for RAC_RFPATHEN0             */
#define _RAC_RFPATHEN0_MASK                                               0x0000184FUL                                        /**< Mask for RAC_RFPATHEN0                      */
#define RAC_RFPATHEN0_LNAMIXEN0                                           (0x1UL << 0)                                        /**< LNAMIXEN0                                   */
#define _RAC_RFPATHEN0_LNAMIXEN0_SHIFT                                    0                                                   /**< Shift value for RAC_LNAMIXEN0               */
#define _RAC_RFPATHEN0_LNAMIXEN0_MASK                                     0x1UL                                               /**< Bit mask for RAC_LNAMIXEN0                  */
#define _RAC_RFPATHEN0_LNAMIXEN0_DEFAULT                                  0x00000000UL                                        /**< Mode DEFAULT for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_LNAMIXEN0_disable                                  0x00000000UL                                        /**< Mode disable for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_LNAMIXEN0_enable                                   0x00000001UL                                        /**< Mode enable for RAC_RFPATHEN0               */
#define RAC_RFPATHEN0_LNAMIXEN0_DEFAULT                                   (_RAC_RFPATHEN0_LNAMIXEN0_DEFAULT << 0)             /**< Shifted mode DEFAULT for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_LNAMIXEN0_disable                                   (_RAC_RFPATHEN0_LNAMIXEN0_disable << 0)             /**< Shifted mode disable for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_LNAMIXEN0_enable                                    (_RAC_RFPATHEN0_LNAMIXEN0_enable << 0)              /**< Shifted mode enable for RAC_RFPATHEN0       */
#define RAC_RFPATHEN0_LNAMIXRFATTDCEN0                                    (0x1UL << 1)                                        /**< LNAMIXRFATTDCEN0                            */
#define _RAC_RFPATHEN0_LNAMIXRFATTDCEN0_SHIFT                             1                                                   /**< Shift value for RAC_LNAMIXRFATTDCEN0        */
#define _RAC_RFPATHEN0_LNAMIXRFATTDCEN0_MASK                              0x2UL                                               /**< Bit mask for RAC_LNAMIXRFATTDCEN0           */
#define _RAC_RFPATHEN0_LNAMIXRFATTDCEN0_DEFAULT                           0x00000001UL                                        /**< Mode DEFAULT for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_LNAMIXRFATTDCEN0_disable_dc                        0x00000000UL                                        /**< Mode disable_dc for RAC_RFPATHEN0           */
#define _RAC_RFPATHEN0_LNAMIXRFATTDCEN0_enable_dc                         0x00000001UL                                        /**< Mode enable_dc for RAC_RFPATHEN0            */
#define RAC_RFPATHEN0_LNAMIXRFATTDCEN0_DEFAULT                            (_RAC_RFPATHEN0_LNAMIXRFATTDCEN0_DEFAULT << 1)      /**< Shifted mode DEFAULT for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_LNAMIXRFATTDCEN0_disable_dc                         (_RAC_RFPATHEN0_LNAMIXRFATTDCEN0_disable_dc << 1)   /**< Shifted mode disable_dc for RAC_RFPATHEN0   */
#define RAC_RFPATHEN0_LNAMIXRFATTDCEN0_enable_dc                          (_RAC_RFPATHEN0_LNAMIXRFATTDCEN0_enable_dc << 1)    /**< Shifted mode enable_dc for RAC_RFPATHEN0    */
#define RAC_RFPATHEN0_LNAMIXRFPKDENRF0                                    (0x1UL << 2)                                        /**< LNAMIXRFPKDENRF0                            */
#define _RAC_RFPATHEN0_LNAMIXRFPKDENRF0_SHIFT                             2                                                   /**< Shift value for RAC_LNAMIXRFPKDENRF0        */
#define _RAC_RFPATHEN0_LNAMIXRFPKDENRF0_MASK                              0x4UL                                               /**< Bit mask for RAC_LNAMIXRFPKDENRF0           */
#define _RAC_RFPATHEN0_LNAMIXRFPKDENRF0_DEFAULT                           0x00000000UL                                        /**< Mode DEFAULT for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_LNAMIXRFPKDENRF0_disable                           0x00000000UL                                        /**< Mode disable for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_LNAMIXRFPKDENRF0_enable_path0                      0x00000001UL                                        /**< Mode enable_path0 for RAC_RFPATHEN0         */
#define RAC_RFPATHEN0_LNAMIXRFPKDENRF0_DEFAULT                            (_RAC_RFPATHEN0_LNAMIXRFPKDENRF0_DEFAULT << 2)      /**< Shifted mode DEFAULT for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_LNAMIXRFPKDENRF0_disable                            (_RAC_RFPATHEN0_LNAMIXRFPKDENRF0_disable << 2)      /**< Shifted mode disable for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_LNAMIXRFPKDENRF0_enable_path0                       (_RAC_RFPATHEN0_LNAMIXRFPKDENRF0_enable_path0 << 2) /**< Shifted mode enable_path0 for RAC_RFPATHEN0 */
#define RAC_RFPATHEN0_SYLODIVRLO0SUBGEN                                   (0x1UL << 3)                                        /**< SYLODIVRLO0SUBGEN                           */
#define _RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_SHIFT                            3                                                   /**< Shift value for RAC_SYLODIVRLO0SUBGEN       */
#define _RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_MASK                             0x8UL                                               /**< Bit mask for RAC_SYLODIVRLO0SUBGEN          */
#define _RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_DEFAULT                          0x00000000UL                                        /**< Mode DEFAULT for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_disable                          0x00000000UL                                        /**< Mode disable for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_enable                           0x00000001UL                                        /**< Mode enable for RAC_RFPATHEN0               */
#define RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_DEFAULT                           (_RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_DEFAULT << 3)     /**< Shifted mode DEFAULT for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_disable                           (_RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_disable << 3)     /**< Shifted mode disable for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_enable                            (_RAC_RFPATHEN0_SYLODIVRLO0SUBGEN_enable << 3)      /**< Shifted mode enable for RAC_RFPATHEN0       */
#define RAC_RFPATHEN0_TXENVMIDHPA0                                        (0x1UL << 6)                                        /**< TXENVMIDHPA0                                */
#define _RAC_RFPATHEN0_TXENVMIDHPA0_SHIFT                                 6                                                   /**< Shift value for RAC_TXENVMIDHPA0            */
#define _RAC_RFPATHEN0_TXENVMIDHPA0_MASK                                  0x40UL                                              /**< Bit mask for RAC_TXENVMIDHPA0               */
#define _RAC_RFPATHEN0_TXENVMIDHPA0_DEFAULT                               0x00000001UL                                        /**< Mode DEFAULT for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_TXENVMIDHPA0_disable                               0x00000000UL                                        /**< Mode disable for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_TXENVMIDHPA0_enable                                0x00000001UL                                        /**< Mode enable for RAC_RFPATHEN0               */
#define RAC_RFPATHEN0_TXENVMIDHPA0_DEFAULT                                (_RAC_RFPATHEN0_TXENVMIDHPA0_DEFAULT << 6)          /**< Shifted mode DEFAULT for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_TXENVMIDHPA0_disable                                (_RAC_RFPATHEN0_TXENVMIDHPA0_disable << 6)          /**< Shifted mode disable for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_TXENVMIDHPA0_enable                                 (_RAC_RFPATHEN0_TXENVMIDHPA0_enable << 6)           /**< Shifted mode enable for RAC_RFPATHEN0       */
#define RAC_RFPATHEN0_TXENFSKPA0                                          (0x1UL << 11)                                       /**< TXENFSKPA0                                  */
#define _RAC_RFPATHEN0_TXENFSKPA0_SHIFT                                   11                                                  /**< Shift value for RAC_TXENFSKPA0              */
#define _RAC_RFPATHEN0_TXENFSKPA0_MASK                                    0x800UL                                             /**< Bit mask for RAC_TXENFSKPA0                 */
#define _RAC_RFPATHEN0_TXENFSKPA0_DEFAULT                                 0x00000000UL                                        /**< Mode DEFAULT for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_TXENFSKPA0_hpa0_off                                0x00000000UL                                        /**< Mode hpa0_off for RAC_RFPATHEN0             */
#define _RAC_RFPATHEN0_TXENFSKPA0_hpa0_on                                 0x00000001UL                                        /**< Mode hpa0_on for RAC_RFPATHEN0              */
#define RAC_RFPATHEN0_TXENFSKPA0_DEFAULT                                  (_RAC_RFPATHEN0_TXENFSKPA0_DEFAULT << 11)           /**< Shifted mode DEFAULT for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_TXENFSKPA0_hpa0_off                                 (_RAC_RFPATHEN0_TXENFSKPA0_hpa0_off << 11)          /**< Shifted mode hpa0_off for RAC_RFPATHEN0     */
#define RAC_RFPATHEN0_TXENFSKPA0_hpa0_on                                  (_RAC_RFPATHEN0_TXENFSKPA0_hpa0_on << 11)           /**< Shifted mode hpa0_on for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_TXENOFDMPA0                                         (0x1UL << 12)                                       /**< TXENOFDMPA0                                 */
#define _RAC_RFPATHEN0_TXENOFDMPA0_SHIFT                                  12                                                  /**< Shift value for RAC_TXENOFDMPA0             */
#define _RAC_RFPATHEN0_TXENOFDMPA0_MASK                                   0x1000UL                                            /**< Bit mask for RAC_TXENOFDMPA0                */
#define _RAC_RFPATHEN0_TXENOFDMPA0_DEFAULT                                0x00000000UL                                        /**< Mode DEFAULT for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_TXENOFDMPA0_disable                                0x00000000UL                                        /**< Mode disable for RAC_RFPATHEN0              */
#define _RAC_RFPATHEN0_TXENOFDMPA0_enable                                 0x00000001UL                                        /**< Mode enable for RAC_RFPATHEN0               */
#define RAC_RFPATHEN0_TXENOFDMPA0_DEFAULT                                 (_RAC_RFPATHEN0_TXENOFDMPA0_DEFAULT << 12)          /**< Shifted mode DEFAULT for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_TXENOFDMPA0_disable                                 (_RAC_RFPATHEN0_TXENOFDMPA0_disable << 12)          /**< Shifted mode disable for RAC_RFPATHEN0      */
#define RAC_RFPATHEN0_TXENOFDMPA0_enable                                  (_RAC_RFPATHEN0_TXENOFDMPA0_enable << 12)           /**< Shifted mode enable for RAC_RFPATHEN0       */

/* Bit fields for RAC RFPATHEN1 */
#define _RAC_RFPATHEN1_RESETVALUE                                         0x00000042UL                                        /**< Default value for RAC_RFPATHEN1             */
#define _RAC_RFPATHEN1_MASK                                               0x0000184FUL                                        /**< Mask for RAC_RFPATHEN1                      */
#define RAC_RFPATHEN1_LNAMIXEN1                                           (0x1UL << 0)                                        /**< LNAMIXEN1                                   */
#define _RAC_RFPATHEN1_LNAMIXEN1_SHIFT                                    0                                                   /**< Shift value for RAC_LNAMIXEN1               */
#define _RAC_RFPATHEN1_LNAMIXEN1_MASK                                     0x1UL                                               /**< Bit mask for RAC_LNAMIXEN1                  */
#define _RAC_RFPATHEN1_LNAMIXEN1_DEFAULT                                  0x00000000UL                                        /**< Mode DEFAULT for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_LNAMIXEN1_disable                                  0x00000000UL                                        /**< Mode disable for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_LNAMIXEN1_enable                                   0x00000001UL                                        /**< Mode enable for RAC_RFPATHEN1               */
#define RAC_RFPATHEN1_LNAMIXEN1_DEFAULT                                   (_RAC_RFPATHEN1_LNAMIXEN1_DEFAULT << 0)             /**< Shifted mode DEFAULT for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_LNAMIXEN1_disable                                   (_RAC_RFPATHEN1_LNAMIXEN1_disable << 0)             /**< Shifted mode disable for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_LNAMIXEN1_enable                                    (_RAC_RFPATHEN1_LNAMIXEN1_enable << 0)              /**< Shifted mode enable for RAC_RFPATHEN1       */
#define RAC_RFPATHEN1_LNAMIXRFATTDCEN1                                    (0x1UL << 1)                                        /**< LNAMIXRFATTDCEN1                            */
#define _RAC_RFPATHEN1_LNAMIXRFATTDCEN1_SHIFT                             1                                                   /**< Shift value for RAC_LNAMIXRFATTDCEN1        */
#define _RAC_RFPATHEN1_LNAMIXRFATTDCEN1_MASK                              0x2UL                                               /**< Bit mask for RAC_LNAMIXRFATTDCEN1           */
#define _RAC_RFPATHEN1_LNAMIXRFATTDCEN1_DEFAULT                           0x00000001UL                                        /**< Mode DEFAULT for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_LNAMIXRFATTDCEN1_disable_dc                        0x00000000UL                                        /**< Mode disable_dc for RAC_RFPATHEN1           */
#define _RAC_RFPATHEN1_LNAMIXRFATTDCEN1_enable_dc                         0x00000001UL                                        /**< Mode enable_dc for RAC_RFPATHEN1            */
#define RAC_RFPATHEN1_LNAMIXRFATTDCEN1_DEFAULT                            (_RAC_RFPATHEN1_LNAMIXRFATTDCEN1_DEFAULT << 1)      /**< Shifted mode DEFAULT for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_LNAMIXRFATTDCEN1_disable_dc                         (_RAC_RFPATHEN1_LNAMIXRFATTDCEN1_disable_dc << 1)   /**< Shifted mode disable_dc for RAC_RFPATHEN1   */
#define RAC_RFPATHEN1_LNAMIXRFATTDCEN1_enable_dc                          (_RAC_RFPATHEN1_LNAMIXRFATTDCEN1_enable_dc << 1)    /**< Shifted mode enable_dc for RAC_RFPATHEN1    */
#define RAC_RFPATHEN1_LNAMIXRFPKDENRF1                                    (0x1UL << 2)                                        /**< LNAMIXRFPKDENRF1                            */
#define _RAC_RFPATHEN1_LNAMIXRFPKDENRF1_SHIFT                             2                                                   /**< Shift value for RAC_LNAMIXRFPKDENRF1        */
#define _RAC_RFPATHEN1_LNAMIXRFPKDENRF1_MASK                              0x4UL                                               /**< Bit mask for RAC_LNAMIXRFPKDENRF1           */
#define _RAC_RFPATHEN1_LNAMIXRFPKDENRF1_DEFAULT                           0x00000000UL                                        /**< Mode DEFAULT for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_LNAMIXRFPKDENRF1_disable                           0x00000000UL                                        /**< Mode disable for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_LNAMIXRFPKDENRF1_enable_path1                      0x00000001UL                                        /**< Mode enable_path1 for RAC_RFPATHEN1         */
#define RAC_RFPATHEN1_LNAMIXRFPKDENRF1_DEFAULT                            (_RAC_RFPATHEN1_LNAMIXRFPKDENRF1_DEFAULT << 2)      /**< Shifted mode DEFAULT for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_LNAMIXRFPKDENRF1_disable                            (_RAC_RFPATHEN1_LNAMIXRFPKDENRF1_disable << 2)      /**< Shifted mode disable for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_LNAMIXRFPKDENRF1_enable_path1                       (_RAC_RFPATHEN1_LNAMIXRFPKDENRF1_enable_path1 << 2) /**< Shifted mode enable_path1 for RAC_RFPATHEN1 */
#define RAC_RFPATHEN1_SYLODIVRLO1SUBGEN                                   (0x1UL << 3)                                        /**< SYLODIVRLO1SUBGEN                           */
#define _RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_SHIFT                            3                                                   /**< Shift value for RAC_SYLODIVRLO1SUBGEN       */
#define _RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_MASK                             0x8UL                                               /**< Bit mask for RAC_SYLODIVRLO1SUBGEN          */
#define _RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_DEFAULT                          0x00000000UL                                        /**< Mode DEFAULT for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_disable                          0x00000000UL                                        /**< Mode disable for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_enable                           0x00000001UL                                        /**< Mode enable for RAC_RFPATHEN1               */
#define RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_DEFAULT                           (_RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_DEFAULT << 3)     /**< Shifted mode DEFAULT for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_disable                           (_RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_disable << 3)     /**< Shifted mode disable for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_enable                            (_RAC_RFPATHEN1_SYLODIVRLO1SUBGEN_enable << 3)      /**< Shifted mode enable for RAC_RFPATHEN1       */
#define RAC_RFPATHEN1_TXENVMIDHPA1                                        (0x1UL << 6)                                        /**< TXENVMIDHPA1                                */
#define _RAC_RFPATHEN1_TXENVMIDHPA1_SHIFT                                 6                                                   /**< Shift value for RAC_TXENVMIDHPA1            */
#define _RAC_RFPATHEN1_TXENVMIDHPA1_MASK                                  0x40UL                                              /**< Bit mask for RAC_TXENVMIDHPA1               */
#define _RAC_RFPATHEN1_TXENVMIDHPA1_DEFAULT                               0x00000001UL                                        /**< Mode DEFAULT for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_TXENVMIDHPA1_disable                               0x00000000UL                                        /**< Mode disable for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_TXENVMIDHPA1_enable                                0x00000001UL                                        /**< Mode enable for RAC_RFPATHEN1               */
#define RAC_RFPATHEN1_TXENVMIDHPA1_DEFAULT                                (_RAC_RFPATHEN1_TXENVMIDHPA1_DEFAULT << 6)          /**< Shifted mode DEFAULT for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_TXENVMIDHPA1_disable                                (_RAC_RFPATHEN1_TXENVMIDHPA1_disable << 6)          /**< Shifted mode disable for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_TXENVMIDHPA1_enable                                 (_RAC_RFPATHEN1_TXENVMIDHPA1_enable << 6)           /**< Shifted mode enable for RAC_RFPATHEN1       */
#define RAC_RFPATHEN1_TXENFSKPA1                                          (0x1UL << 11)                                       /**< TXENFSKPA1                                  */
#define _RAC_RFPATHEN1_TXENFSKPA1_SHIFT                                   11                                                  /**< Shift value for RAC_TXENFSKPA1              */
#define _RAC_RFPATHEN1_TXENFSKPA1_MASK                                    0x800UL                                             /**< Bit mask for RAC_TXENFSKPA1                 */
#define _RAC_RFPATHEN1_TXENFSKPA1_DEFAULT                                 0x00000000UL                                        /**< Mode DEFAULT for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_TXENFSKPA1_hpa1_off                                0x00000000UL                                        /**< Mode hpa1_off for RAC_RFPATHEN1             */
#define _RAC_RFPATHEN1_TXENFSKPA1_hpa1_on                                 0x00000001UL                                        /**< Mode hpa1_on for RAC_RFPATHEN1              */
#define RAC_RFPATHEN1_TXENFSKPA1_DEFAULT                                  (_RAC_RFPATHEN1_TXENFSKPA1_DEFAULT << 11)           /**< Shifted mode DEFAULT for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_TXENFSKPA1_hpa1_off                                 (_RAC_RFPATHEN1_TXENFSKPA1_hpa1_off << 11)          /**< Shifted mode hpa1_off for RAC_RFPATHEN1     */
#define RAC_RFPATHEN1_TXENFSKPA1_hpa1_on                                  (_RAC_RFPATHEN1_TXENFSKPA1_hpa1_on << 11)           /**< Shifted mode hpa1_on for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_TXENOFDMPA1                                         (0x1UL << 12)                                       /**< TXENOFDMPA1                                 */
#define _RAC_RFPATHEN1_TXENOFDMPA1_SHIFT                                  12                                                  /**< Shift value for RAC_TXENOFDMPA1             */
#define _RAC_RFPATHEN1_TXENOFDMPA1_MASK                                   0x1000UL                                            /**< Bit mask for RAC_TXENOFDMPA1                */
#define _RAC_RFPATHEN1_TXENOFDMPA1_DEFAULT                                0x00000000UL                                        /**< Mode DEFAULT for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_TXENOFDMPA1_disable                                0x00000000UL                                        /**< Mode disable for RAC_RFPATHEN1              */
#define _RAC_RFPATHEN1_TXENOFDMPA1_enable                                 0x00000001UL                                        /**< Mode enable for RAC_RFPATHEN1               */
#define RAC_RFPATHEN1_TXENOFDMPA1_DEFAULT                                 (_RAC_RFPATHEN1_TXENOFDMPA1_DEFAULT << 12)          /**< Shifted mode DEFAULT for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_TXENOFDMPA1_disable                                 (_RAC_RFPATHEN1_TXENOFDMPA1_disable << 12)          /**< Shifted mode disable for RAC_RFPATHEN1      */
#define RAC_RFPATHEN1_TXENOFDMPA1_enable                                  (_RAC_RFPATHEN1_TXENOFDMPA1_enable << 12)           /**< Shifted mode enable for RAC_RFPATHEN1       */

/* Bit fields for RAC RX */
#define _RAC_RX_RESETVALUE                                                0x00000000UL                                        /**< Default value for RAC_RX                    */
#define _RAC_RX_MASK                                                      0x800F03FFUL                                        /**< Mask for RAC_RX                             */
#define RAC_RX_IFADCCAPRESET                                              (0x1UL << 0)                                        /**< IFADCCAPRESET                               */
#define _RAC_RX_IFADCCAPRESET_SHIFT                                       0                                                   /**< Shift value for RAC_IFADCCAPRESET           */
#define _RAC_RX_IFADCCAPRESET_MASK                                        0x1UL                                               /**< Bit mask for RAC_IFADCCAPRESET              */
#define _RAC_RX_IFADCCAPRESET_DEFAULT                                     0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_IFADCCAPRESET_cap_reset_disable                           0x00000000UL                                        /**< Mode cap_reset_disable for RAC_RX           */
#define _RAC_RX_IFADCCAPRESET_cap_reset_enable                            0x00000001UL                                        /**< Mode cap_reset_enable for RAC_RX            */
#define RAC_RX_IFADCCAPRESET_DEFAULT                                      (_RAC_RX_IFADCCAPRESET_DEFAULT << 0)                /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_IFADCCAPRESET_cap_reset_disable                            (_RAC_RX_IFADCCAPRESET_cap_reset_disable << 0)      /**< Shifted mode cap_reset_disable for RAC_RX   */
#define RAC_RX_IFADCCAPRESET_cap_reset_enable                             (_RAC_RX_IFADCCAPRESET_cap_reset_enable << 0)       /**< Shifted mode cap_reset_enable for RAC_RX    */
#define RAC_RX_IFADCENLDOSERIES                                           (0x1UL << 1)                                        /**< IFADCENLDOSERIES                            */
#define _RAC_RX_IFADCENLDOSERIES_SHIFT                                    1                                                   /**< Shift value for RAC_IFADCENLDOSERIES        */
#define _RAC_RX_IFADCENLDOSERIES_MASK                                     0x2UL                                               /**< Bit mask for RAC_IFADCENLDOSERIES           */
#define _RAC_RX_IFADCENLDOSERIES_DEFAULT                                  0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_IFADCENLDOSERIES_series_ldo_disable                       0x00000000UL                                        /**< Mode series_ldo_disable for RAC_RX          */
#define _RAC_RX_IFADCENLDOSERIES_series_ldo_enable                        0x00000001UL                                        /**< Mode series_ldo_enable for RAC_RX           */
#define RAC_RX_IFADCENLDOSERIES_DEFAULT                                   (_RAC_RX_IFADCENLDOSERIES_DEFAULT << 1)             /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_IFADCENLDOSERIES_series_ldo_disable                        (_RAC_RX_IFADCENLDOSERIES_series_ldo_disable << 1)  /**< Shifted mode series_ldo_disable for RAC_RX  */
#define RAC_RX_IFADCENLDOSERIES_series_ldo_enable                         (_RAC_RX_IFADCENLDOSERIES_series_ldo_enable << 1)   /**< Shifted mode series_ldo_enable for RAC_RX   */
#define RAC_RX_IFADCENLDOSHUNT                                            (0x1UL << 2)                                        /**< IFADCENLDOSHUNT                             */
#define _RAC_RX_IFADCENLDOSHUNT_SHIFT                                     2                                                   /**< Shift value for RAC_IFADCENLDOSHUNT         */
#define _RAC_RX_IFADCENLDOSHUNT_MASK                                      0x4UL                                               /**< Bit mask for RAC_IFADCENLDOSHUNT            */
#define _RAC_RX_IFADCENLDOSHUNT_DEFAULT                                   0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_IFADCENLDOSHUNT_shunt_ldo_disable                         0x00000000UL                                        /**< Mode shunt_ldo_disable for RAC_RX           */
#define _RAC_RX_IFADCENLDOSHUNT_shunt_ldo_enable                          0x00000001UL                                        /**< Mode shunt_ldo_enable for RAC_RX            */
#define RAC_RX_IFADCENLDOSHUNT_DEFAULT                                    (_RAC_RX_IFADCENLDOSHUNT_DEFAULT << 2)              /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_IFADCENLDOSHUNT_shunt_ldo_disable                          (_RAC_RX_IFADCENLDOSHUNT_shunt_ldo_disable << 2)    /**< Shifted mode shunt_ldo_disable for RAC_RX   */
#define RAC_RX_IFADCENLDOSHUNT_shunt_ldo_enable                           (_RAC_RX_IFADCENLDOSHUNT_shunt_ldo_enable << 2)     /**< Shifted mode shunt_ldo_enable for RAC_RX    */
#define RAC_RX_LNAMIXENRFPKD                                              (0x1UL << 3)                                        /**< LNAMIXENRFPKD                               */
#define _RAC_RX_LNAMIXENRFPKD_SHIFT                                       3                                                   /**< Shift value for RAC_LNAMIXENRFPKD           */
#define _RAC_RX_LNAMIXENRFPKD_MASK                                        0x8UL                                               /**< Bit mask for RAC_LNAMIXENRFPKD              */
#define _RAC_RX_LNAMIXENRFPKD_DEFAULT                                     0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_LNAMIXENRFPKD_disable                                     0x00000000UL                                        /**< Mode disable for RAC_RX                     */
#define _RAC_RX_LNAMIXENRFPKD_enable                                      0x00000001UL                                        /**< Mode enable for RAC_RX                      */
#define RAC_RX_LNAMIXENRFPKD_DEFAULT                                      (_RAC_RX_LNAMIXENRFPKD_DEFAULT << 3)                /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_LNAMIXENRFPKD_disable                                      (_RAC_RX_LNAMIXENRFPKD_disable << 3)                /**< Shifted mode disable for RAC_RX             */
#define RAC_RX_LNAMIXENRFPKD_enable                                       (_RAC_RX_LNAMIXENRFPKD_enable << 3)                 /**< Shifted mode enable for RAC_RX              */
#define RAC_RX_LNAMIXENRFPKDLOTHRESH                                      (0x1UL << 4)                                        /**< LNAMIXENRFPKDLOTHRESH                       */
#define _RAC_RX_LNAMIXENRFPKDLOTHRESH_SHIFT                               4                                                   /**< Shift value for RAC_LNAMIXENRFPKDLOTHRESH   */
#define _RAC_RX_LNAMIXENRFPKDLOTHRESH_MASK                                0x10UL                                              /**< Bit mask for RAC_LNAMIXENRFPKDLOTHRESH      */
#define _RAC_RX_LNAMIXENRFPKDLOTHRESH_DEFAULT                             0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_LNAMIXENRFPKDLOTHRESH_disable                             0x00000000UL                                        /**< Mode disable for RAC_RX                     */
#define _RAC_RX_LNAMIXENRFPKDLOTHRESH_enable                              0x00000001UL                                        /**< Mode enable for RAC_RX                      */
#define RAC_RX_LNAMIXENRFPKDLOTHRESH_DEFAULT                              (_RAC_RX_LNAMIXENRFPKDLOTHRESH_DEFAULT << 4)        /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_LNAMIXENRFPKDLOTHRESH_disable                              (_RAC_RX_LNAMIXENRFPKDLOTHRESH_disable << 4)        /**< Shifted mode disable for RAC_RX             */
#define RAC_RX_LNAMIXENRFPKDLOTHRESH_enable                               (_RAC_RX_LNAMIXENRFPKDLOTHRESH_enable << 4)         /**< Shifted mode enable for RAC_RX              */
#define _RAC_RX_LNAMIXLDOLOWCUR_SHIFT                                     5                                                   /**< Shift value for RAC_LNAMIXLDOLOWCUR         */
#define _RAC_RX_LNAMIXLDOLOWCUR_MASK                                      0x60UL                                              /**< Bit mask for RAC_LNAMIXLDOLOWCUR            */
#define _RAC_RX_LNAMIXLDOLOWCUR_DEFAULT                                   0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_LNAMIXLDOLOWCUR_regular_mode                              0x00000000UL                                        /**< Mode regular_mode for RAC_RX                */
#define _RAC_RX_LNAMIXLDOLOWCUR_low_current_mode                          0x00000001UL                                        /**< Mode low_current_mode for RAC_RX            */
#define _RAC_RX_LNAMIXLDOLOWCUR_high_current_mode                         0x00000003UL                                        /**< Mode high_current_mode for RAC_RX           */
#define RAC_RX_LNAMIXLDOLOWCUR_DEFAULT                                    (_RAC_RX_LNAMIXLDOLOWCUR_DEFAULT << 5)              /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_LNAMIXLDOLOWCUR_regular_mode                               (_RAC_RX_LNAMIXLDOLOWCUR_regular_mode << 5)         /**< Shifted mode regular_mode for RAC_RX        */
#define RAC_RX_LNAMIXLDOLOWCUR_low_current_mode                           (_RAC_RX_LNAMIXLDOLOWCUR_low_current_mode << 5)     /**< Shifted mode low_current_mode for RAC_RX    */
#define RAC_RX_LNAMIXLDOLOWCUR_high_current_mode                          (_RAC_RX_LNAMIXLDOLOWCUR_high_current_mode << 5)    /**< Shifted mode high_current_mode for RAC_RX   */
#define RAC_RX_LNAMIXREGLOADEN                                            (0x1UL << 7)                                        /**< LNAMIXREGLOADEN                             */
#define _RAC_RX_LNAMIXREGLOADEN_SHIFT                                     7                                                   /**< Shift value for RAC_LNAMIXREGLOADEN         */
#define _RAC_RX_LNAMIXREGLOADEN_MASK                                      0x80UL                                              /**< Bit mask for RAC_LNAMIXREGLOADEN            */
#define _RAC_RX_LNAMIXREGLOADEN_DEFAULT                                   0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_LNAMIXREGLOADEN_disable_resistor                          0x00000000UL                                        /**< Mode disable_resistor for RAC_RX            */
#define _RAC_RX_LNAMIXREGLOADEN_enable_resistor                           0x00000001UL                                        /**< Mode enable_resistor for RAC_RX             */
#define RAC_RX_LNAMIXREGLOADEN_DEFAULT                                    (_RAC_RX_LNAMIXREGLOADEN_DEFAULT << 7)              /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_LNAMIXREGLOADEN_disable_resistor                           (_RAC_RX_LNAMIXREGLOADEN_disable_resistor << 7)     /**< Shifted mode disable_resistor for RAC_RX    */
#define RAC_RX_LNAMIXREGLOADEN_enable_resistor                            (_RAC_RX_LNAMIXREGLOADEN_enable_resistor << 7)      /**< Shifted mode enable_resistor for RAC_RX     */
#define RAC_RX_PGAENLDO                                                   (0x1UL << 8)                                        /**< PGAENLDO                                    */
#define _RAC_RX_PGAENLDO_SHIFT                                            8                                                   /**< Shift value for RAC_PGAENLDO                */
#define _RAC_RX_PGAENLDO_MASK                                             0x100UL                                             /**< Bit mask for RAC_PGAENLDO                   */
#define _RAC_RX_PGAENLDO_DEFAULT                                          0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_PGAENLDO_disable_ldo                                      0x00000000UL                                        /**< Mode disable_ldo for RAC_RX                 */
#define _RAC_RX_PGAENLDO_enable_ldo                                       0x00000001UL                                        /**< Mode enable_ldo for RAC_RX                  */
#define RAC_RX_PGAENLDO_DEFAULT                                           (_RAC_RX_PGAENLDO_DEFAULT << 8)                     /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_PGAENLDO_disable_ldo                                       (_RAC_RX_PGAENLDO_disable_ldo << 8)                 /**< Shifted mode disable_ldo for RAC_RX         */
#define RAC_RX_PGAENLDO_enable_ldo                                        (_RAC_RX_PGAENLDO_enable_ldo << 8)                  /**< Shifted mode enable_ldo for RAC_RX          */
#define RAC_RX_SYCHPQNC3EN                                                (0x1UL << 9)                                        /**< SYCHPQNC3EN                                 */
#define _RAC_RX_SYCHPQNC3EN_SHIFT                                         9                                                   /**< Shift value for RAC_SYCHPQNC3EN             */
#define _RAC_RX_SYCHPQNC3EN_MASK                                          0x200UL                                             /**< Bit mask for RAC_SYCHPQNC3EN                */
#define _RAC_RX_SYCHPQNC3EN_DEFAULT                                       0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_SYCHPQNC3EN_qnc_2                                         0x00000000UL                                        /**< Mode qnc_2 for RAC_RX                       */
#define _RAC_RX_SYCHPQNC3EN_qnc_3                                         0x00000001UL                                        /**< Mode qnc_3 for RAC_RX                       */
#define RAC_RX_SYCHPQNC3EN_DEFAULT                                        (_RAC_RX_SYCHPQNC3EN_DEFAULT << 9)                  /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_SYCHPQNC3EN_qnc_2                                          (_RAC_RX_SYCHPQNC3EN_qnc_2 << 9)                    /**< Shifted mode qnc_2 for RAC_RX               */
#define RAC_RX_SYCHPQNC3EN_qnc_3                                          (_RAC_RX_SYCHPQNC3EN_qnc_3 << 9)                    /**< Shifted mode qnc_3 for RAC_RX               */
#define RAC_RX_SYCHPBIASTRIMBUFRX                                         (0x1UL << 16)                                       /**< SYCHPBIASTRIMBUFRX                          */
#define _RAC_RX_SYCHPBIASTRIMBUFRX_SHIFT                                  16                                                  /**< Shift value for RAC_SYCHPBIASTRIMBUFRX      */
#define _RAC_RX_SYCHPBIASTRIMBUFRX_MASK                                   0x10000UL                                           /**< Bit mask for RAC_SYCHPBIASTRIMBUFRX         */
#define _RAC_RX_SYCHPBIASTRIMBUFRX_DEFAULT                                0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_SYCHPBIASTRIMBUFRX_i_tail_10u                             0x00000000UL                                        /**< Mode i_tail_10u for RAC_RX                  */
#define _RAC_RX_SYCHPBIASTRIMBUFRX_i_tail_20u                             0x00000001UL                                        /**< Mode i_tail_20u for RAC_RX                  */
#define RAC_RX_SYCHPBIASTRIMBUFRX_DEFAULT                                 (_RAC_RX_SYCHPBIASTRIMBUFRX_DEFAULT << 16)          /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_SYCHPBIASTRIMBUFRX_i_tail_10u                              (_RAC_RX_SYCHPBIASTRIMBUFRX_i_tail_10u << 16)       /**< Shifted mode i_tail_10u for RAC_RX          */
#define RAC_RX_SYCHPBIASTRIMBUFRX_i_tail_20u                              (_RAC_RX_SYCHPBIASTRIMBUFRX_i_tail_20u << 16)       /**< Shifted mode i_tail_20u for RAC_RX          */
#define RAC_RX_SYPFDCHPLPENRX                                             (0x1UL << 17)                                       /**< SYPFDCHPLPENRX                              */
#define _RAC_RX_SYPFDCHPLPENRX_SHIFT                                      17                                                  /**< Shift value for RAC_SYPFDCHPLPENRX          */
#define _RAC_RX_SYPFDCHPLPENRX_MASK                                       0x20000UL                                           /**< Bit mask for RAC_SYPFDCHPLPENRX             */
#define _RAC_RX_SYPFDCHPLPENRX_DEFAULT                                    0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_SYPFDCHPLPENRX_disable                                    0x00000000UL                                        /**< Mode disable for RAC_RX                     */
#define _RAC_RX_SYPFDCHPLPENRX_enable                                     0x00000001UL                                        /**< Mode enable for RAC_RX                      */
#define RAC_RX_SYPFDCHPLPENRX_DEFAULT                                     (_RAC_RX_SYPFDCHPLPENRX_DEFAULT << 17)              /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_SYPFDCHPLPENRX_disable                                     (_RAC_RX_SYPFDCHPLPENRX_disable << 17)              /**< Shifted mode disable for RAC_RX             */
#define RAC_RX_SYPFDCHPLPENRX_enable                                      (_RAC_RX_SYPFDCHPLPENRX_enable << 17)               /**< Shifted mode enable for RAC_RX              */
#define RAC_RX_SYPFDFPWENRX                                               (0x1UL << 18)                                       /**< SYPFDFPWENRX                                */
#define _RAC_RX_SYPFDFPWENRX_SHIFT                                        18                                                  /**< Shift value for RAC_SYPFDFPWENRX            */
#define _RAC_RX_SYPFDFPWENRX_MASK                                         0x40000UL                                           /**< Bit mask for RAC_SYPFDFPWENRX               */
#define _RAC_RX_SYPFDFPWENRX_DEFAULT                                      0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_SYPFDFPWENRX_disable                                      0x00000000UL                                        /**< Mode disable for RAC_RX                     */
#define _RAC_RX_SYPFDFPWENRX_enable                                       0x00000001UL                                        /**< Mode enable for RAC_RX                      */
#define RAC_RX_SYPFDFPWENRX_DEFAULT                                       (_RAC_RX_SYPFDFPWENRX_DEFAULT << 18)                /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_SYPFDFPWENRX_disable                                       (_RAC_RX_SYPFDFPWENRX_disable << 18)                /**< Shifted mode disable for RAC_RX             */
#define RAC_RX_SYPFDFPWENRX_enable                                        (_RAC_RX_SYPFDFPWENRX_enable << 18)                 /**< Shifted mode enable for RAC_RX              */
#define RAC_RX_SYVCOVCAPFASTRAMPRX                                        (0x1UL << 19)                                       /**< SYVCOVCAPFASTRAMPRX                         */
#define _RAC_RX_SYVCOVCAPFASTRAMPRX_SHIFT                                 19                                                  /**< Shift value for RAC_SYVCOVCAPFASTRAMPRX     */
#define _RAC_RX_SYVCOVCAPFASTRAMPRX_MASK                                  0x80000UL                                           /**< Bit mask for RAC_SYVCOVCAPFASTRAMPRX        */
#define _RAC_RX_SYVCOVCAPFASTRAMPRX_DEFAULT                               0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_SYVCOVCAPFASTRAMPRX_vcap_fastramp_0                       0x00000000UL                                        /**< Mode vcap_fastramp_0 for RAC_RX             */
#define _RAC_RX_SYVCOVCAPFASTRAMPRX_vcap_fastramp_1                       0x00000001UL                                        /**< Mode vcap_fastramp_1 for RAC_RX             */
#define RAC_RX_SYVCOVCAPFASTRAMPRX_DEFAULT                                (_RAC_RX_SYVCOVCAPFASTRAMPRX_DEFAULT << 19)         /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_SYVCOVCAPFASTRAMPRX_vcap_fastramp_0                        (_RAC_RX_SYVCOVCAPFASTRAMPRX_vcap_fastramp_0 << 19) /**< Shifted mode vcap_fastramp_0 for RAC_RX     */
#define RAC_RX_SYVCOVCAPFASTRAMPRX_vcap_fastramp_1                        (_RAC_RX_SYVCOVCAPFASTRAMPRX_vcap_fastramp_1 << 19) /**< Shifted mode vcap_fastramp_1 for RAC_RX     */
#define RAC_RX_FEFILTOUTPUTSEL                                            (0x1UL << 31)                                       /**< Select output between two FEFILTs           */
#define _RAC_RX_FEFILTOUTPUTSEL_SHIFT                                     31                                                  /**< Shift value for RAC_FEFILTOUTPUTSEL         */
#define _RAC_RX_FEFILTOUTPUTSEL_MASK                                      0x80000000UL                                        /**< Bit mask for RAC_FEFILTOUTPUTSEL            */
#define _RAC_RX_FEFILTOUTPUTSEL_DEFAULT                                   0x00000000UL                                        /**< Mode DEFAULT for RAC_RX                     */
#define _RAC_RX_FEFILTOUTPUTSEL_FEFILT0                                   0x00000000UL                                        /**< Mode FEFILT0 for RAC_RX                     */
#define _RAC_RX_FEFILTOUTPUTSEL_FEFILT1                                   0x00000001UL                                        /**< Mode FEFILT1 for RAC_RX                     */
#define RAC_RX_FEFILTOUTPUTSEL_DEFAULT                                    (_RAC_RX_FEFILTOUTPUTSEL_DEFAULT << 31)             /**< Shifted mode DEFAULT for RAC_RX             */
#define RAC_RX_FEFILTOUTPUTSEL_FEFILT0                                    (_RAC_RX_FEFILTOUTPUTSEL_FEFILT0 << 31)             /**< Shifted mode FEFILT0 for RAC_RX             */
#define RAC_RX_FEFILTOUTPUTSEL_FEFILT1                                    (_RAC_RX_FEFILTOUTPUTSEL_FEFILT1 << 31)             /**< Shifted mode FEFILT1 for RAC_RX             */

/* Bit fields for RAC TX */
#define _RAC_TX_RESETVALUE                                                0x00000000UL                                        /**< Default value for RAC_TX                    */
#define _RAC_TX_MASK                                                      0xDF3FEFFFUL                                        /**< Mask for RAC_TX                             */
#define RAC_TX_TXENDREG                                                   (0x1UL << 0)                                        /**< TXENDREG                                    */
#define _RAC_TX_TXENDREG_SHIFT                                            0                                                   /**< Shift value for RAC_TXENDREG                */
#define _RAC_TX_TXENDREG_MASK                                             0x1UL                                               /**< Bit mask for RAC_TXENDREG                   */
#define _RAC_TX_TXENDREG_DEFAULT                                          0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENDREG_dreg_off                                         0x00000000UL                                        /**< Mode dreg_off for RAC_TX                    */
#define _RAC_TX_TXENDREG_dreg_on                                          0x00000001UL                                        /**< Mode dreg_on for RAC_TX                     */
#define RAC_TX_TXENDREG_DEFAULT                                           (_RAC_TX_TXENDREG_DEFAULT << 0)                     /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENDREG_dreg_off                                          (_RAC_TX_TXENDREG_dreg_off << 0)                    /**< Shifted mode dreg_off for RAC_TX            */
#define RAC_TX_TXENDREG_dreg_on                                           (_RAC_TX_TXENDREG_dreg_on << 0)                     /**< Shifted mode dreg_on for RAC_TX             */
#define RAC_TX_TXENOREG                                                   (0x1UL << 1)                                        /**< TXENOREG                                    */
#define _RAC_TX_TXENOREG_SHIFT                                            1                                                   /**< Shift value for RAC_TXENOREG                */
#define _RAC_TX_TXENOREG_MASK                                             0x2UL                                               /**< Bit mask for RAC_TXENOREG                   */
#define _RAC_TX_TXENOREG_DEFAULT                                          0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENOREG_oreg_off                                         0x00000000UL                                        /**< Mode oreg_off for RAC_TX                    */
#define _RAC_TX_TXENOREG_oreg_on                                          0x00000001UL                                        /**< Mode oreg_on for RAC_TX                     */
#define RAC_TX_TXENOREG_DEFAULT                                           (_RAC_TX_TXENOREG_DEFAULT << 1)                     /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENOREG_oreg_off                                          (_RAC_TX_TXENOREG_oreg_off << 1)                    /**< Shifted mode oreg_off for RAC_TX            */
#define RAC_TX_TXENOREG_oreg_on                                           (_RAC_TX_TXENOREG_oreg_on << 1)                     /**< Shifted mode oreg_on for RAC_TX             */
#define RAC_TX_TXENOREGBLEED                                              (0x1UL << 2)                                        /**< TXENOREGBLEED                               */
#define _RAC_TX_TXENOREGBLEED_SHIFT                                       2                                                   /**< Shift value for RAC_TXENOREGBLEED           */
#define _RAC_TX_TXENOREGBLEED_MASK                                        0x4UL                                               /**< Bit mask for RAC_TXENOREGBLEED              */
#define _RAC_TX_TXENOREGBLEED_DEFAULT                                     0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENOREGBLEED_oreg_bleed_off                              0x00000000UL                                        /**< Mode oreg_bleed_off for RAC_TX              */
#define _RAC_TX_TXENOREGBLEED_oreg_bleed_on                               0x00000001UL                                        /**< Mode oreg_bleed_on for RAC_TX               */
#define RAC_TX_TXENOREGBLEED_DEFAULT                                      (_RAC_TX_TXENOREGBLEED_DEFAULT << 2)                /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENOREGBLEED_oreg_bleed_off                               (_RAC_TX_TXENOREGBLEED_oreg_bleed_off << 2)         /**< Shifted mode oreg_bleed_off for RAC_TX      */
#define RAC_TX_TXENOREGBLEED_oreg_bleed_on                                (_RAC_TX_TXENOREGBLEED_oreg_bleed_on << 2)          /**< Shifted mode oreg_bleed_on for RAC_TX       */
#define RAC_TX_TXENRREG                                                   (0x1UL << 3)                                        /**< TXENRREG                                    */
#define _RAC_TX_TXENRREG_SHIFT                                            3                                                   /**< Shift value for RAC_TXENRREG                */
#define _RAC_TX_TXENRREG_MASK                                             0x8UL                                               /**< Bit mask for RAC_TXENRREG                   */
#define _RAC_TX_TXENRREG_DEFAULT                                          0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENRREG_iso_enabled                                      0x00000000UL                                        /**< Mode iso_enabled for RAC_TX                 */
#define _RAC_TX_TXENRREG_iso_disabled                                     0x00000001UL                                        /**< Mode iso_disabled for RAC_TX                */
#define RAC_TX_TXENRREG_DEFAULT                                           (_RAC_TX_TXENRREG_DEFAULT << 3)                     /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENRREG_iso_enabled                                       (_RAC_TX_TXENRREG_iso_enabled << 3)                 /**< Shifted mode iso_enabled for RAC_TX         */
#define RAC_TX_TXENRREG_iso_disabled                                      (_RAC_TX_TXENRREG_iso_disabled << 3)                /**< Shifted mode iso_disabled for RAC_TX        */
#define RAC_TX_TXENCLKGEN                                                 (0x1UL << 4)                                        /**< TXENCLKGEN                                  */
#define _RAC_TX_TXENCLKGEN_SHIFT                                          4                                                   /**< Shift value for RAC_TXENCLKGEN              */
#define _RAC_TX_TXENCLKGEN_MASK                                           0x10UL                                              /**< Bit mask for RAC_TXENCLKGEN                 */
#define _RAC_TX_TXENCLKGEN_DEFAULT                                        0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENCLKGEN_clkgen_off                                     0x00000000UL                                        /**< Mode clkgen_off for RAC_TX                  */
#define _RAC_TX_TXENCLKGEN_clkgen_on                                      0x00000001UL                                        /**< Mode clkgen_on for RAC_TX                   */
#define RAC_TX_TXENCLKGEN_DEFAULT                                         (_RAC_TX_TXENCLKGEN_DEFAULT << 4)                   /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENCLKGEN_clkgen_off                                      (_RAC_TX_TXENCLKGEN_clkgen_off << 4)                /**< Shifted mode clkgen_off for RAC_TX          */
#define RAC_TX_TXENCLKGEN_clkgen_on                                       (_RAC_TX_TXENCLKGEN_clkgen_on << 4)                 /**< Shifted mode clkgen_on for RAC_TX           */
#define RAC_TX_TXENPADDCFORCE                                             (0x1UL << 5)                                        /**< TXENPADDCFORCE                              */
#define _RAC_TX_TXENPADDCFORCE_SHIFT                                      5                                                   /**< Shift value for RAC_TXENPADDCFORCE          */
#define _RAC_TX_TXENPADDCFORCE_MASK                                       0x20UL                                              /**< Bit mask for RAC_TXENPADDCFORCE             */
#define _RAC_TX_TXENPADDCFORCE_DEFAULT                                    0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENPADDCFORCE_dc_force_off                               0x00000000UL                                        /**< Mode dc_force_off for RAC_TX                */
#define _RAC_TX_TXENPADDCFORCE_dc_force_on                                0x00000001UL                                        /**< Mode dc_force_on for RAC_TX                 */
#define RAC_TX_TXENPADDCFORCE_DEFAULT                                     (_RAC_TX_TXENPADDCFORCE_DEFAULT << 5)               /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENPADDCFORCE_dc_force_off                                (_RAC_TX_TXENPADDCFORCE_dc_force_off << 5)          /**< Shifted mode dc_force_off for RAC_TX        */
#define RAC_TX_TXENPADDCFORCE_dc_force_on                                 (_RAC_TX_TXENPADDCFORCE_dc_force_on << 5)           /**< Shifted mode dc_force_on for RAC_TX         */
#define RAC_TX_TXENPKDOGND                                                (0x1UL << 6)                                        /**< TXENPKDOGND                                 */
#define _RAC_TX_TXENPKDOGND_SHIFT                                         6                                                   /**< Shift value for RAC_TXENPKDOGND             */
#define _RAC_TX_TXENPKDOGND_MASK                                          0x40UL                                              /**< Bit mask for RAC_TXENPKDOGND                */
#define _RAC_TX_TXENPKDOGND_DEFAULT                                       0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENPKDOGND_ognd_pkd_off                                  0x00000000UL                                        /**< Mode ognd_pkd_off for RAC_TX                */
#define _RAC_TX_TXENPKDOGND_ognd_pkd_on                                   0x00000001UL                                        /**< Mode ognd_pkd_on for RAC_TX                 */
#define RAC_TX_TXENPKDOGND_DEFAULT                                        (_RAC_TX_TXENPKDOGND_DEFAULT << 6)                  /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENPKDOGND_ognd_pkd_off                                   (_RAC_TX_TXENPKDOGND_ognd_pkd_off << 6)             /**< Shifted mode ognd_pkd_off for RAC_TX        */
#define RAC_TX_TXENPKDOGND_ognd_pkd_on                                    (_RAC_TX_TXENPKDOGND_ognd_pkd_on << 6)              /**< Shifted mode ognd_pkd_on for RAC_TX         */
#define RAC_TX_TXENPKDOGNDCLK                                             (0x1UL << 7)                                        /**< TXENPKDOGNDCLK                              */
#define _RAC_TX_TXENPKDOGNDCLK_SHIFT                                      7                                                   /**< Shift value for RAC_TXENPKDOGNDCLK          */
#define _RAC_TX_TXENPKDOGNDCLK_MASK                                       0x80UL                                              /**< Bit mask for RAC_TXENPKDOGNDCLK             */
#define _RAC_TX_TXENPKDOGNDCLK_DEFAULT                                    0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENPKDOGNDCLK_pkdognd_clk_off                            0x00000000UL                                        /**< Mode pkdognd_clk_off for RAC_TX             */
#define _RAC_TX_TXENPKDOGNDCLK_pkdognd_clki_on                            0x00000001UL                                        /**< Mode pkdognd_clki_on for RAC_TX             */
#define RAC_TX_TXENPKDOGNDCLK_DEFAULT                                     (_RAC_TX_TXENPKDOGNDCLK_DEFAULT << 7)               /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENPKDOGNDCLK_pkdognd_clk_off                             (_RAC_TX_TXENPKDOGNDCLK_pkdognd_clk_off << 7)       /**< Shifted mode pkdognd_clk_off for RAC_TX     */
#define RAC_TX_TXENPKDOGNDCLK_pkdognd_clki_on                             (_RAC_TX_TXENPKDOGNDCLK_pkdognd_clki_on << 7)       /**< Shifted mode pkdognd_clki_on for RAC_TX     */
#define RAC_TX_TXENPUPDNPROTECT                                           (0x1UL << 8)                                        /**< TXENPUPDNPROTECT                            */
#define _RAC_TX_TXENPUPDNPROTECT_SHIFT                                    8                                                   /**< Shift value for RAC_TXENPUPDNPROTECT        */
#define _RAC_TX_TXENPUPDNPROTECT_MASK                                     0x100UL                                             /**< Bit mask for RAC_TXENPUPDNPROTECT           */
#define _RAC_TX_TXENPUPDNPROTECT_DEFAULT                                  0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENPUPDNPROTECT_pupdn_protect_off                        0x00000000UL                                        /**< Mode pupdn_protect_off for RAC_TX           */
#define _RAC_TX_TXENPUPDNPROTECT_pupdn_protect_on                         0x00000001UL                                        /**< Mode pupdn_protect_on for RAC_TX            */
#define RAC_TX_TXENPUPDNPROTECT_DEFAULT                                   (_RAC_TX_TXENPUPDNPROTECT_DEFAULT << 8)             /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENPUPDNPROTECT_pupdn_protect_off                         (_RAC_TX_TXENPUPDNPROTECT_pupdn_protect_off << 8)   /**< Shifted mode pupdn_protect_off for RAC_TX   */
#define RAC_TX_TXENPUPDNPROTECT_pupdn_protect_on                          (_RAC_TX_TXENPUPDNPROTECT_pupdn_protect_on << 8)    /**< Shifted mode pupdn_protect_on for RAC_TX    */
#define RAC_TX_TXENRAMPCLK                                                (0x1UL << 9)                                        /**< TXENRAMPCLK                                 */
#define _RAC_TX_TXENRAMPCLK_SHIFT                                         9                                                   /**< Shift value for RAC_TXENRAMPCLK             */
#define _RAC_TX_TXENRAMPCLK_MASK                                          0x200UL                                             /**< Bit mask for RAC_TXENRAMPCLK                */
#define _RAC_TX_TXENRAMPCLK_DEFAULT                                       0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENRAMPCLK_disable_ramp_clk                              0x00000000UL                                        /**< Mode disable_ramp_clk for RAC_TX            */
#define _RAC_TX_TXENRAMPCLK_enable_ramp_clk                               0x00000001UL                                        /**< Mode enable_ramp_clk for RAC_TX             */
#define RAC_TX_TXENRAMPCLK_DEFAULT                                        (_RAC_TX_TXENRAMPCLK_DEFAULT << 9)                  /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENRAMPCLK_disable_ramp_clk                               (_RAC_TX_TXENRAMPCLK_disable_ramp_clk << 9)         /**< Shifted mode disable_ramp_clk for RAC_TX    */
#define RAC_TX_TXENRAMPCLK_enable_ramp_clk                                (_RAC_TX_TXENRAMPCLK_enable_ramp_clk << 9)          /**< Shifted mode enable_ramp_clk for RAC_TX     */
#define RAC_TX_TXENVTRCURRENT                                             (0x1UL << 10)                                       /**< TXENVTRCURRENT                              */
#define _RAC_TX_TXENVTRCURRENT_SHIFT                                      10                                                  /**< Shift value for RAC_TXENVTRCURRENT          */
#define _RAC_TX_TXENVTRCURRENT_MASK                                       0x400UL                                             /**< Bit mask for RAC_TXENVTRCURRENT             */
#define _RAC_TX_TXENVTRCURRENT_DEFAULT                                    0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENVTRCURRENT_disable                                    0x00000000UL                                        /**< Mode disable for RAC_TX                     */
#define _RAC_TX_TXENVTRCURRENT_enable                                     0x00000001UL                                        /**< Mode enable for RAC_TX                      */
#define RAC_TX_TXENVTRCURRENT_DEFAULT                                     (_RAC_TX_TXENVTRCURRENT_DEFAULT << 10)              /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENVTRCURRENT_disable                                     (_RAC_TX_TXENVTRCURRENT_disable << 10)              /**< Shifted mode disable for RAC_TX             */
#define RAC_TX_TXENVTRCURRENT_enable                                      (_RAC_TX_TXENVTRCURRENT_enable << 10)               /**< Shifted mode enable for RAC_TX              */
#define RAC_TX_TXENXDRVVMID                                               (0x1UL << 11)                                       /**< TXENXDRVVMID                                */
#define _RAC_TX_TXENXDRVVMID_SHIFT                                        11                                                  /**< Shift value for RAC_TXENXDRVVMID            */
#define _RAC_TX_TXENXDRVVMID_MASK                                         0x800UL                                             /**< Bit mask for RAC_TXENXDRVVMID               */
#define _RAC_TX_TXENXDRVVMID_DEFAULT                                      0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENXDRVVMID_disable                                      0x00000000UL                                        /**< Mode disable for RAC_TX                     */
#define _RAC_TX_TXENXDRVVMID_enable                                       0x00000001UL                                        /**< Mode enable for RAC_TX                      */
#define RAC_TX_TXENXDRVVMID_DEFAULT                                       (_RAC_TX_TXENXDRVVMID_DEFAULT << 11)                /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENXDRVVMID_disable                                       (_RAC_TX_TXENXDRVVMID_disable << 11)                /**< Shifted mode disable for RAC_TX             */
#define RAC_TX_TXENXDRVVMID_enable                                        (_RAC_TX_TXENXDRVVMID_enable << 11)                 /**< Shifted mode enable for RAC_TX              */
#define RAC_TX_TXMODESE                                                   (0x1UL << 13)                                       /**< TXMODESE                                    */
#define _RAC_TX_TXMODESE_SHIFT                                            13                                                  /**< Shift value for RAC_TXMODESE                */
#define _RAC_TX_TXMODESE_MASK                                             0x2000UL                                            /**< Bit mask for RAC_TXMODESE                   */
#define _RAC_TX_TXMODESE_DEFAULT                                          0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXMODESE_differential                                     0x00000000UL                                        /**< Mode differential for RAC_TX                */
#define _RAC_TX_TXMODESE_single_ended                                     0x00000001UL                                        /**< Mode single_ended for RAC_TX                */
#define RAC_TX_TXMODESE_DEFAULT                                           (_RAC_TX_TXMODESE_DEFAULT << 13)                    /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXMODESE_differential                                      (_RAC_TX_TXMODESE_differential << 13)               /**< Shifted mode differential for RAC_TX        */
#define RAC_TX_TXMODESE_single_ended                                      (_RAC_TX_TXMODESE_single_ended << 13)               /**< Shifted mode single_ended for RAC_TX        */
#define RAC_TX_TXENRFPKD0                                                 (0x1UL << 14)                                       /**< TXENRFPKD0                                  */
#define _RAC_TX_TXENRFPKD0_SHIFT                                          14                                                  /**< Shift value for RAC_TXENRFPKD0              */
#define _RAC_TX_TXENRFPKD0_MASK                                           0x4000UL                                            /**< Bit mask for RAC_TXENRFPKD0                 */
#define _RAC_TX_TXENRFPKD0_DEFAULT                                        0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENRFPKD0_disable                                        0x00000000UL                                        /**< Mode disable for RAC_TX                     */
#define _RAC_TX_TXENRFPKD0_enable                                         0x00000001UL                                        /**< Mode enable for RAC_TX                      */
#define RAC_TX_TXENRFPKD0_DEFAULT                                         (_RAC_TX_TXENRFPKD0_DEFAULT << 14)                  /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENRFPKD0_disable                                         (_RAC_TX_TXENRFPKD0_disable << 14)                  /**< Shifted mode disable for RAC_TX             */
#define RAC_TX_TXENRFPKD0_enable                                          (_RAC_TX_TXENRFPKD0_enable << 14)                   /**< Shifted mode enable for RAC_TX              */
#define RAC_TX_TXENRFPKD1                                                 (0x1UL << 15)                                       /**< TXENRFPKD1                                  */
#define _RAC_TX_TXENRFPKD1_SHIFT                                          15                                                  /**< Shift value for RAC_TXENRFPKD1              */
#define _RAC_TX_TXENRFPKD1_MASK                                           0x8000UL                                            /**< Bit mask for RAC_TXENRFPKD1                 */
#define _RAC_TX_TXENRFPKD1_DEFAULT                                        0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENRFPKD1_disable                                        0x00000000UL                                        /**< Mode disable for RAC_TX                     */
#define _RAC_TX_TXENRFPKD1_enable                                         0x00000001UL                                        /**< Mode enable for RAC_TX                      */
#define RAC_TX_TXENRFPKD1_DEFAULT                                         (_RAC_TX_TXENRFPKD1_DEFAULT << 15)                  /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENRFPKD1_disable                                         (_RAC_TX_TXENRFPKD1_disable << 15)                  /**< Shifted mode disable for RAC_TX             */
#define RAC_TX_TXENRFPKD1_enable                                          (_RAC_TX_TXENRFPKD1_enable << 15)                   /**< Shifted mode enable for RAC_TX              */
#define RAC_TX_TXENRREGBLEED                                              (0x1UL << 16)                                       /**< TXENRREGBLEED                               */
#define _RAC_TX_TXENRREGBLEED_SHIFT                                       16                                                  /**< Shift value for RAC_TXENRREGBLEED           */
#define _RAC_TX_TXENRREGBLEED_MASK                                        0x10000UL                                           /**< Bit mask for RAC_TXENRREGBLEED              */
#define _RAC_TX_TXENRREGBLEED_DEFAULT                                     0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENRREGBLEED_disable                                     0x00000000UL                                        /**< Mode disable for RAC_TX                     */
#define _RAC_TX_TXENRREGBLEED_enable                                      0x00000001UL                                        /**< Mode enable for RAC_TX                      */
#define RAC_TX_TXENRREGBLEED_DEFAULT                                      (_RAC_TX_TXENRREGBLEED_DEFAULT << 16)               /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENRREGBLEED_disable                                      (_RAC_TX_TXENRREGBLEED_disable << 16)               /**< Shifted mode disable for RAC_TX             */
#define RAC_TX_TXENRREGBLEED_enable                                       (_RAC_TX_TXENRREGBLEED_enable << 16)                /**< Shifted mode enable for RAC_TX              */
#define RAC_TX_SYCHPBIASTRIMBUFTX                                         (0x1UL << 17)                                       /**< SYCHPBIASTRIMBUFTX                          */
#define _RAC_TX_SYCHPBIASTRIMBUFTX_SHIFT                                  17                                                  /**< Shift value for RAC_SYCHPBIASTRIMBUFTX      */
#define _RAC_TX_SYCHPBIASTRIMBUFTX_MASK                                   0x20000UL                                           /**< Bit mask for RAC_SYCHPBIASTRIMBUFTX         */
#define _RAC_TX_SYCHPBIASTRIMBUFTX_DEFAULT                                0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_SYCHPBIASTRIMBUFTX_i_tail_10u                             0x00000000UL                                        /**< Mode i_tail_10u for RAC_TX                  */
#define _RAC_TX_SYCHPBIASTRIMBUFTX_i_tail_20u                             0x00000001UL                                        /**< Mode i_tail_20u for RAC_TX                  */
#define RAC_TX_SYCHPBIASTRIMBUFTX_DEFAULT                                 (_RAC_TX_SYCHPBIASTRIMBUFTX_DEFAULT << 17)          /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_SYCHPBIASTRIMBUFTX_i_tail_10u                              (_RAC_TX_SYCHPBIASTRIMBUFTX_i_tail_10u << 17)       /**< Shifted mode i_tail_10u for RAC_TX          */
#define RAC_TX_SYCHPBIASTRIMBUFTX_i_tail_20u                              (_RAC_TX_SYCHPBIASTRIMBUFTX_i_tail_20u << 17)       /**< Shifted mode i_tail_20u for RAC_TX          */
#define RAC_TX_SYPFDCHPLPENTX                                             (0x1UL << 18)                                       /**< SYPFDCHPLPENTX                              */
#define _RAC_TX_SYPFDCHPLPENTX_SHIFT                                      18                                                  /**< Shift value for RAC_SYPFDCHPLPENTX          */
#define _RAC_TX_SYPFDCHPLPENTX_MASK                                       0x40000UL                                           /**< Bit mask for RAC_SYPFDCHPLPENTX             */
#define _RAC_TX_SYPFDCHPLPENTX_DEFAULT                                    0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_SYPFDCHPLPENTX_disable                                    0x00000000UL                                        /**< Mode disable for RAC_TX                     */
#define _RAC_TX_SYPFDCHPLPENTX_enable                                     0x00000001UL                                        /**< Mode enable for RAC_TX                      */
#define RAC_TX_SYPFDCHPLPENTX_DEFAULT                                     (_RAC_TX_SYPFDCHPLPENTX_DEFAULT << 18)              /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_SYPFDCHPLPENTX_disable                                     (_RAC_TX_SYPFDCHPLPENTX_disable << 18)              /**< Shifted mode disable for RAC_TX             */
#define RAC_TX_SYPFDCHPLPENTX_enable                                      (_RAC_TX_SYPFDCHPLPENTX_enable << 18)               /**< Shifted mode enable for RAC_TX              */
#define RAC_TX_SYPFDFPWENTX                                               (0x1UL << 19)                                       /**< SYPFDFPWENTX                                */
#define _RAC_TX_SYPFDFPWENTX_SHIFT                                        19                                                  /**< Shift value for RAC_SYPFDFPWENTX            */
#define _RAC_TX_SYPFDFPWENTX_MASK                                         0x80000UL                                           /**< Bit mask for RAC_SYPFDFPWENTX               */
#define _RAC_TX_SYPFDFPWENTX_DEFAULT                                      0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_SYPFDFPWENTX_disable                                      0x00000000UL                                        /**< Mode disable for RAC_TX                     */
#define _RAC_TX_SYPFDFPWENTX_enable                                       0x00000001UL                                        /**< Mode enable for RAC_TX                      */
#define RAC_TX_SYPFDFPWENTX_DEFAULT                                       (_RAC_TX_SYPFDFPWENTX_DEFAULT << 19)                /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_SYPFDFPWENTX_disable                                       (_RAC_TX_SYPFDFPWENTX_disable << 19)                /**< Shifted mode disable for RAC_TX             */
#define RAC_TX_SYPFDFPWENTX_enable                                        (_RAC_TX_SYPFDFPWENTX_enable << 19)                 /**< Shifted mode enable for RAC_TX              */
#define RAC_TX_SYVCOVCAPFASTRAMPTX                                        (0x1UL << 20)                                       /**< SYVCOVCAPFASTRAMPTX                         */
#define _RAC_TX_SYVCOVCAPFASTRAMPTX_SHIFT                                 20                                                  /**< Shift value for RAC_SYVCOVCAPFASTRAMPTX     */
#define _RAC_TX_SYVCOVCAPFASTRAMPTX_MASK                                  0x100000UL                                          /**< Bit mask for RAC_SYVCOVCAPFASTRAMPTX        */
#define _RAC_TX_SYVCOVCAPFASTRAMPTX_DEFAULT                               0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_SYVCOVCAPFASTRAMPTX_vcap_fastramp_0                       0x00000000UL                                        /**< Mode vcap_fastramp_0 for RAC_TX             */
#define _RAC_TX_SYVCOVCAPFASTRAMPTX_vcap_fastramp_1                       0x00000001UL                                        /**< Mode vcap_fastramp_1 for RAC_TX             */
#define RAC_TX_SYVCOVCAPFASTRAMPTX_DEFAULT                                (_RAC_TX_SYVCOVCAPFASTRAMPTX_DEFAULT << 20)         /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_SYVCOVCAPFASTRAMPTX_vcap_fastramp_0                        (_RAC_TX_SYVCOVCAPFASTRAMPTX_vcap_fastramp_0 << 20) /**< Shifted mode vcap_fastramp_0 for RAC_TX     */
#define RAC_TX_SYVCOVCAPFASTRAMPTX_vcap_fastramp_1                        (_RAC_TX_SYVCOVCAPFASTRAMPTX_vcap_fastramp_1 << 20) /**< Shifted mode vcap_fastramp_1 for RAC_TX     */
#define RAC_TX_TXMODEPMOSOFF                                              (0x1UL << 21)                                       /**< TXMODEPMOSOFF                               */
#define _RAC_TX_TXMODEPMOSOFF_SHIFT                                       21                                                  /**< Shift value for RAC_TXMODEPMOSOFF           */
#define _RAC_TX_TXMODEPMOSOFF_MASK                                        0x200000UL                                          /**< Bit mask for RAC_TXMODEPMOSOFF              */
#define _RAC_TX_TXMODEPMOSOFF_DEFAULT                                     0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXMODEPMOSOFF_disable                                     0x00000000UL                                        /**< Mode disable for RAC_TX                     */
#define _RAC_TX_TXMODEPMOSOFF_enable                                      0x00000001UL                                        /**< Mode enable for RAC_TX                      */
#define RAC_TX_TXMODEPMOSOFF_DEFAULT                                      (_RAC_TX_TXMODEPMOSOFF_DEFAULT << 21)               /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXMODEPMOSOFF_disable                                      (_RAC_TX_TXMODEPMOSOFF_disable << 21)               /**< Shifted mode disable for RAC_TX             */
#define RAC_TX_TXMODEPMOSOFF_enable                                       (_RAC_TX_TXMODEPMOSOFF_enable << 21)                /**< Shifted mode enable for RAC_TX              */
#define RAC_TX_TXSWPENDACI                                                (0x1UL << 24)                                       /**< TXSWPENDACI                                 */
#define _RAC_TX_TXSWPENDACI_SHIFT                                         24                                                  /**< Shift value for RAC_TXSWPENDACI             */
#define _RAC_TX_TXSWPENDACI_MASK                                          0x1000000UL                                         /**< Bit mask for RAC_TXSWPENDACI                */
#define _RAC_TX_TXSWPENDACI_DEFAULT                                       0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXSWPENDACI_disabled                                      0x00000000UL                                        /**< Mode disabled for RAC_TX                    */
#define _RAC_TX_TXSWPENDACI_enabled                                       0x00000001UL                                        /**< Mode enabled for RAC_TX                     */
#define RAC_TX_TXSWPENDACI_DEFAULT                                        (_RAC_TX_TXSWPENDACI_DEFAULT << 24)                 /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXSWPENDACI_disabled                                       (_RAC_TX_TXSWPENDACI_disabled << 24)                /**< Shifted mode disabled for RAC_TX            */
#define RAC_TX_TXSWPENDACI_enabled                                        (_RAC_TX_TXSWPENDACI_enabled << 24)                 /**< Shifted mode enabled for RAC_TX             */
#define RAC_TX_TXSWPENDACQ                                                (0x1UL << 25)                                       /**< TXSWPENDACQ                                 */
#define _RAC_TX_TXSWPENDACQ_SHIFT                                         25                                                  /**< Shift value for RAC_TXSWPENDACQ             */
#define _RAC_TX_TXSWPENDACQ_MASK                                          0x2000000UL                                         /**< Bit mask for RAC_TXSWPENDACQ                */
#define _RAC_TX_TXSWPENDACQ_DEFAULT                                       0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXSWPENDACQ_disabled                                      0x00000000UL                                        /**< Mode disabled for RAC_TX                    */
#define _RAC_TX_TXSWPENDACQ_enabled                                       0x00000001UL                                        /**< Mode enabled for RAC_TX                     */
#define RAC_TX_TXSWPENDACQ_DEFAULT                                        (_RAC_TX_TXSWPENDACQ_DEFAULT << 25)                 /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXSWPENDACQ_disabled                                       (_RAC_TX_TXSWPENDACQ_disabled << 25)                /**< Shifted mode disabled for RAC_TX            */
#define RAC_TX_TXSWPENDACQ_enabled                                        (_RAC_TX_TXSWPENDACQ_enabled << 25)                 /**< Shifted mode enabled for RAC_TX             */
#define RAC_TX_TXENITCDAC                                                 (0x1UL << 26)                                       /**< TXENITCDAC                                  */
#define _RAC_TX_TXENITCDAC_SHIFT                                          26                                                  /**< Shift value for RAC_TXENITCDAC              */
#define _RAC_TX_TXENITCDAC_MASK                                           0x4000000UL                                         /**< Bit mask for RAC_TXENITCDAC                 */
#define _RAC_TX_TXENITCDAC_DEFAULT                                        0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENITCDAC_disabled                                       0x00000000UL                                        /**< Mode disabled for RAC_TX                    */
#define _RAC_TX_TXENITCDAC_enabled                                        0x00000001UL                                        /**< Mode enabled for RAC_TX                     */
#define RAC_TX_TXENITCDAC_DEFAULT                                         (_RAC_TX_TXENITCDAC_DEFAULT << 26)                  /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENITCDAC_disabled                                        (_RAC_TX_TXENITCDAC_disabled << 26)                 /**< Shifted mode disabled for RAC_TX            */
#define RAC_TX_TXENITCDAC_enabled                                         (_RAC_TX_TXENITCDAC_enabled << 26)                  /**< Shifted mode enabled for RAC_TX             */
#define RAC_TX_TXENITCPA                                                  (0x1UL << 27)                                       /**< TXENITCPA                                   */
#define _RAC_TX_TXENITCPA_SHIFT                                           27                                                  /**< Shift value for RAC_TXENITCPA               */
#define _RAC_TX_TXENITCPA_MASK                                            0x8000000UL                                         /**< Bit mask for RAC_TXENITCPA                  */
#define _RAC_TX_TXENITCPA_DEFAULT                                         0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENITCPA_disabled                                        0x00000000UL                                        /**< Mode disabled for RAC_TX                    */
#define _RAC_TX_TXENITCPA_enabled                                         0x00000001UL                                        /**< Mode enabled for RAC_TX                     */
#define RAC_TX_TXENITCPA_DEFAULT                                          (_RAC_TX_TXENITCPA_DEFAULT << 27)                   /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENITCPA_disabled                                         (_RAC_TX_TXENITCPA_disabled << 27)                  /**< Shifted mode disabled for RAC_TX            */
#define RAC_TX_TXENITCPA_enabled                                          (_RAC_TX_TXENITCPA_enabled << 27)                   /**< Shifted mode enabled for RAC_TX             */
#define RAC_TX_TXENITCCORE                                                (0x1UL << 28)                                       /**< TXENITCCORE                                 */
#define _RAC_TX_TXENITCCORE_SHIFT                                         28                                                  /**< Shift value for RAC_TXENITCCORE             */
#define _RAC_TX_TXENITCCORE_MASK                                          0x10000000UL                                        /**< Bit mask for RAC_TXENITCCORE                */
#define _RAC_TX_TXENITCCORE_DEFAULT                                       0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define _RAC_TX_TXENITCCORE_disabled                                      0x00000000UL                                        /**< Mode disabled for RAC_TX                    */
#define _RAC_TX_TXENITCCORE_enabled                                       0x00000001UL                                        /**< Mode enabled for RAC_TX                     */
#define RAC_TX_TXENITCCORE_DEFAULT                                        (_RAC_TX_TXENITCCORE_DEFAULT << 28)                 /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_TXENITCCORE_disabled                                       (_RAC_TX_TXENITCCORE_disabled << 28)                /**< Shifted mode disabled for RAC_TX            */
#define RAC_TX_TXENITCCORE_enabled                                        (_RAC_TX_TXENITCCORE_enabled << 28)                 /**< Shifted mode enabled for RAC_TX             */
#define RAC_TX_ENPAPOWER                                                  (0x1UL << 30)                                       /**< Override                                    */
#define _RAC_TX_ENPAPOWER_SHIFT                                           30                                                  /**< Shift value for RAC_ENPAPOWER               */
#define _RAC_TX_ENPAPOWER_MASK                                            0x40000000UL                                        /**< Bit mask for RAC_ENPAPOWER                  */
#define _RAC_TX_ENPAPOWER_DEFAULT                                         0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define RAC_TX_ENPAPOWER_DEFAULT                                          (_RAC_TX_ENPAPOWER_DEFAULT << 30)                   /**< Shifted mode DEFAULT for RAC_TX             */
#define RAC_TX_ENPASELSLICE                                               (0x1UL << 31)                                       /**< Override                                    */
#define _RAC_TX_ENPASELSLICE_SHIFT                                        31                                                  /**< Shift value for RAC_ENPASELSLICE            */
#define _RAC_TX_ENPASELSLICE_MASK                                         0x80000000UL                                        /**< Bit mask for RAC_ENPASELSLICE               */
#define _RAC_TX_ENPASELSLICE_DEFAULT                                      0x00000000UL                                        /**< Mode DEFAULT for RAC_TX                     */
#define RAC_TX_ENPASELSLICE_DEFAULT                                       (_RAC_TX_ENPASELSLICE_DEFAULT << 31)                /**< Shifted mode DEFAULT for RAC_TX             */

/* Bit fields for RAC SYTRIM0 */
#define _RAC_SYTRIM0_RESETVALUE                                           0x018FF169UL                                       /**< Default value for RAC_SYTRIM0               */
#define _RAC_SYTRIM0_MASK                                                 0x0FFFFFFFUL                                       /**< Mask for RAC_SYTRIM0                        */
#define _RAC_SYTRIM0_SYCHPBIAS_SHIFT                                      0                                                  /**< Shift value for RAC_SYCHPBIAS               */
#define _RAC_SYTRIM0_SYCHPBIAS_MASK                                       0x7UL                                              /**< Bit mask for RAC_SYCHPBIAS                  */
#define _RAC_SYTRIM0_SYCHPBIAS_DEFAULT                                    0x00000001UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYCHPBIAS_bias_0                                     0x00000000UL                                       /**< Mode bias_0 for RAC_SYTRIM0                 */
#define _RAC_SYTRIM0_SYCHPBIAS_bias_1                                     0x00000001UL                                       /**< Mode bias_1 for RAC_SYTRIM0                 */
#define _RAC_SYTRIM0_SYCHPBIAS_bias_2                                     0x00000003UL                                       /**< Mode bias_2 for RAC_SYTRIM0                 */
#define _RAC_SYTRIM0_SYCHPBIAS_bias_3                                     0x00000007UL                                       /**< Mode bias_3 for RAC_SYTRIM0                 */
#define RAC_SYTRIM0_SYCHPBIAS_DEFAULT                                     (_RAC_SYTRIM0_SYCHPBIAS_DEFAULT << 0)              /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYCHPBIAS_bias_0                                      (_RAC_SYTRIM0_SYCHPBIAS_bias_0 << 0)               /**< Shifted mode bias_0 for RAC_SYTRIM0         */
#define RAC_SYTRIM0_SYCHPBIAS_bias_1                                      (_RAC_SYTRIM0_SYCHPBIAS_bias_1 << 0)               /**< Shifted mode bias_1 for RAC_SYTRIM0         */
#define RAC_SYTRIM0_SYCHPBIAS_bias_2                                      (_RAC_SYTRIM0_SYCHPBIAS_bias_2 << 0)               /**< Shifted mode bias_2 for RAC_SYTRIM0         */
#define RAC_SYTRIM0_SYCHPBIAS_bias_3                                      (_RAC_SYTRIM0_SYCHPBIAS_bias_3 << 0)               /**< Shifted mode bias_3 for RAC_SYTRIM0         */
#define _RAC_SYTRIM0_SYCHPCURRRX_SHIFT                                    3                                                  /**< Shift value for RAC_SYCHPCURRRX             */
#define _RAC_SYTRIM0_SYCHPCURRRX_MASK                                     0x38UL                                             /**< Bit mask for RAC_SYCHPCURRRX                */
#define _RAC_SYTRIM0_SYCHPCURRRX_DEFAULT                                  0x00000005UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYCHPCURRRX_curr_1p5uA                               0x00000000UL                                       /**< Mode curr_1p5uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRRX_curr_2p0uA                               0x00000001UL                                       /**< Mode curr_2p0uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRRX_curr_2p5uA                               0x00000002UL                                       /**< Mode curr_2p5uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRRX_curr_3p0uA                               0x00000003UL                                       /**< Mode curr_3p0uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRRX_curr_3p5uA                               0x00000004UL                                       /**< Mode curr_3p5uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRRX_curr_4p0uA                               0x00000005UL                                       /**< Mode curr_4p0uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRRX_curr_4p5uA                               0x00000006UL                                       /**< Mode curr_4p5uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRRX_curr_5p0uA                               0x00000007UL                                       /**< Mode curr_5p0uA for RAC_SYTRIM0             */
#define RAC_SYTRIM0_SYCHPCURRRX_DEFAULT                                   (_RAC_SYTRIM0_SYCHPCURRRX_DEFAULT << 3)            /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYCHPCURRRX_curr_1p5uA                                (_RAC_SYTRIM0_SYCHPCURRRX_curr_1p5uA << 3)         /**< Shifted mode curr_1p5uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRRX_curr_2p0uA                                (_RAC_SYTRIM0_SYCHPCURRRX_curr_2p0uA << 3)         /**< Shifted mode curr_2p0uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRRX_curr_2p5uA                                (_RAC_SYTRIM0_SYCHPCURRRX_curr_2p5uA << 3)         /**< Shifted mode curr_2p5uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRRX_curr_3p0uA                                (_RAC_SYTRIM0_SYCHPCURRRX_curr_3p0uA << 3)         /**< Shifted mode curr_3p0uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRRX_curr_3p5uA                                (_RAC_SYTRIM0_SYCHPCURRRX_curr_3p5uA << 3)         /**< Shifted mode curr_3p5uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRRX_curr_4p0uA                                (_RAC_SYTRIM0_SYCHPCURRRX_curr_4p0uA << 3)         /**< Shifted mode curr_4p0uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRRX_curr_4p5uA                                (_RAC_SYTRIM0_SYCHPCURRRX_curr_4p5uA << 3)         /**< Shifted mode curr_4p5uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRRX_curr_5p0uA                                (_RAC_SYTRIM0_SYCHPCURRRX_curr_5p0uA << 3)         /**< Shifted mode curr_5p0uA for RAC_SYTRIM0     */
#define _RAC_SYTRIM0_SYCHPCURRTX_SHIFT                                    6                                                  /**< Shift value for RAC_SYCHPCURRTX             */
#define _RAC_SYTRIM0_SYCHPCURRTX_MASK                                     0x1C0UL                                            /**< Bit mask for RAC_SYCHPCURRTX                */
#define _RAC_SYTRIM0_SYCHPCURRTX_DEFAULT                                  0x00000005UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYCHPCURRTX_curr_1p5uA                               0x00000000UL                                       /**< Mode curr_1p5uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRTX_curr_2p0uA                               0x00000001UL                                       /**< Mode curr_2p0uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRTX_curr_2p5uA                               0x00000002UL                                       /**< Mode curr_2p5uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRTX_curr_3p0uA                               0x00000003UL                                       /**< Mode curr_3p0uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRTX_curr_3p5uA                               0x00000004UL                                       /**< Mode curr_3p5uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRTX_curr_4p0uA                               0x00000005UL                                       /**< Mode curr_4p0uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRTX_curr_4p5uA                               0x00000006UL                                       /**< Mode curr_4p5uA for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPCURRTX_curr_5p0uA                               0x00000007UL                                       /**< Mode curr_5p0uA for RAC_SYTRIM0             */
#define RAC_SYTRIM0_SYCHPCURRTX_DEFAULT                                   (_RAC_SYTRIM0_SYCHPCURRTX_DEFAULT << 6)            /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYCHPCURRTX_curr_1p5uA                                (_RAC_SYTRIM0_SYCHPCURRTX_curr_1p5uA << 6)         /**< Shifted mode curr_1p5uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRTX_curr_2p0uA                                (_RAC_SYTRIM0_SYCHPCURRTX_curr_2p0uA << 6)         /**< Shifted mode curr_2p0uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRTX_curr_2p5uA                                (_RAC_SYTRIM0_SYCHPCURRTX_curr_2p5uA << 6)         /**< Shifted mode curr_2p5uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRTX_curr_3p0uA                                (_RAC_SYTRIM0_SYCHPCURRTX_curr_3p0uA << 6)         /**< Shifted mode curr_3p0uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRTX_curr_3p5uA                                (_RAC_SYTRIM0_SYCHPCURRTX_curr_3p5uA << 6)         /**< Shifted mode curr_3p5uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRTX_curr_4p0uA                                (_RAC_SYTRIM0_SYCHPCURRTX_curr_4p0uA << 6)         /**< Shifted mode curr_4p0uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRTX_curr_4p5uA                                (_RAC_SYTRIM0_SYCHPCURRTX_curr_4p5uA << 6)         /**< Shifted mode curr_4p5uA for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPCURRTX_curr_5p0uA                                (_RAC_SYTRIM0_SYCHPCURRTX_curr_5p0uA << 6)         /**< Shifted mode curr_5p0uA for RAC_SYTRIM0     */
#define _RAC_SYTRIM0_SYCHPLEVNSRC_SHIFT                                   9                                                  /**< Shift value for RAC_SYCHPLEVNSRC            */
#define _RAC_SYTRIM0_SYCHPLEVNSRC_MASK                                    0xE00UL                                            /**< Bit mask for RAC_SYCHPLEVNSRC               */
#define _RAC_SYTRIM0_SYCHPLEVNSRC_DEFAULT                                 0x00000000UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define RAC_SYTRIM0_SYCHPLEVNSRC_DEFAULT                                  (_RAC_SYTRIM0_SYCHPLEVNSRC_DEFAULT << 9)           /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_SHIFT                                 12                                                 /**< Shift value for RAC_SYCHPLEVPSRCRX          */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_MASK                                  0x7000UL                                           /**< Bit mask for RAC_SYCHPLEVPSRCRX             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_DEFAULT                               0x00000007UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n105m                           0x00000000UL                                       /**< Mode vsrcp_n105m for RAC_SYTRIM0            */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n90m                            0x00000001UL                                       /**< Mode vsrcp_n90m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n75m                            0x00000002UL                                       /**< Mode vsrcp_n75m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n60m                            0x00000003UL                                       /**< Mode vsrcp_n60m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n45m                            0x00000004UL                                       /**< Mode vsrcp_n45m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n30m                            0x00000005UL                                       /**< Mode vsrcp_n30m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n15m                            0x00000006UL                                       /**< Mode vsrcp_n15m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n0m                             0x00000007UL                                       /**< Mode vsrcp_n0m for RAC_SYTRIM0              */
#define RAC_SYTRIM0_SYCHPLEVPSRCRX_DEFAULT                                (_RAC_SYTRIM0_SYCHPLEVPSRCRX_DEFAULT << 12)        /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n105m                            (_RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n105m << 12)    /**< Shifted mode vsrcp_n105m for RAC_SYTRIM0    */
#define RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n90m                             (_RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n90m << 12)     /**< Shifted mode vsrcp_n90m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n75m                             (_RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n75m << 12)     /**< Shifted mode vsrcp_n75m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n60m                             (_RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n60m << 12)     /**< Shifted mode vsrcp_n60m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n45m                             (_RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n45m << 12)     /**< Shifted mode vsrcp_n45m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n30m                             (_RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n30m << 12)     /**< Shifted mode vsrcp_n30m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n15m                             (_RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n15m << 12)     /**< Shifted mode vsrcp_n15m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n0m                              (_RAC_SYTRIM0_SYCHPLEVPSRCRX_vsrcp_n0m << 12)      /**< Shifted mode vsrcp_n0m for RAC_SYTRIM0      */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_SHIFT                                 15                                                 /**< Shift value for RAC_SYCHPLEVPSRCTX          */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_MASK                                  0x38000UL                                          /**< Bit mask for RAC_SYCHPLEVPSRCTX             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_DEFAULT                               0x00000007UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n105m                           0x00000000UL                                       /**< Mode vsrcp_n105m for RAC_SYTRIM0            */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n90m                            0x00000001UL                                       /**< Mode vsrcp_n90m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n75m                            0x00000002UL                                       /**< Mode vsrcp_n75m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n60m                            0x00000003UL                                       /**< Mode vsrcp_n60m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n45m                            0x00000004UL                                       /**< Mode vsrcp_n45m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n30m                            0x00000005UL                                       /**< Mode vsrcp_n30m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n15m                            0x00000006UL                                       /**< Mode vsrcp_n15m for RAC_SYTRIM0             */
#define _RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n0m                             0x00000007UL                                       /**< Mode vsrcp_n0m for RAC_SYTRIM0              */
#define RAC_SYTRIM0_SYCHPLEVPSRCTX_DEFAULT                                (_RAC_SYTRIM0_SYCHPLEVPSRCTX_DEFAULT << 15)        /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n105m                            (_RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n105m << 15)    /**< Shifted mode vsrcp_n105m for RAC_SYTRIM0    */
#define RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n90m                             (_RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n90m << 15)     /**< Shifted mode vsrcp_n90m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n75m                             (_RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n75m << 15)     /**< Shifted mode vsrcp_n75m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n60m                             (_RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n60m << 15)     /**< Shifted mode vsrcp_n60m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n45m                             (_RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n45m << 15)     /**< Shifted mode vsrcp_n45m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n30m                             (_RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n30m << 15)     /**< Shifted mode vsrcp_n30m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n15m                             (_RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n15m << 15)     /**< Shifted mode vsrcp_n15m for RAC_SYTRIM0     */
#define RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n0m                              (_RAC_SYTRIM0_SYCHPLEVPSRCTX_vsrcp_n0m << 15)      /**< Shifted mode vsrcp_n0m for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYCHPSRCENRX                                          (0x1UL << 18)                                      /**< SYCHPSRCENRX                                */
#define _RAC_SYTRIM0_SYCHPSRCENRX_SHIFT                                   18                                                 /**< Shift value for RAC_SYCHPSRCENRX            */
#define _RAC_SYTRIM0_SYCHPSRCENRX_MASK                                    0x40000UL                                          /**< Bit mask for RAC_SYCHPSRCENRX               */
#define _RAC_SYTRIM0_SYCHPSRCENRX_DEFAULT                                 0x00000001UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYCHPSRCENRX_disable                                 0x00000000UL                                       /**< Mode disable for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYCHPSRCENRX_enable                                  0x00000001UL                                       /**< Mode enable for RAC_SYTRIM0                 */
#define RAC_SYTRIM0_SYCHPSRCENRX_DEFAULT                                  (_RAC_SYTRIM0_SYCHPSRCENRX_DEFAULT << 18)          /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYCHPSRCENRX_disable                                  (_RAC_SYTRIM0_SYCHPSRCENRX_disable << 18)          /**< Shifted mode disable for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYCHPSRCENRX_enable                                   (_RAC_SYTRIM0_SYCHPSRCENRX_enable << 18)           /**< Shifted mode enable for RAC_SYTRIM0         */
#define RAC_SYTRIM0_SYCHPSRCENTX                                          (0x1UL << 19)                                      /**< SYCHPSRCENTX                                */
#define _RAC_SYTRIM0_SYCHPSRCENTX_SHIFT                                   19                                                 /**< Shift value for RAC_SYCHPSRCENTX            */
#define _RAC_SYTRIM0_SYCHPSRCENTX_MASK                                    0x80000UL                                          /**< Bit mask for RAC_SYCHPSRCENTX               */
#define _RAC_SYTRIM0_SYCHPSRCENTX_DEFAULT                                 0x00000001UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYCHPSRCENTX_disable                                 0x00000000UL                                       /**< Mode disable for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYCHPSRCENTX_enable                                  0x00000001UL                                       /**< Mode enable for RAC_SYTRIM0                 */
#define RAC_SYTRIM0_SYCHPSRCENTX_DEFAULT                                  (_RAC_SYTRIM0_SYCHPSRCENTX_DEFAULT << 19)          /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYCHPSRCENTX_disable                                  (_RAC_SYTRIM0_SYCHPSRCENTX_disable << 19)          /**< Shifted mode disable for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYCHPSRCENTX_enable                                   (_RAC_SYTRIM0_SYCHPSRCENTX_enable << 19)           /**< Shifted mode enable for RAC_SYTRIM0         */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_SHIFT                            20                                                 /**< Shift value for RAC_SYCHPREPLICACURRADJ     */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_MASK                             0x700000UL                                         /**< Bit mask for RAC_SYCHPREPLICACURRADJ        */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_DEFAULT                          0x00000000UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_8ua                         0x00000000UL                                       /**< Mode load_8ua for RAC_SYTRIM0               */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_16ua                        0x00000001UL                                       /**< Mode load_16ua for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_20ua                        0x00000002UL                                       /**< Mode load_20ua for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_28ua                        0x00000003UL                                       /**< Mode load_28ua for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_24ua                        0x00000004UL                                       /**< Mode load_24ua for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_32ua                        0x00000005UL                                       /**< Mode load_32ua for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_36ua                        0x00000006UL                                       /**< Mode load_36ua for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_44ua                        0x00000007UL                                       /**< Mode load_44ua for RAC_SYTRIM0              */
#define RAC_SYTRIM0_SYCHPREPLICACURRADJ_DEFAULT                           (_RAC_SYTRIM0_SYCHPREPLICACURRADJ_DEFAULT << 20)   /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_8ua                          (_RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_8ua << 20)  /**< Shifted mode load_8ua for RAC_SYTRIM0       */
#define RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_16ua                         (_RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_16ua << 20) /**< Shifted mode load_16ua for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_20ua                         (_RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_20ua << 20) /**< Shifted mode load_20ua for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_28ua                         (_RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_28ua << 20) /**< Shifted mode load_28ua for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_24ua                         (_RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_24ua << 20) /**< Shifted mode load_24ua for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_32ua                         (_RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_32ua << 20) /**< Shifted mode load_32ua for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_36ua                         (_RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_36ua << 20) /**< Shifted mode load_36ua for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_44ua                         (_RAC_SYTRIM0_SYCHPREPLICACURRADJ_load_44ua << 20) /**< Shifted mode load_44ua for RAC_SYTRIM0      */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_SHIFT                            23                                                 /**< Shift value for RAC_SYTRIMCHPREGAMPBIAS     */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_MASK                             0x3800000UL                                        /**< Bit mask for RAC_SYTRIMCHPREGAMPBIAS        */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_DEFAULT                          0x00000003UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_14uA                        0x00000000UL                                       /**< Mode bias_14uA for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_20uA                        0x00000001UL                                       /**< Mode bias_20uA for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_26uA                        0x00000002UL                                       /**< Mode bias_26uA for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_32uA                        0x00000003UL                                       /**< Mode bias_32uA for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_38uA                        0x00000004UL                                       /**< Mode bias_38uA for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_44uA                        0x00000005UL                                       /**< Mode bias_44uA for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_50uA                        0x00000006UL                                       /**< Mode bias_50uA for RAC_SYTRIM0              */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_56uA                        0x00000007UL                                       /**< Mode bias_56uA for RAC_SYTRIM0              */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_DEFAULT                           (_RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_DEFAULT << 23)   /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_14uA                         (_RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_14uA << 23) /**< Shifted mode bias_14uA for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_20uA                         (_RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_20uA << 23) /**< Shifted mode bias_20uA for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_26uA                         (_RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_26uA << 23) /**< Shifted mode bias_26uA for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_32uA                         (_RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_32uA << 23) /**< Shifted mode bias_32uA for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_38uA                         (_RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_38uA << 23) /**< Shifted mode bias_38uA for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_44uA                         (_RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_44uA << 23) /**< Shifted mode bias_44uA for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_50uA                         (_RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_50uA << 23) /**< Shifted mode bias_50uA for RAC_SYTRIM0      */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_56uA                         (_RAC_SYTRIM0_SYTRIMCHPREGAMPBIAS_bias_56uA << 23) /**< Shifted mode bias_56uA for RAC_SYTRIM0      */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBW_SHIFT                              26                                                 /**< Shift value for RAC_SYTRIMCHPREGAMPBW       */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBW_MASK                               0xC000000UL                                        /**< Bit mask for RAC_SYTRIMCHPREGAMPBW          */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBW_DEFAULT                            0x00000000UL                                       /**< Mode DEFAULT for RAC_SYTRIM0                */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_000f                             0x00000000UL                                       /**< Mode C_000f for RAC_SYTRIM0                 */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_300f                             0x00000001UL                                       /**< Mode C_300f for RAC_SYTRIM0                 */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_600f                             0x00000002UL                                       /**< Mode C_600f for RAC_SYTRIM0                 */
#define _RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_900f                             0x00000003UL                                       /**< Mode C_900f for RAC_SYTRIM0                 */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBW_DEFAULT                             (_RAC_SYTRIM0_SYTRIMCHPREGAMPBW_DEFAULT << 26)     /**< Shifted mode DEFAULT for RAC_SYTRIM0        */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_000f                              (_RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_000f << 26)      /**< Shifted mode C_000f for RAC_SYTRIM0         */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_300f                              (_RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_300f << 26)      /**< Shifted mode C_300f for RAC_SYTRIM0         */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_600f                              (_RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_600f << 26)      /**< Shifted mode C_600f for RAC_SYTRIM0         */
#define RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_900f                              (_RAC_SYTRIM0_SYTRIMCHPREGAMPBW_C_900f << 26)      /**< Shifted mode C_900f for RAC_SYTRIM0         */

/* Bit fields for RAC SYTRIM1 */
#define _RAC_SYTRIM1_RESETVALUE                                           0x1FE00440UL                                         /**< Default value for RAC_SYTRIM1               */
#define _RAC_SYTRIM1_MASK                                                 0xFFFFCFFFUL                                         /**< Mask for RAC_SYTRIM1                        */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_SHIFT                           0                                                    /**< Shift value for RAC_SYLODIVLDOTRIMCORERX    */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_MASK                            0x3UL                                                /**< Bit mask for RAC_SYLODIVLDOTRIMCORERX       */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_DEFAULT                         0x00000000UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_RXLO                            0x00000000UL                                         /**< Mode RXLO for RAC_SYTRIM1                   */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_TXLO                            0x00000003UL                                         /**< Mode TXLO for RAC_SYTRIM1                   */
#define RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_DEFAULT                          (_RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_DEFAULT << 0)     /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_RXLO                             (_RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_RXLO << 0)        /**< Shifted mode RXLO for RAC_SYTRIM1           */
#define RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_TXLO                             (_RAC_SYTRIM1_SYLODIVLDOTRIMCORERX_TXLO << 0)        /**< Shifted mode TXLO for RAC_SYTRIM1           */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_SHIFT                           2                                                    /**< Shift value for RAC_SYLODIVLDOTRIMCORETX    */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_MASK                            0xCUL                                                /**< Bit mask for RAC_SYLODIVLDOTRIMCORETX       */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_DEFAULT                         0x00000000UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_RXLO                            0x00000000UL                                         /**< Mode RXLO for RAC_SYTRIM1                   */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_TXLO                            0x00000003UL                                         /**< Mode TXLO for RAC_SYTRIM1                   */
#define RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_DEFAULT                          (_RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_DEFAULT << 2)     /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_RXLO                             (_RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_RXLO << 2)        /**< Shifted mode RXLO for RAC_SYTRIM1           */
#define RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_TXLO                             (_RAC_SYTRIM1_SYLODIVLDOTRIMCORETX_TXLO << 2)        /**< Shifted mode TXLO for RAC_SYTRIM1           */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_SHIFT                           4                                                    /**< Shift value for RAC_SYLODIVLDOTRIMNDIORX    */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_MASK                            0xF0UL                                               /**< Bit mask for RAC_SYLODIVLDOTRIMNDIORX       */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_DEFAULT                         0x00000004UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p08                       0x00000000UL                                         /**< Mode vreg_1p08 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p11                       0x00000001UL                                         /**< Mode vreg_1p11 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p15                       0x00000002UL                                         /**< Mode vreg_1p15 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p18                       0x00000003UL                                         /**< Mode vreg_1p18 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p21                       0x00000004UL                                         /**< Mode vreg_1p21 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p24                       0x00000005UL                                         /**< Mode vreg_1p24 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p27                       0x00000006UL                                         /**< Mode vreg_1p27 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p29                       0x00000007UL                                         /**< Mode vreg_1p29 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p32                       0x00000008UL                                         /**< Mode vreg_1p32 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p34                       0x00000009UL                                         /**< Mode vreg_1p34 for RAC_SYTRIM1              */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_DEFAULT                          (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_DEFAULT << 4)     /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p08                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p08 << 4)   /**< Shifted mode vreg_1p08 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p11                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p11 << 4)   /**< Shifted mode vreg_1p11 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p15                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p15 << 4)   /**< Shifted mode vreg_1p15 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p18                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p18 << 4)   /**< Shifted mode vreg_1p18 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p21                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p21 << 4)   /**< Shifted mode vreg_1p21 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p24                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p24 << 4)   /**< Shifted mode vreg_1p24 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p27                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p27 << 4)   /**< Shifted mode vreg_1p27 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p29                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p29 << 4)   /**< Shifted mode vreg_1p29 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p32                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p32 << 4)   /**< Shifted mode vreg_1p32 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p34                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIORX_vreg_1p34 << 4)   /**< Shifted mode vreg_1p34 for RAC_SYTRIM1      */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_SHIFT                           8                                                    /**< Shift value for RAC_SYLODIVLDOTRIMNDIOTX    */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_MASK                            0xF00UL                                              /**< Bit mask for RAC_SYLODIVLDOTRIMNDIOTX       */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_DEFAULT                         0x00000004UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p08                       0x00000000UL                                         /**< Mode vreg_1p08 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p11                       0x00000001UL                                         /**< Mode vreg_1p11 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p15                       0x00000002UL                                         /**< Mode vreg_1p15 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p18                       0x00000003UL                                         /**< Mode vreg_1p18 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p21                       0x00000004UL                                         /**< Mode vreg_1p21 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p24                       0x00000005UL                                         /**< Mode vreg_1p24 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p27                       0x00000006UL                                         /**< Mode vreg_1p27 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p29                       0x00000007UL                                         /**< Mode vreg_1p29 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p32                       0x00000008UL                                         /**< Mode vreg_1p32 for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p34                       0x00000009UL                                         /**< Mode vreg_1p34 for RAC_SYTRIM1              */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_DEFAULT                          (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_DEFAULT << 8)     /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p08                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p08 << 8)   /**< Shifted mode vreg_1p08 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p11                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p11 << 8)   /**< Shifted mode vreg_1p11 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p15                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p15 << 8)   /**< Shifted mode vreg_1p15 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p18                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p18 << 8)   /**< Shifted mode vreg_1p18 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p21                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p21 << 8)   /**< Shifted mode vreg_1p21 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p24                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p24 << 8)   /**< Shifted mode vreg_1p24 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p27                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p27 << 8)   /**< Shifted mode vreg_1p27 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p29                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p29 << 8)   /**< Shifted mode vreg_1p29 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p32                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p32 << 8)   /**< Shifted mode vreg_1p32 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p34                        (_RAC_SYTRIM1_SYLODIVLDOTRIMNDIOTX_vreg_1p34 << 8)   /**< Shifted mode vreg_1p34 for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYLODIVSELOUTINVADC                                   (0x1UL << 14)                                        /**< SYLODIVSELOUTINVADC                         */
#define _RAC_SYTRIM1_SYLODIVSELOUTINVADC_SHIFT                            14                                                   /**< Shift value for RAC_SYLODIVSELOUTINVADC     */
#define _RAC_SYTRIM1_SYLODIVSELOUTINVADC_MASK                             0x4000UL                                             /**< Bit mask for RAC_SYLODIVSELOUTINVADC        */
#define _RAC_SYTRIM1_SYLODIVSELOUTINVADC_DEFAULT                          0x00000000UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define _RAC_SYTRIM1_SYLODIVSELOUTINVADC_disable                          0x00000000UL                                         /**< Mode disable for RAC_SYTRIM1                */
#define _RAC_SYTRIM1_SYLODIVSELOUTINVADC_enable                           0x00000001UL                                         /**< Mode enable for RAC_SYTRIM1                 */
#define RAC_SYTRIM1_SYLODIVSELOUTINVADC_DEFAULT                           (_RAC_SYTRIM1_SYLODIVSELOUTINVADC_DEFAULT << 14)     /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define RAC_SYTRIM1_SYLODIVSELOUTINVADC_disable                           (_RAC_SYTRIM1_SYLODIVSELOUTINVADC_disable << 14)     /**< Shifted mode disable for RAC_SYTRIM1        */
#define RAC_SYTRIM1_SYLODIVSELOUTINVADC_enable                            (_RAC_SYTRIM1_SYLODIVSELOUTINVADC_enable << 14)      /**< Shifted mode enable for RAC_SYTRIM1         */
#define _RAC_SYTRIM1_SYLODIVTLOTRIMDELAYOFDM_SHIFT                        15                                                   /**< Shift value for RAC_SYLODIVTLOTRIMDELAYOFDM */
#define _RAC_SYTRIM1_SYLODIVTLOTRIMDELAYOFDM_MASK                         0x38000UL                                            /**< Bit mask for RAC_SYLODIVTLOTRIMDELAYOFDM    */
#define _RAC_SYTRIM1_SYLODIVTLOTRIMDELAYOFDM_DEFAULT                      0x00000000UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define RAC_SYTRIM1_SYLODIVTLOTRIMDELAYOFDM_DEFAULT                       (_RAC_SYTRIM1_SYLODIVTLOTRIMDELAYOFDM_DEFAULT << 15) /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define _RAC_SYTRIM1_SYLODIVTLOTRIMDELAY_SHIFT                            18                                                   /**< Shift value for RAC_SYLODIVTLOTRIMDELAY     */
#define _RAC_SYTRIM1_SYLODIVTLOTRIMDELAY_MASK                             0x1C0000UL                                           /**< Bit mask for RAC_SYLODIVTLOTRIMDELAY        */
#define _RAC_SYTRIM1_SYLODIVTLOTRIMDELAY_DEFAULT                          0x00000000UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define RAC_SYTRIM1_SYLODIVTLOTRIMDELAY_DEFAULT                           (_RAC_SYTRIM1_SYLODIVTLOTRIMDELAY_DEFAULT << 18)     /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_SHIFT                           21                                                   /**< Shift value for RAC_SYMMDREPLICA1CURRADJ    */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_MASK                            0xE00000UL                                           /**< Bit mask for RAC_SYMMDREPLICA1CURRADJ       */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_DEFAULT                         0x00000007UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_8ua                        0x00000000UL                                         /**< Mode load_8ua for RAC_SYTRIM1               */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_16u                        0x00000001UL                                         /**< Mode load_16u for RAC_SYTRIM1               */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_20ua                       0x00000002UL                                         /**< Mode load_20ua for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_28ua                       0x00000003UL                                         /**< Mode load_28ua for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_24ua                       0x00000004UL                                         /**< Mode load_24ua for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_32ua                       0x00000005UL                                         /**< Mode load_32ua for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_36ua                       0x00000006UL                                         /**< Mode load_36ua for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_44ua                       0x00000007UL                                         /**< Mode load_44ua for RAC_SYTRIM1              */
#define RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_DEFAULT                          (_RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_DEFAULT << 21)    /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_8ua                         (_RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_8ua << 21)   /**< Shifted mode load_8ua for RAC_SYTRIM1       */
#define RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_16u                         (_RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_16u << 21)   /**< Shifted mode load_16u for RAC_SYTRIM1       */
#define RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_20ua                        (_RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_20ua << 21)  /**< Shifted mode load_20ua for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_28ua                        (_RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_28ua << 21)  /**< Shifted mode load_28ua for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_24ua                        (_RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_24ua << 21)  /**< Shifted mode load_24ua for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_32ua                        (_RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_32ua << 21)  /**< Shifted mode load_32ua for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_36ua                        (_RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_36ua << 21)  /**< Shifted mode load_36ua for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_44ua                        (_RAC_SYTRIM1_SYMMDREPLICA1CURRADJ_load_44ua << 21)  /**< Shifted mode load_44ua for RAC_SYTRIM1      */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_SHIFT                           24                                                   /**< Shift value for RAC_SYMMDREPLICA2CURRADJ    */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_MASK                            0x7000000UL                                          /**< Bit mask for RAC_SYMMDREPLICA2CURRADJ       */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_DEFAULT                         0x00000007UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_32u                        0x00000000UL                                         /**< Mode load_32u for RAC_SYTRIM1               */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_64u                        0x00000001UL                                         /**< Mode load_64u for RAC_SYTRIM1               */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_96u                        0x00000002UL                                         /**< Mode load_96u for RAC_SYTRIM1               */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_128u                       0x00000003UL                                         /**< Mode load_128u for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_160u                       0x00000004UL                                         /**< Mode load_160u for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_192u                       0x00000005UL                                         /**< Mode load_192u for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_224u                       0x00000006UL                                         /**< Mode load_224u for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_256u                       0x00000007UL                                         /**< Mode load_256u for RAC_SYTRIM1              */
#define RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_DEFAULT                          (_RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_DEFAULT << 24)    /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_32u                         (_RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_32u << 24)   /**< Shifted mode load_32u for RAC_SYTRIM1       */
#define RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_64u                         (_RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_64u << 24)   /**< Shifted mode load_64u for RAC_SYTRIM1       */
#define RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_96u                         (_RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_96u << 24)   /**< Shifted mode load_96u for RAC_SYTRIM1       */
#define RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_128u                        (_RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_128u << 24)  /**< Shifted mode load_128u for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_160u                        (_RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_160u << 24)  /**< Shifted mode load_160u for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_192u                        (_RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_192u << 24)  /**< Shifted mode load_192u for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_224u                        (_RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_224u << 24)  /**< Shifted mode load_224u for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_256u                        (_RAC_SYTRIM1_SYMMDREPLICA2CURRADJ_load_256u << 24)  /**< Shifted mode load_256u for RAC_SYTRIM1      */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_SHIFT                            27                                                   /**< Shift value for RAC_SYTRIMMMDREGAMPBIAS     */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_MASK                             0x38000000UL                                         /**< Bit mask for RAC_SYTRIMMMDREGAMPBIAS        */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_DEFAULT                          0x00000003UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_14uA                        0x00000000UL                                         /**< Mode bias_14uA for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_20uA                        0x00000001UL                                         /**< Mode bias_20uA for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_26uA                        0x00000002UL                                         /**< Mode bias_26uA for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_32uA                        0x00000003UL                                         /**< Mode bias_32uA for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_38uA                        0x00000004UL                                         /**< Mode bias_38uA for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_44uA                        0x00000005UL                                         /**< Mode bias_44uA for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_50uA                        0x00000006UL                                         /**< Mode bias_50uA for RAC_SYTRIM1              */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_56uA                        0x00000007UL                                         /**< Mode bias_56uA for RAC_SYTRIM1              */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_DEFAULT                           (_RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_DEFAULT << 27)     /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_14uA                         (_RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_14uA << 27)   /**< Shifted mode bias_14uA for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_20uA                         (_RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_20uA << 27)   /**< Shifted mode bias_20uA for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_26uA                         (_RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_26uA << 27)   /**< Shifted mode bias_26uA for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_32uA                         (_RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_32uA << 27)   /**< Shifted mode bias_32uA for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_38uA                         (_RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_38uA << 27)   /**< Shifted mode bias_38uA for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_44uA                         (_RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_44uA << 27)   /**< Shifted mode bias_44uA for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_50uA                         (_RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_50uA << 27)   /**< Shifted mode bias_50uA for RAC_SYTRIM1      */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_56uA                         (_RAC_SYTRIM1_SYTRIMMMDREGAMPBIAS_bias_56uA << 27)   /**< Shifted mode bias_56uA for RAC_SYTRIM1      */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBW_SHIFT                              30                                                   /**< Shift value for RAC_SYTRIMMMDREGAMPBW       */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBW_MASK                               0xC0000000UL                                         /**< Bit mask for RAC_SYTRIMMMDREGAMPBW          */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBW_DEFAULT                            0x00000000UL                                         /**< Mode DEFAULT for RAC_SYTRIM1                */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_000f                             0x00000000UL                                         /**< Mode C_000f for RAC_SYTRIM1                 */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_300f                             0x00000001UL                                         /**< Mode C_300f for RAC_SYTRIM1                 */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_600f                             0x00000002UL                                         /**< Mode C_600f for RAC_SYTRIM1                 */
#define _RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_900f                             0x00000003UL                                         /**< Mode C_900f for RAC_SYTRIM1                 */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBW_DEFAULT                             (_RAC_SYTRIM1_SYTRIMMMDREGAMPBW_DEFAULT << 30)       /**< Shifted mode DEFAULT for RAC_SYTRIM1        */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_000f                              (_RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_000f << 30)        /**< Shifted mode C_000f for RAC_SYTRIM1         */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_300f                              (_RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_300f << 30)        /**< Shifted mode C_300f for RAC_SYTRIM1         */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_600f                              (_RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_600f << 30)        /**< Shifted mode C_600f for RAC_SYTRIM1         */
#define RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_900f                              (_RAC_SYTRIM1_SYTRIMMMDREGAMPBW_C_900f << 30)        /**< Shifted mode C_900f for RAC_SYTRIM1         */

/* Bit fields for RAC SYCAL */
#define _RAC_SYCAL_RESETVALUE                                             0x01008100UL                                                /**< Default value for RAC_SYCAL                 */
#define _RAC_SYCAL_MASK                                                   0x03018700UL                                                /**< Mask for RAC_SYCAL                          */
#define RAC_SYCAL_SYVCOMODEPKD                                            (0x1UL << 8)                                                /**< SYVCOMODEPKD                                */
#define _RAC_SYCAL_SYVCOMODEPKD_SHIFT                                     8                                                           /**< Shift value for RAC_SYVCOMODEPKD            */
#define _RAC_SYCAL_SYVCOMODEPKD_MASK                                      0x100UL                                                     /**< Bit mask for RAC_SYVCOMODEPKD               */
#define _RAC_SYCAL_SYVCOMODEPKD_DEFAULT                                   0x00000001UL                                                /**< Mode DEFAULT for RAC_SYCAL                  */
#define _RAC_SYCAL_SYVCOMODEPKD_t_openloop_0                              0x00000000UL                                                /**< Mode t_openloop_0 for RAC_SYCAL             */
#define _RAC_SYCAL_SYVCOMODEPKD_t_pkdetect_1                              0x00000001UL                                                /**< Mode t_pkdetect_1 for RAC_SYCAL             */
#define RAC_SYCAL_SYVCOMODEPKD_DEFAULT                                    (_RAC_SYCAL_SYVCOMODEPKD_DEFAULT << 8)                      /**< Shifted mode DEFAULT for RAC_SYCAL          */
#define RAC_SYCAL_SYVCOMODEPKD_t_openloop_0                               (_RAC_SYCAL_SYVCOMODEPKD_t_openloop_0 << 8)                 /**< Shifted mode t_openloop_0 for RAC_SYCAL     */
#define RAC_SYCAL_SYVCOMODEPKD_t_pkdetect_1                               (_RAC_SYCAL_SYVCOMODEPKD_t_pkdetect_1 << 8)                 /**< Shifted mode t_pkdetect_1 for RAC_SYCAL     */
#define RAC_SYCAL_SYVCOMORECURRENT                                        (0x1UL << 9)                                                /**< SYVCOMORECURRENT                            */
#define _RAC_SYCAL_SYVCOMORECURRENT_SHIFT                                 9                                                           /**< Shift value for RAC_SYVCOMORECURRENT        */
#define _RAC_SYCAL_SYVCOMORECURRENT_MASK                                  0x200UL                                                     /**< Bit mask for RAC_SYVCOMORECURRENT           */
#define _RAC_SYCAL_SYVCOMORECURRENT_DEFAULT                               0x00000000UL                                                /**< Mode DEFAULT for RAC_SYCAL                  */
#define _RAC_SYCAL_SYVCOMORECURRENT_more_current_0                        0x00000000UL                                                /**< Mode more_current_0 for RAC_SYCAL           */
#define _RAC_SYCAL_SYVCOMORECURRENT_more_current_1                        0x00000001UL                                                /**< Mode more_current_1 for RAC_SYCAL           */
#define RAC_SYCAL_SYVCOMORECURRENT_DEFAULT                                (_RAC_SYCAL_SYVCOMORECURRENT_DEFAULT << 9)                  /**< Shifted mode DEFAULT for RAC_SYCAL          */
#define RAC_SYCAL_SYVCOMORECURRENT_more_current_0                         (_RAC_SYCAL_SYVCOMORECURRENT_more_current_0 << 9)           /**< Shifted mode more_current_0 for RAC_SYCAL   */
#define RAC_SYCAL_SYVCOMORECURRENT_more_current_1                         (_RAC_SYCAL_SYVCOMORECURRENT_more_current_1 << 9)           /**< Shifted mode more_current_1 for RAC_SYCAL   */
#define RAC_SYCAL_SYVCOSLOWNOISEFILTER                                    (0x1UL << 10)                                               /**< SYVCOSLOWNOISEFILTER                        */
#define _RAC_SYCAL_SYVCOSLOWNOISEFILTER_SHIFT                             10                                                          /**< Shift value for RAC_SYVCOSLOWNOISEFILTER    */
#define _RAC_SYCAL_SYVCOSLOWNOISEFILTER_MASK                              0x400UL                                                     /**< Bit mask for RAC_SYVCOSLOWNOISEFILTER       */
#define _RAC_SYCAL_SYVCOSLOWNOISEFILTER_DEFAULT                           0x00000000UL                                                /**< Mode DEFAULT for RAC_SYCAL                  */
#define _RAC_SYCAL_SYVCOSLOWNOISEFILTER_slow_noise_filter_0               0x00000000UL                                                /**< Mode slow_noise_filter_0 for RAC_SYCAL      */
#define _RAC_SYCAL_SYVCOSLOWNOISEFILTER_slow_noise_filter_1               0x00000001UL                                                /**< Mode slow_noise_filter_1 for RAC_SYCAL      */
#define RAC_SYCAL_SYVCOSLOWNOISEFILTER_DEFAULT                            (_RAC_SYCAL_SYVCOSLOWNOISEFILTER_DEFAULT << 10)             /**< Shifted mode DEFAULT for RAC_SYCAL          */
#define RAC_SYCAL_SYVCOSLOWNOISEFILTER_slow_noise_filter_0                (_RAC_SYCAL_SYVCOSLOWNOISEFILTER_slow_noise_filter_0 << 10) /**< Shifted mode slow_noise_filter_0 for RAC_SYCAL*/
#define RAC_SYCAL_SYVCOSLOWNOISEFILTER_slow_noise_filter_1                (_RAC_SYCAL_SYVCOSLOWNOISEFILTER_slow_noise_filter_1 << 10) /**< Shifted mode slow_noise_filter_1 for RAC_SYCAL*/
#define _RAC_SYCAL_SYVCOVCAPVCM_SHIFT                                     15                                                          /**< Shift value for RAC_SYVCOVCAPVCM            */
#define _RAC_SYCAL_SYVCOVCAPVCM_MASK                                      0x18000UL                                                   /**< Bit mask for RAC_SYVCOVCAPVCM               */
#define _RAC_SYCAL_SYVCOVCAPVCM_DEFAULT                                   0x00000001UL                                                /**< Mode DEFAULT for RAC_SYCAL                  */
#define RAC_SYCAL_SYVCOVCAPVCM_DEFAULT                                    (_RAC_SYCAL_SYVCOVCAPVCM_DEFAULT << 15)                     /**< Shifted mode DEFAULT for RAC_SYCAL          */
#define _RAC_SYCAL_SYHILOADCHPREG_SHIFT                                   24                                                          /**< Shift value for RAC_SYHILOADCHPREG          */
#define _RAC_SYCAL_SYHILOADCHPREG_MASK                                    0x3000000UL                                                 /**< Bit mask for RAC_SYHILOADCHPREG             */
#define _RAC_SYCAL_SYHILOADCHPREG_DEFAULT                                 0x00000001UL                                                /**< Mode DEFAULT for RAC_SYCAL                  */
#define _RAC_SYCAL_SYHILOADCHPREG_i_350uA                                 0x00000000UL                                                /**< Mode i_350uA for RAC_SYCAL                  */
#define _RAC_SYCAL_SYHILOADCHPREG_i_500uA                                 0x00000001UL                                                /**< Mode i_500uA for RAC_SYCAL                  */
#define _RAC_SYCAL_SYHILOADCHPREG_i_550uA                                 0x00000002UL                                                /**< Mode i_550uA for RAC_SYCAL                  */
#define _RAC_SYCAL_SYHILOADCHPREG_i_700uA                                 0x00000003UL                                                /**< Mode i_700uA for RAC_SYCAL                  */
#define RAC_SYCAL_SYHILOADCHPREG_DEFAULT                                  (_RAC_SYCAL_SYHILOADCHPREG_DEFAULT << 24)                   /**< Shifted mode DEFAULT for RAC_SYCAL          */
#define RAC_SYCAL_SYHILOADCHPREG_i_350uA                                  (_RAC_SYCAL_SYHILOADCHPREG_i_350uA << 24)                   /**< Shifted mode i_350uA for RAC_SYCAL          */
#define RAC_SYCAL_SYHILOADCHPREG_i_500uA                                  (_RAC_SYCAL_SYHILOADCHPREG_i_500uA << 24)                   /**< Shifted mode i_500uA for RAC_SYCAL          */
#define RAC_SYCAL_SYHILOADCHPREG_i_550uA                                  (_RAC_SYCAL_SYHILOADCHPREG_i_550uA << 24)                   /**< Shifted mode i_550uA for RAC_SYCAL          */
#define RAC_SYCAL_SYHILOADCHPREG_i_700uA                                  (_RAC_SYCAL_SYHILOADCHPREG_i_700uA << 24)                   /**< Shifted mode i_700uA for RAC_SYCAL          */

/* Bit fields for RAC SYEN */
#define _RAC_SYEN_RESETVALUE                                              0x00000000UL                                    /**< Default value for RAC_SYEN                  */
#define _RAC_SYEN_MASK                                                    0x000067FFUL                                    /**< Mask for RAC_SYEN                           */
#define RAC_SYEN_SYCHPEN                                                  (0x1UL << 0)                                    /**< SYCHPEN                                     */
#define _RAC_SYEN_SYCHPEN_SHIFT                                           0                                               /**< Shift value for RAC_SYCHPEN                 */
#define _RAC_SYEN_SYCHPEN_MASK                                            0x1UL                                           /**< Bit mask for RAC_SYCHPEN                    */
#define _RAC_SYEN_SYCHPEN_DEFAULT                                         0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYCHPEN_disable                                         0x00000000UL                                    /**< Mode disable for RAC_SYEN                   */
#define _RAC_SYEN_SYCHPEN_enable                                          0x00000001UL                                    /**< Mode enable for RAC_SYEN                    */
#define RAC_SYEN_SYCHPEN_DEFAULT                                          (_RAC_SYEN_SYCHPEN_DEFAULT << 0)                /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYCHPEN_disable                                          (_RAC_SYEN_SYCHPEN_disable << 0)                /**< Shifted mode disable for RAC_SYEN           */
#define RAC_SYEN_SYCHPEN_enable                                           (_RAC_SYEN_SYCHPEN_enable << 0)                 /**< Shifted mode enable for RAC_SYEN            */
#define RAC_SYEN_SYCHPLPENRX                                              (0x1UL << 1)                                    /**< SYCHPLPENRX                                 */
#define _RAC_SYEN_SYCHPLPENRX_SHIFT                                       1                                               /**< Shift value for RAC_SYCHPLPENRX             */
#define _RAC_SYEN_SYCHPLPENRX_MASK                                        0x2UL                                           /**< Bit mask for RAC_SYCHPLPENRX                */
#define _RAC_SYEN_SYCHPLPENRX_DEFAULT                                     0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYCHPLPENRX_disable                                     0x00000000UL                                    /**< Mode disable for RAC_SYEN                   */
#define _RAC_SYEN_SYCHPLPENRX_enable                                      0x00000001UL                                    /**< Mode enable for RAC_SYEN                    */
#define RAC_SYEN_SYCHPLPENRX_DEFAULT                                      (_RAC_SYEN_SYCHPLPENRX_DEFAULT << 1)            /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYCHPLPENRX_disable                                      (_RAC_SYEN_SYCHPLPENRX_disable << 1)            /**< Shifted mode disable for RAC_SYEN           */
#define RAC_SYEN_SYCHPLPENRX_enable                                       (_RAC_SYEN_SYCHPLPENRX_enable << 1)             /**< Shifted mode enable for RAC_SYEN            */
#define RAC_SYEN_SYCHPLPENTX                                              (0x1UL << 2)                                    /**< SYCHPLPENTX                                 */
#define _RAC_SYEN_SYCHPLPENTX_SHIFT                                       2                                               /**< Shift value for RAC_SYCHPLPENTX             */
#define _RAC_SYEN_SYCHPLPENTX_MASK                                        0x4UL                                           /**< Bit mask for RAC_SYCHPLPENTX                */
#define _RAC_SYEN_SYCHPLPENTX_DEFAULT                                     0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYCHPLPENTX_disable                                     0x00000000UL                                    /**< Mode disable for RAC_SYEN                   */
#define _RAC_SYEN_SYCHPLPENTX_enable                                      0x00000001UL                                    /**< Mode enable for RAC_SYEN                    */
#define RAC_SYEN_SYCHPLPENTX_DEFAULT                                      (_RAC_SYEN_SYCHPLPENTX_DEFAULT << 2)            /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYCHPLPENTX_disable                                      (_RAC_SYEN_SYCHPLPENTX_disable << 2)            /**< Shifted mode disable for RAC_SYEN           */
#define RAC_SYEN_SYCHPLPENTX_enable                                       (_RAC_SYEN_SYCHPLPENTX_enable << 2)             /**< Shifted mode enable for RAC_SYEN            */
#define RAC_SYEN_SYENCHPREG                                               (0x1UL << 3)                                    /**< SYENCHPREG                                  */
#define _RAC_SYEN_SYENCHPREG_SHIFT                                        3                                               /**< Shift value for RAC_SYENCHPREG              */
#define _RAC_SYEN_SYENCHPREG_MASK                                         0x8UL                                           /**< Bit mask for RAC_SYENCHPREG                 */
#define _RAC_SYEN_SYENCHPREG_DEFAULT                                      0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYENCHPREG_Disable                                      0x00000000UL                                    /**< Mode Disable for RAC_SYEN                   */
#define _RAC_SYEN_SYENCHPREG_Enable                                       0x00000001UL                                    /**< Mode Enable for RAC_SYEN                    */
#define RAC_SYEN_SYENCHPREG_DEFAULT                                       (_RAC_SYEN_SYENCHPREG_DEFAULT << 3)             /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYENCHPREG_Disable                                       (_RAC_SYEN_SYENCHPREG_Disable << 3)             /**< Shifted mode Disable for RAC_SYEN           */
#define RAC_SYEN_SYENCHPREG_Enable                                        (_RAC_SYEN_SYENCHPREG_Enable << 3)              /**< Shifted mode Enable for RAC_SYEN            */
#define RAC_SYEN_SYENCHPREPLICA                                           (0x1UL << 4)                                    /**< SYENCHPREPLICA                              */
#define _RAC_SYEN_SYENCHPREPLICA_SHIFT                                    4                                               /**< Shift value for RAC_SYENCHPREPLICA          */
#define _RAC_SYEN_SYENCHPREPLICA_MASK                                     0x10UL                                          /**< Bit mask for RAC_SYENCHPREPLICA             */
#define _RAC_SYEN_SYENCHPREPLICA_DEFAULT                                  0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYENCHPREPLICA_disable                                  0x00000000UL                                    /**< Mode disable for RAC_SYEN                   */
#define _RAC_SYEN_SYENCHPREPLICA_enable                                   0x00000001UL                                    /**< Mode enable for RAC_SYEN                    */
#define RAC_SYEN_SYENCHPREPLICA_DEFAULT                                   (_RAC_SYEN_SYENCHPREPLICA_DEFAULT << 4)         /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYENCHPREPLICA_disable                                   (_RAC_SYEN_SYENCHPREPLICA_disable << 4)         /**< Shifted mode disable for RAC_SYEN           */
#define RAC_SYEN_SYENCHPREPLICA_enable                                    (_RAC_SYEN_SYENCHPREPLICA_enable << 4)          /**< Shifted mode enable for RAC_SYEN            */
#define RAC_SYEN_SYENMMDREG                                               (0x1UL << 5)                                    /**< SYENMMDREG                                  */
#define _RAC_SYEN_SYENMMDREG_SHIFT                                        5                                               /**< Shift value for RAC_SYENMMDREG              */
#define _RAC_SYEN_SYENMMDREG_MASK                                         0x20UL                                          /**< Bit mask for RAC_SYENMMDREG                 */
#define _RAC_SYEN_SYENMMDREG_DEFAULT                                      0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYENMMDREG_Disable                                      0x00000000UL                                    /**< Mode Disable for RAC_SYEN                   */
#define _RAC_SYEN_SYENMMDREG_Enable                                       0x00000001UL                                    /**< Mode Enable for RAC_SYEN                    */
#define RAC_SYEN_SYENMMDREG_DEFAULT                                       (_RAC_SYEN_SYENMMDREG_DEFAULT << 5)             /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYENMMDREG_Disable                                       (_RAC_SYEN_SYENMMDREG_Disable << 5)             /**< Shifted mode Disable for RAC_SYEN           */
#define RAC_SYEN_SYENMMDREG_Enable                                        (_RAC_SYEN_SYENMMDREG_Enable << 5)              /**< Shifted mode Enable for RAC_SYEN            */
#define RAC_SYEN_SYENMMDREPLICA1                                          (0x1UL << 6)                                    /**< SYENMMDREPLICA1                             */
#define _RAC_SYEN_SYENMMDREPLICA1_SHIFT                                   6                                               /**< Shift value for RAC_SYENMMDREPLICA1         */
#define _RAC_SYEN_SYENMMDREPLICA1_MASK                                    0x40UL                                          /**< Bit mask for RAC_SYENMMDREPLICA1            */
#define _RAC_SYEN_SYENMMDREPLICA1_DEFAULT                                 0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYENMMDREPLICA1_disable                                 0x00000000UL                                    /**< Mode disable for RAC_SYEN                   */
#define _RAC_SYEN_SYENMMDREPLICA1_enable                                  0x00000001UL                                    /**< Mode enable for RAC_SYEN                    */
#define RAC_SYEN_SYENMMDREPLICA1_DEFAULT                                  (_RAC_SYEN_SYENMMDREPLICA1_DEFAULT << 6)        /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYENMMDREPLICA1_disable                                  (_RAC_SYEN_SYENMMDREPLICA1_disable << 6)        /**< Shifted mode disable for RAC_SYEN           */
#define RAC_SYEN_SYENMMDREPLICA1_enable                                   (_RAC_SYEN_SYENMMDREPLICA1_enable << 6)         /**< Shifted mode enable for RAC_SYEN            */
#define RAC_SYEN_SYENMMDREPLICA2                                          (0x1UL << 7)                                    /**< SYENMMDREPLICA2                             */
#define _RAC_SYEN_SYENMMDREPLICA2_SHIFT                                   7                                               /**< Shift value for RAC_SYENMMDREPLICA2         */
#define _RAC_SYEN_SYENMMDREPLICA2_MASK                                    0x80UL                                          /**< Bit mask for RAC_SYENMMDREPLICA2            */
#define _RAC_SYEN_SYENMMDREPLICA2_DEFAULT                                 0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYENMMDREPLICA2_Disable                                 0x00000000UL                                    /**< Mode Disable for RAC_SYEN                   */
#define _RAC_SYEN_SYENMMDREPLICA2_Enable                                  0x00000001UL                                    /**< Mode Enable for RAC_SYEN                    */
#define RAC_SYEN_SYENMMDREPLICA2_DEFAULT                                  (_RAC_SYEN_SYENMMDREPLICA2_DEFAULT << 7)        /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYENMMDREPLICA2_Disable                                  (_RAC_SYEN_SYENMMDREPLICA2_Disable << 7)        /**< Shifted mode Disable for RAC_SYEN           */
#define RAC_SYEN_SYENMMDREPLICA2_Enable                                   (_RAC_SYEN_SYENMMDREPLICA2_Enable << 7)         /**< Shifted mode Enable for RAC_SYEN            */
#define RAC_SYEN_SYENVCOBIAS                                              (0x1UL << 8)                                    /**< SYENVCOBIAS                                 */
#define _RAC_SYEN_SYENVCOBIAS_SHIFT                                       8                                               /**< Shift value for RAC_SYENVCOBIAS             */
#define _RAC_SYEN_SYENVCOBIAS_MASK                                        0x100UL                                         /**< Bit mask for RAC_SYENVCOBIAS                */
#define _RAC_SYEN_SYENVCOBIAS_DEFAULT                                     0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYENVCOBIAS_en_vco_bias_0                               0x00000000UL                                    /**< Mode en_vco_bias_0 for RAC_SYEN             */
#define _RAC_SYEN_SYENVCOBIAS_en_vco_bias_1                               0x00000001UL                                    /**< Mode en_vco_bias_1 for RAC_SYEN             */
#define RAC_SYEN_SYENVCOBIAS_DEFAULT                                      (_RAC_SYEN_SYENVCOBIAS_DEFAULT << 8)            /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYENVCOBIAS_en_vco_bias_0                                (_RAC_SYEN_SYENVCOBIAS_en_vco_bias_0 << 8)      /**< Shifted mode en_vco_bias_0 for RAC_SYEN     */
#define RAC_SYEN_SYENVCOBIAS_en_vco_bias_1                                (_RAC_SYEN_SYENVCOBIAS_en_vco_bias_1 << 8)      /**< Shifted mode en_vco_bias_1 for RAC_SYEN     */
#define RAC_SYEN_SYENVCOPFET                                              (0x1UL << 9)                                    /**< SYENVCOPFET                                 */
#define _RAC_SYEN_SYENVCOPFET_SHIFT                                       9                                               /**< Shift value for RAC_SYENVCOPFET             */
#define _RAC_SYEN_SYENVCOPFET_MASK                                        0x200UL                                         /**< Bit mask for RAC_SYENVCOPFET                */
#define _RAC_SYEN_SYENVCOPFET_DEFAULT                                     0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYENVCOPFET_en_vco_pfet_0                               0x00000000UL                                    /**< Mode en_vco_pfet_0 for RAC_SYEN             */
#define _RAC_SYEN_SYENVCOPFET_en_vco_pfet_1                               0x00000001UL                                    /**< Mode en_vco_pfet_1 for RAC_SYEN             */
#define RAC_SYEN_SYENVCOPFET_DEFAULT                                      (_RAC_SYEN_SYENVCOPFET_DEFAULT << 9)            /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYENVCOPFET_en_vco_pfet_0                                (_RAC_SYEN_SYENVCOPFET_en_vco_pfet_0 << 9)      /**< Shifted mode en_vco_pfet_0 for RAC_SYEN     */
#define RAC_SYEN_SYENVCOPFET_en_vco_pfet_1                                (_RAC_SYEN_SYENVCOPFET_en_vco_pfet_1 << 9)      /**< Shifted mode en_vco_pfet_1 for RAC_SYEN     */
#define RAC_SYEN_SYENVCOREG                                               (0x1UL << 10)                                   /**< SYENVCOREG                                  */
#define _RAC_SYEN_SYENVCOREG_SHIFT                                        10                                              /**< Shift value for RAC_SYENVCOREG              */
#define _RAC_SYEN_SYENVCOREG_MASK                                         0x400UL                                         /**< Bit mask for RAC_SYENVCOREG                 */
#define _RAC_SYEN_SYENVCOREG_DEFAULT                                      0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYENVCOREG_en_vco_reg_0                                 0x00000000UL                                    /**< Mode en_vco_reg_0 for RAC_SYEN              */
#define _RAC_SYEN_SYENVCOREG_en_vco_reg_1                                 0x00000001UL                                    /**< Mode en_vco_reg_1 for RAC_SYEN              */
#define RAC_SYEN_SYENVCOREG_DEFAULT                                       (_RAC_SYEN_SYENVCOREG_DEFAULT << 10)            /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYENVCOREG_en_vco_reg_0                                  (_RAC_SYEN_SYENVCOREG_en_vco_reg_0 << 10)       /**< Shifted mode en_vco_reg_0 for RAC_SYEN      */
#define RAC_SYEN_SYENVCOREG_en_vco_reg_1                                  (_RAC_SYEN_SYENVCOREG_en_vco_reg_1 << 10)       /**< Shifted mode en_vco_reg_1 for RAC_SYEN      */
#define RAC_SYEN_SYSTARTCHPREG                                            (0x1UL << 13)                                   /**< SYSTARTCHPREG                               */
#define _RAC_SYEN_SYSTARTCHPREG_SHIFT                                     13                                              /**< Shift value for RAC_SYSTARTCHPREG           */
#define _RAC_SYEN_SYSTARTCHPREG_MASK                                      0x2000UL                                        /**< Bit mask for RAC_SYSTARTCHPREG              */
#define _RAC_SYEN_SYSTARTCHPREG_DEFAULT                                   0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYSTARTCHPREG_no_fast_startup                           0x00000000UL                                    /**< Mode no_fast_startup for RAC_SYEN           */
#define _RAC_SYEN_SYSTARTCHPREG_fast_startup                              0x00000001UL                                    /**< Mode fast_startup for RAC_SYEN              */
#define RAC_SYEN_SYSTARTCHPREG_DEFAULT                                    (_RAC_SYEN_SYSTARTCHPREG_DEFAULT << 13)         /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYSTARTCHPREG_no_fast_startup                            (_RAC_SYEN_SYSTARTCHPREG_no_fast_startup << 13) /**< Shifted mode no_fast_startup for RAC_SYEN   */
#define RAC_SYEN_SYSTARTCHPREG_fast_startup                               (_RAC_SYEN_SYSTARTCHPREG_fast_startup << 13)    /**< Shifted mode fast_startup for RAC_SYEN      */
#define RAC_SYEN_SYSTARTMMDREG                                            (0x1UL << 14)                                   /**< SYSTARTMMDREG                               */
#define _RAC_SYEN_SYSTARTMMDREG_SHIFT                                     14                                              /**< Shift value for RAC_SYSTARTMMDREG           */
#define _RAC_SYEN_SYSTARTMMDREG_MASK                                      0x4000UL                                        /**< Bit mask for RAC_SYSTARTMMDREG              */
#define _RAC_SYEN_SYSTARTMMDREG_DEFAULT                                   0x00000000UL                                    /**< Mode DEFAULT for RAC_SYEN                   */
#define _RAC_SYEN_SYSTARTMMDREG_no_fast_startup                           0x00000000UL                                    /**< Mode no_fast_startup for RAC_SYEN           */
#define _RAC_SYEN_SYSTARTMMDREG_fast_startup                              0x00000001UL                                    /**< Mode fast_startup for RAC_SYEN              */
#define RAC_SYEN_SYSTARTMMDREG_DEFAULT                                    (_RAC_SYEN_SYSTARTMMDREG_DEFAULT << 14)         /**< Shifted mode DEFAULT for RAC_SYEN           */
#define RAC_SYEN_SYSTARTMMDREG_no_fast_startup                            (_RAC_SYEN_SYSTARTMMDREG_no_fast_startup << 14) /**< Shifted mode no_fast_startup for RAC_SYEN   */
#define RAC_SYEN_SYSTARTMMDREG_fast_startup                               (_RAC_SYEN_SYSTARTMMDREG_fast_startup << 14)    /**< Shifted mode fast_startup for RAC_SYEN      */

/* Bit fields for RAC SYLOEN */
#define _RAC_SYLOEN_RESETVALUE                                            0x00000000UL                                       /**< Default value for RAC_SYLOEN                */
#define _RAC_SYLOEN_MASK                                                  0x00000B9EUL                                       /**< Mask for RAC_SYLOEN                         */
#define RAC_SYLOEN_SYLODIVEN                                              (0x1UL << 1)                                       /**< SYLODIVEN                                   */
#define _RAC_SYLOEN_SYLODIVEN_SHIFT                                       1                                                  /**< Shift value for RAC_SYLODIVEN               */
#define _RAC_SYLOEN_SYLODIVEN_MASK                                        0x2UL                                              /**< Bit mask for RAC_SYLODIVEN                  */
#define _RAC_SYLOEN_SYLODIVEN_DEFAULT                                     0x00000000UL                                       /**< Mode DEFAULT for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVEN_disable                                     0x00000000UL                                       /**< Mode disable for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVEN_enable                                      0x00000001UL                                       /**< Mode enable for RAC_SYLOEN                  */
#define RAC_SYLOEN_SYLODIVEN_DEFAULT                                      (_RAC_SYLOEN_SYLODIVEN_DEFAULT << 1)               /**< Shifted mode DEFAULT for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVEN_disable                                      (_RAC_SYLOEN_SYLODIVEN_disable << 1)               /**< Shifted mode disable for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVEN_enable                                       (_RAC_SYLOEN_SYLODIVEN_enable << 1)                /**< Shifted mode enable for RAC_SYLOEN          */
#define RAC_SYLOEN_SYLODIVLDOBIASEN                                       (0x1UL << 2)                                       /**< SYLODIVLDOBIASEN                            */
#define _RAC_SYLOEN_SYLODIVLDOBIASEN_SHIFT                                2                                                  /**< Shift value for RAC_SYLODIVLDOBIASEN        */
#define _RAC_SYLOEN_SYLODIVLDOBIASEN_MASK                                 0x4UL                                              /**< Bit mask for RAC_SYLODIVLDOBIASEN           */
#define _RAC_SYLOEN_SYLODIVLDOBIASEN_DEFAULT                              0x00000000UL                                       /**< Mode DEFAULT for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVLDOBIASEN_disable                              0x00000000UL                                       /**< Mode disable for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVLDOBIASEN_enable                               0x00000001UL                                       /**< Mode enable for RAC_SYLOEN                  */
#define RAC_SYLOEN_SYLODIVLDOBIASEN_DEFAULT                               (_RAC_SYLOEN_SYLODIVLDOBIASEN_DEFAULT << 2)        /**< Shifted mode DEFAULT for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVLDOBIASEN_disable                               (_RAC_SYLOEN_SYLODIVLDOBIASEN_disable << 2)        /**< Shifted mode disable for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVLDOBIASEN_enable                                (_RAC_SYLOEN_SYLODIVLDOBIASEN_enable << 2)         /**< Shifted mode enable for RAC_SYLOEN          */
#define RAC_SYLOEN_SYLODIVLDOEN                                           (0x1UL << 3)                                       /**< SYLODIVLDOEN                                */
#define _RAC_SYLOEN_SYLODIVLDOEN_SHIFT                                    3                                                  /**< Shift value for RAC_SYLODIVLDOEN            */
#define _RAC_SYLOEN_SYLODIVLDOEN_MASK                                     0x8UL                                              /**< Bit mask for RAC_SYLODIVLDOEN               */
#define _RAC_SYLOEN_SYLODIVLDOEN_DEFAULT                                  0x00000000UL                                       /**< Mode DEFAULT for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVLDOEN_disable                                  0x00000000UL                                       /**< Mode disable for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVLDOEN_enable                                   0x00000001UL                                       /**< Mode enable for RAC_SYLOEN                  */
#define RAC_SYLOEN_SYLODIVLDOEN_DEFAULT                                   (_RAC_SYLOEN_SYLODIVLDOEN_DEFAULT << 3)            /**< Shifted mode DEFAULT for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVLDOEN_disable                                   (_RAC_SYLOEN_SYLODIVLDOEN_disable << 3)            /**< Shifted mode disable for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVLDOEN_enable                                    (_RAC_SYLOEN_SYLODIVLDOEN_enable << 3)             /**< Shifted mode enable for RAC_SYLOEN          */
#define RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN                                (0x1UL << 4)                                       /**< SYLODIVRLOSUBGRADCCLKEN                     */
#define _RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_SHIFT                         4                                                  /**< Shift value for RAC_SYLODIVRLOSUBGRADCCLKEN */
#define _RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_MASK                          0x10UL                                             /**< Bit mask for RAC_SYLODIVRLOSUBGRADCCLKEN    */
#define _RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_DEFAULT                       0x00000000UL                                       /**< Mode DEFAULT for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_disable                       0x00000000UL                                       /**< Mode disable for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_enable                        0x00000001UL                                       /**< Mode enable for RAC_SYLOEN                  */
#define RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_DEFAULT                        (_RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_DEFAULT << 4) /**< Shifted mode DEFAULT for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_disable                        (_RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_disable << 4) /**< Shifted mode disable for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_enable                         (_RAC_SYLOEN_SYLODIVRLOSUBGRADCCLKEN_enable << 4)  /**< Shifted mode enable for RAC_SYLOEN          */
#define RAC_SYLOEN_SYLODIVSMUXDIVEN                                       (0x1UL << 7)                                       /**< SYLODIVSMUXDIVEN                            */
#define _RAC_SYLOEN_SYLODIVSMUXDIVEN_SHIFT                                7                                                  /**< Shift value for RAC_SYLODIVSMUXDIVEN        */
#define _RAC_SYLOEN_SYLODIVSMUXDIVEN_MASK                                 0x80UL                                             /**< Bit mask for RAC_SYLODIVSMUXDIVEN           */
#define _RAC_SYLOEN_SYLODIVSMUXDIVEN_DEFAULT                              0x00000000UL                                       /**< Mode DEFAULT for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVSMUXDIVEN_disable                              0x00000000UL                                       /**< Mode disable for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVSMUXDIVEN_enable                               0x00000001UL                                       /**< Mode enable for RAC_SYLOEN                  */
#define RAC_SYLOEN_SYLODIVSMUXDIVEN_DEFAULT                               (_RAC_SYLOEN_SYLODIVSMUXDIVEN_DEFAULT << 7)        /**< Shifted mode DEFAULT for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVSMUXDIVEN_disable                               (_RAC_SYLOEN_SYLODIVSMUXDIVEN_disable << 7)        /**< Shifted mode disable for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVSMUXDIVEN_enable                                (_RAC_SYLOEN_SYLODIVSMUXDIVEN_enable << 7)         /**< Shifted mode enable for RAC_SYLOEN          */
#define RAC_SYLOEN_SYLODIVTLOSUBGAUXEN                                    (0x1UL << 8)                                       /**< SYLODIVTLOSUBGAUXEN                         */
#define _RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_SHIFT                             8                                                  /**< Shift value for RAC_SYLODIVTLOSUBGAUXEN     */
#define _RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_MASK                              0x100UL                                            /**< Bit mask for RAC_SYLODIVTLOSUBGAUXEN        */
#define _RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_DEFAULT                           0x00000000UL                                       /**< Mode DEFAULT for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_disable                           0x00000000UL                                       /**< Mode disable for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_enable                            0x00000001UL                                       /**< Mode enable for RAC_SYLOEN                  */
#define RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_DEFAULT                            (_RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_DEFAULT << 8)     /**< Shifted mode DEFAULT for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_disable                            (_RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_disable << 8)     /**< Shifted mode disable for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_enable                             (_RAC_SYLOEN_SYLODIVTLOSUBGAUXEN_enable << 8)      /**< Shifted mode enable for RAC_SYLOEN          */
#define RAC_SYLOEN_SYLODIVTLOSUBGEN                                       (0x1UL << 9)                                       /**< SYLODIVTLOSUBGEN                            */
#define _RAC_SYLOEN_SYLODIVTLOSUBGEN_SHIFT                                9                                                  /**< Shift value for RAC_SYLODIVTLOSUBGEN        */
#define _RAC_SYLOEN_SYLODIVTLOSUBGEN_MASK                                 0x200UL                                            /**< Bit mask for RAC_SYLODIVTLOSUBGEN           */
#define _RAC_SYLOEN_SYLODIVTLOSUBGEN_DEFAULT                              0x00000000UL                                       /**< Mode DEFAULT for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVTLOSUBGEN_disable                              0x00000000UL                                       /**< Mode disable for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVTLOSUBGEN_enable                               0x00000001UL                                       /**< Mode enable for RAC_SYLOEN                  */
#define RAC_SYLOEN_SYLODIVTLOSUBGEN_DEFAULT                               (_RAC_SYLOEN_SYLODIVTLOSUBGEN_DEFAULT << 9)        /**< Shifted mode DEFAULT for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVTLOSUBGEN_disable                               (_RAC_SYLOEN_SYLODIVTLOSUBGEN_disable << 9)        /**< Shifted mode disable for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVTLOSUBGEN_enable                                (_RAC_SYLOEN_SYLODIVTLOSUBGEN_enable << 9)         /**< Shifted mode enable for RAC_SYLOEN          */
#define RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN                                   (0x1UL << 11)                                      /**< SYLODIVTLOOFDMSUBGEN                        */
#define _RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_SHIFT                            11                                                 /**< Shift value for RAC_SYLODIVTLOOFDMSUBGEN    */
#define _RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_MASK                             0x800UL                                            /**< Bit mask for RAC_SYLODIVTLOOFDMSUBGEN       */
#define _RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_DEFAULT                          0x00000000UL                                       /**< Mode DEFAULT for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_disable                          0x00000000UL                                       /**< Mode disable for RAC_SYLOEN                 */
#define _RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_enable                           0x00000001UL                                       /**< Mode enable for RAC_SYLOEN                  */
#define RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_DEFAULT                           (_RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_DEFAULT << 11)   /**< Shifted mode DEFAULT for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_disable                           (_RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_disable << 11)   /**< Shifted mode disable for RAC_SYLOEN         */
#define RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_enable                            (_RAC_SYLOEN_SYLODIVTLOOFDMSUBGEN_enable << 11)    /**< Shifted mode enable for RAC_SYLOEN          */

/* Bit fields for RAC SYMMDCTRL */
#define _RAC_SYMMDCTRL_RESETVALUE                                         0x00000048UL                                     /**< Default value for RAC_SYMMDCTRL             */
#define _RAC_SYMMDCTRL_MASK                                               0x000000FFUL                                     /**< Mask for RAC_SYMMDCTRL                      */
#define _RAC_SYMMDCTRL_SYMMDDIVRSDIG_SHIFT                                0                                                /**< Shift value for RAC_SYMMDDIVRSDIG           */
#define _RAC_SYMMDCTRL_SYMMDDIVRSDIG_MASK                                 0x3UL                                            /**< Bit mask for RAC_SYMMDDIVRSDIG              */
#define _RAC_SYMMDCTRL_SYMMDDIVRSDIG_DEFAULT                              0x00000000UL                                     /**< Mode DEFAULT for RAC_SYMMDCTRL              */
#define _RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby1                            0x00000000UL                                     /**< Mode Divideby1 for RAC_SYMMDCTRL            */
#define _RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby2                            0x00000001UL                                     /**< Mode Divideby2 for RAC_SYMMDCTRL            */
#define _RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby4                            0x00000002UL                                     /**< Mode Divideby4 for RAC_SYMMDCTRL            */
#define _RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby8                            0x00000003UL                                     /**< Mode Divideby8 for RAC_SYMMDCTRL            */
#define RAC_SYMMDCTRL_SYMMDDIVRSDIG_DEFAULT                               (_RAC_SYMMDCTRL_SYMMDDIVRSDIG_DEFAULT << 0)      /**< Shifted mode DEFAULT for RAC_SYMMDCTRL      */
#define RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby1                             (_RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby1 << 0)    /**< Shifted mode Divideby1 for RAC_SYMMDCTRL    */
#define RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby2                             (_RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby2 << 0)    /**< Shifted mode Divideby2 for RAC_SYMMDCTRL    */
#define RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby4                             (_RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby4 << 0)    /**< Shifted mode Divideby4 for RAC_SYMMDCTRL    */
#define RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby8                             (_RAC_SYMMDCTRL_SYMMDDIVRSDIG_Divideby8 << 0)    /**< Shifted mode Divideby8 for RAC_SYMMDCTRL    */
#define _RAC_SYMMDCTRL_SYMMDMODERX_SHIFT                                  2                                                /**< Shift value for RAC_SYMMDMODERX             */
#define _RAC_SYMMDCTRL_SYMMDMODERX_MASK                                   0x1CUL                                           /**< Bit mask for RAC_SYMMDMODERX                */
#define _RAC_SYMMDCTRL_SYMMDMODERX_DEFAULT                                0x00000002UL                                     /**< Mode DEFAULT for RAC_SYMMDCTRL              */
#define _RAC_SYMMDCTRL_SYMMDMODERX_rx_w_swctrl                            0x00000000UL                                     /**< Mode rx_w_swctrl for RAC_SYMMDCTRL          */
#define _RAC_SYMMDCTRL_SYMMDMODERX_rx_wo_swctrl                           0x00000001UL                                     /**< Mode rx_wo_swctrl for RAC_SYMMDCTRL         */
#define _RAC_SYMMDCTRL_SYMMDMODERX_qnc_dsm2                               0x00000002UL                                     /**< Mode qnc_dsm2 for RAC_SYMMDCTRL             */
#define _RAC_SYMMDCTRL_SYMMDMODERX_qnc_dsm3                               0x00000003UL                                     /**< Mode qnc_dsm3 for RAC_SYMMDCTRL             */
#define _RAC_SYMMDCTRL_SYMMDMODERX_rxlp_wo_swctrl                         0x00000004UL                                     /**< Mode rxlp_wo_swctrl for RAC_SYMMDCTRL       */
#define _RAC_SYMMDCTRL_SYMMDMODERX_notuse_5                               0x00000005UL                                     /**< Mode notuse_5 for RAC_SYMMDCTRL             */
#define _RAC_SYMMDCTRL_SYMMDMODERX_notuse_6                               0x00000006UL                                     /**< Mode notuse_6 for RAC_SYMMDCTRL             */
#define _RAC_SYMMDCTRL_SYMMDMODERX_notuse_7                               0x00000007UL                                     /**< Mode notuse_7 for RAC_SYMMDCTRL             */
#define RAC_SYMMDCTRL_SYMMDMODERX_DEFAULT                                 (_RAC_SYMMDCTRL_SYMMDMODERX_DEFAULT << 2)        /**< Shifted mode DEFAULT for RAC_SYMMDCTRL      */
#define RAC_SYMMDCTRL_SYMMDMODERX_rx_w_swctrl                             (_RAC_SYMMDCTRL_SYMMDMODERX_rx_w_swctrl << 2)    /**< Shifted mode rx_w_swctrl for RAC_SYMMDCTRL  */
#define RAC_SYMMDCTRL_SYMMDMODERX_rx_wo_swctrl                            (_RAC_SYMMDCTRL_SYMMDMODERX_rx_wo_swctrl << 2)   /**< Shifted mode rx_wo_swctrl for RAC_SYMMDCTRL */
#define RAC_SYMMDCTRL_SYMMDMODERX_qnc_dsm2                                (_RAC_SYMMDCTRL_SYMMDMODERX_qnc_dsm2 << 2)       /**< Shifted mode qnc_dsm2 for RAC_SYMMDCTRL     */
#define RAC_SYMMDCTRL_SYMMDMODERX_qnc_dsm3                                (_RAC_SYMMDCTRL_SYMMDMODERX_qnc_dsm3 << 2)       /**< Shifted mode qnc_dsm3 for RAC_SYMMDCTRL     */
#define RAC_SYMMDCTRL_SYMMDMODERX_rxlp_wo_swctrl                          (_RAC_SYMMDCTRL_SYMMDMODERX_rxlp_wo_swctrl << 2) /**< Shifted mode rxlp_wo_swctrl for RAC_SYMMDCTRL*/
#define RAC_SYMMDCTRL_SYMMDMODERX_notuse_5                                (_RAC_SYMMDCTRL_SYMMDMODERX_notuse_5 << 2)       /**< Shifted mode notuse_5 for RAC_SYMMDCTRL     */
#define RAC_SYMMDCTRL_SYMMDMODERX_notuse_6                                (_RAC_SYMMDCTRL_SYMMDMODERX_notuse_6 << 2)       /**< Shifted mode notuse_6 for RAC_SYMMDCTRL     */
#define RAC_SYMMDCTRL_SYMMDMODERX_notuse_7                                (_RAC_SYMMDCTRL_SYMMDMODERX_notuse_7 << 2)       /**< Shifted mode notuse_7 for RAC_SYMMDCTRL     */
#define _RAC_SYMMDCTRL_SYMMDMODETX_SHIFT                                  5                                                /**< Shift value for RAC_SYMMDMODETX             */
#define _RAC_SYMMDCTRL_SYMMDMODETX_MASK                                   0xE0UL                                           /**< Bit mask for RAC_SYMMDMODETX                */
#define _RAC_SYMMDCTRL_SYMMDMODETX_DEFAULT                                0x00000002UL                                     /**< Mode DEFAULT for RAC_SYMMDCTRL              */
#define _RAC_SYMMDCTRL_SYMMDMODETX_rx_w_swctrl                            0x00000000UL                                     /**< Mode rx_w_swctrl for RAC_SYMMDCTRL          */
#define _RAC_SYMMDCTRL_SYMMDMODETX_rx_wo_swctrl                           0x00000001UL                                     /**< Mode rx_wo_swctrl for RAC_SYMMDCTRL         */
#define _RAC_SYMMDCTRL_SYMMDMODETX_qnc_dsm2                               0x00000002UL                                     /**< Mode qnc_dsm2 for RAC_SYMMDCTRL             */
#define _RAC_SYMMDCTRL_SYMMDMODETX_qnc_dsm3                               0x00000003UL                                     /**< Mode qnc_dsm3 for RAC_SYMMDCTRL             */
#define _RAC_SYMMDCTRL_SYMMDMODETX_rxlp_wo_swctrl                         0x00000004UL                                     /**< Mode rxlp_wo_swctrl for RAC_SYMMDCTRL       */
#define _RAC_SYMMDCTRL_SYMMDMODETX_notuse_5                               0x00000005UL                                     /**< Mode notuse_5 for RAC_SYMMDCTRL             */
#define _RAC_SYMMDCTRL_SYMMDMODETX_notuse_6                               0x00000006UL                                     /**< Mode notuse_6 for RAC_SYMMDCTRL             */
#define _RAC_SYMMDCTRL_SYMMDMODETX_notuse_7                               0x00000007UL                                     /**< Mode notuse_7 for RAC_SYMMDCTRL             */
#define RAC_SYMMDCTRL_SYMMDMODETX_DEFAULT                                 (_RAC_SYMMDCTRL_SYMMDMODETX_DEFAULT << 5)        /**< Shifted mode DEFAULT for RAC_SYMMDCTRL      */
#define RAC_SYMMDCTRL_SYMMDMODETX_rx_w_swctrl                             (_RAC_SYMMDCTRL_SYMMDMODETX_rx_w_swctrl << 5)    /**< Shifted mode rx_w_swctrl for RAC_SYMMDCTRL  */
#define RAC_SYMMDCTRL_SYMMDMODETX_rx_wo_swctrl                            (_RAC_SYMMDCTRL_SYMMDMODETX_rx_wo_swctrl << 5)   /**< Shifted mode rx_wo_swctrl for RAC_SYMMDCTRL */
#define RAC_SYMMDCTRL_SYMMDMODETX_qnc_dsm2                                (_RAC_SYMMDCTRL_SYMMDMODETX_qnc_dsm2 << 5)       /**< Shifted mode qnc_dsm2 for RAC_SYMMDCTRL     */
#define RAC_SYMMDCTRL_SYMMDMODETX_qnc_dsm3                                (_RAC_SYMMDCTRL_SYMMDMODETX_qnc_dsm3 << 5)       /**< Shifted mode qnc_dsm3 for RAC_SYMMDCTRL     */
#define RAC_SYMMDCTRL_SYMMDMODETX_rxlp_wo_swctrl                          (_RAC_SYMMDCTRL_SYMMDMODETX_rxlp_wo_swctrl << 5) /**< Shifted mode rxlp_wo_swctrl for RAC_SYMMDCTRL*/
#define RAC_SYMMDCTRL_SYMMDMODETX_notuse_5                                (_RAC_SYMMDCTRL_SYMMDMODETX_notuse_5 << 5)       /**< Shifted mode notuse_5 for RAC_SYMMDCTRL     */
#define RAC_SYMMDCTRL_SYMMDMODETX_notuse_6                                (_RAC_SYMMDCTRL_SYMMDMODETX_notuse_6 << 5)       /**< Shifted mode notuse_6 for RAC_SYMMDCTRL     */
#define RAC_SYMMDCTRL_SYMMDMODETX_notuse_7                                (_RAC_SYMMDCTRL_SYMMDMODETX_notuse_7 << 5)       /**< Shifted mode notuse_7 for RAC_SYMMDCTRL     */

/* Bit fields for RAC SYDIVCTRL */
#define _RAC_SYDIVCTRL_RESETVALUE                                         0x00000000UL                                       /**< Default value for RAC_SYDIVCTRL             */
#define _RAC_SYDIVCTRL_MASK                                               0x00033C00UL                                       /**< Mask for RAC_SYDIVCTRL                      */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_SHIFT                               10                                                 /**< Shift value for RAC_SYLODIVRADCDIV          */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_MASK                                0x3C00UL                                           /**< Bit mask for RAC_SYLODIVRADCDIV             */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_DEFAULT                             0x00000000UL                                       /**< Mode DEFAULT for RAC_SYDIVCTRL              */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_8                         0x00000000UL                                       /**< Mode divide_by_8 for RAC_SYDIVCTRL          */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_9                         0x00000001UL                                       /**< Mode divide_by_9 for RAC_SYDIVCTRL          */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_10                        0x00000002UL                                       /**< Mode divide_by_10 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_11                        0x00000003UL                                       /**< Mode divide_by_11 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_12                        0x00000004UL                                       /**< Mode divide_by_12 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_13                        0x00000005UL                                       /**< Mode divide_by_13 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_14                        0x00000006UL                                       /**< Mode divide_by_14 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_15                        0x00000007UL                                       /**< Mode divide_by_15 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_16                        0x00000008UL                                       /**< Mode divide_by_16 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_17                        0x00000009UL                                       /**< Mode divide_by_17 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_18                        0x0000000AUL                                       /**< Mode divide_by_18 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_19                        0x0000000BUL                                       /**< Mode divide_by_19 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_20                        0x0000000CUL                                       /**< Mode divide_by_20 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_21                        0x0000000DUL                                       /**< Mode divide_by_21 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_22                        0x0000000EUL                                       /**< Mode divide_by_22 for RAC_SYDIVCTRL         */
#define _RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_23                        0x0000000FUL                                       /**< Mode divide_by_23 for RAC_SYDIVCTRL         */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_DEFAULT                              (_RAC_SYDIVCTRL_SYLODIVRADCDIV_DEFAULT << 10)      /**< Shifted mode DEFAULT for RAC_SYDIVCTRL      */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_8                          (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_8 << 10)  /**< Shifted mode divide_by_8 for RAC_SYDIVCTRL  */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_9                          (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_9 << 10)  /**< Shifted mode divide_by_9 for RAC_SYDIVCTRL  */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_10                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_10 << 10) /**< Shifted mode divide_by_10 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_11                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_11 << 10) /**< Shifted mode divide_by_11 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_12                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_12 << 10) /**< Shifted mode divide_by_12 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_13                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_13 << 10) /**< Shifted mode divide_by_13 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_14                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_14 << 10) /**< Shifted mode divide_by_14 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_15                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_15 << 10) /**< Shifted mode divide_by_15 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_16                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_16 << 10) /**< Shifted mode divide_by_16 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_17                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_17 << 10) /**< Shifted mode divide_by_17 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_18                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_18 << 10) /**< Shifted mode divide_by_18 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_19                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_19 << 10) /**< Shifted mode divide_by_19 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_20                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_20 << 10) /**< Shifted mode divide_by_20 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_21                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_21 << 10) /**< Shifted mode divide_by_21 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_22                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_22 << 10) /**< Shifted mode divide_by_22 for RAC_SYDIVCTRL */
#define RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_23                         (_RAC_SYDIVCTRL_SYLODIVRADCDIV_divide_by_23 << 10) /**< Shifted mode divide_by_23 for RAC_SYDIVCTRL */
#define _RAC_SYDIVCTRL_SYLODIVSMUXDIV_SHIFT                               16                                                 /**< Shift value for RAC_SYLODIVSMUXDIV          */
#define _RAC_SYDIVCTRL_SYLODIVSMUXDIV_MASK                                0x30000UL                                          /**< Bit mask for RAC_SYLODIVSMUXDIV             */
#define _RAC_SYDIVCTRL_SYLODIVSMUXDIV_DEFAULT                             0x00000000UL                                       /**< Mode DEFAULT for RAC_SYDIVCTRL              */
#define _RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_1                            0x00000000UL                                       /**< Mode div_by_1 for RAC_SYDIVCTRL             */
#define _RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_2                            0x00000001UL                                       /**< Mode div_by_2 for RAC_SYDIVCTRL             */
#define _RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_4                            0x00000002UL                                       /**< Mode div_by_4 for RAC_SYDIVCTRL             */
#define _RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_8                            0x00000003UL                                       /**< Mode div_by_8 for RAC_SYDIVCTRL             */
#define RAC_SYDIVCTRL_SYLODIVSMUXDIV_DEFAULT                              (_RAC_SYDIVCTRL_SYLODIVSMUXDIV_DEFAULT << 16)      /**< Shifted mode DEFAULT for RAC_SYDIVCTRL      */
#define RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_1                             (_RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_1 << 16)     /**< Shifted mode div_by_1 for RAC_SYDIVCTRL     */
#define RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_2                             (_RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_2 << 16)     /**< Shifted mode div_by_2 for RAC_SYDIVCTRL     */
#define RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_4                             (_RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_4 << 16)     /**< Shifted mode div_by_4 for RAC_SYDIVCTRL     */
#define RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_8                             (_RAC_SYDIVCTRL_SYLODIVSMUXDIV_div_by_8 << 16)     /**< Shifted mode div_by_8 for RAC_SYDIVCTRL     */

/* Bit fields for RAC DIGCLKRETIMECTRL */
#define _RAC_DIGCLKRETIMECTRL_RESETVALUE                                  0x00000000UL                                                      /**< Default value for RAC_DIGCLKRETIMECTRL      */
#define _RAC_DIGCLKRETIMECTRL_MASK                                        0x00000777UL                                                      /**< Mask for RAC_DIGCLKRETIMECTRL               */
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME                         (0x1UL << 0)                                                      /**< DIGCLKRETIMEENRETIME                        */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_SHIFT                  0                                                                 /**< Shift value for RAC_DIGCLKRETIMEENRETIME    */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_MASK                   0x1UL                                                             /**< Bit mask for RAC_DIGCLKRETIMEENRETIME       */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_DEFAULT                0x00000000UL                                                      /**< Mode DEFAULT for RAC_DIGCLKRETIMECTRL       */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_disable                0x00000000UL                                                      /**< Mode disable for RAC_DIGCLKRETIMECTRL       */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_enable                 0x00000001UL                                                      /**< Mode enable for RAC_DIGCLKRETIMECTRL        */
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_DEFAULT                 (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_DIGCLKRETIMECTRL*/
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_disable                 (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_disable << 0)         /**< Shifted mode disable for RAC_DIGCLKRETIMECTRL*/
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_enable                  (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEENRETIME_enable << 0)          /**< Shifted mode enable for RAC_DIGCLKRETIMECTRL*/
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME                        (0x1UL << 1)                                                      /**< DIGCLKRETIMEDISRETIME                       */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_SHIFT                 1                                                                 /**< Shift value for RAC_DIGCLKRETIMEDISRETIME   */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_MASK                  0x2UL                                                             /**< Bit mask for RAC_DIGCLKRETIMEDISRETIME      */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_DEFAULT               0x00000000UL                                                      /**< Mode DEFAULT for RAC_DIGCLKRETIMECTRL       */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_enable_retime         0x00000000UL                                                      /**< Mode enable_retime for RAC_DIGCLKRETIMECTRL */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_disable_retime        0x00000001UL                                                      /**< Mode disable_retime for RAC_DIGCLKRETIMECTRL*/
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_DEFAULT                (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_DEFAULT << 1)        /**< Shifted mode DEFAULT for RAC_DIGCLKRETIMECTRL*/
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_enable_retime          (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_enable_retime << 1)  /**< Shifted mode enable_retime for RAC_DIGCLKRETIMECTRL*/
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_disable_retime         (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMEDISRETIME_disable_retime << 1) /**< Shifted mode disable_retime for RAC_DIGCLKRETIMECTRL*/
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN                           (0x1UL << 2)                                                      /**< DIGCLKRETIMERESETN                          */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_SHIFT                    2                                                                 /**< Shift value for RAC_DIGCLKRETIMERESETN      */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_MASK                     0x4UL                                                             /**< Bit mask for RAC_DIGCLKRETIMERESETN         */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_DEFAULT                  0x00000000UL                                                      /**< Mode DEFAULT for RAC_DIGCLKRETIMECTRL       */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_disable_output2          0x00000000UL                                                      /**< Mode disable_output2 for RAC_DIGCLKRETIMECTRL*/
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_enable_output2           0x00000001UL                                                      /**< Mode enable_output2 for RAC_DIGCLKRETIMECTRL*/
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_DEFAULT                   (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_DEFAULT << 2)           /**< Shifted mode DEFAULT for RAC_DIGCLKRETIMECTRL*/
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_disable_output2           (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_disable_output2 << 2)   /**< Shifted mode disable_output2 for RAC_DIGCLKRETIMECTRL*/
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_enable_output2            (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMERESETN_enable_output2 << 2)    /**< Shifted mode enable_output2 for RAC_DIGCLKRETIMECTRL*/
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMELIMITH_SHIFT                    4                                                                 /**< Shift value for RAC_DIGCLKRETIMELIMITH      */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMELIMITH_MASK                     0x70UL                                                            /**< Bit mask for RAC_DIGCLKRETIMELIMITH         */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMELIMITH_DEFAULT                  0x00000000UL                                                      /**< Mode DEFAULT for RAC_DIGCLKRETIMECTRL       */
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMELIMITH_DEFAULT                   (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMELIMITH_DEFAULT << 4)           /**< Shifted mode DEFAULT for RAC_DIGCLKRETIMECTRL*/
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMELIMITL_SHIFT                    8                                                                 /**< Shift value for RAC_DIGCLKRETIMELIMITL      */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMELIMITL_MASK                     0x700UL                                                           /**< Bit mask for RAC_DIGCLKRETIMELIMITL         */
#define _RAC_DIGCLKRETIMECTRL_DIGCLKRETIMELIMITL_DEFAULT                  0x00000000UL                                                      /**< Mode DEFAULT for RAC_DIGCLKRETIMECTRL       */
#define RAC_DIGCLKRETIMECTRL_DIGCLKRETIMELIMITL_DEFAULT                   (_RAC_DIGCLKRETIMECTRL_DIGCLKRETIMELIMITL_DEFAULT << 8)           /**< Shifted mode DEFAULT for RAC_DIGCLKRETIMECTRL*/

/* Bit fields for RAC DIGCLKRETIMESTATUS */
#define _RAC_DIGCLKRETIMESTATUS_RESETVALUE                                0x00000000UL                                                      /**< Default value for RAC_DIGCLKRETIMESTATUS    */
#define _RAC_DIGCLKRETIMESTATUS_MASK                                      0x00000003UL                                                      /**< Mask for RAC_DIGCLKRETIMESTATUS             */
#define RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL                         (0x1UL << 0)                                                      /**< DIGCLKRETIMECLKSEL                          */
#define _RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_SHIFT                  0                                                                 /**< Shift value for RAC_DIGCLKRETIMECLKSEL      */
#define _RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_MASK                   0x1UL                                                             /**< Bit mask for RAC_DIGCLKRETIMECLKSEL         */
#define _RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_DEFAULT                0x00000000UL                                                      /**< Mode DEFAULT for RAC_DIGCLKRETIMESTATUS     */
#define _RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_use_raw_clk            0x00000000UL                                                      /**< Mode use_raw_clk for RAC_DIGCLKRETIMESTATUS */
#define _RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_use_retimed_clk        0x00000001UL                                                      /**< Mode use_retimed_clk for RAC_DIGCLKRETIMESTATUS*/
#define RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_DEFAULT                 (_RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_DIGCLKRETIMESTATUS*/
#define RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_use_raw_clk             (_RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_use_raw_clk << 0)     /**< Shifted mode use_raw_clk for RAC_DIGCLKRETIMESTATUS*/
#define RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_use_retimed_clk         (_RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMECLKSEL_use_retimed_clk << 0) /**< Shifted mode use_retimed_clk for RAC_DIGCLKRETIMESTATUS*/
#define RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO                       (0x1UL << 1)                                                      /**< DIGCLKRETIMERESETNLO                        */
#define _RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_SHIFT                1                                                                 /**< Shift value for RAC_DIGCLKRETIMERESETNLO    */
#define _RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_MASK                 0x2UL                                                             /**< Bit mask for RAC_DIGCLKRETIMERESETNLO       */
#define _RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_DEFAULT              0x00000000UL                                                      /**< Mode DEFAULT for RAC_DIGCLKRETIMESTATUS     */
#define _RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_lo                   0x00000000UL                                                      /**< Mode lo for RAC_DIGCLKRETIMESTATUS          */
#define _RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_hi                   0x00000001UL                                                      /**< Mode hi for RAC_DIGCLKRETIMESTATUS          */
#define RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_DEFAULT               (_RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_DEFAULT << 1)       /**< Shifted mode DEFAULT for RAC_DIGCLKRETIMESTATUS*/
#define RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_lo                    (_RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_lo << 1)            /**< Shifted mode lo for RAC_DIGCLKRETIMESTATUS  */
#define RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_hi                    (_RAC_DIGCLKRETIMESTATUS_DIGCLKRETIMERESETNLO_hi << 1)            /**< Shifted mode hi for RAC_DIGCLKRETIMESTATUS  */

/* Bit fields for RAC XORETIMECTRL */
#define _RAC_XORETIMECTRL_RESETVALUE                                      0x00000000UL                                              /**< Default value for RAC_XORETIMECTRL          */
#define _RAC_XORETIMECTRL_MASK                                            0x00000777UL                                              /**< Mask for RAC_XORETIMECTRL                   */
#define RAC_XORETIMECTRL_XORETIMEENRETIME                                 (0x1UL << 0)                                              /**< XORETIMEENRETIME                            */
#define _RAC_XORETIMECTRL_XORETIMEENRETIME_SHIFT                          0                                                         /**< Shift value for RAC_XORETIMEENRETIME        */
#define _RAC_XORETIMECTRL_XORETIMEENRETIME_MASK                           0x1UL                                                     /**< Bit mask for RAC_XORETIMEENRETIME           */
#define _RAC_XORETIMECTRL_XORETIMEENRETIME_DEFAULT                        0x00000000UL                                              /**< Mode DEFAULT for RAC_XORETIMECTRL           */
#define _RAC_XORETIMECTRL_XORETIMEENRETIME_disable                        0x00000000UL                                              /**< Mode disable for RAC_XORETIMECTRL           */
#define _RAC_XORETIMECTRL_XORETIMEENRETIME_enable                         0x00000001UL                                              /**< Mode enable for RAC_XORETIMECTRL            */
#define RAC_XORETIMECTRL_XORETIMEENRETIME_DEFAULT                         (_RAC_XORETIMECTRL_XORETIMEENRETIME_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_XORETIMECTRL   */
#define RAC_XORETIMECTRL_XORETIMEENRETIME_disable                         (_RAC_XORETIMECTRL_XORETIMEENRETIME_disable << 0)         /**< Shifted mode disable for RAC_XORETIMECTRL   */
#define RAC_XORETIMECTRL_XORETIMEENRETIME_enable                          (_RAC_XORETIMECTRL_XORETIMEENRETIME_enable << 0)          /**< Shifted mode enable for RAC_XORETIMECTRL    */
#define RAC_XORETIMECTRL_XORETIMEDISRETIME                                (0x1UL << 1)                                              /**< XORETIMEDISRETIME                           */
#define _RAC_XORETIMECTRL_XORETIMEDISRETIME_SHIFT                         1                                                         /**< Shift value for RAC_XORETIMEDISRETIME       */
#define _RAC_XORETIMECTRL_XORETIMEDISRETIME_MASK                          0x2UL                                                     /**< Bit mask for RAC_XORETIMEDISRETIME          */
#define _RAC_XORETIMECTRL_XORETIMEDISRETIME_DEFAULT                       0x00000000UL                                              /**< Mode DEFAULT for RAC_XORETIMECTRL           */
#define _RAC_XORETIMECTRL_XORETIMEDISRETIME_enable_retime                 0x00000000UL                                              /**< Mode enable_retime for RAC_XORETIMECTRL     */
#define _RAC_XORETIMECTRL_XORETIMEDISRETIME_disable_retime                0x00000001UL                                              /**< Mode disable_retime for RAC_XORETIMECTRL    */
#define RAC_XORETIMECTRL_XORETIMEDISRETIME_DEFAULT                        (_RAC_XORETIMECTRL_XORETIMEDISRETIME_DEFAULT << 1)        /**< Shifted mode DEFAULT for RAC_XORETIMECTRL   */
#define RAC_XORETIMECTRL_XORETIMEDISRETIME_enable_retime                  (_RAC_XORETIMECTRL_XORETIMEDISRETIME_enable_retime << 1)  /**< Shifted mode enable_retime for RAC_XORETIMECTRL*/
#define RAC_XORETIMECTRL_XORETIMEDISRETIME_disable_retime                 (_RAC_XORETIMECTRL_XORETIMEDISRETIME_disable_retime << 1) /**< Shifted mode disable_retime for RAC_XORETIMECTRL*/
#define RAC_XORETIMECTRL_XORETIMERESETN                                   (0x1UL << 2)                                              /**< XORETIMERESETN                              */
#define _RAC_XORETIMECTRL_XORETIMERESETN_SHIFT                            2                                                         /**< Shift value for RAC_XORETIMERESETN          */
#define _RAC_XORETIMECTRL_XORETIMERESETN_MASK                             0x4UL                                                     /**< Bit mask for RAC_XORETIMERESETN             */
#define _RAC_XORETIMECTRL_XORETIMERESETN_DEFAULT                          0x00000000UL                                              /**< Mode DEFAULT for RAC_XORETIMECTRL           */
#define _RAC_XORETIMECTRL_XORETIMERESETN_disable_output1                  0x00000000UL                                              /**< Mode disable_output1 for RAC_XORETIMECTRL   */
#define _RAC_XORETIMECTRL_XORETIMERESETN_enable_output1                   0x00000001UL                                              /**< Mode enable_output1 for RAC_XORETIMECTRL    */
#define RAC_XORETIMECTRL_XORETIMERESETN_DEFAULT                           (_RAC_XORETIMECTRL_XORETIMERESETN_DEFAULT << 2)           /**< Shifted mode DEFAULT for RAC_XORETIMECTRL   */
#define RAC_XORETIMECTRL_XORETIMERESETN_disable_output1                   (_RAC_XORETIMECTRL_XORETIMERESETN_disable_output1 << 2)   /**< Shifted mode disable_output1 for RAC_XORETIMECTRL*/
#define RAC_XORETIMECTRL_XORETIMERESETN_enable_output1                    (_RAC_XORETIMECTRL_XORETIMERESETN_enable_output1 << 2)    /**< Shifted mode enable_output1 for RAC_XORETIMECTRL*/
#define _RAC_XORETIMECTRL_XORETIMELIMITH_SHIFT                            4                                                         /**< Shift value for RAC_XORETIMELIMITH          */
#define _RAC_XORETIMECTRL_XORETIMELIMITH_MASK                             0x70UL                                                    /**< Bit mask for RAC_XORETIMELIMITH             */
#define _RAC_XORETIMECTRL_XORETIMELIMITH_DEFAULT                          0x00000000UL                                              /**< Mode DEFAULT for RAC_XORETIMECTRL           */
#define RAC_XORETIMECTRL_XORETIMELIMITH_DEFAULT                           (_RAC_XORETIMECTRL_XORETIMELIMITH_DEFAULT << 4)           /**< Shifted mode DEFAULT for RAC_XORETIMECTRL   */
#define _RAC_XORETIMECTRL_XORETIMELIMITL_SHIFT                            8                                                         /**< Shift value for RAC_XORETIMELIMITL          */
#define _RAC_XORETIMECTRL_XORETIMELIMITL_MASK                             0x700UL                                                   /**< Bit mask for RAC_XORETIMELIMITL             */
#define _RAC_XORETIMECTRL_XORETIMELIMITL_DEFAULT                          0x00000000UL                                              /**< Mode DEFAULT for RAC_XORETIMECTRL           */
#define RAC_XORETIMECTRL_XORETIMELIMITL_DEFAULT                           (_RAC_XORETIMECTRL_XORETIMELIMITL_DEFAULT << 8)           /**< Shifted mode DEFAULT for RAC_XORETIMECTRL   */

/* Bit fields for RAC XORETIMESTATUS */
#define _RAC_XORETIMESTATUS_RESETVALUE                                    0x00000000UL                                              /**< Default value for RAC_XORETIMESTATUS        */
#define _RAC_XORETIMESTATUS_MASK                                          0x00000003UL                                              /**< Mask for RAC_XORETIMESTATUS                 */
#define RAC_XORETIMESTATUS_XORETIMECLKSEL                                 (0x1UL << 0)                                              /**< XORETIMECLKSEL                              */
#define _RAC_XORETIMESTATUS_XORETIMECLKSEL_SHIFT                          0                                                         /**< Shift value for RAC_XORETIMECLKSEL          */
#define _RAC_XORETIMESTATUS_XORETIMECLKSEL_MASK                           0x1UL                                                     /**< Bit mask for RAC_XORETIMECLKSEL             */
#define _RAC_XORETIMESTATUS_XORETIMECLKSEL_DEFAULT                        0x00000000UL                                              /**< Mode DEFAULT for RAC_XORETIMESTATUS         */
#define _RAC_XORETIMESTATUS_XORETIMECLKSEL_use_raw_clk                    0x00000000UL                                              /**< Mode use_raw_clk for RAC_XORETIMESTATUS     */
#define _RAC_XORETIMESTATUS_XORETIMECLKSEL_use_retimed_clk                0x00000001UL                                              /**< Mode use_retimed_clk for RAC_XORETIMESTATUS */
#define RAC_XORETIMESTATUS_XORETIMECLKSEL_DEFAULT                         (_RAC_XORETIMESTATUS_XORETIMECLKSEL_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_XORETIMESTATUS */
#define RAC_XORETIMESTATUS_XORETIMECLKSEL_use_raw_clk                     (_RAC_XORETIMESTATUS_XORETIMECLKSEL_use_raw_clk << 0)     /**< Shifted mode use_raw_clk for RAC_XORETIMESTATUS*/
#define RAC_XORETIMESTATUS_XORETIMECLKSEL_use_retimed_clk                 (_RAC_XORETIMESTATUS_XORETIMECLKSEL_use_retimed_clk << 0) /**< Shifted mode use_retimed_clk for RAC_XORETIMESTATUS*/
#define RAC_XORETIMESTATUS_XORETIMERESETNLO                               (0x1UL << 1)                                              /**< XORETIMERESETNLO                            */
#define _RAC_XORETIMESTATUS_XORETIMERESETNLO_SHIFT                        1                                                         /**< Shift value for RAC_XORETIMERESETNLO        */
#define _RAC_XORETIMESTATUS_XORETIMERESETNLO_MASK                         0x2UL                                                     /**< Bit mask for RAC_XORETIMERESETNLO           */
#define _RAC_XORETIMESTATUS_XORETIMERESETNLO_DEFAULT                      0x00000000UL                                              /**< Mode DEFAULT for RAC_XORETIMESTATUS         */
#define _RAC_XORETIMESTATUS_XORETIMERESETNLO_lo                           0x00000000UL                                              /**< Mode lo for RAC_XORETIMESTATUS              */
#define _RAC_XORETIMESTATUS_XORETIMERESETNLO_hi                           0x00000001UL                                              /**< Mode hi for RAC_XORETIMESTATUS              */
#define RAC_XORETIMESTATUS_XORETIMERESETNLO_DEFAULT                       (_RAC_XORETIMESTATUS_XORETIMERESETNLO_DEFAULT << 1)       /**< Shifted mode DEFAULT for RAC_XORETIMESTATUS */
#define RAC_XORETIMESTATUS_XORETIMERESETNLO_lo                            (_RAC_XORETIMESTATUS_XORETIMERESETNLO_lo << 1)            /**< Shifted mode lo for RAC_XORETIMESTATUS      */
#define RAC_XORETIMESTATUS_XORETIMERESETNLO_hi                            (_RAC_XORETIMESTATUS_XORETIMERESETNLO_hi << 1)            /**< Shifted mode hi for RAC_XORETIMESTATUS      */

/* Bit fields for RAC AGCOVERWRITE0 */
#define _RAC_AGCOVERWRITE0_RESETVALUE                                     0x00000000UL                                       /**< Default value for RAC_AGCOVERWRITE0         */
#define _RAC_AGCOVERWRITE0_MASK                                           0x03F0FFFFUL                                       /**< Mask for RAC_AGCOVERWRITE0                  */
#define RAC_AGCOVERWRITE0_ENMANLNAMIXRFATT                                (0x1UL << 0)                                       /**< Enable RAC Overwite PN                      */
#define _RAC_AGCOVERWRITE0_ENMANLNAMIXRFATT_SHIFT                         0                                                  /**< Shift value for RAC_ENMANLNAMIXRFATT        */
#define _RAC_AGCOVERWRITE0_ENMANLNAMIXRFATT_MASK                          0x1UL                                              /**< Bit mask for RAC_ENMANLNAMIXRFATT           */
#define _RAC_AGCOVERWRITE0_ENMANLNAMIXRFATT_DEFAULT                       0x00000000UL                                       /**< Mode DEFAULT for RAC_AGCOVERWRITE0          */
#define RAC_AGCOVERWRITE0_ENMANLNAMIXRFATT_DEFAULT                        (_RAC_AGCOVERWRITE0_ENMANLNAMIXRFATT_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_AGCOVERWRITE0  */
#define RAC_AGCOVERWRITE0_ENMANLNAMIXSLICE                                (0x1UL << 1)                                       /**< Enable RAC Overwite LNA                     */
#define _RAC_AGCOVERWRITE0_ENMANLNAMIXSLICE_SHIFT                         1                                                  /**< Shift value for RAC_ENMANLNAMIXSLICE        */
#define _RAC_AGCOVERWRITE0_ENMANLNAMIXSLICE_MASK                          0x2UL                                              /**< Bit mask for RAC_ENMANLNAMIXSLICE           */
#define _RAC_AGCOVERWRITE0_ENMANLNAMIXSLICE_DEFAULT                       0x00000000UL                                       /**< Mode DEFAULT for RAC_AGCOVERWRITE0          */
#define RAC_AGCOVERWRITE0_ENMANLNAMIXSLICE_DEFAULT                        (_RAC_AGCOVERWRITE0_ENMANLNAMIXSLICE_DEFAULT << 1) /**< Shifted mode DEFAULT for RAC_AGCOVERWRITE0  */
#define RAC_AGCOVERWRITE0_ENMANPGAGAIN                                    (0x1UL << 2)                                       /**< Enable RAC Overwite PGA                     */
#define _RAC_AGCOVERWRITE0_ENMANPGAGAIN_SHIFT                             2                                                  /**< Shift value for RAC_ENMANPGAGAIN            */
#define _RAC_AGCOVERWRITE0_ENMANPGAGAIN_MASK                              0x4UL                                              /**< Bit mask for RAC_ENMANPGAGAIN               */
#define _RAC_AGCOVERWRITE0_ENMANPGAGAIN_DEFAULT                           0x00000000UL                                       /**< Mode DEFAULT for RAC_AGCOVERWRITE0          */
#define RAC_AGCOVERWRITE0_ENMANPGAGAIN_DEFAULT                            (_RAC_AGCOVERWRITE0_ENMANPGAGAIN_DEFAULT << 2)     /**< Shifted mode DEFAULT for RAC_AGCOVERWRITE0  */
#define RAC_AGCOVERWRITE0_ENMANIFADCSCALE                                 (0x1UL << 3)                                       /**< Enable RAC Overwite PN                      */
#define _RAC_AGCOVERWRITE0_ENMANIFADCSCALE_SHIFT                          3                                                  /**< Shift value for RAC_ENMANIFADCSCALE         */
#define _RAC_AGCOVERWRITE0_ENMANIFADCSCALE_MASK                           0x8UL                                              /**< Bit mask for RAC_ENMANIFADCSCALE            */
#define _RAC_AGCOVERWRITE0_ENMANIFADCSCALE_DEFAULT                        0x00000000UL                                       /**< Mode DEFAULT for RAC_AGCOVERWRITE0          */
#define RAC_AGCOVERWRITE0_ENMANIFADCSCALE_DEFAULT                         (_RAC_AGCOVERWRITE0_ENMANIFADCSCALE_DEFAULT << 3)  /**< Shifted mode DEFAULT for RAC_AGCOVERWRITE0  */
#define _RAC_AGCOVERWRITE0_MANLNAMIXSLICE0_SHIFT                          4                                                  /**< Shift value for RAC_MANLNAMIXSLICE0         */
#define _RAC_AGCOVERWRITE0_MANLNAMIXSLICE0_MASK                           0x3F0UL                                            /**< Bit mask for RAC_MANLNAMIXSLICE0            */
#define _RAC_AGCOVERWRITE0_MANLNAMIXSLICE0_DEFAULT                        0x00000000UL                                       /**< Mode DEFAULT for RAC_AGCOVERWRITE0          */
#define RAC_AGCOVERWRITE0_MANLNAMIXSLICE0_DEFAULT                         (_RAC_AGCOVERWRITE0_MANLNAMIXSLICE0_DEFAULT << 4)  /**< Shifted mode DEFAULT for RAC_AGCOVERWRITE0  */
#define _RAC_AGCOVERWRITE0_MANLNAMIXSLICE1_SHIFT                          10                                                 /**< Shift value for RAC_MANLNAMIXSLICE1         */
#define _RAC_AGCOVERWRITE0_MANLNAMIXSLICE1_MASK                           0xFC00UL                                           /**< Bit mask for RAC_MANLNAMIXSLICE1            */
#define _RAC_AGCOVERWRITE0_MANLNAMIXSLICE1_DEFAULT                        0x00000000UL                                       /**< Mode DEFAULT for RAC_AGCOVERWRITE0          */
#define RAC_AGCOVERWRITE0_MANLNAMIXSLICE1_DEFAULT                         (_RAC_AGCOVERWRITE0_MANLNAMIXSLICE1_DEFAULT << 10) /**< Shifted mode DEFAULT for RAC_AGCOVERWRITE0  */
#define _RAC_AGCOVERWRITE0_MANPGAGAIN_SHIFT                               20                                                 /**< Shift value for RAC_MANPGAGAIN              */
#define _RAC_AGCOVERWRITE0_MANPGAGAIN_MASK                                0xF00000UL                                         /**< Bit mask for RAC_MANPGAGAIN                 */
#define _RAC_AGCOVERWRITE0_MANPGAGAIN_DEFAULT                             0x00000000UL                                       /**< Mode DEFAULT for RAC_AGCOVERWRITE0          */
#define RAC_AGCOVERWRITE0_MANPGAGAIN_DEFAULT                              (_RAC_AGCOVERWRITE0_MANPGAGAIN_DEFAULT << 20)      /**< Shifted mode DEFAULT for RAC_AGCOVERWRITE0  */
#define _RAC_AGCOVERWRITE0_MANIFADCSCALE_SHIFT                            24                                                 /**< Shift value for RAC_MANIFADCSCALE           */
#define _RAC_AGCOVERWRITE0_MANIFADCSCALE_MASK                             0x3000000UL                                        /**< Bit mask for RAC_MANIFADCSCALE              */
#define _RAC_AGCOVERWRITE0_MANIFADCSCALE_DEFAULT                          0x00000000UL                                       /**< Mode DEFAULT for RAC_AGCOVERWRITE0          */
#define RAC_AGCOVERWRITE0_MANIFADCSCALE_DEFAULT                           (_RAC_AGCOVERWRITE0_MANIFADCSCALE_DEFAULT << 24)   /**< Shifted mode DEFAULT for RAC_AGCOVERWRITE0  */

/* Bit fields for RAC AGCOVERWRITE1 */
#define _RAC_AGCOVERWRITE1_RESETVALUE                                     0x00000000UL                                       /**< Default value for RAC_AGCOVERWRITE1         */
#define _RAC_AGCOVERWRITE1_MASK                                           0x3FFF3FFFUL                                       /**< Mask for RAC_AGCOVERWRITE1                  */
#define _RAC_AGCOVERWRITE1_MANLNAMIXRFATT0_SHIFT                          0                                                  /**< Shift value for RAC_MANLNAMIXRFATT0         */
#define _RAC_AGCOVERWRITE1_MANLNAMIXRFATT0_MASK                           0x3FFFUL                                           /**< Bit mask for RAC_MANLNAMIXRFATT0            */
#define _RAC_AGCOVERWRITE1_MANLNAMIXRFATT0_DEFAULT                        0x00000000UL                                       /**< Mode DEFAULT for RAC_AGCOVERWRITE1          */
#define RAC_AGCOVERWRITE1_MANLNAMIXRFATT0_DEFAULT                         (_RAC_AGCOVERWRITE1_MANLNAMIXRFATT0_DEFAULT << 0)  /**< Shifted mode DEFAULT for RAC_AGCOVERWRITE1  */
#define _RAC_AGCOVERWRITE1_MANLNAMIXRFATT1_SHIFT                          16                                                 /**< Shift value for RAC_MANLNAMIXRFATT1         */
#define _RAC_AGCOVERWRITE1_MANLNAMIXRFATT1_MASK                           0x3FFF0000UL                                       /**< Bit mask for RAC_MANLNAMIXRFATT1            */
#define _RAC_AGCOVERWRITE1_MANLNAMIXRFATT1_DEFAULT                        0x00000000UL                                       /**< Mode DEFAULT for RAC_AGCOVERWRITE1          */
#define RAC_AGCOVERWRITE1_MANLNAMIXRFATT1_DEFAULT                         (_RAC_AGCOVERWRITE1_MANLNAMIXRFATT1_DEFAULT << 16) /**< Shifted mode DEFAULT for RAC_AGCOVERWRITE1  */

/* Bit fields for RAC TXOGNDPKD */
#define _RAC_TXOGNDPKD_RESETVALUE                                         0x00000000UL                                           /**< Default value for RAC_TXOGNDPKD             */
#define _RAC_TXOGNDPKD_MASK                                               0x000001FFUL                                           /**< Mask for RAC_TXOGNDPKD                      */
#define _RAC_TXOGNDPKD_TXPKDOGNDTHRESH_SHIFT                              0                                                      /**< Shift value for RAC_TXPKDOGNDTHRESH         */
#define _RAC_TXOGNDPKD_TXPKDOGNDTHRESH_MASK                               0xFUL                                                  /**< Bit mask for RAC_TXPKDOGNDTHRESH            */
#define _RAC_TXOGNDPKD_TXPKDOGNDTHRESH_DEFAULT                            0x00000000UL                                           /**< Mode DEFAULT for RAC_TXOGNDPKD              */
#define RAC_TXOGNDPKD_TXPKDOGNDTHRESH_DEFAULT                             (_RAC_TXOGNDPKD_TXPKDOGNDTHRESH_DEFAULT << 0)          /**< Shifted mode DEFAULT for RAC_TXOGNDPKD      */
#define RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH                                (0x1UL << 4)                                           /**< TXPKDOGNDBYPASSLATCH                        */
#define _RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_SHIFT                         4                                                      /**< Shift value for RAC_TXPKDOGNDBYPASSLATCH    */
#define _RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_MASK                          0x10UL                                                 /**< Bit mask for RAC_TXPKDOGNDBYPASSLATCH       */
#define _RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_DEFAULT                       0x00000000UL                                           /**< Mode DEFAULT for RAC_TXOGNDPKD              */
#define _RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_disable                       0x00000000UL                                           /**< Mode disable for RAC_TXOGNDPKD              */
#define _RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_enable                        0x00000001UL                                           /**< Mode enable for RAC_TXOGNDPKD               */
#define RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_DEFAULT                        (_RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_DEFAULT << 4)     /**< Shifted mode DEFAULT for RAC_TXOGNDPKD      */
#define RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_disable                        (_RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_disable << 4)     /**< Shifted mode disable for RAC_TXOGNDPKD      */
#define RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_enable                         (_RAC_TXOGNDPKD_TXPKDOGNDBYPASSLATCH_enable << 4)      /**< Shifted mode enable for RAC_TXOGNDPKD       */
#define RAC_TXOGNDPKD_TXPKDOGNDTYPE                                       (0x1UL << 5)                                           /**< TXPKDOGNDTYPE                               */
#define _RAC_TXOGNDPKD_TXPKDOGNDTYPE_SHIFT                                5                                                      /**< Shift value for RAC_TXPKDOGNDTYPE           */
#define _RAC_TXOGNDPKD_TXPKDOGNDTYPE_MASK                                 0x20UL                                                 /**< Bit mask for RAC_TXPKDOGNDTYPE              */
#define _RAC_TXOGNDPKD_TXPKDOGNDTYPE_DEFAULT                              0x00000000UL                                           /**< Mode DEFAULT for RAC_TXOGNDPKD              */
#define _RAC_TXOGNDPKD_TXPKDOGNDTYPE_negative                             0x00000000UL                                           /**< Mode negative for RAC_TXOGNDPKD             */
#define _RAC_TXOGNDPKD_TXPKDOGNDTYPE_positive                             0x00000001UL                                           /**< Mode positive for RAC_TXOGNDPKD             */
#define RAC_TXOGNDPKD_TXPKDOGNDTYPE_DEFAULT                               (_RAC_TXOGNDPKD_TXPKDOGNDTYPE_DEFAULT << 5)            /**< Shifted mode DEFAULT for RAC_TXOGNDPKD      */
#define RAC_TXOGNDPKD_TXPKDOGNDTYPE_negative                              (_RAC_TXOGNDPKD_TXPKDOGNDTYPE_negative << 5)           /**< Shifted mode negative for RAC_TXOGNDPKD     */
#define RAC_TXOGNDPKD_TXPKDOGNDTYPE_positive                              (_RAC_TXOGNDPKD_TXPKDOGNDTYPE_positive << 5)           /**< Shifted mode positive for RAC_TXOGNDPKD     */
#define RAC_TXOGNDPKD_TXPKDOGNDRESET                                      (0x1UL << 6)                                           /**< TXPKDOGNDRESET                              */
#define _RAC_TXOGNDPKD_TXPKDOGNDRESET_SHIFT                               6                                                      /**< Shift value for RAC_TXPKDOGNDRESET          */
#define _RAC_TXOGNDPKD_TXPKDOGNDRESET_MASK                                0x40UL                                                 /**< Bit mask for RAC_TXPKDOGNDRESET             */
#define _RAC_TXOGNDPKD_TXPKDOGNDRESET_DEFAULT                             0x00000000UL                                           /**< Mode DEFAULT for RAC_TXOGNDPKD              */
#define _RAC_TXOGNDPKD_TXPKDOGNDRESET_latch                               0x00000000UL                                           /**< Mode latch for RAC_TXOGNDPKD                */
#define _RAC_TXOGNDPKD_TXPKDOGNDRESET_reset_latch                         0x00000001UL                                           /**< Mode reset_latch for RAC_TXOGNDPKD          */
#define RAC_TXOGNDPKD_TXPKDOGNDRESET_DEFAULT                              (_RAC_TXOGNDPKD_TXPKDOGNDRESET_DEFAULT << 6)           /**< Shifted mode DEFAULT for RAC_TXOGNDPKD      */
#define RAC_TXOGNDPKD_TXPKDOGNDRESET_latch                                (_RAC_TXOGNDPKD_TXPKDOGNDRESET_latch << 6)             /**< Shifted mode latch for RAC_TXOGNDPKD        */
#define RAC_TXOGNDPKD_TXPKDOGNDRESET_reset_latch                          (_RAC_TXOGNDPKD_TXPKDOGNDRESET_reset_latch << 6)       /**< Shifted mode reset_latch for RAC_TXOGNDPKD  */
#define RAC_TXOGNDPKD_TXPKDOGNDATTEN                                      (0x1UL << 7)                                           /**< TXPKDOGNDATTEN                              */
#define _RAC_TXOGNDPKD_TXPKDOGNDATTEN_SHIFT                               7                                                      /**< Shift value for RAC_TXPKDOGNDATTEN          */
#define _RAC_TXOGNDPKD_TXPKDOGNDATTEN_MASK                                0x80UL                                                 /**< Bit mask for RAC_TXPKDOGNDATTEN             */
#define _RAC_TXOGNDPKD_TXPKDOGNDATTEN_DEFAULT                             0x00000000UL                                           /**< Mode DEFAULT for RAC_TXOGNDPKD              */
#define _RAC_TXOGNDPKD_TXPKDOGNDATTEN_disable                             0x00000000UL                                           /**< Mode disable for RAC_TXOGNDPKD              */
#define _RAC_TXOGNDPKD_TXPKDOGNDATTEN_enable                              0x00000001UL                                           /**< Mode enable for RAC_TXOGNDPKD               */
#define RAC_TXOGNDPKD_TXPKDOGNDATTEN_DEFAULT                              (_RAC_TXOGNDPKD_TXPKDOGNDATTEN_DEFAULT << 7)           /**< Shifted mode DEFAULT for RAC_TXOGNDPKD      */
#define RAC_TXOGNDPKD_TXPKDOGNDATTEN_disable                              (_RAC_TXOGNDPKD_TXPKDOGNDATTEN_disable << 7)           /**< Shifted mode disable for RAC_TXOGNDPKD      */
#define RAC_TXOGNDPKD_TXPKDOGNDATTEN_enable                               (_RAC_TXOGNDPKD_TXPKDOGNDATTEN_enable << 7)            /**< Shifted mode enable for RAC_TXOGNDPKD       */
#define RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH                                    (0x1UL << 8)                                           /**< TXPKDOGNDCLKHIGH                            */
#define _RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_SHIFT                             8                                                      /**< Shift value for RAC_TXPKDOGNDCLKHIGH        */
#define _RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_MASK                              0x100UL                                                /**< Bit mask for RAC_TXPKDOGNDCLKHIGH           */
#define _RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_DEFAULT                           0x00000000UL                                           /**< Mode DEFAULT for RAC_TXOGNDPKD              */
#define _RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_set_clkhigh_dis                   0x00000000UL                                           /**< Mode set_clkhigh_dis for RAC_TXOGNDPKD      */
#define _RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_set_clkhigh_en                    0x00000001UL                                           /**< Mode set_clkhigh_en for RAC_TXOGNDPKD       */
#define RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_DEFAULT                            (_RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_DEFAULT << 8)         /**< Shifted mode DEFAULT for RAC_TXOGNDPKD      */
#define RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_set_clkhigh_dis                    (_RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_set_clkhigh_dis << 8) /**< Shifted mode set_clkhigh_dis for RAC_TXOGNDPKD*/
#define RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_set_clkhigh_en                     (_RAC_TXOGNDPKD_TXPKDOGNDCLKHIGH_set_clkhigh_en << 8)  /**< Shifted mode set_clkhigh_en for RAC_TXOGNDPKD*/

/* Bit fields for RAC TXOGNDPKDSTATUS */
#define _RAC_TXOGNDPKDSTATUS_RESETVALUE                                   0x00000001UL                                   /**< Default value for RAC_TXOGNDPKDSTATUS       */
#define _RAC_TXOGNDPKDSTATUS_MASK                                         0x00000003UL                                   /**< Mask for RAC_TXOGNDPKDSTATUS                */
#define RAC_TXOGNDPKDSTATUS_TXOGNDPKDN                                    (0x1UL << 0)                                   /**< TXOGNDPKDN                                  */
#define _RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_SHIFT                             0                                              /**< Shift value for RAC_TXOGNDPKDN              */
#define _RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_MASK                              0x1UL                                          /**< Bit mask for RAC_TXOGNDPKDN                 */
#define _RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_DEFAULT                           0x00000001UL                                   /**< Mode DEFAULT for RAC_TXOGNDPKDSTATUS        */
#define _RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_triped                            0x00000000UL                                   /**< Mode triped for RAC_TXOGNDPKDSTATUS         */
#define _RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_no_trip                           0x00000001UL                                   /**< Mode no_trip for RAC_TXOGNDPKDSTATUS        */
#define RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_DEFAULT                            (_RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_TXOGNDPKDSTATUS*/
#define RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_triped                             (_RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_triped << 0)  /**< Shifted mode triped for RAC_TXOGNDPKDSTATUS */
#define RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_no_trip                            (_RAC_TXOGNDPKDSTATUS_TXOGNDPKDN_no_trip << 0) /**< Shifted mode no_trip for RAC_TXOGNDPKDSTATUS*/
#define RAC_TXOGNDPKDSTATUS_TXOGNDPKDP                                    (0x1UL << 1)                                   /**< TXOGNDPKDP                                  */
#define _RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_SHIFT                             1                                              /**< Shift value for RAC_TXOGNDPKDP              */
#define _RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_MASK                              0x2UL                                          /**< Bit mask for RAC_TXOGNDPKDP                 */
#define _RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_DEFAULT                           0x00000000UL                                   /**< Mode DEFAULT for RAC_TXOGNDPKDSTATUS        */
#define _RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_no_trip                           0x00000000UL                                   /**< Mode no_trip for RAC_TXOGNDPKDSTATUS        */
#define _RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_tripped                           0x00000001UL                                   /**< Mode tripped for RAC_TXOGNDPKDSTATUS        */
#define RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_DEFAULT                            (_RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_DEFAULT << 1) /**< Shifted mode DEFAULT for RAC_TXOGNDPKDSTATUS*/
#define RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_no_trip                            (_RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_no_trip << 1) /**< Shifted mode no_trip for RAC_TXOGNDPKDSTATUS*/
#define RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_tripped                            (_RAC_TXOGNDPKDSTATUS_TXOGNDPKDP_tripped << 1) /**< Shifted mode tripped for RAC_TXOGNDPKDSTATUS*/

/* Bit fields for RAC GPPLLCLKRETIMECTRL */
#define _RAC_GPPLLCLKRETIMECTRL_RESETVALUE                                0x00000000UL                                                          /**< Default value for RAC_GPPLLCLKRETIMECTRL    */
#define _RAC_GPPLLCLKRETIMECTRL_MASK                                      0x00000777UL                                                          /**< Mask for RAC_GPPLLCLKRETIMECTRL             */
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME                     (0x1UL << 0)                                                          /**< GPPLLCLKRETIMEENRETIME                      */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_SHIFT              0                                                                     /**< Shift value for RAC_GPPLLCLKRETIMEENRETIME  */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_MASK               0x1UL                                                                 /**< Bit mask for RAC_GPPLLCLKRETIMEENRETIME     */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_DEFAULT            0x00000000UL                                                          /**< Mode DEFAULT for RAC_GPPLLCLKRETIMECTRL     */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_disable            0x00000000UL                                                          /**< Mode disable for RAC_GPPLLCLKRETIMECTRL     */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_enable             0x00000001UL                                                          /**< Mode enable for RAC_GPPLLCLKRETIMECTRL      */
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_DEFAULT             (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_GPPLLCLKRETIMECTRL*/
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_disable             (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_disable << 0)         /**< Shifted mode disable for RAC_GPPLLCLKRETIMECTRL*/
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_enable              (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEENRETIME_enable << 0)          /**< Shifted mode enable for RAC_GPPLLCLKRETIMECTRL*/
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME                    (0x1UL << 1)                                                          /**< GPPLLCLKRETIMEDISRETIME                     */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_SHIFT             1                                                                     /**< Shift value for RAC_GPPLLCLKRETIMEDISRETIME */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_MASK              0x2UL                                                                 /**< Bit mask for RAC_GPPLLCLKRETIMEDISRETIME    */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_DEFAULT           0x00000000UL                                                          /**< Mode DEFAULT for RAC_GPPLLCLKRETIMECTRL     */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_enable_retime     0x00000000UL                                                          /**< Mode enable_retime for RAC_GPPLLCLKRETIMECTRL*/
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_disable_retime    0x00000001UL                                                          /**< Mode disable_retime for RAC_GPPLLCLKRETIMECTRL*/
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_DEFAULT            (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_DEFAULT << 1)        /**< Shifted mode DEFAULT for RAC_GPPLLCLKRETIMECTRL*/
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_enable_retime      (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_enable_retime << 1)  /**< Shifted mode enable_retime for RAC_GPPLLCLKRETIMECTRL*/
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_disable_retime     (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMEDISRETIME_disable_retime << 1) /**< Shifted mode disable_retime for RAC_GPPLLCLKRETIMECTRL*/
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN                       (0x1UL << 2)                                                          /**< GPPLLCLKRETIMERESETN                        */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_SHIFT                2                                                                     /**< Shift value for RAC_GPPLLCLKRETIMERESETN    */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_MASK                 0x4UL                                                                 /**< Bit mask for RAC_GPPLLCLKRETIMERESETN       */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_DEFAULT              0x00000000UL                                                          /**< Mode DEFAULT for RAC_GPPLLCLKRETIMECTRL     */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_disable_output3      0x00000000UL                                                          /**< Mode disable_output3 for RAC_GPPLLCLKRETIMECTRL*/
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_enable_output3       0x00000001UL                                                          /**< Mode enable_output3 for RAC_GPPLLCLKRETIMECTRL*/
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_DEFAULT               (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_DEFAULT << 2)           /**< Shifted mode DEFAULT for RAC_GPPLLCLKRETIMECTRL*/
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_disable_output3       (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_disable_output3 << 2)   /**< Shifted mode disable_output3 for RAC_GPPLLCLKRETIMECTRL*/
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_enable_output3        (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMERESETN_enable_output3 << 2)    /**< Shifted mode enable_output3 for RAC_GPPLLCLKRETIMECTRL*/
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMELIMITH_SHIFT                4                                                                     /**< Shift value for RAC_GPPLLCLKRETIMELIMITH    */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMELIMITH_MASK                 0x70UL                                                                /**< Bit mask for RAC_GPPLLCLKRETIMELIMITH       */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMELIMITH_DEFAULT              0x00000000UL                                                          /**< Mode DEFAULT for RAC_GPPLLCLKRETIMECTRL     */
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMELIMITH_DEFAULT               (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMELIMITH_DEFAULT << 4)           /**< Shifted mode DEFAULT for RAC_GPPLLCLKRETIMECTRL*/
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMELIMITL_SHIFT                8                                                                     /**< Shift value for RAC_GPPLLCLKRETIMELIMITL    */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMELIMITL_MASK                 0x700UL                                                               /**< Bit mask for RAC_GPPLLCLKRETIMELIMITL       */
#define _RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMELIMITL_DEFAULT              0x00000000UL                                                          /**< Mode DEFAULT for RAC_GPPLLCLKRETIMECTRL     */
#define RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMELIMITL_DEFAULT               (_RAC_GPPLLCLKRETIMECTRL_GPPLLCLKRETIMELIMITL_DEFAULT << 8)           /**< Shifted mode DEFAULT for RAC_GPPLLCLKRETIMECTRL*/

/* Bit fields for RAC GPPLLCLKRETIMESTATUS */
#define _RAC_GPPLLCLKRETIMESTATUS_RESETVALUE                              0x00000000UL                                                          /**< Default value for RAC_GPPLLCLKRETIMESTATUS  */
#define _RAC_GPPLLCLKRETIMESTATUS_MASK                                    0x00000003UL                                                          /**< Mask for RAC_GPPLLCLKRETIMESTATUS           */
#define RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL                     (0x1UL << 0)                                                          /**< GPPLLCLKRETIMECLKSEL                        */
#define _RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_SHIFT              0                                                                     /**< Shift value for RAC_GPPLLCLKRETIMECLKSEL    */
#define _RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_MASK               0x1UL                                                                 /**< Bit mask for RAC_GPPLLCLKRETIMECLKSEL       */
#define _RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_DEFAULT            0x00000000UL                                                          /**< Mode DEFAULT for RAC_GPPLLCLKRETIMESTATUS   */
#define _RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_use_raw_clk        0x00000000UL                                                          /**< Mode use_raw_clk for RAC_GPPLLCLKRETIMESTATUS*/
#define _RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_use_retimed_clk    0x00000001UL                                                          /**< Mode use_retimed_clk for RAC_GPPLLCLKRETIMESTATUS*/
#define RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_DEFAULT             (_RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_GPPLLCLKRETIMESTATUS*/
#define RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_use_raw_clk         (_RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_use_raw_clk << 0)     /**< Shifted mode use_raw_clk for RAC_GPPLLCLKRETIMESTATUS*/
#define RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_use_retimed_clk     (_RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMECLKSEL_use_retimed_clk << 0) /**< Shifted mode use_retimed_clk for RAC_GPPLLCLKRETIMESTATUS*/
#define RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO                   (0x1UL << 1)                                                          /**< GPPLLCLKRETIMERESETNLO                      */
#define _RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_SHIFT            1                                                                     /**< Shift value for RAC_GPPLLCLKRETIMERESETNLO  */
#define _RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_MASK             0x2UL                                                                 /**< Bit mask for RAC_GPPLLCLKRETIMERESETNLO     */
#define _RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_DEFAULT          0x00000000UL                                                          /**< Mode DEFAULT for RAC_GPPLLCLKRETIMESTATUS   */
#define _RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_lo               0x00000000UL                                                          /**< Mode lo for RAC_GPPLLCLKRETIMESTATUS        */
#define _RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_hi               0x00000001UL                                                          /**< Mode hi for RAC_GPPLLCLKRETIMESTATUS        */
#define RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_DEFAULT           (_RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_DEFAULT << 1)       /**< Shifted mode DEFAULT for RAC_GPPLLCLKRETIMESTATUS*/
#define RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_lo                (_RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_lo << 1)            /**< Shifted mode lo for RAC_GPPLLCLKRETIMESTATUS*/
#define RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_hi                (_RAC_GPPLLCLKRETIMESTATUS_GPPLLCLKRETIMERESETNLO_hi << 1)            /**< Shifted mode hi for RAC_GPPLLCLKRETIMESTATUS*/

/* Bit fields for RAC PATRIM6 */
#define _RAC_PATRIM6_RESETVALUE                                           0x000451A0UL                                   /**< Default value for RAC_PATRIM6               */
#define _RAC_PATRIM6_MASK                                                 0xFF3FF3FEUL                                   /**< Mask for RAC_PATRIM6                        */
#define _RAC_PATRIM6_TXTRIMBBDIGREGIOUT_SHIFT                             1                                              /**< Shift value for RAC_TXTRIMBBDIGREGIOUT      */
#define _RAC_PATRIM6_TXTRIMBBDIGREGIOUT_MASK                              0x6UL                                          /**< Bit mask for RAC_TXTRIMBBDIGREGIOUT         */
#define _RAC_PATRIM6_TXTRIMBBDIGREGIOUT_DEFAULT                           0x00000000UL                                   /**< Mode DEFAULT for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i050u                             0x00000000UL                                   /**< Mode i050u for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i100u                             0x00000001UL                                   /**< Mode i100u for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i150u                             0x00000002UL                                   /**< Mode i150u for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i200u                             0x00000003UL                                   /**< Mode i200u for RAC_PATRIM6                  */
#define RAC_PATRIM6_TXTRIMBBDIGREGIOUT_DEFAULT                            (_RAC_PATRIM6_TXTRIMBBDIGREGIOUT_DEFAULT << 1) /**< Shifted mode DEFAULT for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i050u                              (_RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i050u << 1)   /**< Shifted mode i050u for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i100u                              (_RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i100u << 1)   /**< Shifted mode i100u for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i150u                              (_RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i150u << 1)   /**< Shifted mode i150u for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i200u                              (_RAC_PATRIM6_TXTRIMBBDIGREGIOUT_i200u << 1)   /**< Shifted mode i200u for RAC_PATRIM6          */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_SHIFT                                3                                              /**< Shift value for RAC_TXTRIMBBREGVREF         */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_MASK                                 0x38UL                                         /**< Bit mask for RAC_TXTRIMBBREGVREF            */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_DEFAULT                              0x00000004UL                                   /**< Mode DEFAULT for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_v_900m                               0x00000000UL                                   /**< Mode v_900m for RAC_PATRIM6                 */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_v_912p5m                             0x00000001UL                                   /**< Mode v_912p5m for RAC_PATRIM6               */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_v_925m                               0x00000002UL                                   /**< Mode v_925m for RAC_PATRIM6                 */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_v_937p5m                             0x00000003UL                                   /**< Mode v_937p5m for RAC_PATRIM6               */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_v_950m                               0x00000004UL                                   /**< Mode v_950m for RAC_PATRIM6                 */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_v_962p5m                             0x00000005UL                                   /**< Mode v_962p5m for RAC_PATRIM6               */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_v_975m                               0x00000006UL                                   /**< Mode v_975m for RAC_PATRIM6                 */
#define _RAC_PATRIM6_TXTRIMBBREGVREF_v_987p5m                             0x00000007UL                                   /**< Mode v_987p5m for RAC_PATRIM6               */
#define RAC_PATRIM6_TXTRIMBBREGVREF_DEFAULT                               (_RAC_PATRIM6_TXTRIMBBREGVREF_DEFAULT << 3)    /**< Shifted mode DEFAULT for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBBREGVREF_v_900m                                (_RAC_PATRIM6_TXTRIMBBREGVREF_v_900m << 3)     /**< Shifted mode v_900m for RAC_PATRIM6         */
#define RAC_PATRIM6_TXTRIMBBREGVREF_v_912p5m                              (_RAC_PATRIM6_TXTRIMBBREGVREF_v_912p5m << 3)   /**< Shifted mode v_912p5m for RAC_PATRIM6       */
#define RAC_PATRIM6_TXTRIMBBREGVREF_v_925m                                (_RAC_PATRIM6_TXTRIMBBREGVREF_v_925m << 3)     /**< Shifted mode v_925m for RAC_PATRIM6         */
#define RAC_PATRIM6_TXTRIMBBREGVREF_v_937p5m                              (_RAC_PATRIM6_TXTRIMBBREGVREF_v_937p5m << 3)   /**< Shifted mode v_937p5m for RAC_PATRIM6       */
#define RAC_PATRIM6_TXTRIMBBREGVREF_v_950m                                (_RAC_PATRIM6_TXTRIMBBREGVREF_v_950m << 3)     /**< Shifted mode v_950m for RAC_PATRIM6         */
#define RAC_PATRIM6_TXTRIMBBREGVREF_v_962p5m                              (_RAC_PATRIM6_TXTRIMBBREGVREF_v_962p5m << 3)   /**< Shifted mode v_962p5m for RAC_PATRIM6       */
#define RAC_PATRIM6_TXTRIMBBREGVREF_v_975m                                (_RAC_PATRIM6_TXTRIMBBREGVREF_v_975m << 3)     /**< Shifted mode v_975m for RAC_PATRIM6         */
#define RAC_PATRIM6_TXTRIMBBREGVREF_v_987p5m                              (_RAC_PATRIM6_TXTRIMBBREGVREF_v_987p5m << 3)   /**< Shifted mode v_987p5m for RAC_PATRIM6       */
#define _RAC_PATRIM6_TXTRIMBBREGFB_SHIFT                                  6                                              /**< Shift value for RAC_TXTRIMBBREGFB           */
#define _RAC_PATRIM6_TXTRIMBBREGFB_MASK                                   0x3C0UL                                        /**< Bit mask for RAC_TXTRIMBBREGFB              */
#define _RAC_PATRIM6_TXTRIMBBREGFB_DEFAULT                                0x00000006UL                                   /**< Mode DEFAULT for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p97                                  0x00000000UL                                   /**< Mode v1p97 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p89                                  0x00000001UL                                   /**< Mode v1p89 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p81                                  0x00000002UL                                   /**< Mode v1p81 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p72                                  0x00000003UL                                   /**< Mode v1p72 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p65                                  0x00000004UL                                   /**< Mode v1p65 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p58                                  0x00000005UL                                   /**< Mode v1p58 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p52                                  0x00000006UL                                   /**< Mode v1p52 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p46                                  0x00000007UL                                   /**< Mode v1p46 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p41                                  0x00000008UL                                   /**< Mode v1p41 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p36                                  0x00000009UL                                   /**< Mode v1p36 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p31                                  0x0000000AUL                                   /**< Mode v1p31 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p27                                  0x0000000BUL                                   /**< Mode v1p27 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p22                                  0x0000000CUL                                   /**< Mode v1p22 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p19                                  0x0000000DUL                                   /**< Mode v1p19 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p15                                  0x0000000EUL                                   /**< Mode v1p15 for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMBBREGFB_v1p11                                  0x0000000FUL                                   /**< Mode v1p11 for RAC_PATRIM6                  */
#define RAC_PATRIM6_TXTRIMBBREGFB_DEFAULT                                 (_RAC_PATRIM6_TXTRIMBBREGFB_DEFAULT << 6)      /**< Shifted mode DEFAULT for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p97                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p97 << 6)        /**< Shifted mode v1p97 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p89                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p89 << 6)        /**< Shifted mode v1p89 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p81                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p81 << 6)        /**< Shifted mode v1p81 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p72                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p72 << 6)        /**< Shifted mode v1p72 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p65                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p65 << 6)        /**< Shifted mode v1p65 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p58                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p58 << 6)        /**< Shifted mode v1p58 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p52                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p52 << 6)        /**< Shifted mode v1p52 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p46                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p46 << 6)        /**< Shifted mode v1p46 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p41                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p41 << 6)        /**< Shifted mode v1p41 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p36                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p36 << 6)        /**< Shifted mode v1p36 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p31                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p31 << 6)        /**< Shifted mode v1p31 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p27                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p27 << 6)        /**< Shifted mode v1p27 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p22                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p22 << 6)        /**< Shifted mode v1p22 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p19                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p19 << 6)        /**< Shifted mode v1p19 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p15                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p15 << 6)        /**< Shifted mode v1p15 for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMBBREGFB_v1p11                                   (_RAC_PATRIM6_TXTRIMBBREGFB_v1p11 << 6)        /**< Shifted mode v1p11 for RAC_PATRIM6          */
#define _RAC_PATRIM6_TXTRIMFILVCOM_SHIFT                                  12                                             /**< Shift value for RAC_TXTRIMFILVCOM           */
#define _RAC_PATRIM6_TXTRIMFILVCOM_MASK                                   0xF000UL                                       /**< Bit mask for RAC_TXTRIMFILVCOM              */
#define _RAC_PATRIM6_TXTRIMFILVCOM_DEFAULT                                0x00000005UL                                   /**< Mode DEFAULT for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v300m                                  0x00000000UL                                   /**< Mode v300m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v333m                                  0x00000001UL                                   /**< Mode v333m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v367m                                  0x00000002UL                                   /**< Mode v367m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v400m                                  0x00000003UL                                   /**< Mode v400m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v433m                                  0x00000004UL                                   /**< Mode v433m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v466m                                  0x00000005UL                                   /**< Mode v466m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v500m                                  0x00000006UL                                   /**< Mode v500m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v533m                                  0x00000007UL                                   /**< Mode v533m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v566m                                  0x00000008UL                                   /**< Mode v566m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v599m                                  0x00000009UL                                   /**< Mode v599m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v631m                                  0x0000000AUL                                   /**< Mode v631m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v664m                                  0x0000000BUL                                   /**< Mode v664m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v696m                                  0x0000000CUL                                   /**< Mode v696m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v728m                                  0x0000000DUL                                   /**< Mode v728m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v760m                                  0x0000000EUL                                   /**< Mode v760m for RAC_PATRIM6                  */
#define _RAC_PATRIM6_TXTRIMFILVCOM_v790m                                  0x0000000FUL                                   /**< Mode v790m for RAC_PATRIM6                  */
#define RAC_PATRIM6_TXTRIMFILVCOM_DEFAULT                                 (_RAC_PATRIM6_TXTRIMFILVCOM_DEFAULT << 12)     /**< Shifted mode DEFAULT for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMFILVCOM_v300m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v300m << 12)       /**< Shifted mode v300m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v333m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v333m << 12)       /**< Shifted mode v333m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v367m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v367m << 12)       /**< Shifted mode v367m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v400m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v400m << 12)       /**< Shifted mode v400m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v433m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v433m << 12)       /**< Shifted mode v433m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v466m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v466m << 12)       /**< Shifted mode v466m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v500m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v500m << 12)       /**< Shifted mode v500m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v533m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v533m << 12)       /**< Shifted mode v533m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v566m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v566m << 12)       /**< Shifted mode v566m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v599m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v599m << 12)       /**< Shifted mode v599m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v631m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v631m << 12)       /**< Shifted mode v631m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v664m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v664m << 12)       /**< Shifted mode v664m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v696m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v696m << 12)       /**< Shifted mode v696m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v728m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v728m << 12)       /**< Shifted mode v728m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v760m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v760m << 12)       /**< Shifted mode v760m for RAC_PATRIM6          */
#define RAC_PATRIM6_TXTRIMFILVCOM_v790m                                   (_RAC_PATRIM6_TXTRIMFILVCOM_v790m << 12)       /**< Shifted mode v790m for RAC_PATRIM6          */
#define _RAC_PATRIM6_TXTRIMFILCAP_SHIFT                                   16                                             /**< Shift value for RAC_TXTRIMFILCAP            */
#define _RAC_PATRIM6_TXTRIMFILCAP_MASK                                    0x30000UL                                      /**< Bit mask for RAC_TXTRIMFILCAP               */
#define _RAC_PATRIM6_TXTRIMFILCAP_DEFAULT                                 0x00000000UL                                   /**< Mode DEFAULT for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMFILCAP_C_1                                     0x00000000UL                                   /**< Mode C_1 for RAC_PATRIM6                    */
#define _RAC_PATRIM6_TXTRIMFILCAP_C_2                                     0x00000001UL                                   /**< Mode C_2 for RAC_PATRIM6                    */
#define _RAC_PATRIM6_TXTRIMFILCAP_C_3                                     0x00000002UL                                   /**< Mode C_3 for RAC_PATRIM6                    */
#define _RAC_PATRIM6_TXTRIMFILCAP_C_4                                     0x00000003UL                                   /**< Mode C_4 for RAC_PATRIM6                    */
#define RAC_PATRIM6_TXTRIMFILCAP_DEFAULT                                  (_RAC_PATRIM6_TXTRIMFILCAP_DEFAULT << 16)      /**< Shifted mode DEFAULT for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMFILCAP_C_1                                      (_RAC_PATRIM6_TXTRIMFILCAP_C_1 << 16)          /**< Shifted mode C_1 for RAC_PATRIM6            */
#define RAC_PATRIM6_TXTRIMFILCAP_C_2                                      (_RAC_PATRIM6_TXTRIMFILCAP_C_2 << 16)          /**< Shifted mode C_2 for RAC_PATRIM6            */
#define RAC_PATRIM6_TXTRIMFILCAP_C_3                                      (_RAC_PATRIM6_TXTRIMFILCAP_C_3 << 16)          /**< Shifted mode C_3 for RAC_PATRIM6            */
#define RAC_PATRIM6_TXTRIMFILCAP_C_4                                      (_RAC_PATRIM6_TXTRIMFILCAP_C_4 << 16)          /**< Shifted mode C_4 for RAC_PATRIM6            */
#define _RAC_PATRIM6_TXTRIMFILGAIN_SHIFT                                  18                                             /**< Shift value for RAC_TXTRIMFILGAIN           */
#define _RAC_PATRIM6_TXTRIMFILGAIN_MASK                                   0xC0000UL                                      /**< Bit mask for RAC_TXTRIMFILGAIN              */
#define _RAC_PATRIM6_TXTRIMFILGAIN_DEFAULT                                0x00000001UL                                   /**< Mode DEFAULT for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMFILGAIN_minus9p5db                             0x00000000UL                                   /**< Mode minus9p5db for RAC_PATRIM6             */
#define _RAC_PATRIM6_TXTRIMFILGAIN_minus6db                               0x00000001UL                                   /**< Mode minus6db for RAC_PATRIM6               */
#define _RAC_PATRIM6_TXTRIMFILGAIN_minus2p5db                             0x00000002UL                                   /**< Mode minus2p5db for RAC_PATRIM6             */
#define _RAC_PATRIM6_TXTRIMFILGAIN_plus1db                                0x00000003UL                                   /**< Mode plus1db for RAC_PATRIM6                */
#define RAC_PATRIM6_TXTRIMFILGAIN_DEFAULT                                 (_RAC_PATRIM6_TXTRIMFILGAIN_DEFAULT << 18)     /**< Shifted mode DEFAULT for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMFILGAIN_minus9p5db                              (_RAC_PATRIM6_TXTRIMFILGAIN_minus9p5db << 18)  /**< Shifted mode minus9p5db for RAC_PATRIM6     */
#define RAC_PATRIM6_TXTRIMFILGAIN_minus6db                                (_RAC_PATRIM6_TXTRIMFILGAIN_minus6db << 18)    /**< Shifted mode minus6db for RAC_PATRIM6       */
#define RAC_PATRIM6_TXTRIMFILGAIN_minus2p5db                              (_RAC_PATRIM6_TXTRIMFILGAIN_minus2p5db << 18)  /**< Shifted mode minus2p5db for RAC_PATRIM6     */
#define RAC_PATRIM6_TXTRIMFILGAIN_plus1db                                 (_RAC_PATRIM6_TXTRIMFILGAIN_plus1db << 18)     /**< Shifted mode plus1db for RAC_PATRIM6        */
#define _RAC_PATRIM6_TXTRIMFILRES_SHIFT                                   20                                             /**< Shift value for RAC_TXTRIMFILRES            */
#define _RAC_PATRIM6_TXTRIMFILRES_MASK                                    0x300000UL                                     /**< Bit mask for RAC_TXTRIMFILRES               */
#define _RAC_PATRIM6_TXTRIMFILRES_DEFAULT                                 0x00000000UL                                   /**< Mode DEFAULT for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMFILRES_R_0                                     0x00000000UL                                   /**< Mode R_0 for RAC_PATRIM6                    */
#define _RAC_PATRIM6_TXTRIMFILRES_R_1                                     0x00000001UL                                   /**< Mode R_1 for RAC_PATRIM6                    */
#define _RAC_PATRIM6_TXTRIMFILRES_R_2                                     0x00000002UL                                   /**< Mode R_2 for RAC_PATRIM6                    */
#define _RAC_PATRIM6_TXTRIMFILRES_R_3                                     0x00000003UL                                   /**< Mode R_3 for RAC_PATRIM6                    */
#define RAC_PATRIM6_TXTRIMFILRES_DEFAULT                                  (_RAC_PATRIM6_TXTRIMFILRES_DEFAULT << 20)      /**< Shifted mode DEFAULT for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMFILRES_R_0                                      (_RAC_PATRIM6_TXTRIMFILRES_R_0 << 20)          /**< Shifted mode R_0 for RAC_PATRIM6            */
#define RAC_PATRIM6_TXTRIMFILRES_R_1                                      (_RAC_PATRIM6_TXTRIMFILRES_R_1 << 20)          /**< Shifted mode R_1 for RAC_PATRIM6            */
#define RAC_PATRIM6_TXTRIMFILRES_R_2                                      (_RAC_PATRIM6_TXTRIMFILRES_R_2 << 20)          /**< Shifted mode R_2 for RAC_PATRIM6            */
#define RAC_PATRIM6_TXTRIMFILRES_R_3                                      (_RAC_PATRIM6_TXTRIMFILRES_R_3 << 20)          /**< Shifted mode R_3 for RAC_PATRIM6            */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_SHIFT                                 24                                             /**< Shift value for RAC_TXTRIMBIASNMAX          */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_MASK                                  0xF000000UL                                    /**< Bit mask for RAC_TXTRIMBIASNMAX             */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_DEFAULT                               0x00000000UL                                   /**< Mode DEFAULT for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_0u                                0x00000000UL                                   /**< Mode add_0u for RAC_PATRIM6                 */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_2p5u                              0x00000001UL                                   /**< Mode add_2p5u for RAC_PATRIM6               */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_5u                                0x00000002UL                                   /**< Mode add_5u for RAC_PATRIM6                 */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_7p5u                              0x00000003UL                                   /**< Mode add_7p5u for RAC_PATRIM6               */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_10u                               0x00000004UL                                   /**< Mode add_10u for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_12p5u                             0x00000005UL                                   /**< Mode add_12p5u for RAC_PATRIM6              */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_15p                               0x00000006UL                                   /**< Mode add_15p for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_17p5u                             0x00000007UL                                   /**< Mode add_17p5u for RAC_PATRIM6              */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_20u                               0x00000008UL                                   /**< Mode add_20u for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_22p5u                             0x00000009UL                                   /**< Mode add_22p5u for RAC_PATRIM6              */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_25u                               0x0000000AUL                                   /**< Mode add_25u for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_27p5u                             0x0000000BUL                                   /**< Mode add_27p5u for RAC_PATRIM6              */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_30u                               0x0000000CUL                                   /**< Mode add_30u for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_32p5u                             0x0000000DUL                                   /**< Mode add_32p5u for RAC_PATRIM6              */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_35u                               0x0000000EUL                                   /**< Mode add_35u for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASNMAX_add_37p5u                             0x0000000FUL                                   /**< Mode add_37p5u for RAC_PATRIM6              */
#define RAC_PATRIM6_TXTRIMBIASNMAX_DEFAULT                                (_RAC_PATRIM6_TXTRIMBIASNMAX_DEFAULT << 24)    /**< Shifted mode DEFAULT for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_0u                                 (_RAC_PATRIM6_TXTRIMBIASNMAX_add_0u << 24)     /**< Shifted mode add_0u for RAC_PATRIM6         */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_2p5u                               (_RAC_PATRIM6_TXTRIMBIASNMAX_add_2p5u << 24)   /**< Shifted mode add_2p5u for RAC_PATRIM6       */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_5u                                 (_RAC_PATRIM6_TXTRIMBIASNMAX_add_5u << 24)     /**< Shifted mode add_5u for RAC_PATRIM6         */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_7p5u                               (_RAC_PATRIM6_TXTRIMBIASNMAX_add_7p5u << 24)   /**< Shifted mode add_7p5u for RAC_PATRIM6       */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_10u                                (_RAC_PATRIM6_TXTRIMBIASNMAX_add_10u << 24)    /**< Shifted mode add_10u for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_12p5u                              (_RAC_PATRIM6_TXTRIMBIASNMAX_add_12p5u << 24)  /**< Shifted mode add_12p5u for RAC_PATRIM6      */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_15p                                (_RAC_PATRIM6_TXTRIMBIASNMAX_add_15p << 24)    /**< Shifted mode add_15p for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_17p5u                              (_RAC_PATRIM6_TXTRIMBIASNMAX_add_17p5u << 24)  /**< Shifted mode add_17p5u for RAC_PATRIM6      */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_20u                                (_RAC_PATRIM6_TXTRIMBIASNMAX_add_20u << 24)    /**< Shifted mode add_20u for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_22p5u                              (_RAC_PATRIM6_TXTRIMBIASNMAX_add_22p5u << 24)  /**< Shifted mode add_22p5u for RAC_PATRIM6      */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_25u                                (_RAC_PATRIM6_TXTRIMBIASNMAX_add_25u << 24)    /**< Shifted mode add_25u for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_27p5u                              (_RAC_PATRIM6_TXTRIMBIASNMAX_add_27p5u << 24)  /**< Shifted mode add_27p5u for RAC_PATRIM6      */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_30u                                (_RAC_PATRIM6_TXTRIMBIASNMAX_add_30u << 24)    /**< Shifted mode add_30u for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_32p5u                              (_RAC_PATRIM6_TXTRIMBIASNMAX_add_32p5u << 24)  /**< Shifted mode add_32p5u for RAC_PATRIM6      */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_35u                                (_RAC_PATRIM6_TXTRIMBIASNMAX_add_35u << 24)    /**< Shifted mode add_35u for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASNMAX_add_37p5u                              (_RAC_PATRIM6_TXTRIMBIASNMAX_add_37p5u << 24)  /**< Shifted mode add_37p5u for RAC_PATRIM6      */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_SHIFT                                 28                                             /**< Shift value for RAC_TXTRIMBIASPMAX          */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_MASK                                  0xF0000000UL                                   /**< Bit mask for RAC_TXTRIMBIASPMAX             */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_DEFAULT                               0x00000000UL                                   /**< Mode DEFAULT for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_0u                                0x00000000UL                                   /**< Mode add_0u for RAC_PATRIM6                 */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_2p5u                              0x00000001UL                                   /**< Mode add_2p5u for RAC_PATRIM6               */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_5u                                0x00000002UL                                   /**< Mode add_5u for RAC_PATRIM6                 */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_7p5u                              0x00000003UL                                   /**< Mode add_7p5u for RAC_PATRIM6               */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_10u                               0x00000004UL                                   /**< Mode add_10u for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_12p5u                             0x00000005UL                                   /**< Mode add_12p5u for RAC_PATRIM6              */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_15p                               0x00000006UL                                   /**< Mode add_15p for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_17p5u                             0x00000007UL                                   /**< Mode add_17p5u for RAC_PATRIM6              */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_20u                               0x00000008UL                                   /**< Mode add_20u for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_22p5u                             0x00000009UL                                   /**< Mode add_22p5u for RAC_PATRIM6              */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_25u                               0x0000000AUL                                   /**< Mode add_25u for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_27p5u                             0x0000000BUL                                   /**< Mode add_27p5u for RAC_PATRIM6              */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_30u                               0x0000000CUL                                   /**< Mode add_30u for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_32p5u                             0x0000000DUL                                   /**< Mode add_32p5u for RAC_PATRIM6              */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_35u                               0x0000000EUL                                   /**< Mode add_35u for RAC_PATRIM6                */
#define _RAC_PATRIM6_TXTRIMBIASPMAX_add_37p5u                             0x0000000FUL                                   /**< Mode add_37p5u for RAC_PATRIM6              */
#define RAC_PATRIM6_TXTRIMBIASPMAX_DEFAULT                                (_RAC_PATRIM6_TXTRIMBIASPMAX_DEFAULT << 28)    /**< Shifted mode DEFAULT for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_0u                                 (_RAC_PATRIM6_TXTRIMBIASPMAX_add_0u << 28)     /**< Shifted mode add_0u for RAC_PATRIM6         */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_2p5u                               (_RAC_PATRIM6_TXTRIMBIASPMAX_add_2p5u << 28)   /**< Shifted mode add_2p5u for RAC_PATRIM6       */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_5u                                 (_RAC_PATRIM6_TXTRIMBIASPMAX_add_5u << 28)     /**< Shifted mode add_5u for RAC_PATRIM6         */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_7p5u                               (_RAC_PATRIM6_TXTRIMBIASPMAX_add_7p5u << 28)   /**< Shifted mode add_7p5u for RAC_PATRIM6       */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_10u                                (_RAC_PATRIM6_TXTRIMBIASPMAX_add_10u << 28)    /**< Shifted mode add_10u for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_12p5u                              (_RAC_PATRIM6_TXTRIMBIASPMAX_add_12p5u << 28)  /**< Shifted mode add_12p5u for RAC_PATRIM6      */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_15p                                (_RAC_PATRIM6_TXTRIMBIASPMAX_add_15p << 28)    /**< Shifted mode add_15p for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_17p5u                              (_RAC_PATRIM6_TXTRIMBIASPMAX_add_17p5u << 28)  /**< Shifted mode add_17p5u for RAC_PATRIM6      */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_20u                                (_RAC_PATRIM6_TXTRIMBIASPMAX_add_20u << 28)    /**< Shifted mode add_20u for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_22p5u                              (_RAC_PATRIM6_TXTRIMBIASPMAX_add_22p5u << 28)  /**< Shifted mode add_22p5u for RAC_PATRIM6      */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_25u                                (_RAC_PATRIM6_TXTRIMBIASPMAX_add_25u << 28)    /**< Shifted mode add_25u for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_27p5u                              (_RAC_PATRIM6_TXTRIMBIASPMAX_add_27p5u << 28)  /**< Shifted mode add_27p5u for RAC_PATRIM6      */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_30u                                (_RAC_PATRIM6_TXTRIMBIASPMAX_add_30u << 28)    /**< Shifted mode add_30u for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_32p5u                              (_RAC_PATRIM6_TXTRIMBIASPMAX_add_32p5u << 28)  /**< Shifted mode add_32p5u for RAC_PATRIM6      */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_35u                                (_RAC_PATRIM6_TXTRIMBIASPMAX_add_35u << 28)    /**< Shifted mode add_35u for RAC_PATRIM6        */
#define RAC_PATRIM6_TXTRIMBIASPMAX_add_37p5u                              (_RAC_PATRIM6_TXTRIMBIASPMAX_add_37p5u << 28)  /**< Shifted mode add_37p5u for RAC_PATRIM6      */

/* Bit fields for RAC PATRIM7 */
#define _RAC_PATRIM7_RESETVALUE                                           0x029C8015UL                                     /**< Default value for RAC_PATRIM7               */
#define _RAC_PATRIM7_MASK                                                 0x03FFC73FUL                                     /**< Mask for RAC_PATRIM7                        */
#define _RAC_PATRIM7_TXTRIMMIXGMBIAS_SHIFT                                0                                                /**< Shift value for RAC_TXTRIMMIXGMBIAS         */
#define _RAC_PATRIM7_TXTRIMMIXGMBIAS_MASK                                 0x3UL                                            /**< Bit mask for RAC_TXTRIMMIXGMBIAS            */
#define _RAC_PATRIM7_TXTRIMMIXGMBIAS_DEFAULT                              0x00000001UL                                     /**< Mode DEFAULT for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXGMBIAS_gm500uA                              0x00000000UL                                     /**< Mode gm500uA for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXGMBIAS_gm700uA                              0x00000001UL                                     /**< Mode gm700uA for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXGMBIAS_unused_1                             0x00000002UL                                     /**< Mode unused_1 for RAC_PATRIM7               */
#define _RAC_PATRIM7_TXTRIMMIXGMBIAS_unused_2                             0x00000003UL                                     /**< Mode unused_2 for RAC_PATRIM7               */
#define RAC_PATRIM7_TXTRIMMIXGMBIAS_DEFAULT                               (_RAC_PATRIM7_TXTRIMMIXGMBIAS_DEFAULT << 0)      /**< Shifted mode DEFAULT for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXGMBIAS_gm500uA                               (_RAC_PATRIM7_TXTRIMMIXGMBIAS_gm500uA << 0)      /**< Shifted mode gm500uA for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXGMBIAS_gm700uA                               (_RAC_PATRIM7_TXTRIMMIXGMBIAS_gm700uA << 0)      /**< Shifted mode gm700uA for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXGMBIAS_unused_1                              (_RAC_PATRIM7_TXTRIMMIXGMBIAS_unused_1 << 0)     /**< Shifted mode unused_1 for RAC_PATRIM7       */
#define RAC_PATRIM7_TXTRIMMIXGMBIAS_unused_2                              (_RAC_PATRIM7_TXTRIMMIXGMBIAS_unused_2 << 0)     /**< Shifted mode unused_2 for RAC_PATRIM7       */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASI_SHIFT                               2                                                /**< Shift value for RAC_TXTRIMMIXLOBIASI        */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASI_MASK                                0xCUL                                            /**< Bit mask for RAC_TXTRIMMIXLOBIASI           */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASI_DEFAULT                             0x00000001UL                                     /**< Mode DEFAULT for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASI_v_29o53_vdd                         0x00000000UL                                     /**< Mode v_29o53_vdd for RAC_PATRIM7            */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASI_v_30o54_vdd                         0x00000001UL                                     /**< Mode v_30o54_vdd for RAC_PATRIM7            */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASI_v_31o55_vdd                         0x00000002UL                                     /**< Mode v_31o55_vdd for RAC_PATRIM7            */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASI_v_32o56_vdd                         0x00000003UL                                     /**< Mode v_32o56_vdd for RAC_PATRIM7            */
#define RAC_PATRIM7_TXTRIMMIXLOBIASI_DEFAULT                              (_RAC_PATRIM7_TXTRIMMIXLOBIASI_DEFAULT << 2)     /**< Shifted mode DEFAULT for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXLOBIASI_v_29o53_vdd                          (_RAC_PATRIM7_TXTRIMMIXLOBIASI_v_29o53_vdd << 2) /**< Shifted mode v_29o53_vdd for RAC_PATRIM7    */
#define RAC_PATRIM7_TXTRIMMIXLOBIASI_v_30o54_vdd                          (_RAC_PATRIM7_TXTRIMMIXLOBIASI_v_30o54_vdd << 2) /**< Shifted mode v_30o54_vdd for RAC_PATRIM7    */
#define RAC_PATRIM7_TXTRIMMIXLOBIASI_v_31o55_vdd                          (_RAC_PATRIM7_TXTRIMMIXLOBIASI_v_31o55_vdd << 2) /**< Shifted mode v_31o55_vdd for RAC_PATRIM7    */
#define RAC_PATRIM7_TXTRIMMIXLOBIASI_v_32o56_vdd                          (_RAC_PATRIM7_TXTRIMMIXLOBIASI_v_32o56_vdd << 2) /**< Shifted mode v_32o56_vdd for RAC_PATRIM7    */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASQ_SHIFT                               4                                                /**< Shift value for RAC_TXTRIMMIXLOBIASQ        */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASQ_MASK                                0x30UL                                           /**< Bit mask for RAC_TXTRIMMIXLOBIASQ           */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASQ_DEFAULT                             0x00000001UL                                     /**< Mode DEFAULT for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_29o53_vdd                         0x00000000UL                                     /**< Mode v_29o53_vdd for RAC_PATRIM7            */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_30o54_vdd                         0x00000001UL                                     /**< Mode v_30o54_vdd for RAC_PATRIM7            */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_31o55_vdd                         0x00000002UL                                     /**< Mode v_31o55_vdd for RAC_PATRIM7            */
#define _RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_32o56_vdd                         0x00000003UL                                     /**< Mode v_32o56_vdd for RAC_PATRIM7            */
#define RAC_PATRIM7_TXTRIMMIXLOBIASQ_DEFAULT                              (_RAC_PATRIM7_TXTRIMMIXLOBIASQ_DEFAULT << 4)     /**< Shifted mode DEFAULT for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_29o53_vdd                          (_RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_29o53_vdd << 4) /**< Shifted mode v_29o53_vdd for RAC_PATRIM7    */
#define RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_30o54_vdd                          (_RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_30o54_vdd << 4) /**< Shifted mode v_30o54_vdd for RAC_PATRIM7    */
#define RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_31o55_vdd                          (_RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_31o55_vdd << 4) /**< Shifted mode v_31o55_vdd for RAC_PATRIM7    */
#define RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_32o56_vdd                          (_RAC_PATRIM7_TXTRIMMIXLOBIASQ_v_32o56_vdd << 4) /**< Shifted mode v_32o56_vdd for RAC_PATRIM7    */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_SHIFT                                 8                                                /**< Shift value for RAC_TXTRIMMIXINDSW          */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_MASK                                  0x700UL                                          /**< Bit mask for RAC_TXTRIMMIXINDSW             */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_DEFAULT                               0x00000000UL                                     /**< Mode DEFAULT for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_sw_off                                0x00000000UL                                     /**< Mode sw_off for RAC_PATRIM7                 */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_sw_2x_1                               0x00000001UL                                     /**< Mode sw_2x_1 for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_sw_2x_2                               0x00000002UL                                     /**< Mode sw_2x_2 for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_sw_4x_1                               0x00000003UL                                     /**< Mode sw_4x_1 for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_sw_4x_2                               0x00000004UL                                     /**< Mode sw_4x_2 for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_sw_6x_1                               0x00000005UL                                     /**< Mode sw_6x_1 for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_sw_6x_2                               0x00000006UL                                     /**< Mode sw_6x_2 for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMMIXINDSW_sw_8x                                 0x00000007UL                                     /**< Mode sw_8x for RAC_PATRIM7                  */
#define RAC_PATRIM7_TXTRIMMIXINDSW_DEFAULT                                (_RAC_PATRIM7_TXTRIMMIXINDSW_DEFAULT << 8)       /**< Shifted mode DEFAULT for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXINDSW_sw_off                                 (_RAC_PATRIM7_TXTRIMMIXINDSW_sw_off << 8)        /**< Shifted mode sw_off for RAC_PATRIM7         */
#define RAC_PATRIM7_TXTRIMMIXINDSW_sw_2x_1                                (_RAC_PATRIM7_TXTRIMMIXINDSW_sw_2x_1 << 8)       /**< Shifted mode sw_2x_1 for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXINDSW_sw_2x_2                                (_RAC_PATRIM7_TXTRIMMIXINDSW_sw_2x_2 << 8)       /**< Shifted mode sw_2x_2 for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXINDSW_sw_4x_1                                (_RAC_PATRIM7_TXTRIMMIXINDSW_sw_4x_1 << 8)       /**< Shifted mode sw_4x_1 for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXINDSW_sw_4x_2                                (_RAC_PATRIM7_TXTRIMMIXINDSW_sw_4x_2 << 8)       /**< Shifted mode sw_4x_2 for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXINDSW_sw_6x_1                                (_RAC_PATRIM7_TXTRIMMIXINDSW_sw_6x_1 << 8)       /**< Shifted mode sw_6x_1 for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXINDSW_sw_6x_2                                (_RAC_PATRIM7_TXTRIMMIXINDSW_sw_6x_2 << 8)       /**< Shifted mode sw_6x_2 for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMMIXINDSW_sw_8x                                  (_RAC_PATRIM7_TXTRIMMIXINDSW_sw_8x << 8)         /**< Shifted mode sw_8x for RAC_PATRIM7          */
#define _RAC_PATRIM7_TXTRIMSHVDDREG_SHIFT                                 14                                               /**< Shift value for RAC_TXTRIMSHVDDREG          */
#define _RAC_PATRIM7_TXTRIMSHVDDREG_MASK                                  0xC000UL                                         /**< Bit mask for RAC_TXTRIMSHVDDREG             */
#define _RAC_PATRIM7_TXTRIMSHVDDREG_DEFAULT                               0x00000002UL                                     /**< Mode DEFAULT for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMSHVDDREG_v1p1                                  0x00000000UL                                     /**< Mode v1p1 for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHVDDREG_v1p15                                 0x00000001UL                                     /**< Mode v1p15 for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVDDREG_v1p2                                  0x00000002UL                                     /**< Mode v1p2 for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHVDDREG_v1p25                                 0x00000003UL                                     /**< Mode v1p25 for RAC_PATRIM7                  */
#define RAC_PATRIM7_TXTRIMSHVDDREG_DEFAULT                                (_RAC_PATRIM7_TXTRIMSHVDDREG_DEFAULT << 14)      /**< Shifted mode DEFAULT for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMSHVDDREG_v1p1                                   (_RAC_PATRIM7_TXTRIMSHVDDREG_v1p1 << 14)         /**< Shifted mode v1p1 for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHVDDREG_v1p15                                  (_RAC_PATRIM7_TXTRIMSHVDDREG_v1p15 << 14)        /**< Shifted mode v1p15 for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVDDREG_v1p2                                   (_RAC_PATRIM7_TXTRIMSHVDDREG_v1p2 << 14)         /**< Shifted mode v1p2 for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHVDDREG_v1p25                                  (_RAC_PATRIM7_TXTRIMSHVDDREG_v1p25 << 14)        /**< Shifted mode v1p25 for RAC_PATRIM7          */
#define _RAC_PATRIM7_TXTRIMSHIBINBUF_SHIFT                                16                                               /**< Shift value for RAC_TXTRIMSHIBINBUF         */
#define _RAC_PATRIM7_TXTRIMSHIBINBUF_MASK                                 0x70000UL                                        /**< Bit mask for RAC_TXTRIMSHIBINBUF            */
#define _RAC_PATRIM7_TXTRIMSHIBINBUF_DEFAULT                              0x00000004UL                                     /**< Mode DEFAULT for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMSHIBINBUF_i35u                                 0x00000001UL                                     /**< Mode i35u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBINBUF_i40u                                 0x00000002UL                                     /**< Mode i40u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBINBUF_i45u                                 0x00000003UL                                     /**< Mode i45u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBINBUF_i50u                                 0x00000004UL                                     /**< Mode i50u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBINBUF_i55u                                 0x00000005UL                                     /**< Mode i55u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBINBUF_i60u                                 0x00000006UL                                     /**< Mode i60u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBINBUF_i65u                                 0x00000007UL                                     /**< Mode i65u for RAC_PATRIM7                   */
#define RAC_PATRIM7_TXTRIMSHIBINBUF_DEFAULT                               (_RAC_PATRIM7_TXTRIMSHIBINBUF_DEFAULT << 16)     /**< Shifted mode DEFAULT for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMSHIBINBUF_i35u                                  (_RAC_PATRIM7_TXTRIMSHIBINBUF_i35u << 16)        /**< Shifted mode i35u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBINBUF_i40u                                  (_RAC_PATRIM7_TXTRIMSHIBINBUF_i40u << 16)        /**< Shifted mode i40u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBINBUF_i45u                                  (_RAC_PATRIM7_TXTRIMSHIBINBUF_i45u << 16)        /**< Shifted mode i45u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBINBUF_i50u                                  (_RAC_PATRIM7_TXTRIMSHIBINBUF_i50u << 16)        /**< Shifted mode i50u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBINBUF_i55u                                  (_RAC_PATRIM7_TXTRIMSHIBINBUF_i55u << 16)        /**< Shifted mode i55u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBINBUF_i60u                                  (_RAC_PATRIM7_TXTRIMSHIBINBUF_i60u << 16)        /**< Shifted mode i60u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBINBUF_i65u                                  (_RAC_PATRIM7_TXTRIMSHIBINBUF_i65u << 16)        /**< Shifted mode i65u for RAC_PATRIM7           */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_SHIFT                                  19                                               /**< Shift value for RAC_TXTRIMSHIBVCM           */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_MASK                                   0x380000UL                                       /**< Bit mask for RAC_TXTRIMSHIBVCM              */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_DEFAULT                                0x00000003UL                                     /**< Mode DEFAULT for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_i30u                                   0x00000000UL                                     /**< Mode i30u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_i35u                                   0x00000001UL                                     /**< Mode i35u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_i40u                                   0x00000002UL                                     /**< Mode i40u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_i45u                                   0x00000003UL                                     /**< Mode i45u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_i50u                                   0x00000004UL                                     /**< Mode i50u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_i55u                                   0x00000005UL                                     /**< Mode i55u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_i60u                                   0x00000006UL                                     /**< Mode i60u for RAC_PATRIM7                   */
#define _RAC_PATRIM7_TXTRIMSHIBVCM_i65u                                   0x00000007UL                                     /**< Mode i65u for RAC_PATRIM7                   */
#define RAC_PATRIM7_TXTRIMSHIBVCM_DEFAULT                                 (_RAC_PATRIM7_TXTRIMSHIBVCM_DEFAULT << 19)       /**< Shifted mode DEFAULT for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMSHIBVCM_i30u                                    (_RAC_PATRIM7_TXTRIMSHIBVCM_i30u << 19)          /**< Shifted mode i30u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBVCM_i35u                                    (_RAC_PATRIM7_TXTRIMSHIBVCM_i35u << 19)          /**< Shifted mode i35u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBVCM_i40u                                    (_RAC_PATRIM7_TXTRIMSHIBVCM_i40u << 19)          /**< Shifted mode i40u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBVCM_i45u                                    (_RAC_PATRIM7_TXTRIMSHIBVCM_i45u << 19)          /**< Shifted mode i45u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBVCM_i50u                                    (_RAC_PATRIM7_TXTRIMSHIBVCM_i50u << 19)          /**< Shifted mode i50u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBVCM_i55u                                    (_RAC_PATRIM7_TXTRIMSHIBVCM_i55u << 19)          /**< Shifted mode i55u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBVCM_i60u                                    (_RAC_PATRIM7_TXTRIMSHIBVCM_i60u << 19)          /**< Shifted mode i60u for RAC_PATRIM7           */
#define RAC_PATRIM7_TXTRIMSHIBVCM_i65u                                    (_RAC_PATRIM7_TXTRIMSHIBVCM_i65u << 19)          /**< Shifted mode i65u for RAC_PATRIM7           */
#define _RAC_PATRIM7_TXTRIMSHVCM_SHIFT                                    22                                               /**< Shift value for RAC_TXTRIMSHVCM             */
#define _RAC_PATRIM7_TXTRIMSHVCM_MASK                                     0x3C00000UL                                      /**< Bit mask for RAC_TXTRIMSHVCM                */
#define _RAC_PATRIM7_TXTRIMSHVCM_DEFAULT                                  0x0000000AUL                                     /**< Mode DEFAULT for RAC_PATRIM7                */
#define _RAC_PATRIM7_TXTRIMSHVCM_v300m                                    0x00000000UL                                     /**< Mode v300m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v333m                                    0x00000001UL                                     /**< Mode v333m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v367m                                    0x00000002UL                                     /**< Mode v367m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v400m                                    0x00000003UL                                     /**< Mode v400m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v433m                                    0x00000004UL                                     /**< Mode v433m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v466m                                    0x00000005UL                                     /**< Mode v466m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v500m                                    0x00000006UL                                     /**< Mode v500m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v533m                                    0x00000007UL                                     /**< Mode v533m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v566m                                    0x00000008UL                                     /**< Mode v566m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v599m                                    0x00000009UL                                     /**< Mode v599m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v631m                                    0x0000000AUL                                     /**< Mode v631m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v664m                                    0x0000000BUL                                     /**< Mode v664m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v696m                                    0x0000000CUL                                     /**< Mode v696m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v728m                                    0x0000000DUL                                     /**< Mode v728m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v760m                                    0x0000000EUL                                     /**< Mode v760m for RAC_PATRIM7                  */
#define _RAC_PATRIM7_TXTRIMSHVCM_v790m                                    0x0000000FUL                                     /**< Mode v790m for RAC_PATRIM7                  */
#define RAC_PATRIM7_TXTRIMSHVCM_DEFAULT                                   (_RAC_PATRIM7_TXTRIMSHVCM_DEFAULT << 22)         /**< Shifted mode DEFAULT for RAC_PATRIM7        */
#define RAC_PATRIM7_TXTRIMSHVCM_v300m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v300m << 22)           /**< Shifted mode v300m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v333m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v333m << 22)           /**< Shifted mode v333m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v367m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v367m << 22)           /**< Shifted mode v367m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v400m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v400m << 22)           /**< Shifted mode v400m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v433m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v433m << 22)           /**< Shifted mode v433m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v466m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v466m << 22)           /**< Shifted mode v466m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v500m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v500m << 22)           /**< Shifted mode v500m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v533m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v533m << 22)           /**< Shifted mode v533m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v566m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v566m << 22)           /**< Shifted mode v566m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v599m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v599m << 22)           /**< Shifted mode v599m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v631m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v631m << 22)           /**< Shifted mode v631m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v664m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v664m << 22)           /**< Shifted mode v664m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v696m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v696m << 22)           /**< Shifted mode v696m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v728m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v728m << 22)           /**< Shifted mode v728m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v760m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v760m << 22)           /**< Shifted mode v760m for RAC_PATRIM7          */
#define RAC_PATRIM7_TXTRIMSHVCM_v790m                                     (_RAC_PATRIM7_TXTRIMSHVCM_v790m << 22)           /**< Shifted mode v790m for RAC_PATRIM7          */

/* Bit fields for RAC PATRIM8 */
#define _RAC_PATRIM8_RESETVALUE                                           0x000501C6UL                                  /**< Default value for RAC_PATRIM8               */
#define _RAC_PATRIM8_MASK                                                 0x000FFFFFUL                                  /**< Mask for RAC_PATRIM8                        */
#define _RAC_PATRIM8_TXTRIMRFPKDVDDD_SHIFT                                0                                             /**< Shift value for RAC_TXTRIMRFPKDVDDD         */
#define _RAC_PATRIM8_TXTRIMRFPKDVDDD_MASK                                 0x3UL                                         /**< Bit mask for RAC_TXTRIMRFPKDVDDD            */
#define _RAC_PATRIM8_TXTRIMRFPKDVDDD_DEFAULT                              0x00000002UL                                  /**< Mode DEFAULT for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p1                             0x00000000UL                                  /**< Mode vreg_1p1 for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p15                            0x00000001UL                                  /**< Mode vreg_1p15 for RAC_PATRIM8              */
#define _RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p2                             0x00000002UL                                  /**< Mode vreg_1p2 for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p25                            0x00000003UL                                  /**< Mode vreg_1p25 for RAC_PATRIM8              */
#define RAC_PATRIM8_TXTRIMRFPKDVDDD_DEFAULT                               (_RAC_PATRIM8_TXTRIMRFPKDVDDD_DEFAULT << 0)   /**< Shifted mode DEFAULT for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p1                              (_RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p1 << 0)  /**< Shifted mode vreg_1p1 for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p15                             (_RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p15 << 0) /**< Shifted mode vreg_1p15 for RAC_PATRIM8      */
#define RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p2                              (_RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p2 << 0)  /**< Shifted mode vreg_1p2 for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p25                             (_RAC_PATRIM8_TXTRIMRFPKDVDDD_vreg_1p25 << 0) /**< Shifted mode vreg_1p25 for RAC_PATRIM8      */
#define _RAC_PATRIM8_TXTRIMRFPKDIB_SHIFT                                  2                                             /**< Shift value for RAC_TXTRIMRFPKDIB           */
#define _RAC_PATRIM8_TXTRIMRFPKDIB_MASK                                   0xCUL                                         /**< Bit mask for RAC_TXTRIMRFPKDIB              */
#define _RAC_PATRIM8_TXTRIMRFPKDIB_DEFAULT                                0x00000001UL                                  /**< Mode DEFAULT for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMRFPKDIB_ib_15uA                                0x00000000UL                                  /**< Mode ib_15uA for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMRFPKDIB_ib_10uA_1                              0x00000001UL                                  /**< Mode ib_10uA_1 for RAC_PATRIM8              */
#define _RAC_PATRIM8_TXTRIMRFPKDIB_ib_10uA_2                              0x00000002UL                                  /**< Mode ib_10uA_2 for RAC_PATRIM8              */
#define _RAC_PATRIM8_TXTRIMRFPKDIB_tib_15uA                               0x00000003UL                                  /**< Mode tib_15uA for RAC_PATRIM8               */
#define RAC_PATRIM8_TXTRIMRFPKDIB_DEFAULT                                 (_RAC_PATRIM8_TXTRIMRFPKDIB_DEFAULT << 2)     /**< Shifted mode DEFAULT for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMRFPKDIB_ib_15uA                                 (_RAC_PATRIM8_TXTRIMRFPKDIB_ib_15uA << 2)     /**< Shifted mode ib_15uA for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMRFPKDIB_ib_10uA_1                               (_RAC_PATRIM8_TXTRIMRFPKDIB_ib_10uA_1 << 2)   /**< Shifted mode ib_10uA_1 for RAC_PATRIM8      */
#define RAC_PATRIM8_TXTRIMRFPKDIB_ib_10uA_2                               (_RAC_PATRIM8_TXTRIMRFPKDIB_ib_10uA_2 << 2)   /**< Shifted mode ib_10uA_2 for RAC_PATRIM8      */
#define RAC_PATRIM8_TXTRIMRFPKDIB_tib_15uA                                (_RAC_PATRIM8_TXTRIMRFPKDIB_tib_15uA << 2)    /**< Shifted mode tib_15uA for RAC_PATRIM8       */
#define _RAC_PATRIM8_TXTRIMRFPKDVCM_SHIFT                                 4                                             /**< Shift value for RAC_TXTRIMRFPKDVCM          */
#define _RAC_PATRIM8_TXTRIMRFPKDVCM_MASK                                  0x30UL                                        /**< Bit mask for RAC_TXTRIMRFPKDVCM             */
#define _RAC_PATRIM8_TXTRIMRFPKDVCM_DEFAULT                               0x00000000UL                                  /**< Mode DEFAULT for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_R0_1                              0x00000000UL                                  /**< Mode VCM_R0_1 for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_R0_2                              0x00000001UL                                  /**< Mode VCM_R0_2 for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_R5k                               0x00000002UL                                  /**< Mode VCM_R5k for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_10k                               0x00000003UL                                  /**< Mode VCM_10k for RAC_PATRIM8                */
#define RAC_PATRIM8_TXTRIMRFPKDVCM_DEFAULT                                (_RAC_PATRIM8_TXTRIMRFPKDVCM_DEFAULT << 4)    /**< Shifted mode DEFAULT for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_R0_1                               (_RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_R0_1 << 4)   /**< Shifted mode VCM_R0_1 for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_R0_2                               (_RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_R0_2 << 4)   /**< Shifted mode VCM_R0_2 for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_R5k                                (_RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_R5k << 4)    /**< Shifted mode VCM_R5k for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_10k                                (_RAC_PATRIM8_TXTRIMRFPKDVCM_VCM_10k << 4)    /**< Shifted mode VCM_10k for RAC_PATRIM8        */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_SHIFT                                  6                                             /**< Shift value for RAC_TXTRIMBUFBIAS           */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_MASK                                   0x3C0UL                                       /**< Bit mask for RAC_TXTRIMBUFBIAS              */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_DEFAULT                                0x00000007UL                                  /**< Mode DEFAULT for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_125uA                               0x00000000UL                                  /**< Mode ib_125uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_130uA                               0x00000001UL                                  /**< Mode ib_130uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_135uA                               0x00000002UL                                  /**< Mode ib_135uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_140uA                               0x00000003UL                                  /**< Mode ib_140uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_145uA                               0x00000004UL                                  /**< Mode ib_145uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_150uA                               0x00000005UL                                  /**< Mode ib_150uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_155uA                               0x00000006UL                                  /**< Mode ib_155uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_160uA                               0x00000007UL                                  /**< Mode ib_160uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_165uA                               0x00000008UL                                  /**< Mode ib_165uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_170uA                               0x00000009UL                                  /**< Mode ib_170uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_175uA                               0x0000000AUL                                  /**< Mode ib_175uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_180uA                               0x0000000BUL                                  /**< Mode ib_180uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_185uA                               0x0000000CUL                                  /**< Mode ib_185uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_190uA                               0x0000000DUL                                  /**< Mode ib_190uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_195uA                               0x0000000EUL                                  /**< Mode ib_195uA for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFBIAS_ib_200uA                               0x0000000FUL                                  /**< Mode ib_200uA for RAC_PATRIM8               */
#define RAC_PATRIM8_TXTRIMBUFBIAS_DEFAULT                                 (_RAC_PATRIM8_TXTRIMBUFBIAS_DEFAULT << 6)     /**< Shifted mode DEFAULT for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_125uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_125uA << 6)    /**< Shifted mode ib_125uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_130uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_130uA << 6)    /**< Shifted mode ib_130uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_135uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_135uA << 6)    /**< Shifted mode ib_135uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_140uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_140uA << 6)    /**< Shifted mode ib_140uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_145uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_145uA << 6)    /**< Shifted mode ib_145uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_150uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_150uA << 6)    /**< Shifted mode ib_150uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_155uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_155uA << 6)    /**< Shifted mode ib_155uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_160uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_160uA << 6)    /**< Shifted mode ib_160uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_165uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_165uA << 6)    /**< Shifted mode ib_165uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_170uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_170uA << 6)    /**< Shifted mode ib_170uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_175uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_175uA << 6)    /**< Shifted mode ib_175uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_180uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_180uA << 6)    /**< Shifted mode ib_180uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_185uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_185uA << 6)    /**< Shifted mode ib_185uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_190uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_190uA << 6)    /**< Shifted mode ib_190uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_195uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_195uA << 6)    /**< Shifted mode ib_195uA for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFBIAS_ib_200uA                                (_RAC_PATRIM8_TXTRIMBUFBIAS_ib_200uA << 6)    /**< Shifted mode ib_200uA for RAC_PATRIM8       */
#define _RAC_PATRIM8_TXTRIMBUFSLICESN_SHIFT                               10                                            /**< Shift value for RAC_TXTRIMBUFSLICESN        */
#define _RAC_PATRIM8_TXTRIMBUFSLICESN_MASK                                0x1C00UL                                      /**< Bit mask for RAC_TXTRIMBUFSLICESN           */
#define _RAC_PATRIM8_TXTRIMBUFSLICESN_DEFAULT                             0x00000000UL                                  /**< Mode DEFAULT for RAC_PATRIM8                */
#define RAC_PATRIM8_TXTRIMBUFSLICESN_DEFAULT                              (_RAC_PATRIM8_TXTRIMBUFSLICESN_DEFAULT << 10) /**< Shifted mode DEFAULT for RAC_PATRIM8        */
#define _RAC_PATRIM8_TXTRIMBUFSLICESP_SHIFT                               13                                            /**< Shift value for RAC_TXTRIMBUFSLICESP        */
#define _RAC_PATRIM8_TXTRIMBUFSLICESP_MASK                                0xE000UL                                      /**< Bit mask for RAC_TXTRIMBUFSLICESP           */
#define _RAC_PATRIM8_TXTRIMBUFSLICESP_DEFAULT                             0x00000000UL                                  /**< Mode DEFAULT for RAC_PATRIM8                */
#define RAC_PATRIM8_TXTRIMBUFSLICESP_DEFAULT                              (_RAC_PATRIM8_TXTRIMBUFSLICESP_DEFAULT << 13) /**< Shifted mode DEFAULT for RAC_PATRIM8        */
#define _RAC_PATRIM8_TXTRIMBUFVMID_SHIFT                                  16                                            /**< Shift value for RAC_TXTRIMBUFVMID           */
#define _RAC_PATRIM8_TXTRIMBUFVMID_MASK                                   0x30000UL                                     /**< Bit mask for RAC_TXTRIMBUFVMID              */
#define _RAC_PATRIM8_TXTRIMBUFVMID_DEFAULT                                0x00000001UL                                  /**< Mode DEFAULT for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMBUFVMID_v_1p20V                                0x00000000UL                                  /**< Mode v_1p20V for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMBUFVMID_v_1p25V                                0x00000001UL                                  /**< Mode v_1p25V for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMBUFVMID_v_1p30V                                0x00000002UL                                  /**< Mode v_1p30V for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMBUFVMID_v_1p35V                                0x00000003UL                                  /**< Mode v_1p35V for RAC_PATRIM8                */
#define RAC_PATRIM8_TXTRIMBUFVMID_DEFAULT                                 (_RAC_PATRIM8_TXTRIMBUFVMID_DEFAULT << 16)    /**< Shifted mode DEFAULT for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMBUFVMID_v_1p20V                                 (_RAC_PATRIM8_TXTRIMBUFVMID_v_1p20V << 16)    /**< Shifted mode v_1p20V for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMBUFVMID_v_1p25V                                 (_RAC_PATRIM8_TXTRIMBUFVMID_v_1p25V << 16)    /**< Shifted mode v_1p25V for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMBUFVMID_v_1p30V                                 (_RAC_PATRIM8_TXTRIMBUFVMID_v_1p30V << 16)    /**< Shifted mode v_1p30V for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMBUFVMID_v_1p35V                                 (_RAC_PATRIM8_TXTRIMBUFVMID_v_1p35V << 16)    /**< Shifted mode v_1p35V for RAC_PATRIM8        */
#define _RAC_PATRIM8_TXTRIMBUFVREG_SHIFT                                  18                                            /**< Shift value for RAC_TXTRIMBUFVREG           */
#define _RAC_PATRIM8_TXTRIMBUFVREG_MASK                                   0xC0000UL                                     /**< Bit mask for RAC_TXTRIMBUFVREG              */
#define _RAC_PATRIM8_TXTRIMBUFVREG_DEFAULT                                0x00000001UL                                  /**< Mode DEFAULT for RAC_PATRIM8                */
#define _RAC_PATRIM8_TXTRIMBUFVREG_v_2p375V                               0x00000000UL                                  /**< Mode v_2p375V for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFVREG_v_2p500V                               0x00000001UL                                  /**< Mode v_2p500V for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFVREG_v_2p625V                               0x00000002UL                                  /**< Mode v_2p625V for RAC_PATRIM8               */
#define _RAC_PATRIM8_TXTRIMBUFVREG_v_2p750V                               0x00000003UL                                  /**< Mode v_2p750V for RAC_PATRIM8               */
#define RAC_PATRIM8_TXTRIMBUFVREG_DEFAULT                                 (_RAC_PATRIM8_TXTRIMBUFVREG_DEFAULT << 18)    /**< Shifted mode DEFAULT for RAC_PATRIM8        */
#define RAC_PATRIM8_TXTRIMBUFVREG_v_2p375V                                (_RAC_PATRIM8_TXTRIMBUFVREG_v_2p375V << 18)   /**< Shifted mode v_2p375V for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFVREG_v_2p500V                                (_RAC_PATRIM8_TXTRIMBUFVREG_v_2p500V << 18)   /**< Shifted mode v_2p500V for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFVREG_v_2p625V                                (_RAC_PATRIM8_TXTRIMBUFVREG_v_2p625V << 18)   /**< Shifted mode v_2p625V for RAC_PATRIM8       */
#define RAC_PATRIM8_TXTRIMBUFVREG_v_2p750V                                (_RAC_PATRIM8_TXTRIMBUFVREG_v_2p750V << 18)   /**< Shifted mode v_2p750V for RAC_PATRIM8       */

/* Bit fields for RAC PATRIM9 */
#define _RAC_PATRIM9_RESETVALUE                                           0x00000045UL                                 /**< Default value for RAC_PATRIM9               */
#define _RAC_PATRIM9_MASK                                                 0xFFFF007FUL                                 /**< Mask for RAC_PATRIM9                        */
#define RAC_PATRIM9_TXTRIMDACVCAS                                         (0x1UL << 0)                                 /**< TXTRIMDACVCAS                               */
#define _RAC_PATRIM9_TXTRIMDACVCAS_SHIFT                                  0                                            /**< Shift value for RAC_TXTRIMDACVCAS           */
#define _RAC_PATRIM9_TXTRIMDACVCAS_MASK                                   0x1UL                                        /**< Bit mask for RAC_TXTRIMDACVCAS              */
#define _RAC_PATRIM9_TXTRIMDACVCAS_DEFAULT                                0x00000001UL                                 /**< Mode DEFAULT for RAC_PATRIM9                */
#define _RAC_PATRIM9_TXTRIMDACVCAS_v200m                                  0x00000000UL                                 /**< Mode v200m for RAC_PATRIM9                  */
#define _RAC_PATRIM9_TXTRIMDACVCAS_v110m                                  0x00000001UL                                 /**< Mode v110m for RAC_PATRIM9                  */
#define RAC_PATRIM9_TXTRIMDACVCAS_DEFAULT                                 (_RAC_PATRIM9_TXTRIMDACVCAS_DEFAULT << 0)    /**< Shifted mode DEFAULT for RAC_PATRIM9        */
#define RAC_PATRIM9_TXTRIMDACVCAS_v200m                                   (_RAC_PATRIM9_TXTRIMDACVCAS_v200m << 0)      /**< Shifted mode v200m for RAC_PATRIM9          */
#define RAC_PATRIM9_TXTRIMDACVCAS_v110m                                   (_RAC_PATRIM9_TXTRIMDACVCAS_v110m << 0)      /**< Shifted mode v110m for RAC_PATRIM9          */
#define RAC_PATRIM9_TXTRIMDACSCALE                                        (0x1UL << 1)                                 /**< TXTRIMDACSCALE                              */
#define _RAC_PATRIM9_TXTRIMDACSCALE_SHIFT                                 1                                            /**< Shift value for RAC_TXTRIMDACSCALE          */
#define _RAC_PATRIM9_TXTRIMDACSCALE_MASK                                  0x2UL                                        /**< Bit mask for RAC_TXTRIMDACSCALE             */
#define _RAC_PATRIM9_TXTRIMDACSCALE_DEFAULT                               0x00000000UL                                 /**< Mode DEFAULT for RAC_PATRIM9                */
#define _RAC_PATRIM9_TXTRIMDACSCALE_disabled                              0x00000000UL                                 /**< Mode disabled for RAC_PATRIM9               */
#define _RAC_PATRIM9_TXTRIMDACSCALE_enabled                               0x00000001UL                                 /**< Mode enabled for RAC_PATRIM9                */
#define RAC_PATRIM9_TXTRIMDACSCALE_DEFAULT                                (_RAC_PATRIM9_TXTRIMDACSCALE_DEFAULT << 1)   /**< Shifted mode DEFAULT for RAC_PATRIM9        */
#define RAC_PATRIM9_TXTRIMDACSCALE_disabled                               (_RAC_PATRIM9_TXTRIMDACSCALE_disabled << 1)  /**< Shifted mode disabled for RAC_PATRIM9       */
#define RAC_PATRIM9_TXTRIMDACSCALE_enabled                                (_RAC_PATRIM9_TXTRIMDACSCALE_enabled << 1)   /**< Shifted mode enabled for RAC_PATRIM9        */
#define _RAC_PATRIM9_TXTRIMDACVDDD_SHIFT                                  2                                            /**< Shift value for RAC_TXTRIMDACVDDD           */
#define _RAC_PATRIM9_TXTRIMDACVDDD_MASK                                   0xCUL                                        /**< Bit mask for RAC_TXTRIMDACVDDD              */
#define _RAC_PATRIM9_TXTRIMDACVDDD_DEFAULT                                0x00000001UL                                 /**< Mode DEFAULT for RAC_PATRIM9                */
#define _RAC_PATRIM9_TXTRIMDACVDDD_v1                                     0x00000000UL                                 /**< Mode v1 for RAC_PATRIM9                     */
#define _RAC_PATRIM9_TXTRIMDACVDDD_v1p1                                   0x00000001UL                                 /**< Mode v1p1 for RAC_PATRIM9                   */
#define _RAC_PATRIM9_TXTRIMDACVDDD_v1p18                                  0x00000002UL                                 /**< Mode v1p18 for RAC_PATRIM9                  */
#define _RAC_PATRIM9_TXTRIMDACVDDD_v1p25                                  0x00000003UL                                 /**< Mode v1p25 for RAC_PATRIM9                  */
#define RAC_PATRIM9_TXTRIMDACVDDD_DEFAULT                                 (_RAC_PATRIM9_TXTRIMDACVDDD_DEFAULT << 2)    /**< Shifted mode DEFAULT for RAC_PATRIM9        */
#define RAC_PATRIM9_TXTRIMDACVDDD_v1                                      (_RAC_PATRIM9_TXTRIMDACVDDD_v1 << 2)         /**< Shifted mode v1 for RAC_PATRIM9             */
#define RAC_PATRIM9_TXTRIMDACVDDD_v1p1                                    (_RAC_PATRIM9_TXTRIMDACVDDD_v1p1 << 2)       /**< Shifted mode v1p1 for RAC_PATRIM9           */
#define RAC_PATRIM9_TXTRIMDACVDDD_v1p18                                   (_RAC_PATRIM9_TXTRIMDACVDDD_v1p18 << 2)      /**< Shifted mode v1p18 for RAC_PATRIM9          */
#define RAC_PATRIM9_TXTRIMDACVDDD_v1p25                                   (_RAC_PATRIM9_TXTRIMDACVDDD_v1p25 << 2)      /**< Shifted mode v1p25 for RAC_PATRIM9          */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_SHIFT                                 4                                            /**< Shift value for RAC_TXTRIMDACIBIAS          */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_MASK                                  0x70UL                                       /**< Bit mask for RAC_TXTRIMDACIBIAS             */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_DEFAULT                               0x00000004UL                                 /**< Mode DEFAULT for RAC_PATRIM9                */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_i10u                                  0x00000000UL                                 /**< Mode i10u for RAC_PATRIM9                   */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_i12p5u                                0x00000001UL                                 /**< Mode i12p5u for RAC_PATRIM9                 */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_i15u                                  0x00000002UL                                 /**< Mode i15u for RAC_PATRIM9                   */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_i17p5u                                0x00000003UL                                 /**< Mode i17p5u for RAC_PATRIM9                 */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_i20u                                  0x00000004UL                                 /**< Mode i20u for RAC_PATRIM9                   */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_i22p5u                                0x00000005UL                                 /**< Mode i22p5u for RAC_PATRIM9                 */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_i25u                                  0x00000006UL                                 /**< Mode i25u for RAC_PATRIM9                   */
#define _RAC_PATRIM9_TXTRIMDACIBIAS_i27p5u                                0x00000007UL                                 /**< Mode i27p5u for RAC_PATRIM9                 */
#define RAC_PATRIM9_TXTRIMDACIBIAS_DEFAULT                                (_RAC_PATRIM9_TXTRIMDACIBIAS_DEFAULT << 4)   /**< Shifted mode DEFAULT for RAC_PATRIM9        */
#define RAC_PATRIM9_TXTRIMDACIBIAS_i10u                                   (_RAC_PATRIM9_TXTRIMDACIBIAS_i10u << 4)      /**< Shifted mode i10u for RAC_PATRIM9           */
#define RAC_PATRIM9_TXTRIMDACIBIAS_i12p5u                                 (_RAC_PATRIM9_TXTRIMDACIBIAS_i12p5u << 4)    /**< Shifted mode i12p5u for RAC_PATRIM9         */
#define RAC_PATRIM9_TXTRIMDACIBIAS_i15u                                   (_RAC_PATRIM9_TXTRIMDACIBIAS_i15u << 4)      /**< Shifted mode i15u for RAC_PATRIM9           */
#define RAC_PATRIM9_TXTRIMDACIBIAS_i17p5u                                 (_RAC_PATRIM9_TXTRIMDACIBIAS_i17p5u << 4)    /**< Shifted mode i17p5u for RAC_PATRIM9         */
#define RAC_PATRIM9_TXTRIMDACIBIAS_i20u                                   (_RAC_PATRIM9_TXTRIMDACIBIAS_i20u << 4)      /**< Shifted mode i20u for RAC_PATRIM9           */
#define RAC_PATRIM9_TXTRIMDACIBIAS_i22p5u                                 (_RAC_PATRIM9_TXTRIMDACIBIAS_i22p5u << 4)    /**< Shifted mode i22p5u for RAC_PATRIM9         */
#define RAC_PATRIM9_TXTRIMDACIBIAS_i25u                                   (_RAC_PATRIM9_TXTRIMDACIBIAS_i25u << 4)      /**< Shifted mode i25u for RAC_PATRIM9           */
#define RAC_PATRIM9_TXTRIMDACIBIAS_i27p5u                                 (_RAC_PATRIM9_TXTRIMDACIBIAS_i27p5u << 4)    /**< Shifted mode i27p5u for RAC_PATRIM9         */
#define _RAC_PATRIM9_TXTRIMPASLICESN_SHIFT                                16                                           /**< Shift value for RAC_TXTRIMPASLICESN         */
#define _RAC_PATRIM9_TXTRIMPASLICESN_MASK                                 0xFF0000UL                                   /**< Bit mask for RAC_TXTRIMPASLICESN            */
#define _RAC_PATRIM9_TXTRIMPASLICESN_DEFAULT                              0x00000000UL                                 /**< Mode DEFAULT for RAC_PATRIM9                */
#define RAC_PATRIM9_TXTRIMPASLICESN_DEFAULT                               (_RAC_PATRIM9_TXTRIMPASLICESN_DEFAULT << 16) /**< Shifted mode DEFAULT for RAC_PATRIM9        */
#define _RAC_PATRIM9_TXTRIMPASLICESP_SHIFT                                24                                           /**< Shift value for RAC_TXTRIMPASLICESP         */
#define _RAC_PATRIM9_TXTRIMPASLICESP_MASK                                 0xFF000000UL                                 /**< Bit mask for RAC_TXTRIMPASLICESP            */
#define _RAC_PATRIM9_TXTRIMPASLICESP_DEFAULT                              0x00000000UL                                 /**< Mode DEFAULT for RAC_PATRIM9                */
#define RAC_PATRIM9_TXTRIMPASLICESP_DEFAULT                               (_RAC_PATRIM9_TXTRIMPASLICESP_DEFAULT << 24) /**< Shifted mode DEFAULT for RAC_PATRIM9        */

/* Bit fields for RAC PATRIM10 */
#define _RAC_PATRIM10_RESETVALUE                                          0x015E0579UL                                    /**< Default value for RAC_PATRIM10              */
#define _RAC_PATRIM10_MASK                                                0x07FF1FFFUL                                    /**< Mask for RAC_PATRIM10                       */
#define _RAC_PATRIM10_TXTRIMPAMIRROR_SHIFT                                0                                               /**< Shift value for RAC_TXTRIMPAMIRROR          */
#define _RAC_PATRIM10_TXTRIMPAMIRROR_MASK                                 0x3UL                                           /**< Bit mask for RAC_TXTRIMPAMIRROR             */
#define _RAC_PATRIM10_TXTRIMPAMIRROR_DEFAULT                              0x00000001UL                                    /**< Mode DEFAULT for RAC_PATRIM10               */
#define _RAC_PATRIM10_TXTRIMPAMIRROR_bias_0p5LSB                          0x00000000UL                                    /**< Mode bias_0p5LSB for RAC_PATRIM10           */
#define _RAC_PATRIM10_TXTRIMPAMIRROR_bias_1p0LSB                          0x00000001UL                                    /**< Mode bias_1p0LSB for RAC_PATRIM10           */
#define _RAC_PATRIM10_TXTRIMPAMIRROR_bias_1p5LSB                          0x00000002UL                                    /**< Mode bias_1p5LSB for RAC_PATRIM10           */
#define _RAC_PATRIM10_TXTRIMPAMIRROR_bias_2p0LSB                          0x00000003UL                                    /**< Mode bias_2p0LSB for RAC_PATRIM10           */
#define RAC_PATRIM10_TXTRIMPAMIRROR_DEFAULT                               (_RAC_PATRIM10_TXTRIMPAMIRROR_DEFAULT << 0)     /**< Shifted mode DEFAULT for RAC_PATRIM10       */
#define RAC_PATRIM10_TXTRIMPAMIRROR_bias_0p5LSB                           (_RAC_PATRIM10_TXTRIMPAMIRROR_bias_0p5LSB << 0) /**< Shifted mode bias_0p5LSB for RAC_PATRIM10   */
#define RAC_PATRIM10_TXTRIMPAMIRROR_bias_1p0LSB                           (_RAC_PATRIM10_TXTRIMPAMIRROR_bias_1p0LSB << 0) /**< Shifted mode bias_1p0LSB for RAC_PATRIM10   */
#define RAC_PATRIM10_TXTRIMPAMIRROR_bias_1p5LSB                           (_RAC_PATRIM10_TXTRIMPAMIRROR_bias_1p5LSB << 0) /**< Shifted mode bias_1p5LSB for RAC_PATRIM10   */
#define RAC_PATRIM10_TXTRIMPAMIRROR_bias_2p0LSB                           (_RAC_PATRIM10_TXTRIMPAMIRROR_bias_2p0LSB << 0) /**< Shifted mode bias_2p0LSB for RAC_PATRIM10   */
#define _RAC_PATRIM10_TXTRIMPANBIAS_SHIFT                                 2                                               /**< Shift value for RAC_TXTRIMPANBIAS           */
#define _RAC_PATRIM10_TXTRIMPANBIAS_MASK                                  0x3FCUL                                         /**< Bit mask for RAC_TXTRIMPANBIAS              */
#define _RAC_PATRIM10_TXTRIMPANBIAS_DEFAULT                               0x0000005EUL                                    /**< Mode DEFAULT for RAC_PATRIM10               */
#define RAC_PATRIM10_TXTRIMPANBIAS_DEFAULT                                (_RAC_PATRIM10_TXTRIMPANBIAS_DEFAULT << 2)      /**< Shifted mode DEFAULT for RAC_PATRIM10       */
#define _RAC_PATRIM10_TXTRIMPANCBIAS_SHIFT                                10                                              /**< Shift value for RAC_TXTRIMPANCBIAS          */
#define _RAC_PATRIM10_TXTRIMPANCBIAS_MASK                                 0x1C00UL                                        /**< Bit mask for RAC_TXTRIMPANCBIAS             */
#define _RAC_PATRIM10_TXTRIMPANCBIAS_DEFAULT                              0x00000001UL                                    /**< Mode DEFAULT for RAC_PATRIM10               */
#define RAC_PATRIM10_TXTRIMPANCBIAS_DEFAULT                               (_RAC_PATRIM10_TXTRIMPANCBIAS_DEFAULT << 10)    /**< Shifted mode DEFAULT for RAC_PATRIM10       */
#define _RAC_PATRIM10_TXTRIMPAPBIAS_SHIFT                                 16                                              /**< Shift value for RAC_TXTRIMPAPBIAS           */
#define _RAC_PATRIM10_TXTRIMPAPBIAS_MASK                                  0xFF0000UL                                      /**< Bit mask for RAC_TXTRIMPAPBIAS              */
#define _RAC_PATRIM10_TXTRIMPAPBIAS_DEFAULT                               0x0000005EUL                                    /**< Mode DEFAULT for RAC_PATRIM10               */
#define RAC_PATRIM10_TXTRIMPAPBIAS_DEFAULT                                (_RAC_PATRIM10_TXTRIMPAPBIAS_DEFAULT << 16)     /**< Shifted mode DEFAULT for RAC_PATRIM10       */
#define _RAC_PATRIM10_TXTRIMPAPCBIAS_SHIFT                                24                                              /**< Shift value for RAC_TXTRIMPAPCBIAS          */
#define _RAC_PATRIM10_TXTRIMPAPCBIAS_MASK                                 0x7000000UL                                     /**< Bit mask for RAC_TXTRIMPAPCBIAS             */
#define _RAC_PATRIM10_TXTRIMPAPCBIAS_DEFAULT                              0x00000001UL                                    /**< Mode DEFAULT for RAC_PATRIM10               */
#define RAC_PATRIM10_TXTRIMPAPCBIAS_DEFAULT                               (_RAC_PATRIM10_TXTRIMPAPCBIAS_DEFAULT << 24)    /**< Shifted mode DEFAULT for RAC_PATRIM10       */

/* Bit fields for RAC TXRFPKD */
#define _RAC_TXRFPKD_RESETVALUE                                           0x00010011UL                                        /**< Default value for RAC_TXRFPKD               */
#define _RAC_TXRFPKD_MASK                                                 0x0071F71DUL                                        /**< Mask for RAC_TXRFPKD                        */
#define RAC_TXRFPKD_TXRESETRFPKD                                          (0x1UL << 0)                                        /**< TXRESETRFPKD                                */
#define _RAC_TXRFPKD_TXRESETRFPKD_SHIFT                                   0                                                   /**< Shift value for RAC_TXRESETRFPKD            */
#define _RAC_TXRFPKD_TXRESETRFPKD_MASK                                    0x1UL                                               /**< Bit mask for RAC_TXRESETRFPKD               */
#define _RAC_TXRFPKD_TXRESETRFPKD_DEFAULT                                 0x00000001UL                                        /**< Mode DEFAULT for RAC_TXRFPKD                */
#define _RAC_TXRFPKD_TXRESETRFPKD_tbd0                                    0x00000000UL                                        /**< Mode tbd0 for RAC_TXRFPKD                   */
#define _RAC_TXRFPKD_TXRESETRFPKD_tbd1                                    0x00000001UL                                        /**< Mode tbd1 for RAC_TXRFPKD                   */
#define RAC_TXRFPKD_TXRESETRFPKD_DEFAULT                                  (_RAC_TXRFPKD_TXRESETRFPKD_DEFAULT << 0)            /**< Shifted mode DEFAULT for RAC_TXRFPKD        */
#define RAC_TXRFPKD_TXRESETRFPKD_tbd0                                     (_RAC_TXRFPKD_TXRESETRFPKD_tbd0 << 0)               /**< Shifted mode tbd0 for RAC_TXRFPKD           */
#define RAC_TXRFPKD_TXRESETRFPKD_tbd1                                     (_RAC_TXRFPKD_TXRESETRFPKD_tbd1 << 0)               /**< Shifted mode tbd1 for RAC_TXRFPKD           */
#define _RAC_TXRFPKD_TXSELRFPKDREF_SHIFT                                  2                                                   /**< Shift value for RAC_TXSELRFPKDREF           */
#define _RAC_TXRFPKD_TXSELRFPKDREF_MASK                                   0x1CUL                                              /**< Bit mask for RAC_TXSELRFPKDREF              */
#define _RAC_TXRFPKD_TXSELRFPKDREF_DEFAULT                                0x00000004UL                                        /**< Mode DEFAULT for RAC_TXRFPKD                */
#define _RAC_TXRFPKD_TXSELRFPKDREF_th_79p4mV                              0x00000000UL                                        /**< Mode th_79p4mV for RAC_TXRFPKD              */
#define _RAC_TXRFPKD_TXSELRFPKDREF_tb_84p1mV                              0x00000001UL                                        /**< Mode tb_84p1mV for RAC_TXRFPKD              */
#define _RAC_TXRFPKD_TXSELRFPKDREF_th_89p1mV                              0x00000002UL                                        /**< Mode th_89p1mV for RAC_TXRFPKD              */
#define _RAC_TXRFPKD_TXSELRFPKDREF_th_94p4mV                              0x00000003UL                                        /**< Mode th_94p4mV for RAC_TXRFPKD              */
#define _RAC_TXRFPKD_TXSELRFPKDREF_th_100mV                               0x00000004UL                                        /**< Mode th_100mV for RAC_TXRFPKD               */
#define _RAC_TXRFPKD_TXSELRFPKDREF_th_105p9mV                             0x00000005UL                                        /**< Mode th_105p9mV for RAC_TXRFPKD             */
#define _RAC_TXRFPKD_TXSELRFPKDREF_tth_112p2mV                            0x00000006UL                                        /**< Mode tth_112p2mV for RAC_TXRFPKD            */
#define _RAC_TXRFPKD_TXSELRFPKDREF_th_118p9mV                             0x00000007UL                                        /**< Mode th_118p9mV for RAC_TXRFPKD             */
#define RAC_TXRFPKD_TXSELRFPKDREF_DEFAULT                                 (_RAC_TXRFPKD_TXSELRFPKDREF_DEFAULT << 2)           /**< Shifted mode DEFAULT for RAC_TXRFPKD        */
#define RAC_TXRFPKD_TXSELRFPKDREF_th_79p4mV                               (_RAC_TXRFPKD_TXSELRFPKDREF_th_79p4mV << 2)         /**< Shifted mode th_79p4mV for RAC_TXRFPKD      */
#define RAC_TXRFPKD_TXSELRFPKDREF_tb_84p1mV                               (_RAC_TXRFPKD_TXSELRFPKDREF_tb_84p1mV << 2)         /**< Shifted mode tb_84p1mV for RAC_TXRFPKD      */
#define RAC_TXRFPKD_TXSELRFPKDREF_th_89p1mV                               (_RAC_TXRFPKD_TXSELRFPKDREF_th_89p1mV << 2)         /**< Shifted mode th_89p1mV for RAC_TXRFPKD      */
#define RAC_TXRFPKD_TXSELRFPKDREF_th_94p4mV                               (_RAC_TXRFPKD_TXSELRFPKDREF_th_94p4mV << 2)         /**< Shifted mode th_94p4mV for RAC_TXRFPKD      */
#define RAC_TXRFPKD_TXSELRFPKDREF_th_100mV                                (_RAC_TXRFPKD_TXSELRFPKDREF_th_100mV << 2)          /**< Shifted mode th_100mV for RAC_TXRFPKD       */
#define RAC_TXRFPKD_TXSELRFPKDREF_th_105p9mV                              (_RAC_TXRFPKD_TXSELRFPKDREF_th_105p9mV << 2)        /**< Shifted mode th_105p9mV for RAC_TXRFPKD     */
#define RAC_TXRFPKD_TXSELRFPKDREF_tth_112p2mV                             (_RAC_TXRFPKD_TXSELRFPKDREF_tth_112p2mV << 2)       /**< Shifted mode tth_112p2mV for RAC_TXRFPKD    */
#define RAC_TXRFPKD_TXSELRFPKDREF_th_118p9mV                              (_RAC_TXRFPKD_TXSELRFPKDREF_th_118p9mV << 2)        /**< Shifted mode th_118p9mV for RAC_TXRFPKD     */
#define RAC_TXRFPKD_TXRFPKDOUTMODE                                        (0x1UL << 8)                                        /**< TXRFPKDOUTMODE                              */
#define _RAC_TXRFPKD_TXRFPKDOUTMODE_SHIFT                                 8                                                   /**< Shift value for RAC_TXRFPKDOUTMODE          */
#define _RAC_TXRFPKD_TXRFPKDOUTMODE_MASK                                  0x100UL                                             /**< Bit mask for RAC_TXRFPKDOUTMODE             */
#define _RAC_TXRFPKD_TXRFPKDOUTMODE_DEFAULT                               0x00000000UL                                        /**< Mode DEFAULT for RAC_TXRFPKD                */
#define _RAC_TXRFPKD_TXRFPKDOUTMODE_output_unlatched                      0x00000000UL                                        /**< Mode output_unlatched for RAC_TXRFPKD       */
#define _RAC_TXRFPKD_TXRFPKDOUTMODE_output_latched                        0x00000001UL                                        /**< Mode output_latched for RAC_TXRFPKD         */
#define RAC_TXRFPKD_TXRFPKDOUTMODE_DEFAULT                                (_RAC_TXRFPKD_TXRFPKDOUTMODE_DEFAULT << 8)          /**< Shifted mode DEFAULT for RAC_TXRFPKD        */
#define RAC_TXRFPKD_TXRFPKDOUTMODE_output_unlatched                       (_RAC_TXRFPKD_TXRFPKDOUTMODE_output_unlatched << 8) /**< Shifted mode output_unlatched for RAC_TXRFPKD*/
#define RAC_TXRFPKD_TXRFPKDOUTMODE_output_latched                         (_RAC_TXRFPKD_TXRFPKDOUTMODE_output_latched << 8)   /**< Shifted mode output_latched for RAC_TXRFPKD */
#define _RAC_TXRFPKD_TXRFPKDCALMODE_SHIFT                                 9                                                   /**< Shift value for RAC_TXRFPKDCALMODE          */
#define _RAC_TXRFPKD_TXRFPKDCALMODE_MASK                                  0x600UL                                             /**< Bit mask for RAC_TXRFPKDCALMODE             */
#define _RAC_TXRFPKD_TXRFPKDCALMODE_DEFAULT                               0x00000000UL                                        /**< Mode DEFAULT for RAC_TXRFPKD                */
#define _RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_vmid1                          0x00000000UL                                        /**< Mode RFbias_vmid1 for RAC_TXRFPKD           */
#define _RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_vmid2                          0x00000001UL                                        /**< Mode RFbias_vmid2 for RAC_TXRFPKD           */
#define _RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_thH_thL                        0x00000002UL                                        /**< Mode RFbias_thH_thL for RAC_TXRFPKD         */
#define _RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_thL_thH                        0x00000003UL                                        /**< Mode RFbias_thL_thH for RAC_TXRFPKD         */
#define RAC_TXRFPKD_TXRFPKDCALMODE_DEFAULT                                (_RAC_TXRFPKD_TXRFPKDCALMODE_DEFAULT << 9)          /**< Shifted mode DEFAULT for RAC_TXRFPKD        */
#define RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_vmid1                           (_RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_vmid1 << 9)     /**< Shifted mode RFbias_vmid1 for RAC_TXRFPKD   */
#define RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_vmid2                           (_RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_vmid2 << 9)     /**< Shifted mode RFbias_vmid2 for RAC_TXRFPKD   */
#define RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_thH_thL                         (_RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_thH_thL << 9)   /**< Shifted mode RFbias_thH_thL for RAC_TXRFPKD */
#define RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_thL_thH                         (_RAC_TXRFPKD_TXRFPKDCALMODE_RFbias_thL_thH << 9)   /**< Shifted mode RFbias_thL_thH for RAC_TXRFPKD */
#define _RAC_TXRFPKD_TXRFPKDCALCODE_SHIFT                                 12                                                  /**< Shift value for RAC_TXRFPKDCALCODE          */
#define _RAC_TXRFPKD_TXRFPKDCALCODE_MASK                                  0x1F000UL                                           /**< Bit mask for RAC_TXRFPKDCALCODE             */
#define _RAC_TXRFPKD_TXRFPKDCALCODE_DEFAULT                               0x00000010UL                                        /**< Mode DEFAULT for RAC_TXRFPKD                */
#define _RAC_TXRFPKD_TXRFPKDCALCODE_tbd0                                  0x00000000UL                                        /**< Mode tbd0 for RAC_TXRFPKD                   */
#define _RAC_TXRFPKD_TXRFPKDCALCODE_tbd1                                  0x00000001UL                                        /**< Mode tbd1 for RAC_TXRFPKD                   */
#define RAC_TXRFPKD_TXRFPKDCALCODE_DEFAULT                                (_RAC_TXRFPKD_TXRFPKDCALCODE_DEFAULT << 12)         /**< Shifted mode DEFAULT for RAC_TXRFPKD        */
#define RAC_TXRFPKD_TXRFPKDCALCODE_tbd0                                   (_RAC_TXRFPKD_TXRFPKDCALCODE_tbd0 << 12)            /**< Shifted mode tbd0 for RAC_TXRFPKD           */
#define RAC_TXRFPKD_TXRFPKDCALCODE_tbd1                                   (_RAC_TXRFPKD_TXRFPKDCALCODE_tbd1 << 12)            /**< Shifted mode tbd1 for RAC_TXRFPKD           */
#define _RAC_TXRFPKD_TXRFPKDCAPATT_SHIFT                                  20                                                  /**< Shift value for RAC_TXRFPKDCAPATT           */
#define _RAC_TXRFPKD_TXRFPKDCAPATT_MASK                                   0x700000UL                                          /**< Bit mask for RAC_TXRFPKDCAPATT              */
#define _RAC_TXRFPKD_TXRFPKDCAPATT_DEFAULT                                0x00000000UL                                        /**< Mode DEFAULT for RAC_TXRFPKD                */
#define _RAC_TXRFPKD_TXRFPKDCAPATT_att_15dB                               0x00000000UL                                        /**< Mode att_15dB for RAC_TXRFPKD               */
#define _RAC_TXRFPKD_TXRFPKDCAPATT_att_18dB                               0x00000001UL                                        /**< Mode att_18dB for RAC_TXRFPKD               */
#define _RAC_TXRFPKD_TXRFPKDCAPATT_att_21dB                               0x00000003UL                                        /**< Mode att_21dB for RAC_TXRFPKD               */
#define _RAC_TXRFPKD_TXRFPKDCAPATT_tbd_24dB                               0x00000007UL                                        /**< Mode tbd_24dB for RAC_TXRFPKD               */
#define RAC_TXRFPKD_TXRFPKDCAPATT_DEFAULT                                 (_RAC_TXRFPKD_TXRFPKDCAPATT_DEFAULT << 20)          /**< Shifted mode DEFAULT for RAC_TXRFPKD        */
#define RAC_TXRFPKD_TXRFPKDCAPATT_att_15dB                                (_RAC_TXRFPKD_TXRFPKDCAPATT_att_15dB << 20)         /**< Shifted mode att_15dB for RAC_TXRFPKD       */
#define RAC_TXRFPKD_TXRFPKDCAPATT_att_18dB                                (_RAC_TXRFPKD_TXRFPKDCAPATT_att_18dB << 20)         /**< Shifted mode att_18dB for RAC_TXRFPKD       */
#define RAC_TXRFPKD_TXRFPKDCAPATT_att_21dB                                (_RAC_TXRFPKD_TXRFPKDCAPATT_att_21dB << 20)         /**< Shifted mode att_21dB for RAC_TXRFPKD       */
#define RAC_TXRFPKD_TXRFPKDCAPATT_tbd_24dB                                (_RAC_TXRFPKD_TXRFPKDCAPATT_tbd_24dB << 20)         /**< Shifted mode tbd_24dB for RAC_TXRFPKD       */

/* Bit fields for RAC TXSTATUS */
#define _RAC_TXSTATUS_RESETVALUE                                          0x00000000UL                            /**< Default value for RAC_TXSTATUS              */
#define _RAC_TXSTATUS_MASK                                                0x00000001UL                            /**< Mask for RAC_TXSTATUS                       */
#define RAC_TXSTATUS_TXRFPKDOUT                                           (0x1UL << 0)                            /**< TXRFPKDOUT                                  */
#define _RAC_TXSTATUS_TXRFPKDOUT_SHIFT                                    0                                       /**< Shift value for RAC_TXRFPKDOUT              */
#define _RAC_TXSTATUS_TXRFPKDOUT_MASK                                     0x1UL                                   /**< Bit mask for RAC_TXRFPKDOUT                 */
#define _RAC_TXSTATUS_TXRFPKDOUT_DEFAULT                                  0x00000000UL                            /**< Mode DEFAULT for RAC_TXSTATUS               */
#define _RAC_TXSTATUS_TXRFPKDOUT_tbd0                                     0x00000000UL                            /**< Mode tbd0 for RAC_TXSTATUS                  */
#define _RAC_TXSTATUS_TXRFPKDOUT_tbd1                                     0x00000001UL                            /**< Mode tbd1 for RAC_TXSTATUS                  */
#define RAC_TXSTATUS_TXRFPKDOUT_DEFAULT                                   (_RAC_TXSTATUS_TXRFPKDOUT_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_TXSTATUS       */
#define RAC_TXSTATUS_TXRFPKDOUT_tbd0                                      (_RAC_TXSTATUS_TXRFPKDOUT_tbd0 << 0)    /**< Shifted mode tbd0 for RAC_TXSTATUS          */
#define RAC_TXSTATUS_TXRFPKDOUT_tbd1                                      (_RAC_TXSTATUS_TXRFPKDOUT_tbd1 << 0)    /**< Shifted mode tbd1 for RAC_TXSTATUS          */

/* Bit fields for RAC TXOFDM */
#define _RAC_TXOFDM_RESETVALUE                                            0x00200008UL                                  /**< Default value for RAC_TXOFDM                */
#define _RAC_TXOFDM_MASK                                                  0x03BFB7FBUL                                  /**< Mask for RAC_TXOFDM                         */
#define RAC_TXOFDM_TXENBBDIGREG                                           (0x1UL << 0)                                  /**< TXENBBDIGREG                                */
#define _RAC_TXOFDM_TXENBBDIGREG_SHIFT                                    0                                             /**< Shift value for RAC_TXENBBDIGREG            */
#define _RAC_TXOFDM_TXENBBDIGREG_MASK                                     0x1UL                                         /**< Bit mask for RAC_TXENBBDIGREG               */
#define _RAC_TXOFDM_TXENBBDIGREG_DEFAULT                                  0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBBDIGREG_disabled                                 0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENBBDIGREG_enabled                                  0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENBBDIGREG_DEFAULT                                   (_RAC_TXOFDM_TXENBBDIGREG_DEFAULT << 0)       /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBBDIGREG_disabled                                  (_RAC_TXOFDM_TXENBBDIGREG_disabled << 0)      /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENBBDIGREG_enabled                                   (_RAC_TXOFDM_TXENBBDIGREG_enabled << 0)       /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBBREG                                              (0x1UL << 1)                                  /**< TXENBBREG                                   */
#define _RAC_TXOFDM_TXENBBREG_SHIFT                                       1                                             /**< Shift value for RAC_TXENBBREG               */
#define _RAC_TXOFDM_TXENBBREG_MASK                                        0x2UL                                         /**< Bit mask for RAC_TXENBBREG                  */
#define _RAC_TXOFDM_TXENBBREG_DEFAULT                                     0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBBREG_disabled                                    0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENBBREG_enabled                                     0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENBBREG_DEFAULT                                      (_RAC_TXOFDM_TXENBBREG_DEFAULT << 1)          /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBBREG_disabled                                     (_RAC_TXOFDM_TXENBBREG_disabled << 1)         /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENBBREG_enabled                                      (_RAC_TXOFDM_TXENBBREG_enabled << 1)          /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBBREGBLEED                                         (0x1UL << 3)                                  /**< TXENBBREGBLEED                              */
#define _RAC_TXOFDM_TXENBBREGBLEED_SHIFT                                  3                                             /**< Shift value for RAC_TXENBBREGBLEED          */
#define _RAC_TXOFDM_TXENBBREGBLEED_MASK                                   0x8UL                                         /**< Bit mask for RAC_TXENBBREGBLEED             */
#define _RAC_TXOFDM_TXENBBREGBLEED_DEFAULT                                0x00000001UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBBREGBLEED_bleedoff                               0x00000000UL                                  /**< Mode bleedoff for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENBBREGBLEED_bleedon                                0x00000001UL                                  /**< Mode bleedon for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENBBREGBLEED_DEFAULT                                 (_RAC_TXOFDM_TXENBBREGBLEED_DEFAULT << 3)     /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBBREGBLEED_bleedoff                                (_RAC_TXOFDM_TXENBBREGBLEED_bleedoff << 3)    /**< Shifted mode bleedoff for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENBBREGBLEED_bleedon                                 (_RAC_TXOFDM_TXENBBREGBLEED_bleedon << 3)     /**< Shifted mode bleedon for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBUF0                                               (0x1UL << 4)                                  /**< TXENBUF0                                    */
#define _RAC_TXOFDM_TXENBUF0_SHIFT                                        4                                             /**< Shift value for RAC_TXENBUF0                */
#define _RAC_TXOFDM_TXENBUF0_MASK                                         0x10UL                                        /**< Bit mask for RAC_TXENBUF0                   */
#define _RAC_TXOFDM_TXENBUF0_DEFAULT                                      0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBUF0_disable                                      0x00000000UL                                  /**< Mode disable for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBUF0_enable                                       0x00000001UL                                  /**< Mode enable for RAC_TXOFDM                  */
#define RAC_TXOFDM_TXENBUF0_DEFAULT                                       (_RAC_TXOFDM_TXENBUF0_DEFAULT << 4)           /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBUF0_disable                                       (_RAC_TXOFDM_TXENBUF0_disable << 4)           /**< Shifted mode disable for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBUF0_enable                                        (_RAC_TXOFDM_TXENBUF0_enable << 4)            /**< Shifted mode enable for RAC_TXOFDM          */
#define RAC_TXOFDM_TXENBUF1                                               (0x1UL << 5)                                  /**< TXENBUF1                                    */
#define _RAC_TXOFDM_TXENBUF1_SHIFT                                        5                                             /**< Shift value for RAC_TXENBUF1                */
#define _RAC_TXOFDM_TXENBUF1_MASK                                         0x20UL                                        /**< Bit mask for RAC_TXENBUF1                   */
#define _RAC_TXOFDM_TXENBUF1_DEFAULT                                      0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBUF1_disable                                      0x00000000UL                                  /**< Mode disable for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBUF1_enable                                       0x00000001UL                                  /**< Mode enable for RAC_TXOFDM                  */
#define RAC_TXOFDM_TXENBUF1_DEFAULT                                       (_RAC_TXOFDM_TXENBUF1_DEFAULT << 5)           /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBUF1_disable                                       (_RAC_TXOFDM_TXENBUF1_disable << 5)           /**< Shifted mode disable for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBUF1_enable                                        (_RAC_TXOFDM_TXENBUF1_enable << 5)            /**< Shifted mode enable for RAC_TXOFDM          */
#define RAC_TXOFDM_TXENBBDACI                                             (0x1UL << 6)                                  /**< TXENBBDACI                                  */
#define _RAC_TXOFDM_TXENBBDACI_SHIFT                                      6                                             /**< Shift value for RAC_TXENBBDACI              */
#define _RAC_TXOFDM_TXENBBDACI_MASK                                       0x40UL                                        /**< Bit mask for RAC_TXENBBDACI                 */
#define _RAC_TXOFDM_TXENBBDACI_DEFAULT                                    0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBBDACI_disabled                                   0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENBBDACI_enabled                                    0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENBBDACI_DEFAULT                                     (_RAC_TXOFDM_TXENBBDACI_DEFAULT << 6)         /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBBDACI_disabled                                    (_RAC_TXOFDM_TXENBBDACI_disabled << 6)        /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENBBDACI_enabled                                     (_RAC_TXOFDM_TXENBBDACI_enabled << 6)         /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBBDACQ                                             (0x1UL << 7)                                  /**< TXENBBDACQ                                  */
#define _RAC_TXOFDM_TXENBBDACQ_SHIFT                                      7                                             /**< Shift value for RAC_TXENBBDACQ              */
#define _RAC_TXOFDM_TXENBBDACQ_MASK                                       0x80UL                                        /**< Bit mask for RAC_TXENBBDACQ                 */
#define _RAC_TXOFDM_TXENBBDACQ_DEFAULT                                    0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBBDACQ_disabled                                   0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENBBDACQ_enabled                                    0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENBBDACQ_DEFAULT                                     (_RAC_TXOFDM_TXENBBDACQ_DEFAULT << 7)         /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBBDACQ_disabled                                    (_RAC_TXOFDM_TXENBBDACQ_disabled << 7)        /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENBBDACQ_enabled                                     (_RAC_TXOFDM_TXENBBDACQ_enabled << 7)         /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENMIX                                                (0x1UL << 8)                                  /**< TXENMIX                                     */
#define _RAC_TXOFDM_TXENMIX_SHIFT                                         8                                             /**< Shift value for RAC_TXENMIX                 */
#define _RAC_TXOFDM_TXENMIX_MASK                                          0x100UL                                       /**< Bit mask for RAC_TXENMIX                    */
#define _RAC_TXOFDM_TXENMIX_DEFAULT                                       0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENMIX_disable                                       0x00000000UL                                  /**< Mode disable for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENMIX_enable                                        0x00000001UL                                  /**< Mode enable for RAC_TXOFDM                  */
#define RAC_TXOFDM_TXENMIX_DEFAULT                                        (_RAC_TXOFDM_TXENMIX_DEFAULT << 8)            /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENMIX_disable                                        (_RAC_TXOFDM_TXENMIX_disable << 8)            /**< Shifted mode disable for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENMIX_enable                                         (_RAC_TXOFDM_TXENMIX_enable << 8)             /**< Shifted mode enable for RAC_TXOFDM          */
#define RAC_TXOFDM_TXENBUFREG                                             (0x1UL << 9)                                  /**< TXENBUFREG                                  */
#define _RAC_TXOFDM_TXENBUFREG_SHIFT                                      9                                             /**< Shift value for RAC_TXENBUFREG              */
#define _RAC_TXOFDM_TXENBUFREG_MASK                                       0x200UL                                       /**< Bit mask for RAC_TXENBUFREG                 */
#define _RAC_TXOFDM_TXENBUFREG_DEFAULT                                    0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBUFREG_disabled                                   0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENBUFREG_enabled                                    0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENBUFREG_DEFAULT                                     (_RAC_TXOFDM_TXENBUFREG_DEFAULT << 9)         /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBUFREG_disabled                                    (_RAC_TXOFDM_TXENBUFREG_disabled << 9)        /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENBUFREG_enabled                                     (_RAC_TXOFDM_TXENBUFREG_enabled << 9)         /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBUFREGBLEED                                        (0x1UL << 10)                                 /**< TXENBUFREGBLEED                             */
#define _RAC_TXOFDM_TXENBUFREGBLEED_SHIFT                                 10                                            /**< Shift value for RAC_TXENBUFREGBLEED         */
#define _RAC_TXOFDM_TXENBUFREGBLEED_MASK                                  0x400UL                                       /**< Bit mask for RAC_TXENBUFREGBLEED            */
#define _RAC_TXOFDM_TXENBUFREGBLEED_DEFAULT                               0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBUFREGBLEED_disabled                              0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENBUFREGBLEED_enabled                               0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENBUFREGBLEED_DEFAULT                                (_RAC_TXOFDM_TXENBUFREGBLEED_DEFAULT << 10)   /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBUFREGBLEED_disabled                               (_RAC_TXOFDM_TXENBUFREGBLEED_disabled << 10)  /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENBUFREGBLEED_enabled                                (_RAC_TXOFDM_TXENBUFREGBLEED_enabled << 10)   /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENMIXRLOAD                                           (0x1UL << 12)                                 /**< TXENMIXRLOAD                                */
#define _RAC_TXOFDM_TXENMIXRLOAD_SHIFT                                    12                                            /**< Shift value for RAC_TXENMIXRLOAD            */
#define _RAC_TXOFDM_TXENMIXRLOAD_MASK                                     0x1000UL                                      /**< Bit mask for RAC_TXENMIXRLOAD               */
#define _RAC_TXOFDM_TXENMIXRLOAD_DEFAULT                                  0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENMIXRLOAD_disable                                  0x00000000UL                                  /**< Mode disable for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENMIXRLOAD_enable                                   0x00000001UL                                  /**< Mode enable for RAC_TXOFDM                  */
#define RAC_TXOFDM_TXENMIXRLOAD_DEFAULT                                   (_RAC_TXOFDM_TXENMIXRLOAD_DEFAULT << 12)      /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENMIXRLOAD_disable                                   (_RAC_TXOFDM_TXENMIXRLOAD_disable << 12)      /**< Shifted mode disable for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENMIXRLOAD_enable                                    (_RAC_TXOFDM_TXENMIXRLOAD_enable << 12)       /**< Shifted mode enable for RAC_TXOFDM          */
#define RAC_TXOFDM_TXENPAFASTSTARTUP                                      (0x1UL << 13)                                 /**< TXENPAFASTSTARTUP                           */
#define _RAC_TXOFDM_TXENPAFASTSTARTUP_SHIFT                               13                                            /**< Shift value for RAC_TXENPAFASTSTARTUP       */
#define _RAC_TXOFDM_TXENPAFASTSTARTUP_MASK                                0x2000UL                                      /**< Bit mask for RAC_TXENPAFASTSTARTUP          */
#define _RAC_TXOFDM_TXENPAFASTSTARTUP_DEFAULT                             0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENPAFASTSTARTUP_disable                             0x00000000UL                                  /**< Mode disable for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENPAFASTSTARTUP_enable                              0x00000001UL                                  /**< Mode enable for RAC_TXOFDM                  */
#define RAC_TXOFDM_TXENPAFASTSTARTUP_DEFAULT                              (_RAC_TXOFDM_TXENPAFASTSTARTUP_DEFAULT << 13) /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENPAFASTSTARTUP_disable                              (_RAC_TXOFDM_TXENPAFASTSTARTUP_disable << 13) /**< Shifted mode disable for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENPAFASTSTARTUP_enable                               (_RAC_TXOFDM_TXENPAFASTSTARTUP_enable << 13)  /**< Shifted mode enable for RAC_TXOFDM          */
#define RAC_TXOFDM_TXENSH                                                 (0x1UL << 15)                                 /**< TXENSH                                      */
#define _RAC_TXOFDM_TXENSH_SHIFT                                          15                                            /**< Shift value for RAC_TXENSH                  */
#define _RAC_TXOFDM_TXENSH_MASK                                           0x8000UL                                      /**< Bit mask for RAC_TXENSH                     */
#define _RAC_TXOFDM_TXENSH_DEFAULT                                        0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENSH_disabled                                       0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENSH_enabled                                        0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENSH_DEFAULT                                         (_RAC_TXOFDM_TXENSH_DEFAULT << 15)            /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENSH_disabled                                        (_RAC_TXOFDM_TXENSH_disabled << 15)           /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENSH_enabled                                         (_RAC_TXOFDM_TXENSH_enabled << 15)            /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENSHINBUF                                            (0x1UL << 16)                                 /**< TXENSHINBUF                                 */
#define _RAC_TXOFDM_TXENSHINBUF_SHIFT                                     16                                            /**< Shift value for RAC_TXENSHINBUF             */
#define _RAC_TXOFDM_TXENSHINBUF_MASK                                      0x10000UL                                     /**< Bit mask for RAC_TXENSHINBUF                */
#define _RAC_TXOFDM_TXENSHINBUF_DEFAULT                                   0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENSHINBUF_disabled                                  0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENSHINBUF_enabled                                   0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENSHINBUF_DEFAULT                                    (_RAC_TXOFDM_TXENSHINBUF_DEFAULT << 16)       /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENSHINBUF_disabled                                   (_RAC_TXOFDM_TXENSHINBUF_disabled << 16)      /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENSHINBUF_enabled                                    (_RAC_TXOFDM_TXENSHINBUF_enabled << 16)       /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENSHUGB                                              (0x1UL << 17)                                 /**< TXENSHUGB                                   */
#define _RAC_TXOFDM_TXENSHUGB_SHIFT                                       17                                            /**< Shift value for RAC_TXENSHUGB               */
#define _RAC_TXOFDM_TXENSHUGB_MASK                                        0x20000UL                                     /**< Bit mask for RAC_TXENSHUGB                  */
#define _RAC_TXOFDM_TXENSHUGB_DEFAULT                                     0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENSHUGB_disabled                                    0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENSHUGB_enabled                                     0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENSHUGB_DEFAULT                                      (_RAC_TXOFDM_TXENSHUGB_DEFAULT << 17)         /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENSHUGB_disabled                                     (_RAC_TXOFDM_TXENSHUGB_disabled << 17)        /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENSHUGB_enabled                                      (_RAC_TXOFDM_TXENSHUGB_enabled << 17)         /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENFILI                                               (0x1UL << 18)                                 /**< TXENFILI                                    */
#define _RAC_TXOFDM_TXENFILI_SHIFT                                        18                                            /**< Shift value for RAC_TXENFILI                */
#define _RAC_TXOFDM_TXENFILI_MASK                                         0x40000UL                                     /**< Bit mask for RAC_TXENFILI                   */
#define _RAC_TXOFDM_TXENFILI_DEFAULT                                      0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENFILI_disabled                                     0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENFILI_enabled                                      0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENFILI_DEFAULT                                       (_RAC_TXOFDM_TXENFILI_DEFAULT << 18)          /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENFILI_disabled                                      (_RAC_TXOFDM_TXENFILI_disabled << 18)         /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENFILI_enabled                                       (_RAC_TXOFDM_TXENFILI_enabled << 18)          /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENFILQ                                               (0x1UL << 19)                                 /**< TXENFILQ                                    */
#define _RAC_TXOFDM_TXENFILQ_SHIFT                                        19                                            /**< Shift value for RAC_TXENFILQ                */
#define _RAC_TXOFDM_TXENFILQ_MASK                                         0x80000UL                                     /**< Bit mask for RAC_TXENFILQ                   */
#define _RAC_TXOFDM_TXENFILQ_DEFAULT                                      0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENFILQ_disabled                                     0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENFILQ_enabled                                      0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENFILQ_DEFAULT                                       (_RAC_TXOFDM_TXENFILQ_DEFAULT << 19)          /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENFILQ_disabled                                      (_RAC_TXOFDM_TXENFILQ_disabled << 19)         /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENFILQ_enabled                                       (_RAC_TXOFDM_TXENFILQ_enabled << 19)          /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBBDATA                                             (0x1UL << 20)                                 /**< TXENBBDATA                                  */
#define _RAC_TXOFDM_TXENBBDATA_SHIFT                                      20                                            /**< Shift value for RAC_TXENBBDATA              */
#define _RAC_TXOFDM_TXENBBDATA_MASK                                       0x100000UL                                    /**< Bit mask for RAC_TXENBBDATA                 */
#define _RAC_TXOFDM_TXENBBDATA_DEFAULT                                    0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENBBDATA_disabled                                   0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENBBDATA_enabled                                    0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENBBDATA_DEFAULT                                     (_RAC_TXOFDM_TXENBBDATA_DEFAULT << 20)        /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENBBDATA_disabled                                    (_RAC_TXOFDM_TXENBBDATA_disabled << 20)       /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENBBDATA_enabled                                     (_RAC_TXOFDM_TXENBBDATA_enabled << 20)        /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENPACMOS                                             (0x1UL << 21)                                 /**< TXENPACMOS                                  */
#define _RAC_TXOFDM_TXENPACMOS_SHIFT                                      21                                            /**< Shift value for RAC_TXENPACMOS              */
#define _RAC_TXOFDM_TXENPACMOS_MASK                                       0x200000UL                                    /**< Bit mask for RAC_TXENPACMOS                 */
#define _RAC_TXOFDM_TXENPACMOS_DEFAULT                                    0x00000001UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENPACMOS_opendrain                                  0x00000000UL                                  /**< Mode opendrain for RAC_TXOFDM               */
#define _RAC_TXOFDM_TXENPACMOS_cmos                                       0x00000001UL                                  /**< Mode cmos for RAC_TXOFDM                    */
#define RAC_TXOFDM_TXENPACMOS_DEFAULT                                     (_RAC_TXOFDM_TXENPACMOS_DEFAULT << 21)        /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENPACMOS_opendrain                                   (_RAC_TXOFDM_TXENPACMOS_opendrain << 21)      /**< Shifted mode opendrain for RAC_TXOFDM       */
#define RAC_TXOFDM_TXENPACMOS_cmos                                        (_RAC_TXOFDM_TXENPACMOS_cmos << 21)           /**< Shifted mode cmos for RAC_TXOFDM            */
#define RAC_TXOFDM_TXENTXBIAS                                             (0x1UL << 23)                                 /**< TXENTXBIAS                                  */
#define _RAC_TXOFDM_TXENTXBIAS_SHIFT                                      23                                            /**< Shift value for RAC_TXENTXBIAS              */
#define _RAC_TXOFDM_TXENTXBIAS_MASK                                       0x800000UL                                    /**< Bit mask for RAC_TXENTXBIAS                 */
#define _RAC_TXOFDM_TXENTXBIAS_DEFAULT                                    0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXENTXBIAS_disabled                                   0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXENTXBIAS_enabled                                    0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXENTXBIAS_DEFAULT                                     (_RAC_TXOFDM_TXENTXBIAS_DEFAULT << 23)        /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXENTXBIAS_disabled                                    (_RAC_TXOFDM_TXENTXBIAS_disabled << 23)       /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXENTXBIAS_enabled                                     (_RAC_TXOFDM_TXENTXBIAS_enabled << 23)        /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXRESETSHCLKDIV                                        (0x1UL << 24)                                 /**< TXRESETSHCLKDIV                             */
#define _RAC_TXOFDM_TXRESETSHCLKDIV_SHIFT                                 24                                            /**< Shift value for RAC_TXRESETSHCLKDIV         */
#define _RAC_TXOFDM_TXRESETSHCLKDIV_MASK                                  0x1000000UL                                   /**< Bit mask for RAC_TXRESETSHCLKDIV            */
#define _RAC_TXOFDM_TXRESETSHCLKDIV_DEFAULT                               0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXRESETSHCLKDIV_disabled                              0x00000000UL                                  /**< Mode disabled for RAC_TXOFDM                */
#define _RAC_TXOFDM_TXRESETSHCLKDIV_enabled                               0x00000001UL                                  /**< Mode enabled for RAC_TXOFDM                 */
#define RAC_TXOFDM_TXRESETSHCLKDIV_DEFAULT                                (_RAC_TXOFDM_TXRESETSHCLKDIV_DEFAULT << 24)   /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXRESETSHCLKDIV_disabled                               (_RAC_TXOFDM_TXRESETSHCLKDIV_disabled << 24)  /**< Shifted mode disabled for RAC_TXOFDM        */
#define RAC_TXOFDM_TXRESETSHCLKDIV_enabled                                (_RAC_TXOFDM_TXRESETSHCLKDIV_enabled << 24)   /**< Shifted mode enabled for RAC_TXOFDM         */
#define RAC_TXOFDM_TXSELPABIASMODE                                        (0x1UL << 25)                                 /**< TXSELPABIASMODE                             */
#define _RAC_TXOFDM_TXSELPABIASMODE_SHIFT                                 25                                            /**< Shift value for RAC_TXSELPABIASMODE         */
#define _RAC_TXOFDM_TXSELPABIASMODE_MASK                                  0x2000000UL                                   /**< Bit mask for RAC_TXSELPABIASMODE            */
#define _RAC_TXOFDM_TXSELPABIASMODE_DEFAULT                               0x00000000UL                                  /**< Mode DEFAULT for RAC_TXOFDM                 */
#define _RAC_TXOFDM_TXSELPABIASMODE_ofdm                                  0x00000000UL                                  /**< Mode ofdm for RAC_TXOFDM                    */
#define _RAC_TXOFDM_TXSELPABIASMODE_fsk                                   0x00000001UL                                  /**< Mode fsk for RAC_TXOFDM                     */
#define RAC_TXOFDM_TXSELPABIASMODE_DEFAULT                                (_RAC_TXOFDM_TXSELPABIASMODE_DEFAULT << 25)   /**< Shifted mode DEFAULT for RAC_TXOFDM         */
#define RAC_TXOFDM_TXSELPABIASMODE_ofdm                                   (_RAC_TXOFDM_TXSELPABIASMODE_ofdm << 25)      /**< Shifted mode ofdm for RAC_TXOFDM            */
#define RAC_TXOFDM_TXSELPABIASMODE_fsk                                    (_RAC_TXOFDM_TXSELPABIASMODE_fsk << 25)       /**< Shifted mode fsk for RAC_TXOFDM             */

/* Bit fields for RAC TXMIX */
#define _RAC_TXMIX_RESETVALUE                                             0x00001100UL                                      /**< Default value for RAC_TXMIX                 */
#define _RAC_TXMIX_MASK                                                   0x1FFFFFFFUL                                      /**< Mask for RAC_TXMIX                          */
#define _RAC_TXMIX_TXSELMIXCTUNE_SHIFT                                    0                                                 /**< Shift value for RAC_TXSELMIXCTUNE           */
#define _RAC_TXMIX_TXSELMIXCTUNE_MASK                                     0x3FUL                                            /**< Bit mask for RAC_TXSELMIXCTUNE              */
#define _RAC_TXMIX_TXSELMIXCTUNE_DEFAULT                                  0x00000000UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELMIXCTUNE_tbd0                                     0x00000000UL                                      /**< Mode tbd0 for RAC_TXMIX                     */
#define _RAC_TXMIX_TXSELMIXCTUNE_tbd1                                     0x00000001UL                                      /**< Mode tbd1 for RAC_TXMIX                     */
#define RAC_TXMIX_TXSELMIXCTUNE_DEFAULT                                   (_RAC_TXMIX_TXSELMIXCTUNE_DEFAULT << 0)           /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXSELMIXCTUNE_tbd0                                      (_RAC_TXMIX_TXSELMIXCTUNE_tbd0 << 0)              /**< Shifted mode tbd0 for RAC_TXMIX             */
#define RAC_TXMIX_TXSELMIXCTUNE_tbd1                                      (_RAC_TXMIX_TXSELMIXCTUNE_tbd1 << 0)              /**< Shifted mode tbd1 for RAC_TXMIX             */
#define _RAC_TXMIX_TXSELMIXGMSLICEI_SHIFT                                 6                                                 /**< Shift value for RAC_TXSELMIXGMSLICEI        */
#define _RAC_TXMIX_TXSELMIXGMSLICEI_MASK                                  0x3C0UL                                           /**< Bit mask for RAC_TXSELMIXGMSLICEI           */
#define _RAC_TXMIX_TXSELMIXGMSLICEI_DEFAULT                               0x00000004UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELMIXGMSLICEI_tbd0                                  0x00000000UL                                      /**< Mode tbd0 for RAC_TXMIX                     */
#define _RAC_TXMIX_TXSELMIXGMSLICEI_tbd1                                  0x00000001UL                                      /**< Mode tbd1 for RAC_TXMIX                     */
#define RAC_TXMIX_TXSELMIXGMSLICEI_DEFAULT                                (_RAC_TXMIX_TXSELMIXGMSLICEI_DEFAULT << 6)        /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXSELMIXGMSLICEI_tbd0                                   (_RAC_TXMIX_TXSELMIXGMSLICEI_tbd0 << 6)           /**< Shifted mode tbd0 for RAC_TXMIX             */
#define RAC_TXMIX_TXSELMIXGMSLICEI_tbd1                                   (_RAC_TXMIX_TXSELMIXGMSLICEI_tbd1 << 6)           /**< Shifted mode tbd1 for RAC_TXMIX             */
#define _RAC_TXMIX_TXSELMIXGMSLICEQ_SHIFT                                 10                                                /**< Shift value for RAC_TXSELMIXGMSLICEQ        */
#define _RAC_TXMIX_TXSELMIXGMSLICEQ_MASK                                  0x3C00UL                                          /**< Bit mask for RAC_TXSELMIXGMSLICEQ           */
#define _RAC_TXMIX_TXSELMIXGMSLICEQ_DEFAULT                               0x00000004UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELMIXGMSLICEQ_tbd0                                  0x00000000UL                                      /**< Mode tbd0 for RAC_TXMIX                     */
#define _RAC_TXMIX_TXSELMIXGMSLICEQ_tbd1                                  0x00000001UL                                      /**< Mode tbd1 for RAC_TXMIX                     */
#define RAC_TXMIX_TXSELMIXGMSLICEQ_DEFAULT                                (_RAC_TXMIX_TXSELMIXGMSLICEQ_DEFAULT << 10)       /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXSELMIXGMSLICEQ_tbd0                                   (_RAC_TXMIX_TXSELMIXGMSLICEQ_tbd0 << 10)          /**< Shifted mode tbd0 for RAC_TXMIX             */
#define RAC_TXMIX_TXSELMIXGMSLICEQ_tbd1                                   (_RAC_TXMIX_TXSELMIXGMSLICEQ_tbd1 << 10)          /**< Shifted mode tbd1 for RAC_TXMIX             */
#define _RAC_TXMIX_TXSELMIXRLOAD_SHIFT                                    14                                                /**< Shift value for RAC_TXSELMIXRLOAD           */
#define _RAC_TXMIX_TXSELMIXRLOAD_MASK                                     0x1C000UL                                         /**< Bit mask for RAC_TXSELMIXRLOAD              */
#define _RAC_TXMIX_TXSELMIXRLOAD_DEFAULT                                  0x00000000UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELMIXRLOAD_off                                      0x00000000UL                                      /**< Mode off for RAC_TXMIX                      */
#define _RAC_TXMIX_TXSELMIXRLOAD_r5p00K                                   0x00000001UL                                      /**< Mode r5p00K for RAC_TXMIX                   */
#define _RAC_TXMIX_TXSELMIXRLOAD_r2p50K                                   0x00000002UL                                      /**< Mode r2p50K for RAC_TXMIX                   */
#define _RAC_TXMIX_TXSELMIXRLOAD_r1p67K                                   0x00000003UL                                      /**< Mode r1p67K for RAC_TXMIX                   */
#define _RAC_TXMIX_TXSELMIXRLOAD_r1p25K                                   0x00000004UL                                      /**< Mode r1p25K for RAC_TXMIX                   */
#define _RAC_TXMIX_TXSELMIXRLOAD_r1p00K                                   0x00000005UL                                      /**< Mode r1p00K for RAC_TXMIX                   */
#define _RAC_TXMIX_TXSELMIXRLOAD_r0p83K                                   0x00000006UL                                      /**< Mode r0p83K for RAC_TXMIX                   */
#define _RAC_TXMIX_TXSELMIXRLOAD_r0p71K                                   0x00000007UL                                      /**< Mode r0p71K for RAC_TXMIX                   */
#define RAC_TXMIX_TXSELMIXRLOAD_DEFAULT                                   (_RAC_TXMIX_TXSELMIXRLOAD_DEFAULT << 14)          /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXSELMIXRLOAD_off                                       (_RAC_TXMIX_TXSELMIXRLOAD_off << 14)              /**< Shifted mode off for RAC_TXMIX              */
#define RAC_TXMIX_TXSELMIXRLOAD_r5p00K                                    (_RAC_TXMIX_TXSELMIXRLOAD_r5p00K << 14)           /**< Shifted mode r5p00K for RAC_TXMIX           */
#define RAC_TXMIX_TXSELMIXRLOAD_r2p50K                                    (_RAC_TXMIX_TXSELMIXRLOAD_r2p50K << 14)           /**< Shifted mode r2p50K for RAC_TXMIX           */
#define RAC_TXMIX_TXSELMIXRLOAD_r1p67K                                    (_RAC_TXMIX_TXSELMIXRLOAD_r1p67K << 14)           /**< Shifted mode r1p67K for RAC_TXMIX           */
#define RAC_TXMIX_TXSELMIXRLOAD_r1p25K                                    (_RAC_TXMIX_TXSELMIXRLOAD_r1p25K << 14)           /**< Shifted mode r1p25K for RAC_TXMIX           */
#define RAC_TXMIX_TXSELMIXRLOAD_r1p00K                                    (_RAC_TXMIX_TXSELMIXRLOAD_r1p00K << 14)           /**< Shifted mode r1p00K for RAC_TXMIX           */
#define RAC_TXMIX_TXSELMIXRLOAD_r0p83K                                    (_RAC_TXMIX_TXSELMIXRLOAD_r0p83K << 14)           /**< Shifted mode r0p83K for RAC_TXMIX           */
#define RAC_TXMIX_TXSELMIXRLOAD_r0p71K                                    (_RAC_TXMIX_TXSELMIXRLOAD_r0p71K << 14)           /**< Shifted mode r0p71K for RAC_TXMIX           */
#define RAC_TXMIX_TXSELMIXBAND                                            (0x1UL << 17)                                     /**< TXSELMIXBAND                                */
#define _RAC_TXMIX_TXSELMIXBAND_SHIFT                                     17                                                /**< Shift value for RAC_TXSELMIXBAND            */
#define _RAC_TXMIX_TXSELMIXBAND_MASK                                      0x20000UL                                         /**< Bit mask for RAC_TXSELMIXBAND               */
#define _RAC_TXMIX_TXSELMIXBAND_DEFAULT                                   0x00000000UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELMIXBAND_low                                       0x00000000UL                                      /**< Mode low for RAC_TXMIX                      */
#define _RAC_TXMIX_TXSELMIXBAND_high                                      0x00000001UL                                      /**< Mode high for RAC_TXMIX                     */
#define RAC_TXMIX_TXSELMIXBAND_DEFAULT                                    (_RAC_TXMIX_TXSELMIXBAND_DEFAULT << 17)           /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXSELMIXBAND_low                                        (_RAC_TXMIX_TXSELMIXBAND_low << 17)               /**< Shifted mode low for RAC_TXMIX              */
#define RAC_TXMIX_TXSELMIXBAND_high                                       (_RAC_TXMIX_TXSELMIXBAND_high << 17)              /**< Shifted mode high for RAC_TXMIX             */
#define _RAC_TXMIX_TXSELMIXRDEG_SHIFT                                     18                                                /**< Shift value for RAC_TXSELMIXRDEG            */
#define _RAC_TXMIX_TXSELMIXRDEG_MASK                                      0x1C0000UL                                        /**< Bit mask for RAC_TXSELMIXRDEG               */
#define _RAC_TXMIX_TXSELMIXRDEG_DEFAULT                                   0x00000000UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define RAC_TXMIX_TXSELMIXRDEG_DEFAULT                                    (_RAC_TXMIX_TXSELMIXRDEG_DEFAULT << 18)           /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXMIXCAPPULLDOWN                                        (0x1UL << 21)                                     /**< TXMIXCAPPULLDOWN                            */
#define _RAC_TXMIX_TXMIXCAPPULLDOWN_SHIFT                                 21                                                /**< Shift value for RAC_TXMIXCAPPULLDOWN        */
#define _RAC_TXMIX_TXMIXCAPPULLDOWN_MASK                                  0x200000UL                                        /**< Bit mask for RAC_TXMIXCAPPULLDOWN           */
#define _RAC_TXMIX_TXMIXCAPPULLDOWN_DEFAULT                               0x00000000UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define _RAC_TXMIX_TXMIXCAPPULLDOWN_cap_to_supply                         0x00000000UL                                      /**< Mode cap_to_supply for RAC_TXMIX            */
#define _RAC_TXMIX_TXMIXCAPPULLDOWN_cap_to_ground                         0x00000001UL                                      /**< Mode cap_to_ground for RAC_TXMIX            */
#define RAC_TXMIX_TXMIXCAPPULLDOWN_DEFAULT                                (_RAC_TXMIX_TXMIXCAPPULLDOWN_DEFAULT << 21)       /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXMIXCAPPULLDOWN_cap_to_supply                          (_RAC_TXMIX_TXMIXCAPPULLDOWN_cap_to_supply << 21) /**< Shifted mode cap_to_supply for RAC_TXMIX    */
#define RAC_TXMIX_TXMIXCAPPULLDOWN_cap_to_ground                          (_RAC_TXMIX_TXMIXCAPPULLDOWN_cap_to_ground << 21) /**< Shifted mode cap_to_ground for RAC_TXMIX    */
#define RAC_TXMIX_TXSELSHINPUT                                            (0x1UL << 22)                                     /**< TXSELSHINPUT                                */
#define _RAC_TXMIX_TXSELSHINPUT_SHIFT                                     22                                                /**< Shift value for RAC_TXSELSHINPUT            */
#define _RAC_TXMIX_TXSELSHINPUT_MASK                                      0x400000UL                                        /**< Bit mask for RAC_TXSELSHINPUT               */
#define _RAC_TXMIX_TXSELSHINPUT_DEFAULT                                   0x00000000UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELSHINPUT_input_hp                                  0x00000000UL                                      /**< Mode input_hp for RAC_TXMIX                 */
#define _RAC_TXMIX_TXSELSHINPUT_input_lp                                  0x00000001UL                                      /**< Mode input_lp for RAC_TXMIX                 */
#define RAC_TXMIX_TXSELSHINPUT_DEFAULT                                    (_RAC_TXMIX_TXSELSHINPUT_DEFAULT << 22)           /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXSELSHINPUT_input_hp                                   (_RAC_TXMIX_TXSELSHINPUT_input_hp << 22)          /**< Shifted mode input_hp for RAC_TXMIX         */
#define RAC_TXMIX_TXSELSHINPUT_input_lp                                   (_RAC_TXMIX_TXSELSHINPUT_input_lp << 22)          /**< Shifted mode input_lp for RAC_TXMIX         */
#define _RAC_TXMIX_TXSELSHCAPATTN_SHIFT                                   23                                                /**< Shift value for RAC_TXSELSHCAPATTN          */
#define _RAC_TXMIX_TXSELSHCAPATTN_MASK                                    0x3800000UL                                       /**< Bit mask for RAC_TXSELSHCAPATTN             */
#define _RAC_TXMIX_TXSELSHCAPATTN_DEFAULT                                 0x00000000UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELSHCAPATTN_Att_7dB                                 0x00000000UL                                      /**< Mode Att_7dB for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELSHCAPATTN_Att_11dB                                0x00000001UL                                      /**< Mode Att_11dB for RAC_TXMIX                 */
#define _RAC_TXMIX_TXSELSHCAPATTN_Att_15dB                                0x00000002UL                                      /**< Mode Att_15dB for RAC_TXMIX                 */
#define _RAC_TXMIX_TXSELSHCAPATTN_Att_18dB                                0x00000003UL                                      /**< Mode Att_18dB for RAC_TXMIX                 */
#define _RAC_TXMIX_TXSELSHCAPATTN_Att_22dB                                0x00000004UL                                      /**< Mode Att_22dB for RAC_TXMIX                 */
#define _RAC_TXMIX_TXSELSHCAPATTN_Att_25dB_1                              0x00000005UL                                      /**< Mode Att_25dB_1 for RAC_TXMIX               */
#define _RAC_TXMIX_TXSELSHCAPATTN_Att_25dB_2                              0x00000006UL                                      /**< Mode Att_25dB_2 for RAC_TXMIX               */
#define _RAC_TXMIX_TXSELSHCAPATTN_Att_25dB_3                              0x00000007UL                                      /**< Mode Att_25dB_3 for RAC_TXMIX               */
#define RAC_TXMIX_TXSELSHCAPATTN_DEFAULT                                  (_RAC_TXMIX_TXSELSHCAPATTN_DEFAULT << 23)         /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXSELSHCAPATTN_Att_7dB                                  (_RAC_TXMIX_TXSELSHCAPATTN_Att_7dB << 23)         /**< Shifted mode Att_7dB for RAC_TXMIX          */
#define RAC_TXMIX_TXSELSHCAPATTN_Att_11dB                                 (_RAC_TXMIX_TXSELSHCAPATTN_Att_11dB << 23)        /**< Shifted mode Att_11dB for RAC_TXMIX         */
#define RAC_TXMIX_TXSELSHCAPATTN_Att_15dB                                 (_RAC_TXMIX_TXSELSHCAPATTN_Att_15dB << 23)        /**< Shifted mode Att_15dB for RAC_TXMIX         */
#define RAC_TXMIX_TXSELSHCAPATTN_Att_18dB                                 (_RAC_TXMIX_TXSELSHCAPATTN_Att_18dB << 23)        /**< Shifted mode Att_18dB for RAC_TXMIX         */
#define RAC_TXMIX_TXSELSHCAPATTN_Att_22dB                                 (_RAC_TXMIX_TXSELSHCAPATTN_Att_22dB << 23)        /**< Shifted mode Att_22dB for RAC_TXMIX         */
#define RAC_TXMIX_TXSELSHCAPATTN_Att_25dB_1                               (_RAC_TXMIX_TXSELSHCAPATTN_Att_25dB_1 << 23)      /**< Shifted mode Att_25dB_1 for RAC_TXMIX       */
#define RAC_TXMIX_TXSELSHCAPATTN_Att_25dB_2                               (_RAC_TXMIX_TXSELSHCAPATTN_Att_25dB_2 << 23)      /**< Shifted mode Att_25dB_2 for RAC_TXMIX       */
#define RAC_TXMIX_TXSELSHCAPATTN_Att_25dB_3                               (_RAC_TXMIX_TXSELSHCAPATTN_Att_25dB_3 << 23)      /**< Shifted mode Att_25dB_3 for RAC_TXMIX       */
#define _RAC_TXMIX_TXSELSHCLKDIV_SHIFT                                    26                                                /**< Shift value for RAC_TXSELSHCLKDIV           */
#define _RAC_TXMIX_TXSELSHCLKDIV_MASK                                     0xC000000UL                                       /**< Bit mask for RAC_TXSELSHCLKDIV              */
#define _RAC_TXMIX_TXSELSHCLKDIV_DEFAULT                                  0x00000000UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELSHCLKDIV_FS_40MHz                                 0x00000000UL                                      /**< Mode FS_40MHz for RAC_TXMIX                 */
#define _RAC_TXMIX_TXSELSHCLKDIV_FS_20MHz                                 0x00000001UL                                      /**< Mode FS_20MHz for RAC_TXMIX                 */
#define _RAC_TXMIX_TXSELSHCLKDIV_FS_5MHz                                  0x00000002UL                                      /**< Mode FS_5MHz for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELSHCLKDIV_FS_2p5MHz                                0x00000003UL                                      /**< Mode FS_2p5MHz for RAC_TXMIX                */
#define RAC_TXMIX_TXSELSHCLKDIV_DEFAULT                                   (_RAC_TXMIX_TXSELSHCLKDIV_DEFAULT << 26)          /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXSELSHCLKDIV_FS_40MHz                                  (_RAC_TXMIX_TXSELSHCLKDIV_FS_40MHz << 26)         /**< Shifted mode FS_40MHz for RAC_TXMIX         */
#define RAC_TXMIX_TXSELSHCLKDIV_FS_20MHz                                  (_RAC_TXMIX_TXSELSHCLKDIV_FS_20MHz << 26)         /**< Shifted mode FS_20MHz for RAC_TXMIX         */
#define RAC_TXMIX_TXSELSHCLKDIV_FS_5MHz                                   (_RAC_TXMIX_TXSELSHCLKDIV_FS_5MHz << 26)          /**< Shifted mode FS_5MHz for RAC_TXMIX          */
#define RAC_TXMIX_TXSELSHCLKDIV_FS_2p5MHz                                 (_RAC_TXMIX_TXSELSHCLKDIV_FS_2p5MHz << 26)        /**< Shifted mode FS_2p5MHz for RAC_TXMIX        */
#define RAC_TXMIX_TXSELSHINBUFATTN                                        (0x1UL << 28)                                     /**< TXSELSHINBUFATTN                            */
#define _RAC_TXMIX_TXSELSHINBUFATTN_SHIFT                                 28                                                /**< Shift value for RAC_TXSELSHINBUFATTN        */
#define _RAC_TXMIX_TXSELSHINBUFATTN_MASK                                  0x10000000UL                                      /**< Bit mask for RAC_TXSELSHINBUFATTN           */
#define _RAC_TXMIX_TXSELSHINBUFATTN_DEFAULT                               0x00000000UL                                      /**< Mode DEFAULT for RAC_TXMIX                  */
#define _RAC_TXMIX_TXSELSHINBUFATTN_attn_6dB                              0x00000000UL                                      /**< Mode attn_6dB for RAC_TXMIX                 */
#define _RAC_TXMIX_TXSELSHINBUFATTN_attn_10dB                             0x00000001UL                                      /**< Mode attn_10dB for RAC_TXMIX                */
#define RAC_TXMIX_TXSELSHINBUFATTN_DEFAULT                                (_RAC_TXMIX_TXSELSHINBUFATTN_DEFAULT << 28)       /**< Shifted mode DEFAULT for RAC_TXMIX          */
#define RAC_TXMIX_TXSELSHINBUFATTN_attn_6dB                               (_RAC_TXMIX_TXSELSHINBUFATTN_attn_6dB << 28)      /**< Shifted mode attn_6dB for RAC_TXMIX         */
#define RAC_TXMIX_TXSELSHINBUFATTN_attn_10dB                              (_RAC_TXMIX_TXSELSHINBUFATTN_attn_10dB << 28)     /**< Shifted mode attn_10dB for RAC_TXMIX        */

/* Bit fields for RAC TXITC */
#define _RAC_TXITC_RESETVALUE                                             0x00000040UL                               /**< Default value for RAC_TXITC                 */
#define _RAC_TXITC_MASK                                                   0x000000F3UL                               /**< Mask for RAC_TXITC                          */
#define RAC_TXITC_TXSELITCDAC                                             (0x1UL << 0)                               /**< TXSELITCDAC                                 */
#define _RAC_TXITC_TXSELITCDAC_SHIFT                                      0                                          /**< Shift value for RAC_TXSELITCDAC             */
#define _RAC_TXITC_TXSELITCDAC_MASK                                       0x1UL                                      /**< Bit mask for RAC_TXSELITCDAC                */
#define _RAC_TXITC_TXSELITCDAC_DEFAULT                                    0x00000000UL                               /**< Mode DEFAULT for RAC_TXITC                  */
#define _RAC_TXITC_TXSELITCDAC_wo_tempco                                  0x00000000UL                               /**< Mode wo_tempco for RAC_TXITC                */
#define _RAC_TXITC_TXSELITCDAC_wi_tempco                                  0x00000001UL                               /**< Mode wi_tempco for RAC_TXITC                */
#define RAC_TXITC_TXSELITCDAC_DEFAULT                                     (_RAC_TXITC_TXSELITCDAC_DEFAULT << 0)      /**< Shifted mode DEFAULT for RAC_TXITC          */
#define RAC_TXITC_TXSELITCDAC_wo_tempco                                   (_RAC_TXITC_TXSELITCDAC_wo_tempco << 0)    /**< Shifted mode wo_tempco for RAC_TXITC        */
#define RAC_TXITC_TXSELITCDAC_wi_tempco                                   (_RAC_TXITC_TXSELITCDAC_wi_tempco << 0)    /**< Shifted mode wi_tempco for RAC_TXITC        */
#define RAC_TXITC_TXSELITCPA                                              (0x1UL << 1)                               /**< TXSELITCPA                                  */
#define _RAC_TXITC_TXSELITCPA_SHIFT                                       1                                          /**< Shift value for RAC_TXSELITCPA              */
#define _RAC_TXITC_TXSELITCPA_MASK                                        0x2UL                                      /**< Bit mask for RAC_TXSELITCPA                 */
#define _RAC_TXITC_TXSELITCPA_DEFAULT                                     0x00000000UL                               /**< Mode DEFAULT for RAC_TXITC                  */
#define _RAC_TXITC_TXSELITCPA_wo_tempco                                   0x00000000UL                               /**< Mode wo_tempco for RAC_TXITC                */
#define _RAC_TXITC_TXSELITCPA_wi_tempco                                   0x00000001UL                               /**< Mode wi_tempco for RAC_TXITC                */
#define RAC_TXITC_TXSELITCPA_DEFAULT                                      (_RAC_TXITC_TXSELITCPA_DEFAULT << 1)       /**< Shifted mode DEFAULT for RAC_TXITC          */
#define RAC_TXITC_TXSELITCPA_wo_tempco                                    (_RAC_TXITC_TXSELITCPA_wo_tempco << 1)     /**< Shifted mode wo_tempco for RAC_TXITC        */
#define RAC_TXITC_TXSELITCPA_wi_tempco                                    (_RAC_TXITC_TXSELITCPA_wi_tempco << 1)     /**< Shifted mode wi_tempco for RAC_TXITC        */
#define _RAC_TXITC_TXSELITCDACLEVEL_SHIFT                                 4                                          /**< Shift value for RAC_TXSELITCDACLEVEL        */
#define _RAC_TXITC_TXSELITCDACLEVEL_MASK                                  0x30UL                                     /**< Bit mask for RAC_TXSELITCDACLEVEL           */
#define _RAC_TXITC_TXSELITCDACLEVEL_DEFAULT                               0x00000000UL                               /**< Mode DEFAULT for RAC_TXITC                  */
#define _RAC_TXITC_TXSELITCDACLEVEL_tbd_0                                 0x00000000UL                               /**< Mode tbd_0 for RAC_TXITC                    */
#define _RAC_TXITC_TXSELITCDACLEVEL_tbd_1                                 0x00000001UL                               /**< Mode tbd_1 for RAC_TXITC                    */
#define _RAC_TXITC_TXSELITCDACLEVEL_tbd_2                                 0x00000002UL                               /**< Mode tbd_2 for RAC_TXITC                    */
#define _RAC_TXITC_TXSELITCDACLEVEL_tbd_3                                 0x00000003UL                               /**< Mode tbd_3 for RAC_TXITC                    */
#define RAC_TXITC_TXSELITCDACLEVEL_DEFAULT                                (_RAC_TXITC_TXSELITCDACLEVEL_DEFAULT << 4) /**< Shifted mode DEFAULT for RAC_TXITC          */
#define RAC_TXITC_TXSELITCDACLEVEL_tbd_0                                  (_RAC_TXITC_TXSELITCDACLEVEL_tbd_0 << 4)   /**< Shifted mode tbd_0 for RAC_TXITC            */
#define RAC_TXITC_TXSELITCDACLEVEL_tbd_1                                  (_RAC_TXITC_TXSELITCDACLEVEL_tbd_1 << 4)   /**< Shifted mode tbd_1 for RAC_TXITC            */
#define RAC_TXITC_TXSELITCDACLEVEL_tbd_2                                  (_RAC_TXITC_TXSELITCDACLEVEL_tbd_2 << 4)   /**< Shifted mode tbd_2 for RAC_TXITC            */
#define RAC_TXITC_TXSELITCDACLEVEL_tbd_3                                  (_RAC_TXITC_TXSELITCDACLEVEL_tbd_3 << 4)   /**< Shifted mode tbd_3 for RAC_TXITC            */
#define _RAC_TXITC_TXSELITCPALEVEL_SHIFT                                  6                                          /**< Shift value for RAC_TXSELITCPALEVEL         */
#define _RAC_TXITC_TXSELITCPALEVEL_MASK                                   0xC0UL                                     /**< Bit mask for RAC_TXSELITCPALEVEL            */
#define _RAC_TXITC_TXSELITCPALEVEL_DEFAULT                                0x00000001UL                               /**< Mode DEFAULT for RAC_TXITC                  */
#define _RAC_TXITC_TXSELITCPALEVEL_t3350                                  0x00000000UL                               /**< Mode t3350 for RAC_TXITC                    */
#define _RAC_TXITC_TXSELITCPALEVEL_t2800                                  0x00000001UL                               /**< Mode t2800 for RAC_TXITC                    */
#define _RAC_TXITC_TXSELITCPALEVEL_t2400                                  0x00000002UL                               /**< Mode t2400 for RAC_TXITC                    */
#define _RAC_TXITC_TXSELITCPALEVEL_t2000                                  0x00000003UL                               /**< Mode t2000 for RAC_TXITC                    */
#define RAC_TXITC_TXSELITCPALEVEL_DEFAULT                                 (_RAC_TXITC_TXSELITCPALEVEL_DEFAULT << 6)  /**< Shifted mode DEFAULT for RAC_TXITC          */
#define RAC_TXITC_TXSELITCPALEVEL_t3350                                   (_RAC_TXITC_TXSELITCPALEVEL_t3350 << 6)    /**< Shifted mode t3350 for RAC_TXITC            */
#define RAC_TXITC_TXSELITCPALEVEL_t2800                                   (_RAC_TXITC_TXSELITCPALEVEL_t2800 << 6)    /**< Shifted mode t2800 for RAC_TXITC            */
#define RAC_TXITC_TXSELITCPALEVEL_t2400                                   (_RAC_TXITC_TXSELITCPALEVEL_t2400 << 6)    /**< Shifted mode t2400 for RAC_TXITC            */
#define RAC_TXITC_TXSELITCPALEVEL_t2000                                   (_RAC_TXITC_TXSELITCPALEVEL_t2000 << 6)    /**< Shifted mode t2000 for RAC_TXITC            */

/* Bit fields for RAC TXCALITC */
#define _RAC_TXCALITC_RESETVALUE                                          0x03C20830UL                                 /**< Default value for RAC_TXCALITC              */
#define _RAC_TXCALITC_MASK                                                0x07CF7DF3UL                                 /**< Mask for RAC_TXCALITC                       */
#define RAC_TXCALITC_TXCALENITCDAC                                        (0x1UL << 0)                                 /**< TXCALENITCDAC                               */
#define _RAC_TXCALITC_TXCALENITCDAC_SHIFT                                 0                                            /**< Shift value for RAC_TXCALENITCDAC           */
#define _RAC_TXCALITC_TXCALENITCDAC_MASK                                  0x1UL                                        /**< Bit mask for RAC_TXCALENITCDAC              */
#define _RAC_TXCALITC_TXCALENITCDAC_DEFAULT                               0x00000000UL                                 /**< Mode DEFAULT for RAC_TXCALITC               */
#define _RAC_TXCALITC_TXCALENITCDAC_disabled                              0x00000000UL                                 /**< Mode disabled for RAC_TXCALITC              */
#define _RAC_TXCALITC_TXCALENITCDAC_enabled                               0x00000001UL                                 /**< Mode enabled for RAC_TXCALITC               */
#define RAC_TXCALITC_TXCALENITCDAC_DEFAULT                                (_RAC_TXCALITC_TXCALENITCDAC_DEFAULT << 0)   /**< Shifted mode DEFAULT for RAC_TXCALITC       */
#define RAC_TXCALITC_TXCALENITCDAC_disabled                               (_RAC_TXCALITC_TXCALENITCDAC_disabled << 0)  /**< Shifted mode disabled for RAC_TXCALITC      */
#define RAC_TXCALITC_TXCALENITCDAC_enabled                                (_RAC_TXCALITC_TXCALENITCDAC_enabled << 0)   /**< Shifted mode enabled for RAC_TXCALITC       */
#define RAC_TXCALITC_TXCALENITCPA                                         (0x1UL << 1)                                 /**< TXCALENITCPA                                */
#define _RAC_TXCALITC_TXCALENITCPA_SHIFT                                  1                                            /**< Shift value for RAC_TXCALENITCPA            */
#define _RAC_TXCALITC_TXCALENITCPA_MASK                                   0x2UL                                        /**< Bit mask for RAC_TXCALENITCPA               */
#define _RAC_TXCALITC_TXCALENITCPA_DEFAULT                                0x00000000UL                                 /**< Mode DEFAULT for RAC_TXCALITC               */
#define _RAC_TXCALITC_TXCALENITCPA_disabled                               0x00000000UL                                 /**< Mode disabled for RAC_TXCALITC              */
#define _RAC_TXCALITC_TXCALENITCPA_enabled                                0x00000001UL                                 /**< Mode enabled for RAC_TXCALITC               */
#define RAC_TXCALITC_TXCALENITCPA_DEFAULT                                 (_RAC_TXCALITC_TXCALENITCPA_DEFAULT << 1)    /**< Shifted mode DEFAULT for RAC_TXCALITC       */
#define RAC_TXCALITC_TXCALENITCPA_disabled                                (_RAC_TXCALITC_TXCALENITCPA_disabled << 1)   /**< Shifted mode disabled for RAC_TXCALITC      */
#define RAC_TXCALITC_TXCALENITCPA_enabled                                 (_RAC_TXCALITC_TXCALENITCPA_enabled << 1)    /**< Shifted mode enabled for RAC_TXCALITC       */
#define _RAC_TXCALITC_TXCALITCDACIB_SHIFT                                 4                                            /**< Shift value for RAC_TXCALITCDACIB           */
#define _RAC_TXCALITC_TXCALITCDACIB_MASK                                  0x1F0UL                                      /**< Bit mask for RAC_TXCALITCDACIB              */
#define _RAC_TXCALITC_TXCALITCDACIB_DEFAULT                               0x00000003UL                                 /**< Mode DEFAULT for RAC_TXCALITC               */
#define RAC_TXCALITC_TXCALITCDACIB_DEFAULT                                (_RAC_TXCALITC_TXCALITCDACIB_DEFAULT << 4)   /**< Shifted mode DEFAULT for RAC_TXCALITC       */
#define _RAC_TXCALITC_TXCALITCPAIB_SHIFT                                  10                                           /**< Shift value for RAC_TXCALITCPAIB            */
#define _RAC_TXCALITC_TXCALITCPAIB_MASK                                   0x7C00UL                                     /**< Bit mask for RAC_TXCALITCPAIB               */
#define _RAC_TXCALITC_TXCALITCPAIB_DEFAULT                                0x00000002UL                                 /**< Mode DEFAULT for RAC_TXCALITC               */
#define RAC_TXCALITC_TXCALITCPAIB_DEFAULT                                 (_RAC_TXCALITC_TXCALITCPAIB_DEFAULT << 10)   /**< Shifted mode DEFAULT for RAC_TXCALITC       */
#define _RAC_TXCALITC_TXCALITCCOREIB_SHIFT                                16                                           /**< Shift value for RAC_TXCALITCCOREIB          */
#define _RAC_TXCALITC_TXCALITCCOREIB_MASK                                 0xF0000UL                                    /**< Bit mask for RAC_TXCALITCCOREIB             */
#define _RAC_TXCALITC_TXCALITCCOREIB_DEFAULT                              0x00000002UL                                 /**< Mode DEFAULT for RAC_TXCALITC               */
#define RAC_TXCALITC_TXCALITCCOREIB_DEFAULT                               (_RAC_TXCALITC_TXCALITCCOREIB_DEFAULT << 16) /**< Shifted mode DEFAULT for RAC_TXCALITC       */
#define _RAC_TXCALITC_TXCALITCCORETC_SHIFT                                22                                           /**< Shift value for RAC_TXCALITCCORETC          */
#define _RAC_TXCALITC_TXCALITCCORETC_MASK                                 0x7C00000UL                                  /**< Bit mask for RAC_TXCALITCCORETC             */
#define _RAC_TXCALITC_TXCALITCCORETC_DEFAULT                              0x0000000FUL                                 /**< Mode DEFAULT for RAC_TXCALITC               */
#define RAC_TXCALITC_TXCALITCCORETC_DEFAULT                               (_RAC_TXCALITC_TXCALITCCORETC_DEFAULT << 22) /**< Shifted mode DEFAULT for RAC_TXCALITC       */

/* Bit fields for RAC TXPKDCTRL */
#define _RAC_TXPKDCTRL_RESETVALUE                                         0x00000000UL                              /**< Default value for RAC_TXPKDCTRL             */
#define _RAC_TXPKDCTRL_MASK                                               0x0001FFF7UL                              /**< Mask for RAC_TXPKDCTRL                      */
#define _RAC_TXPKDCTRL_TXPKDCLKDIV_SHIFT                                  0                                         /**< Shift value for RAC_TXPKDCLKDIV             */
#define _RAC_TXPKDCTRL_TXPKDCLKDIV_MASK                                   0x7UL                                     /**< Bit mask for RAC_TXPKDCLKDIV                */
#define _RAC_TXPKDCTRL_TXPKDCLKDIV_DEFAULT                                0x00000000UL                              /**< Mode DEFAULT for RAC_TXPKDCTRL              */
#define RAC_TXPKDCTRL_TXPKDCLKDIV_DEFAULT                                 (_RAC_TXPKDCTRL_TXPKDCLKDIV_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_TXPKDCTRL      */
#define _RAC_TXPKDCTRL_TXPKDCNTLEN_SHIFT                                  4                                         /**< Shift value for RAC_TXPKDCNTLEN             */
#define _RAC_TXPKDCTRL_TXPKDCNTLEN_MASK                                   0x1FFF0UL                                 /**< Bit mask for RAC_TXPKDCNTLEN                */
#define _RAC_TXPKDCTRL_TXPKDCNTLEN_DEFAULT                                0x00000000UL                              /**< Mode DEFAULT for RAC_TXPKDCTRL              */
#define RAC_TXPKDCTRL_TXPKDCNTLEN_DEFAULT                                 (_RAC_TXPKDCTRL_TXPKDCNTLEN_DEFAULT << 4) /**< Shifted mode DEFAULT for RAC_TXPKDCTRL      */

/* Bit fields for RAC TXPKDCMD */
#define _RAC_TXPKDCMD_RESETVALUE                                          0x00000000UL                            /**< Default value for RAC_TXPKDCMD              */
#define _RAC_TXPKDCMD_MASK                                                0x00000007UL                            /**< Mask for RAC_TXPKDCMD                       */
#define RAC_TXPKDCMD_TXPKDSTART                                           (0x1UL << 0)                            /**< Start counters                              */
#define _RAC_TXPKDCMD_TXPKDSTART_SHIFT                                    0                                       /**< Shift value for RAC_TXPKDSTART              */
#define _RAC_TXPKDCMD_TXPKDSTART_MASK                                     0x1UL                                   /**< Bit mask for RAC_TXPKDSTART                 */
#define _RAC_TXPKDCMD_TXPKDSTART_DEFAULT                                  0x00000000UL                            /**< Mode DEFAULT for RAC_TXPKDCMD               */
#define RAC_TXPKDCMD_TXPKDSTART_DEFAULT                                   (_RAC_TXPKDCMD_TXPKDSTART_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_TXPKDCMD       */
#define RAC_TXPKDCMD_TXPKDSTOP                                            (0x1UL << 1)                            /**< Stop counters                               */
#define _RAC_TXPKDCMD_TXPKDSTOP_SHIFT                                     1                                       /**< Shift value for RAC_TXPKDSTOP               */
#define _RAC_TXPKDCMD_TXPKDSTOP_MASK                                      0x2UL                                   /**< Bit mask for RAC_TXPKDSTOP                  */
#define _RAC_TXPKDCMD_TXPKDSTOP_DEFAULT                                   0x00000000UL                            /**< Mode DEFAULT for RAC_TXPKDCMD               */
#define RAC_TXPKDCMD_TXPKDSTOP_DEFAULT                                    (_RAC_TXPKDCMD_TXPKDSTOP_DEFAULT << 1)  /**< Shifted mode DEFAULT for RAC_TXPKDCMD       */
#define RAC_TXPKDCMD_TXPKDCLR                                             (0x1UL << 2)                            /**< Clear counters                              */
#define _RAC_TXPKDCMD_TXPKDCLR_SHIFT                                      2                                       /**< Shift value for RAC_TXPKDCLR                */
#define _RAC_TXPKDCMD_TXPKDCLR_MASK                                       0x4UL                                   /**< Bit mask for RAC_TXPKDCLR                   */
#define _RAC_TXPKDCMD_TXPKDCLR_DEFAULT                                    0x00000000UL                            /**< Mode DEFAULT for RAC_TXPKDCMD               */
#define RAC_TXPKDCMD_TXPKDCLR_DEFAULT                                     (_RAC_TXPKDCMD_TXPKDCLR_DEFAULT << 2)   /**< Shifted mode DEFAULT for RAC_TXPKDCMD       */

/* Bit fields for RAC TXPKDSTATUS */
#define _RAC_TXPKDSTATUS_RESETVALUE                                       0x00000000UL                              /**< Default value for RAC_TXPKDSTATUS           */
#define _RAC_TXPKDSTATUS_MASK                                             0x0001FFF1UL                              /**< Mask for RAC_TXPKDSTATUS                    */
#define RAC_TXPKDSTATUS_TXPKDDONE                                         (0x1UL << 0)                              /**< Counters matched compare value              */
#define _RAC_TXPKDSTATUS_TXPKDDONE_SHIFT                                  0                                         /**< Shift value for RAC_TXPKDDONE               */
#define _RAC_TXPKDSTATUS_TXPKDDONE_MASK                                   0x1UL                                     /**< Bit mask for RAC_TXPKDDONE                  */
#define _RAC_TXPKDSTATUS_TXPKDDONE_DEFAULT                                0x00000000UL                              /**< Mode DEFAULT for RAC_TXPKDSTATUS            */
#define RAC_TXPKDSTATUS_TXPKDDONE_DEFAULT                                 (_RAC_TXPKDSTATUS_TXPKDDONE_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_TXPKDSTATUS    */
#define _RAC_TXPKDSTATUS_TXPKDCNT_SHIFT                                   4                                         /**< Shift value for RAC_TXPKDCNT                */
#define _RAC_TXPKDSTATUS_TXPKDCNT_MASK                                    0x1FFF0UL                                 /**< Bit mask for RAC_TXPKDCNT                   */
#define _RAC_TXPKDSTATUS_TXPKDCNT_DEFAULT                                 0x00000000UL                              /**< Mode DEFAULT for RAC_TXPKDSTATUS            */
#define RAC_TXPKDSTATUS_TXPKDCNT_DEFAULT                                  (_RAC_TXPKDSTATUS_TXPKDCNT_DEFAULT << 4)  /**< Shifted mode DEFAULT for RAC_TXPKDSTATUS    */

/* Bit fields for RAC RADIOCLKCTRL */
#define _RAC_RADIOCLKCTRL_RESETVALUE                                      0x00000101UL                                    /**< Default value for RAC_RADIOCLKCTRL          */
#define _RAC_RADIOCLKCTRL_MASK                                            0x00000111UL                                    /**< Mask for RAC_RADIOCLKCTRL                   */
#define RAC_RADIOCLKCTRL_CLKSRWUHSPRESC                                   (0x1UL << 0)                                    /**< Ultra High Speed Prescaler                  */
#define _RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_SHIFT                            0                                               /**< Shift value for RAC_CLKSRWUHSPRESC          */
#define _RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_MASK                             0x1UL                                           /**< Bit mask for RAC_CLKSRWUHSPRESC             */
#define _RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_DEFAULT                          0x00000001UL                                    /**< Mode DEFAULT for RAC_RADIOCLKCTRL           */
#define _RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_DIV1                             0x00000000UL                                    /**< Mode DIV1 for RAC_RADIOCLKCTRL              */
#define _RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_DIV2                             0x00000001UL                                    /**< Mode DIV2 for RAC_RADIOCLKCTRL              */
#define RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_DEFAULT                           (_RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_RADIOCLKCTRL   */
#define RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_DIV1                              (_RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_DIV1 << 0)    /**< Shifted mode DIV1 for RAC_RADIOCLKCTRL      */
#define RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_DIV2                              (_RAC_RADIOCLKCTRL_CLKSRWUHSPRESC_DIV2 << 0)    /**< Shifted mode DIV2 for RAC_RADIOCLKCTRL      */
#define RAC_RADIOCLKCTRL_CLKSRWHSPRESC                                    (0x1UL << 4)                                    /**< High Speed Prescaler                        */
#define _RAC_RADIOCLKCTRL_CLKSRWHSPRESC_SHIFT                             4                                               /**< Shift value for RAC_CLKSRWHSPRESC           */
#define _RAC_RADIOCLKCTRL_CLKSRWHSPRESC_MASK                              0x10UL                                          /**< Bit mask for RAC_CLKSRWHSPRESC              */
#define _RAC_RADIOCLKCTRL_CLKSRWHSPRESC_DEFAULT                           0x00000000UL                                    /**< Mode DEFAULT for RAC_RADIOCLKCTRL           */
#define _RAC_RADIOCLKCTRL_CLKSRWHSPRESC_DIV1                              0x00000000UL                                    /**< Mode DIV1 for RAC_RADIOCLKCTRL              */
#define _RAC_RADIOCLKCTRL_CLKSRWHSPRESC_DIV2                              0x00000001UL                                    /**< Mode DIV2 for RAC_RADIOCLKCTRL              */
#define RAC_RADIOCLKCTRL_CLKSRWHSPRESC_DEFAULT                            (_RAC_RADIOCLKCTRL_CLKSRWHSPRESC_DEFAULT << 4)  /**< Shifted mode DEFAULT for RAC_RADIOCLKCTRL   */
#define RAC_RADIOCLKCTRL_CLKSRWHSPRESC_DIV1                               (_RAC_RADIOCLKCTRL_CLKSRWHSPRESC_DIV1 << 4)     /**< Shifted mode DIV1 for RAC_RADIOCLKCTRL      */
#define RAC_RADIOCLKCTRL_CLKSRWHSPRESC_DIV2                               (_RAC_RADIOCLKCTRL_CLKSRWHSPRESC_DIV2 << 4)     /**< Shifted mode DIV2 for RAC_RADIOCLKCTRL      */
#define RAC_RADIOCLKCTRL_CLKSRWLSPRESC                                    (0x1UL << 8)                                    /**< Low Speed Prescaler                         */
#define _RAC_RADIOCLKCTRL_CLKSRWLSPRESC_SHIFT                             8                                               /**< Shift value for RAC_CLKSRWLSPRESC           */
#define _RAC_RADIOCLKCTRL_CLKSRWLSPRESC_MASK                              0x100UL                                         /**< Bit mask for RAC_CLKSRWLSPRESC              */
#define _RAC_RADIOCLKCTRL_CLKSRWLSPRESC_DEFAULT                           0x00000001UL                                    /**< Mode DEFAULT for RAC_RADIOCLKCTRL           */
#define _RAC_RADIOCLKCTRL_CLKSRWLSPRESC_DIV1                              0x00000000UL                                    /**< Mode DIV1 for RAC_RADIOCLKCTRL              */
#define _RAC_RADIOCLKCTRL_CLKSRWLSPRESC_DIV2                              0x00000001UL                                    /**< Mode DIV2 for RAC_RADIOCLKCTRL              */
#define RAC_RADIOCLKCTRL_CLKSRWLSPRESC_DEFAULT                            (_RAC_RADIOCLKCTRL_CLKSRWLSPRESC_DEFAULT << 8)  /**< Shifted mode DEFAULT for RAC_RADIOCLKCTRL   */
#define RAC_RADIOCLKCTRL_CLKSRWLSPRESC_DIV1                               (_RAC_RADIOCLKCTRL_CLKSRWLSPRESC_DIV1 << 8)     /**< Shifted mode DIV1 for RAC_RADIOCLKCTRL      */
#define RAC_RADIOCLKCTRL_CLKSRWLSPRESC_DIV2                               (_RAC_RADIOCLKCTRL_CLKSRWLSPRESC_DIV2 << 8)     /**< Shifted mode DIV2 for RAC_RADIOCLKCTRL      */

/* Bit fields for RAC SCRATCH0 */
#define _RAC_SCRATCH0_RESETVALUE                                          0x00000000UL                          /**< Default value for RAC_SCRATCH0              */
#define _RAC_SCRATCH0_MASK                                                0xFFFFFFFFUL                          /**< Mask for RAC_SCRATCH0                       */
#define _RAC_SCRATCH0_SCRATCH0_SHIFT                                      0                                     /**< Shift value for RAC_SCRATCH0                */
#define _RAC_SCRATCH0_SCRATCH0_MASK                                       0xFFFFFFFFUL                          /**< Bit mask for RAC_SCRATCH0                   */
#define _RAC_SCRATCH0_SCRATCH0_DEFAULT                                    0x00000000UL                          /**< Mode DEFAULT for RAC_SCRATCH0               */
#define RAC_SCRATCH0_SCRATCH0_DEFAULT                                     (_RAC_SCRATCH0_SCRATCH0_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SCRATCH0       */

/* Bit fields for RAC SCRATCH1 */
#define _RAC_SCRATCH1_RESETVALUE                                          0x00000000UL                          /**< Default value for RAC_SCRATCH1              */
#define _RAC_SCRATCH1_MASK                                                0xFFFFFFFFUL                          /**< Mask for RAC_SCRATCH1                       */
#define _RAC_SCRATCH1_SCRATCH1_SHIFT                                      0                                     /**< Shift value for RAC_SCRATCH1                */
#define _RAC_SCRATCH1_SCRATCH1_MASK                                       0xFFFFFFFFUL                          /**< Bit mask for RAC_SCRATCH1                   */
#define _RAC_SCRATCH1_SCRATCH1_DEFAULT                                    0x00000000UL                          /**< Mode DEFAULT for RAC_SCRATCH1               */
#define RAC_SCRATCH1_SCRATCH1_DEFAULT                                     (_RAC_SCRATCH1_SCRATCH1_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SCRATCH1       */

/* Bit fields for RAC SCRATCH2 */
#define _RAC_SCRATCH2_RESETVALUE                                          0x00000000UL                          /**< Default value for RAC_SCRATCH2              */
#define _RAC_SCRATCH2_MASK                                                0xFFFFFFFFUL                          /**< Mask for RAC_SCRATCH2                       */
#define _RAC_SCRATCH2_SCRATCH2_SHIFT                                      0                                     /**< Shift value for RAC_SCRATCH2                */
#define _RAC_SCRATCH2_SCRATCH2_MASK                                       0xFFFFFFFFUL                          /**< Bit mask for RAC_SCRATCH2                   */
#define _RAC_SCRATCH2_SCRATCH2_DEFAULT                                    0x00000000UL                          /**< Mode DEFAULT for RAC_SCRATCH2               */
#define RAC_SCRATCH2_SCRATCH2_DEFAULT                                     (_RAC_SCRATCH2_SCRATCH2_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SCRATCH2       */

/* Bit fields for RAC SCRATCH3 */
#define _RAC_SCRATCH3_RESETVALUE                                          0x00000000UL                          /**< Default value for RAC_SCRATCH3              */
#define _RAC_SCRATCH3_MASK                                                0xFFFFFFFFUL                          /**< Mask for RAC_SCRATCH3                       */
#define _RAC_SCRATCH3_SCRATCH3_SHIFT                                      0                                     /**< Shift value for RAC_SCRATCH3                */
#define _RAC_SCRATCH3_SCRATCH3_MASK                                       0xFFFFFFFFUL                          /**< Bit mask for RAC_SCRATCH3                   */
#define _RAC_SCRATCH3_SCRATCH3_DEFAULT                                    0x00000000UL                          /**< Mode DEFAULT for RAC_SCRATCH3               */
#define RAC_SCRATCH3_SCRATCH3_DEFAULT                                     (_RAC_SCRATCH3_SCRATCH3_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SCRATCH3       */

/* Bit fields for RAC SCRATCH4 */
#define _RAC_SCRATCH4_RESETVALUE                                          0x00000000UL                          /**< Default value for RAC_SCRATCH4              */
#define _RAC_SCRATCH4_MASK                                                0xFFFFFFFFUL                          /**< Mask for RAC_SCRATCH4                       */
#define _RAC_SCRATCH4_SCRATCH4_SHIFT                                      0                                     /**< Shift value for RAC_SCRATCH4                */
#define _RAC_SCRATCH4_SCRATCH4_MASK                                       0xFFFFFFFFUL                          /**< Bit mask for RAC_SCRATCH4                   */
#define _RAC_SCRATCH4_SCRATCH4_DEFAULT                                    0x00000000UL                          /**< Mode DEFAULT for RAC_SCRATCH4               */
#define RAC_SCRATCH4_SCRATCH4_DEFAULT                                     (_RAC_SCRATCH4_SCRATCH4_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SCRATCH4       */

/* Bit fields for RAC SCRATCH5 */
#define _RAC_SCRATCH5_RESETVALUE                                          0x00000000UL                          /**< Default value for RAC_SCRATCH5              */
#define _RAC_SCRATCH5_MASK                                                0xFFFFFFFFUL                          /**< Mask for RAC_SCRATCH5                       */
#define _RAC_SCRATCH5_SCRATCH5_SHIFT                                      0                                     /**< Shift value for RAC_SCRATCH5                */
#define _RAC_SCRATCH5_SCRATCH5_MASK                                       0xFFFFFFFFUL                          /**< Bit mask for RAC_SCRATCH5                   */
#define _RAC_SCRATCH5_SCRATCH5_DEFAULT                                    0x00000000UL                          /**< Mode DEFAULT for RAC_SCRATCH5               */
#define RAC_SCRATCH5_SCRATCH5_DEFAULT                                     (_RAC_SCRATCH5_SCRATCH5_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SCRATCH5       */

/* Bit fields for RAC SCRATCH6 */
#define _RAC_SCRATCH6_RESETVALUE                                          0x00000000UL                          /**< Default value for RAC_SCRATCH6              */
#define _RAC_SCRATCH6_MASK                                                0xFFFFFFFFUL                          /**< Mask for RAC_SCRATCH6                       */
#define _RAC_SCRATCH6_SCRATCH6_SHIFT                                      0                                     /**< Shift value for RAC_SCRATCH6                */
#define _RAC_SCRATCH6_SCRATCH6_MASK                                       0xFFFFFFFFUL                          /**< Bit mask for RAC_SCRATCH6                   */
#define _RAC_SCRATCH6_SCRATCH6_DEFAULT                                    0x00000000UL                          /**< Mode DEFAULT for RAC_SCRATCH6               */
#define RAC_SCRATCH6_SCRATCH6_DEFAULT                                     (_RAC_SCRATCH6_SCRATCH6_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SCRATCH6       */

/* Bit fields for RAC SCRATCH7 */
#define _RAC_SCRATCH7_RESETVALUE                                          0x00000000UL                          /**< Default value for RAC_SCRATCH7              */
#define _RAC_SCRATCH7_MASK                                                0xFFFFFFFFUL                          /**< Mask for RAC_SCRATCH7                       */
#define _RAC_SCRATCH7_SCRATCH7_SHIFT                                      0                                     /**< Shift value for RAC_SCRATCH7                */
#define _RAC_SCRATCH7_SCRATCH7_MASK                                       0xFFFFFFFFUL                          /**< Bit mask for RAC_SCRATCH7                   */
#define _RAC_SCRATCH7_SCRATCH7_DEFAULT                                    0x00000000UL                          /**< Mode DEFAULT for RAC_SCRATCH7               */
#define RAC_SCRATCH7_SCRATCH7_DEFAULT                                     (_RAC_SCRATCH7_SCRATCH7_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SCRATCH7       */

/* Bit fields for RAC SOFTMCTRL */
#define _RAC_SOFTMCTRL_RESETVALUE                                         0x00000000UL                                   /**< Default value for RAC_SOFTMCTRL             */
#define _RAC_SOFTMCTRL_MASK                                               0x00000DFFUL                                   /**< Mask for RAC_SOFTMCTRL                      */
#define RAC_SOFTMCTRL_TXPATHEN                                            (0x1UL << 0)                                   /**< Soft modem TX data path enable              */
#define _RAC_SOFTMCTRL_TXPATHEN_SHIFT                                     0                                              /**< Shift value for RAC_TXPATHEN                */
#define _RAC_SOFTMCTRL_TXPATHEN_MASK                                      0x1UL                                          /**< Bit mask for RAC_TXPATHEN                   */
#define _RAC_SOFTMCTRL_TXPATHEN_DEFAULT                                   0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_TXPATHEN_DEFAULT                                    (_RAC_SOFTMCTRL_TXPATHEN_DEFAULT << 0)         /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */
#define RAC_SOFTMCTRL_RXPATHEN                                            (0x1UL << 1)                                   /**< Soft modem RX data path enable              */
#define _RAC_SOFTMCTRL_RXPATHEN_SHIFT                                     1                                              /**< Shift value for RAC_RXPATHEN                */
#define _RAC_SOFTMCTRL_RXPATHEN_MASK                                      0x2UL                                          /**< Bit mask for RAC_RXPATHEN                   */
#define _RAC_SOFTMCTRL_RXPATHEN_DEFAULT                                   0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_RXPATHEN_DEFAULT                                    (_RAC_SOFTMCTRL_RXPATHEN_DEFAULT << 1)         /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */
#define RAC_SOFTMCTRL_FRCPATHEN                                           (0x1UL << 2)                                   /**< Soft modem FRC data path enable             */
#define _RAC_SOFTMCTRL_FRCPATHEN_SHIFT                                    2                                              /**< Shift value for RAC_FRCPATHEN               */
#define _RAC_SOFTMCTRL_FRCPATHEN_MASK                                     0x4UL                                          /**< Bit mask for RAC_FRCPATHEN                  */
#define _RAC_SOFTMCTRL_FRCPATHEN_DEFAULT                                  0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_FRCPATHEN_DEFAULT                                   (_RAC_SOFTMCTRL_FRCPATHEN_DEFAULT << 2)        /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */
#define RAC_SOFTMCTRL_CLKEN                                               (0x1UL << 3)                                   /**< soft modem clock enable                     */
#define _RAC_SOFTMCTRL_CLKEN_SHIFT                                        3                                              /**< Shift value for RAC_CLKEN                   */
#define _RAC_SOFTMCTRL_CLKEN_MASK                                         0x8UL                                          /**< Bit mask for RAC_CLKEN                      */
#define _RAC_SOFTMCTRL_CLKEN_DEFAULT                                      0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_CLKEN_DEFAULT                                       (_RAC_SOFTMCTRL_CLKEN_DEFAULT << 3)            /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */
#define RAC_SOFTMCTRL_CLKRUNNING                                          (0x1UL << 4)                                   /**< soft modem clock running                    */
#define _RAC_SOFTMCTRL_CLKRUNNING_SHIFT                                   4                                              /**< Shift value for RAC_CLKRUNNING              */
#define _RAC_SOFTMCTRL_CLKRUNNING_MASK                                    0x10UL                                         /**< Bit mask for RAC_CLKRUNNING                 */
#define _RAC_SOFTMCTRL_CLKRUNNING_DEFAULT                                 0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_CLKRUNNING_DEFAULT                                  (_RAC_SOFTMCTRL_CLKRUNNING_DEFAULT << 4)       /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */
#define RAC_SOFTMCTRL_TXMODSEL                                            (0x1UL << 5)                                   /**< softm to srw modulator path enable          */
#define _RAC_SOFTMCTRL_TXMODSEL_SHIFT                                     5                                              /**< Shift value for RAC_TXMODSEL                */
#define _RAC_SOFTMCTRL_TXMODSEL_MASK                                      0x20UL                                         /**< Bit mask for RAC_TXMODSEL                   */
#define _RAC_SOFTMCTRL_TXMODSEL_DEFAULT                                   0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_TXMODSEL_DEFAULT                                    (_RAC_SOFTMCTRL_TXMODSEL_DEFAULT << 5)         /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */
#define RAC_SOFTMCTRL_ANTSELSRCSEL                                        (0x1UL << 6)                                   /**< softm to control antsel                     */
#define _RAC_SOFTMCTRL_ANTSELSRCSEL_SHIFT                                 6                                              /**< Shift value for RAC_ANTSELSRCSEL            */
#define _RAC_SOFTMCTRL_ANTSELSRCSEL_MASK                                  0x40UL                                         /**< Bit mask for RAC_ANTSELSRCSEL               */
#define _RAC_SOFTMCTRL_ANTSELSRCSEL_DEFAULT                               0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_ANTSELSRCSEL_DEFAULT                                (_RAC_SOFTMCTRL_ANTSELSRCSEL_DEFAULT << 6)     /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */
#define RAC_SOFTMCTRL_FRCEN                                               (0x1UL << 7)                                   /**< Soft modem FRC enable                       */
#define _RAC_SOFTMCTRL_FRCEN_SHIFT                                        7                                              /**< Shift value for RAC_FRCEN                   */
#define _RAC_SOFTMCTRL_FRCEN_MASK                                         0x80UL                                         /**< Bit mask for RAC_FRCEN                      */
#define _RAC_SOFTMCTRL_FRCEN_DEFAULT                                      0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_FRCEN_DEFAULT                                       (_RAC_SOFTMCTRL_FRCEN_DEFAULT << 7)            /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */
#define RAC_SOFTMCTRL_DISLEGACYPATH                                       (0x1UL << 8)                                   /**< Disable FRC enable legacy path              */
#define _RAC_SOFTMCTRL_DISLEGACYPATH_SHIFT                                8                                              /**< Shift value for RAC_DISLEGACYPATH           */
#define _RAC_SOFTMCTRL_DISLEGACYPATH_MASK                                 0x100UL                                        /**< Bit mask for RAC_DISLEGACYPATH              */
#define _RAC_SOFTMCTRL_DISLEGACYPATH_DEFAULT                              0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_DISLEGACYPATH_DEFAULT                               (_RAC_SOFTMCTRL_DISLEGACYPATH_DEFAULT << 8)    /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */
#define RAC_SOFTMCTRL_TXDACDISABLECLK                                     (0x1UL << 10)                                  /**< Disable TX DAC clock to TXFRONT             */
#define _RAC_SOFTMCTRL_TXDACDISABLECLK_SHIFT                              10                                             /**< Shift value for RAC_TXDACDISABLECLK         */
#define _RAC_SOFTMCTRL_TXDACDISABLECLK_MASK                               0x400UL                                        /**< Bit mask for RAC_TXDACDISABLECLK            */
#define _RAC_SOFTMCTRL_TXDACDISABLECLK_DEFAULT                            0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_TXDACDISABLECLK_DEFAULT                             (_RAC_SOFTMCTRL_TXDACDISABLECLK_DEFAULT << 10) /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */
#define RAC_SOFTMCTRL_TXDACINVERTCLK                                      (0x1UL << 11)                                  /**< Invert TX DAC clock to TXFRONT              */
#define _RAC_SOFTMCTRL_TXDACINVERTCLK_SHIFT                               11                                             /**< Shift value for RAC_TXDACINVERTCLK          */
#define _RAC_SOFTMCTRL_TXDACINVERTCLK_MASK                                0x800UL                                        /**< Bit mask for RAC_TXDACINVERTCLK             */
#define _RAC_SOFTMCTRL_TXDACINVERTCLK_DEFAULT                             0x00000000UL                                   /**< Mode DEFAULT for RAC_SOFTMCTRL              */
#define RAC_SOFTMCTRL_TXDACINVERTCLK_DEFAULT                              (_RAC_SOFTMCTRL_TXDACINVERTCLK_DEFAULT << 11)  /**< Shifted mode DEFAULT for RAC_SOFTMCTRL      */

/* Bit fields for RAC SFMIF */
#define _RAC_SFMIF_RESETVALUE                                             0x00000000UL                               /**< Default value for RAC_SFMIF                 */
#define _RAC_SFMIF_MASK                                                   0x00FF000FUL                               /**< Mask for RAC_SFMIF                          */
#define RAC_SFMIF_STATECHANGESFMIF                                        (0x1UL << 0)                               /**< Radio State Change                          */
#define _RAC_SFMIF_STATECHANGESFMIF_SHIFT                                 0                                          /**< Shift value for RAC_STATECHANGESFMIF        */
#define _RAC_SFMIF_STATECHANGESFMIF_MASK                                  0x1UL                                      /**< Bit mask for RAC_STATECHANGESFMIF           */
#define _RAC_SFMIF_STATECHANGESFMIF_DEFAULT                               0x00000000UL                               /**< Mode DEFAULT for RAC_SFMIF                  */
#define RAC_SFMIF_STATECHANGESFMIF_DEFAULT                                (_RAC_SFMIF_STATECHANGESFMIF_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SFMIF          */
#define RAC_SFMIF_STIMCMPEVSFMIF                                          (0x1UL << 1)                               /**< STIMER Compare Event                        */
#define _RAC_SFMIF_STIMCMPEVSFMIF_SHIFT                                   1                                          /**< Shift value for RAC_STIMCMPEVSFMIF          */
#define _RAC_SFMIF_STIMCMPEVSFMIF_MASK                                    0x2UL                                      /**< Bit mask for RAC_STIMCMPEVSFMIF             */
#define _RAC_SFMIF_STIMCMPEVSFMIF_DEFAULT                                 0x00000000UL                               /**< Mode DEFAULT for RAC_SFMIF                  */
#define RAC_SFMIF_STIMCMPEVSFMIF_DEFAULT                                  (_RAC_SFMIF_STIMCMPEVSFMIF_DEFAULT << 1)   /**< Shifted mode DEFAULT for RAC_SFMIF          */
#define RAC_SFMIF_SEQLOCKUPSFMIF                                          (0x1UL << 2)                               /**< SEQ locked up                               */
#define _RAC_SFMIF_SEQLOCKUPSFMIF_SHIFT                                   2                                          /**< Shift value for RAC_SEQLOCKUPSFMIF          */
#define _RAC_SFMIF_SEQLOCKUPSFMIF_MASK                                    0x4UL                                      /**< Bit mask for RAC_SEQLOCKUPSFMIF             */
#define _RAC_SFMIF_SEQLOCKUPSFMIF_DEFAULT                                 0x00000000UL                               /**< Mode DEFAULT for RAC_SFMIF                  */
#define RAC_SFMIF_SEQLOCKUPSFMIF_DEFAULT                                  (_RAC_SFMIF_SEQLOCKUPSFMIF_DEFAULT << 2)   /**< Shifted mode DEFAULT for RAC_SFMIF          */
#define RAC_SFMIF_SEQRESETREQSFMIF                                        (0x1UL << 3)                               /**< SEQ reset request                           */
#define _RAC_SFMIF_SEQRESETREQSFMIF_SHIFT                                 3                                          /**< Shift value for RAC_SEQRESETREQSFMIF        */
#define _RAC_SFMIF_SEQRESETREQSFMIF_MASK                                  0x8UL                                      /**< Bit mask for RAC_SEQRESETREQSFMIF           */
#define _RAC_SFMIF_SEQRESETREQSFMIF_DEFAULT                               0x00000000UL                               /**< Mode DEFAULT for RAC_SFMIF                  */
#define RAC_SFMIF_SEQRESETREQSFMIF_DEFAULT                                (_RAC_SFMIF_SEQRESETREQSFMIF_DEFAULT << 3) /**< Shifted mode DEFAULT for RAC_SFMIF          */
#define _RAC_SFMIF_SEQSFMIF_SHIFT                                         16                                         /**< Shift value for RAC_SEQSFMIF                */
#define _RAC_SFMIF_SEQSFMIF_MASK                                          0xFF0000UL                                 /**< Bit mask for RAC_SEQSFMIF                   */
#define _RAC_SFMIF_SEQSFMIF_DEFAULT                                       0x00000000UL                               /**< Mode DEFAULT for RAC_SFMIF                  */
#define RAC_SFMIF_SEQSFMIF_DEFAULT                                        (_RAC_SFMIF_SEQSFMIF_DEFAULT << 16)        /**< Shifted mode DEFAULT for RAC_SFMIF          */

/* Bit fields for RAC SFMIEN */
#define _RAC_SFMIEN_RESETVALUE                                            0x00000000UL                                 /**< Default value for RAC_SFMIEN                */
#define _RAC_SFMIEN_MASK                                                  0x00FF000FUL                                 /**< Mask for RAC_SFMIEN                         */
#define RAC_SFMIEN_STATECHANGESFMIEN                                      (0x1UL << 0)                                 /**< Radio State Change Interrupt Enable         */
#define _RAC_SFMIEN_STATECHANGESFMIEN_SHIFT                               0                                            /**< Shift value for RAC_STATECHANGESFMIEN       */
#define _RAC_SFMIEN_STATECHANGESFMIEN_MASK                                0x1UL                                        /**< Bit mask for RAC_STATECHANGESFMIEN          */
#define _RAC_SFMIEN_STATECHANGESFMIEN_DEFAULT                             0x00000000UL                                 /**< Mode DEFAULT for RAC_SFMIEN                 */
#define RAC_SFMIEN_STATECHANGESFMIEN_DEFAULT                              (_RAC_SFMIEN_STATECHANGESFMIEN_DEFAULT << 0) /**< Shifted mode DEFAULT for RAC_SFMIEN         */
#define RAC_SFMIEN_STIMCMPEVSFMIEN                                        (0x1UL << 1)                                 /**< STIMER Compare Event Interrupt Enable       */
#define _RAC_SFMIEN_STIMCMPEVSFMIEN_SHIFT                                 1                                            /**< Shift value for RAC_STIMCMPEVSFMIEN         */
#define _RAC_SFMIEN_STIMCMPEVSFMIEN_MASK                                  0x2UL                                        /**< Bit mask for RAC_STIMCMPEVSFMIEN            */
#define _RAC_SFMIEN_STIMCMPEVSFMIEN_DEFAULT                               0x00000000UL                                 /**< Mode DEFAULT for RAC_SFMIEN                 */
#define RAC_SFMIEN_STIMCMPEVSFMIEN_DEFAULT                                (_RAC_SFMIEN_STIMCMPEVSFMIEN_DEFAULT << 1)   /**< Shifted mode DEFAULT for RAC_SFMIEN         */
#define RAC_SFMIEN_SEQLOCKUPSFMIEN                                        (0x1UL << 2)                                 /**< SEQ locked up Interrupt Enable              */
#define _RAC_SFMIEN_SEQLOCKUPSFMIEN_SHIFT                                 2                                            /**< Shift value for RAC_SEQLOCKUPSFMIEN         */
#define _RAC_SFMIEN_SEQLOCKUPSFMIEN_MASK                                  0x4UL                                        /**< Bit mask for RAC_SEQLOCKUPSFMIEN            */
#define _RAC_SFMIEN_SEQLOCKUPSFMIEN_DEFAULT                               0x00000000UL                                 /**< Mode DEFAULT for RAC_SFMIEN                 */
#define RAC_SFMIEN_SEQLOCKUPSFMIEN_DEFAULT                                (_RAC_SFMIEN_SEQLOCKUPSFMIEN_DEFAULT << 2)   /**< Shifted mode DEFAULT for RAC_SFMIEN         */
#define RAC_SFMIEN_SEQRESETREQSFMIEN                                      (0x1UL << 3)                                 /**< SEQ reset request Interrupt Enable          */
#define _RAC_SFMIEN_SEQRESETREQSFMIEN_SHIFT                               3                                            /**< Shift value for RAC_SEQRESETREQSFMIEN       */
#define _RAC_SFMIEN_SEQRESETREQSFMIEN_MASK                                0x8UL                                        /**< Bit mask for RAC_SEQRESETREQSFMIEN          */
#define _RAC_SFMIEN_SEQRESETREQSFMIEN_DEFAULT                             0x00000000UL                                 /**< Mode DEFAULT for RAC_SFMIEN                 */
#define RAC_SFMIEN_SEQRESETREQSFMIEN_DEFAULT                              (_RAC_SFMIEN_SEQRESETREQSFMIEN_DEFAULT << 3) /**< Shifted mode DEFAULT for RAC_SFMIEN         */
#define _RAC_SFMIEN_SEQSFMIEN_SHIFT                                       16                                           /**< Shift value for RAC_SEQSFMIEN               */
#define _RAC_SFMIEN_SEQSFMIEN_MASK                                        0xFF0000UL                                   /**< Bit mask for RAC_SEQSFMIEN                  */
#define _RAC_SFMIEN_SEQSFMIEN_DEFAULT                                     0x00000000UL                                 /**< Mode DEFAULT for RAC_SFMIEN                 */
#define RAC_SFMIEN_SEQSFMIEN_DEFAULT                                      (_RAC_SFMIEN_SEQSFMIEN_DEFAULT << 16)        /**< Shifted mode DEFAULT for RAC_SFMIEN         */

/* Bit fields for RAC THMSW */
#define _RAC_THMSW_RESETVALUE                                             0x00000000UL                          /**< Default value for RAC_THMSW                 */
#define _RAC_THMSW_MASK                                                   0x00000003UL                          /**< Mask for RAC_THMSW                          */
#define RAC_THMSW_EN                                                      (0x1UL << 0)                          /**< Enable Switch                               */
#define _RAC_THMSW_EN_SHIFT                                               0                                     /**< Shift value for RAC_EN                      */
#define _RAC_THMSW_EN_MASK                                                0x1UL                                 /**< Bit mask for RAC_EN                         */
#define _RAC_THMSW_EN_DEFAULT                                             0x00000000UL                          /**< Mode DEFAULT for RAC_THMSW                  */
#define _RAC_THMSW_EN_Disabled                                            0x00000000UL                          /**< Mode Disabled for RAC_THMSW                 */
#define _RAC_THMSW_EN_Enabled                                             0x00000001UL                          /**< Mode Enabled for RAC_THMSW                  */
#define RAC_THMSW_EN_DEFAULT                                              (_RAC_THMSW_EN_DEFAULT << 0)          /**< Shifted mode DEFAULT for RAC_THMSW          */
#define RAC_THMSW_EN_Disabled                                             (_RAC_THMSW_EN_Disabled << 0)         /**< Shifted mode Disabled for RAC_THMSW         */
#define RAC_THMSW_EN_Enabled                                              (_RAC_THMSW_EN_Enabled << 0)          /**< Shifted mode Enabled for RAC_THMSW          */
#define RAC_THMSW_HALFSWITCH                                              (0x1UL << 1)                          /**< Halfswitch Mode enable                      */
#define _RAC_THMSW_HALFSWITCH_SHIFT                                       1                                     /**< Shift value for RAC_HALFSWITCH              */
#define _RAC_THMSW_HALFSWITCH_MASK                                        0x2UL                                 /**< Bit mask for RAC_HALFSWITCH                 */
#define _RAC_THMSW_HALFSWITCH_DEFAULT                                     0x00000000UL                          /**< Mode DEFAULT for RAC_THMSW                  */
#define _RAC_THMSW_HALFSWITCH_Disabled                                    0x00000000UL                          /**< Mode Disabled for RAC_THMSW                 */
#define _RAC_THMSW_HALFSWITCH_Enabled                                     0x00000001UL                          /**< Mode Enabled for RAC_THMSW                  */
#define RAC_THMSW_HALFSWITCH_DEFAULT                                      (_RAC_THMSW_HALFSWITCH_DEFAULT << 1)  /**< Shifted mode DEFAULT for RAC_THMSW          */
#define RAC_THMSW_HALFSWITCH_Disabled                                     (_RAC_THMSW_HALFSWITCH_Disabled << 1) /**< Shifted mode Disabled for RAC_THMSW         */
#define RAC_THMSW_HALFSWITCH_Enabled                                      (_RAC_THMSW_HALFSWITCH_Enabled << 1)  /**< Shifted mode Enabled for RAC_THMSW          */

/** @} End of group EFR32FG25_RAC_BitFields */
/** @} End of group EFR32FG25_RAC */
/** @} End of group Parts */

#endif /* EFR32FG25_RAC_H */
